/*************************************************************************************/
/*                                                                                   */
/* Copyright (c) 2024, William Lenthe                                                */
/* Author: William Lenthe                                                            */
/* All rights reserved.                                                              */
/*                                                                                   */
/* Redistribution and use in source and binary forms, with or without                */
/* modification, are permitted provided that the following conditions are met:       */
/*                                                                                   */
/*     - Redistributions of source code must retain the above copyright notice, this */
/*       list of conditions and the following disclaimer.                            */
/*     - Redistributions in binary form must reproduce the above copyright notice,   */
/*       this list of conditions and the following disclaimer in the documentation   */
/*       and/or other materials provided with the distribution.                      */
/*     - Neither the copyright holder nor the names of its                           */
/*       contributors may be used to endorse or promote products derived from        */
/*       this software without specific prior written permission.                    */
/*                                                                                   */
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"       */
/* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE         */
/* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE    */
/* DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE      */
/* FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL        */
/* DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR        */
/* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER        */
/* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,     */
/* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE         */
/* USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.          */
/*                                                                                   */
/*************************************************************************************/

#pragma once
#ifndef _CET_LUT_HPP_
#define _CET_LUT_HPP_

#include <array>

// 8 bit CET luts as {R,G,B,R,G,B,...}
// see https://colorcet.com/gallery.html for more details

namespace CET {
	// linear
	static constexpr std::array<uint8_t, 768> L01  = {0x00,0x00,0x00,0x01,0x01,0x01,0x03,0x03,0x03,0x04,0x04,0x04,0x06,0x06,0x06,0x07,0x07,0x07,0x09,0x09,0x09,0x0a,0x0a,0x0a,0x0b,0x0b,0x0b,0x0d,0x0d,0x0d,0x0e,0x0e,0x0e,0x0f,0x0f,0x0f,0x10,0x10,0x10,0x11,0x11,0x11,0x12,0x12,0x12,0x13,0x13,0x13,0x14,0x14,0x14,0x15,0x15,0x15,0x16,0x16,0x16,0x16,0x16,0x16,0x17,0x17,0x17,0x18,0x18,0x18,0x19,0x19,0x19,0x1a,0x1a,0x1a,0x1a,0x1a,0x1a,0x1b,0x1b,0x1b,0x1c,0x1c,0x1c,0x1d,0x1d,0x1d,0x1d,0x1d,0x1d,0x1e,0x1e,0x1e,0x1f,0x1f,0x1f,0x20,0x20,0x20,0x21,0x21,0x21,0x21,0x21,0x21,0x22,0x22,0x22,0x23,0x23,0x23,0x24,0x24,0x24,0x25,0x25,0x25,0x25,0x25,0x25,0x26,0x26,0x26,0x27,0x27,0x27,0x28,0x28,0x28,0x29,0x29,0x29,0x2a,0x2a,0x2a,0x2a,0x2a,0x2a,0x2b,0x2b,0x2b,0x2c,0x2c,0x2c,0x2d,0x2d,0x2d,0x2e,0x2e,0x2e,0x2f,0x2f,0x2f,0x2f,0x2f,0x2f,0x30,0x30,0x30,0x31,0x31,0x31,0x32,0x32,0x32,0x33,0x33,0x33,0x34,0x34,0x34,0x35,0x35,0x35,0x35,0x35,0x35,0x36,0x36,0x36,0x37,0x37,0x37,0x38,0x38,0x38,0x39,0x39,0x39,0x3a,0x3a,0x3a,0x3b,0x3b,0x3b,0x3b,0x3c,0x3c,0x3c,0x3c,0x3c,0x3d,0x3d,0x3d,0x3e,0x3e,0x3e,0x3f,0x3f,0x3f,0x40,0x40,0x40,0x41,0x41,0x41,0x42,0x42,0x42,0x43,0x43,0x43,0x43,0x43,0x43,0x44,0x44,0x44,0x45,0x45,0x45,0x46,0x46,0x46,0x47,0x47,0x47,0x48,0x48,0x48,0x49,0x49,0x49,0x4a,0x4a,0x4a,0x4b,0x4b,0x4b,0x4c,0x4c,0x4c,0x4d,0x4d,0x4d,0x4d,0x4d,0x4d,0x4e,0x4e,0x4e,0x4f,0x4f,0x4f,0x50,0x50,0x50,0x51,0x51,0x51,0x52,0x52,0x52,0x53,0x53,0x53,0x54,0x54,0x54,0x55,0x55,0x55,0x56,0x56,0x56,0x57,0x57,0x57,0x58,0x58,0x58,0x59,0x59,0x59,0x5a,0x5a,0x5a,0x5a,0x5a,0x5a,0x5b,0x5b,0x5b,0x5c,0x5c,0x5c,0x5d,0x5d,0x5d,0x5e,0x5e,0x5e,0x5f,0x5f,0x5f,0x60,0x60,0x60,0x61,0x61,0x61,0x62,0x62,0x62,0x63,0x63,0x63,0x64,0x64,0x64,0x65,0x65,0x65,0x66,0x66,0x66,0x67,0x67,0x67,0x68,0x68,0x68,0x69,0x69,0x69,0x6a,0x6a,0x6a,0x6b,0x6b,0x6b,0x6c,0x6c,0x6c,0x6d,0x6d,0x6d,0x6e,0x6e,0x6e,0x6f,0x6f,0x6f,0x70,0x70,0x70,0x71,0x71,0x71,0x71,0x72,0x72,0x72,0x72,0x72,0x73,0x73,0x73,0x74,0x74,0x74,0x75,0x75,0x75,0x76,0x76,0x76,0x77,0x77,0x77,0x78,0x78,0x78,0x79,0x79,0x79,0x7a,0x7a,0x7a,0x7b,0x7b,0x7b,0x7c,0x7c,0x7c,0x7d,0x7d,0x7d,0x7e,0x7e,0x7e,0x7f,0x7f,0x7f,0x80,0x80,0x80,0x81,0x81,0x81,0x82,0x82,0x82,0x83,0x83,0x83,0x84,0x84,0x84,0x85,0x85,0x85,0x86,0x86,0x86,0x87,0x87,0x87,0x88,0x88,0x88,0x89,0x89,0x89,0x8a,0x8a,0x8a,0x8b,0x8b,0x8b,0x8c,0x8c,0x8c,0x8d,0x8d,0x8d,0x8e,0x8f,0x8f,0x90,0x90,0x90,0x91,0x91,0x91,0x92,0x92,0x92,0x93,0x93,0x93,0x94,0x94,0x94,0x95,0x95,0x95,0x96,0x96,0x96,0x97,0x97,0x97,0x98,0x98,0x98,0x99,0x99,0x99,0x9a,0x9a,0x9a,0x9b,0x9b,0x9b,0x9c,0x9c,0x9c,0x9d,0x9d,0x9d,0x9e,0x9e,0x9e,0x9f,0x9f,0x9f,0xa0,0xa0,0xa0,0xa1,0xa1,0xa1,0xa2,0xa2,0xa2,0xa3,0xa3,0xa3,0xa4,0xa4,0xa4,0xa5,0xa5,0xa5,0xa6,0xa6,0xa6,0xa7,0xa7,0xa7,0xa8,0xa8,0xa8,0xa9,0xa9,0xa9,0xaa,0xab,0xab,0xac,0xac,0xac,0xad,0xad,0xad,0xae,0xae,0xae,0xaf,0xaf,0xaf,0xb0,0xb0,0xb0,0xb1,0xb1,0xb1,0xb2,0xb2,0xb2,0xb3,0xb3,0xb3,0xb4,0xb4,0xb4,0xb5,0xb5,0xb5,0xb6,0xb6,0xb6,0xb7,0xb7,0xb7,0xb8,0xb8,0xb8,0xb9,0xb9,0xb9,0xba,0xba,0xba,0xbc,0xbc,0xbc,0xbd,0xbd,0xbd,0xbe,0xbe,0xbe,0xbf,0xbf,0xbf,0xc0,0xc0,0xc0,0xc1,0xc1,0xc1,0xc2,0xc2,0xc2,0xc3,0xc3,0xc3,0xc4,0xc4,0xc4,0xc5,0xc5,0xc5,0xc6,0xc6,0xc6,0xc7,0xc7,0xc7,0xc8,0xc9,0xc9,0xca,0xca,0xca,0xcb,0xcb,0xcb,0xcc,0xcc,0xcc,0xcd,0xcd,0xcd,0xce,0xce,0xce,0xcf,0xcf,0xcf,0xd0,0xd0,0xd0,0xd1,0xd1,0xd1,0xd2,0xd2,0xd2,0xd3,0xd3,0xd3,0xd4,0xd5,0xd5,0xd6,0xd6,0xd6,0xd7,0xd7,0xd7,0xd8,0xd8,0xd8,0xd9,0xd9,0xd9,0xda,0xda,0xda,0xdb,0xdb,0xdb,0xdc,0xdc,0xdc,0xdd,0xdd,0xdd,0xde,0xde,0xde,0xe0,0xe0,0xe0,0xe1,0xe1,0xe1,0xe2,0xe2,0xe2,0xe3,0xe3,0xe3,0xe4,0xe4,0xe4,0xe5,0xe5,0xe5,0xe6,0xe6,0xe6,0xe7,0xe7,0xe7,0xe8,0xe8,0xe8,0xea,0xea,0xea,0xeb,0xeb,0xeb,0xec,0xec,0xec,0xed,0xed,0xed,0xee,0xee,0xee,0xef,0xef,0xef,0xf0,0xf0,0xf0,0xf1,0xf1,0xf1,0xf3,0xf3,0xf3,0xf4,0xf4,0xf4,0xf5,0xf5,0xf5,0xf6,0xf6,0xf6,0xf7,0xf7,0xf7,0xf8,0xf8,0xf8,0xf9,0xf9,0xf9,0xfa,0xfa,0xfa,0xfc,0xfc,0xfc,0xfd,0xfd,0xfd,0xfe,0xfe,0xfe,0xff,0xff,0xff};
	static constexpr std::array<uint8_t, 768> L02  = {0x1b,0x1b,0x1b,0x1c,0x1c,0x1c,0x1d,0x1d,0x1d,0x1d,0x1d,0x1d,0x1e,0x1e,0x1e,0x1f,0x1f,0x1f,0x1f,0x1f,0x1f,0x20,0x20,0x20,0x21,0x21,0x21,0x22,0x22,0x22,0x22,0x22,0x22,0x23,0x23,0x23,0x24,0x24,0x24,0x24,0x24,0x24,0x25,0x25,0x25,0x26,0x26,0x26,0x26,0x26,0x26,0x27,0x27,0x27,0x28,0x28,0x28,0x28,0x28,0x28,0x29,0x29,0x29,0x2a,0x2a,0x2a,0x2b,0x2b,0x2b,0x2b,0x2b,0x2b,0x2c,0x2c,0x2c,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2e,0x2e,0x2e,0x2f,0x2f,0x2f,0x30,0x30,0x30,0x30,0x30,0x30,0x31,0x31,0x31,0x32,0x32,0x32,0x32,0x32,0x32,0x33,0x33,0x33,0x34,0x34,0x34,0x35,0x35,0x35,0x35,0x35,0x35,0x36,0x36,0x36,0x37,0x37,0x37,0x38,0x38,0x38,0x38,0x38,0x38,0x39,0x39,0x39,0x3a,0x3a,0x3a,0x3b,0x3b,0x3b,0x3b,0x3b,0x3b,0x3c,0x3c,0x3c,0x3d,0x3d,0x3d,0x3e,0x3e,0x3e,0x3e,0x3e,0x3e,0x3f,0x3f,0x3f,0x40,0x40,0x40,0x41,0x41,0x41,0x41,0x41,0x41,0x42,0x42,0x42,0x43,0x43,0x43,0x44,0x44,0x44,0x44,0x44,0x44,0x45,0x45,0x45,0x46,0x46,0x46,0x47,0x47,0x47,0x47,0x47,0x47,0x48,0x48,0x48,0x49,0x49,0x49,0x4a,0x4a,0x4a,0x4a,0x4a,0x4a,0x4b,0x4b,0x4b,0x4c,0x4c,0x4c,0x4d,0x4d,0x4d,0x4e,0x4e,0x4e,0x4e,0x4e,0x4e,0x4f,0x4f,0x4f,0x50,0x50,0x50,0x51,0x51,0x51,0x51,0x52,0x52,0x52,0x52,0x52,0x53,0x53,0x53,0x54,0x54,0x54,0x55,0x55,0x55,0x55,0x55,0x55,0x56,0x56,0x56,0x57,0x57,0x57,0x58,0x58,0x58,0x59,0x59,0x59,0x59,0x59,0x59,0x5a,0x5a,0x5a,0x5b,0x5b,0x5b,0x5c,0x5c,0x5c,0x5d,0x5d,0x5d,0x5d,0x5d,0x5d,0x5e,0x5e,0x5e,0x5f,0x5f,0x5f,0x60,0x60,0x60,0x61,0x61,0x61,0x61,0x61,0x61,0x62,0x62,0x62,0x63,0x63,0x63,0x64,0x64,0x64,0x65,0x65,0x65,0x66,0x66,0x66,0x66,0x66,0x66,0x67,0x67,0x67,0x68,0x68,0x68,0x69,0x69,0x69,0x6a,0x6a,0x6a,0x6a,0x6a,0x6a,0x6b,0x6b,0x6b,0x6c,0x6c,0x6c,0x6d,0x6d,0x6d,0x6e,0x6e,0x6e,0x6f,0x6f,0x6f,0x6f,0x6f,0x6f,0x70,0x70,0x70,0x71,0x71,0x71,0x72,0x72,0x72,0x73,0x73,0x73,0x74,0x74,0x74,0x74,0x74,0x74,0x75,0x75,0x75,0x76,0x76,0x76,0x77,0x77,0x77,0x78,0x78,0x78,0x79,0x79,0x79,0x79,0x79,0x79,0x7a,0x7a,0x7a,0x7b,0x7b,0x7b,0x7c,0x7c,0x7c,0x7d,0x7d,0x7d,0x7e,0x7e,0x7e,0x7e,0x7f,0x7f,0x7f,0x7f,0x7f,0x80,0x80,0x80,0x81,0x81,0x81,0x82,0x82,0x82,0x83,0x83,0x83,0x84,0x84,0x84,0x84,0x84,0x84,0x85,0x85,0x85,0x86,0x86,0x86,0x87,0x87,0x87,0x88,0x88,0x88,0x89,0x89,0x89,0x8a,0x8a,0x8a,0x8a,0x8a,0x8a,0x8b,0x8b,0x8b,0x8c,0x8c,0x8c,0x8d,0x8d,0x8d,0x8e,0x8e,0x8e,0x8f,0x8f,0x8f,0x90,0x90,0x90,0x91,0x91,0x91,0x91,0x91,0x91,0x92,0x92,0x92,0x93,0x93,0x93,0x94,0x94,0x94,0x95,0x95,0x95,0x96,0x96,0x96,0x97,0x97,0x97,0x98,0x98,0x98,0x98,0x98,0x98,0x99,0x99,0x99,0x9a,0x9a,0x9a,0x9b,0x9b,0x9b,0x9c,0x9c,0x9c,0x9d,0x9d,0x9d,0x9e,0x9e,0x9e,0x9f,0x9f,0x9f,0x9f,0x9f,0x9f,0xa0,0xa0,0xa0,0xa1,0xa1,0xa1,0xa2,0xa2,0xa2,0xa3,0xa3,0xa3,0xa4,0xa4,0xa4,0xa5,0xa5,0xa5,0xa6,0xa6,0xa6,0xa7,0xa7,0xa7,0xa7,0xa7,0xa7,0xa8,0xa8,0xa8,0xa9,0xa9,0xa9,0xaa,0xaa,0xaa,0xab,0xab,0xab,0xac,0xac,0xac,0xad,0xad,0xad,0xae,0xae,0xae,0xaf,0xaf,0xaf,0xb0,0xb0,0xb0,0xb0,0xb0,0xb0,0xb1,0xb1,0xb1,0xb2,0xb2,0xb2,0xb3,0xb3,0xb3,0xb4,0xb4,0xb4,0xb5,0xb5,0xb5,0xb6,0xb6,0xb6,0xb7,0xb7,0xb7,0xb8,0xb8,0xb8,0xb9,0xb9,0xb9,0xb9,0xba,0xba,0xba,0xba,0xba,0xbb,0xbb,0xbb,0xbc,0xbc,0xbc,0xbd,0xbd,0xbd,0xbe,0xbe,0xbe,0xbf,0xbf,0xbf,0xc0,0xc0,0xc0,0xc1,0xc1,0xc1,0xc2,0xc2,0xc2,0xc3,0xc3,0xc3,0xc4,0xc4,0xc4,0xc4,0xc4,0xc4,0xc5,0xc5,0xc5,0xc6,0xc6,0xc6,0xc7,0xc7,0xc7,0xc8,0xc8,0xc8,0xc9,0xc9,0xc9,0xca,0xca,0xca,0xcb,0xcb,0xcb,0xcc,0xcc,0xcc,0xcd,0xcd,0xcd,0xce,0xce,0xce,0xcf,0xcf,0xcf,0xd0,0xd0,0xd0,0xd0,0xd1,0xd1,0xd1,0xd1,0xd1,0xd2,0xd2,0xd2,0xd3,0xd3,0xd3,0xd4,0xd4,0xd4,0xd5,0xd5,0xd5,0xd6,0xd6,0xd6,0xd7,0xd7,0xd7,0xd8,0xd8,0xd8,0xd9,0xd9,0xd9,0xda,0xda,0xda,0xdb,0xdb,0xdb,0xdc,0xdc,0xdc,0xdd,0xdd,0xdd,0xde,0xde,0xde,0xdf,0xdf,0xdf,0xdf,0xe0,0xe0,0xe0,0xe0,0xe0,0xe1,0xe1,0xe1,0xe2,0xe2,0xe2,0xe3,0xe3,0xe3,0xe4,0xe4,0xe4,0xe5,0xe5,0xe5,0xe6,0xe6,0xe6,0xe7,0xe7,0xe7,0xe8,0xe8,0xe8,0xe9,0xe9,0xe9,0xea,0xea,0xea,0xeb,0xeb,0xeb,0xec,0xec,0xec,0xed,0xed,0xed,0xee,0xee,0xee,0xef,0xef,0xef,0xf0,0xf0,0xf0,0xf1,0xf1,0xf1};
	static constexpr std::array<uint8_t, 768> L03  = {0x00,0x00,0x00,0x07,0x00,0x00,0x0d,0x00,0x00,0x12,0x00,0x00,0x16,0x00,0x00,0x1a,0x00,0x00,0x1d,0x00,0x00,0x20,0x00,0x00,0x22,0x00,0x00,0x25,0x00,0x00,0x27,0x00,0x00,0x29,0x00,0x00,0x2b,0x00,0x00,0x2d,0x00,0x00,0x2f,0x00,0x00,0x31,0x00,0x00,0x32,0x00,0x00,0x34,0x00,0x00,0x36,0x01,0x00,0x37,0x01,0x00,0x39,0x00,0x00,0x3a,0x00,0x00,0x3c,0x00,0x00,0x3d,0x00,0x00,0x3f,0x00,0x00,0x40,0x00,0x00,0x42,0x01,0x00,0x43,0x01,0x00,0x45,0x01,0x00,0x46,0x01,0x00,0x48,0x01,0x00,0x49,0x01,0x00,0x4b,0x01,0x00,0x4c,0x01,0x00,0x4e,0x01,0x00,0x4f,0x01,0x00,0x51,0x01,0x00,0x52,0x01,0x00,0x54,0x01,0x00,0x55,0x01,0x00,0x57,0x01,0x00,0x58,0x01,0x00,0x5a,0x01,0x00,0x5c,0x01,0x00,0x5d,0x01,0x00,0x5f,0x01,0x00,0x60,0x01,0x00,0x62,0x01,0x00,0x63,0x01,0x00,0x65,0x01,0x00,0x67,0x01,0x00,0x68,0x01,0x00,0x6a,0x01,0x00,0x6b,0x02,0x00,0x6d,0x02,0x00,0x6f,0x02,0x00,0x70,0x02,0x00,0x72,0x02,0x00,0x74,0x02,0x00,0x75,0x02,0x00,0x77,0x02,0x00,0x79,0x02,0x00,0x7a,0x02,0x00,0x7c,0x02,0x00,0x7e,0x02,0x00,0x7f,0x02,0x00,0x81,0x02,0x00,0x83,0x02,0x00,0x84,0x03,0x00,0x86,0x03,0x00,0x88,0x03,0x00,0x89,0x03,0x00,0x8b,0x03,0x00,0x8d,0x03,0x00,0x8e,0x03,0x00,0x90,0x03,0x00,0x92,0x03,0x00,0x93,0x03,0x00,0x95,0x03,0x00,0x97,0x04,0x00,0x99,0x04,0x00,0x9a,0x04,0x00,0x9c,0x04,0x00,0x9e,0x04,0x00,0x9f,0x04,0x00,0xa1,0x04,0x00,0xa3,0x04,0x00,0xa5,0x05,0x00,0xa6,0x05,0x00,0xa8,0x05,0x00,0xaa,0x05,0x00,0xac,0x05,0x00,0xad,0x05,0x00,0xaf,0x05,0x00,0xb1,0x06,0x00,0xb3,0x06,0x00,0xb5,0x06,0x00,0xb6,0x06,0x00,0xb8,0x06,0x00,0xba,0x07,0x00,0xbc,0x07,0x00,0xbd,0x07,0x00,0xbf,0x07,0x00,0xc1,0x07,0x00,0xc3,0x08,0x00,0xc5,0x08,0x00,0xc6,0x08,0x00,0xc8,0x08,0x00,0xca,0x09,0x00,0xcc,0x09,0x00,0xce,0x09,0x00,0xcf,0x09,0x00,0xd1,0x0a,0x00,0xd3,0x0a,0x00,0xd5,0x0b,0x00,0xd7,0x0b,0x00,0xd8,0x0b,0x00,0xda,0x0c,0x00,0xdc,0x0c,0x00,0xde,0x0d,0x00,0xe0,0x0d,0x00,0xe1,0x0e,0x00,0xe3,0x0e,0x00,0xe5,0x0f,0x00,0xe7,0x10,0x00,0xe8,0x11,0x00,0xea,0x12,0x00,0xec,0x13,0x00,0xed,0x15,0x00,0xef,0x17,0x00,0xf0,0x19,0x00,0xf2,0x1b,0x00,0xf3,0x1e,0x00,0xf4,0x20,0x00,0xf5,0x23,0x00,0xf6,0x26,0x00,0xf7,0x29,0x00,0xf8,0x2c,0x00,0xf8,0x2f,0x00,0xf9,0x32,0x00,0xfa,0x35,0x00,0xfa,0x38,0x00,0xfb,0x3b,0x00,0xfb,0x3e,0x00,0xfc,0x41,0x00,0xfc,0x44,0x00,0xfc,0x46,0x00,0xfd,0x49,0x00,0xfd,0x4c,0x00,0xfd,0x4e,0x00,0xfd,0x51,0x00,0xfe,0x54,0x00,0xfe,0x56,0x00,0xfe,0x59,0x00,0xfe,0x5b,0x00,0xfe,0x5d,0x00,0xfe,0x60,0x00,0xfe,0x62,0x00,0xfe,0x64,0x00,0xff,0x67,0x00,0xff,0x69,0x00,0xff,0x6b,0x00,0xff,0x6d,0x00,0xff,0x6f,0x00,0xff,0x72,0x00,0xff,0x74,0x00,0xff,0x76,0x00,0xff,0x78,0x00,0xff,0x7a,0x00,0xff,0x7c,0x00,0xff,0x7e,0x00,0xff,0x80,0x00,0xff,0x82,0x00,0xff,0x84,0x00,0xff,0x86,0x00,0xff,0x88,0x00,0xff,0x8a,0x00,0xff,0x8c,0x00,0xff,0x8e,0x00,0xff,0x8f,0x00,0xff,0x91,0x00,0xff,0x93,0x00,0xff,0x95,0x00,0xff,0x97,0x00,0xff,0x99,0x00,0xff,0x9a,0x00,0xff,0x9c,0x01,0xff,0x9e,0x01,0xff,0xa0,0x01,0xff,0xa1,0x01,0xff,0xa3,0x01,0xff,0xa5,0x01,0xff,0xa7,0x01,0xff,0xa8,0x01,0xff,0xaa,0x01,0xff,0xac,0x01,0xff,0xad,0x02,0xff,0xaf,0x02,0xff,0xb1,0x02,0xff,0xb2,0x02,0xff,0xb4,0x02,0xff,0xb6,0x02,0xff,0xb7,0x03,0xff,0xb9,0x03,0xff,0xbb,0x03,0xff,0xbc,0x03,0xff,0xbe,0x03,0xff,0xc0,0x04,0xff,0xc1,0x04,0xff,0xc3,0x04,0xff,0xc4,0x04,0xff,0xc6,0x05,0xff,0xc8,0x05,0xff,0xc9,0x05,0xff,0xcb,0x05,0xff,0xcc,0x06,0xff,0xce,0x06,0xff,0xd0,0x06,0xff,0xd1,0x07,0xff,0xd3,0x07,0xff,0xd4,0x08,0xff,0xd6,0x08,0xff,0xd7,0x09,0xff,0xd9,0x09,0xff,0xdb,0x0a,0xff,0xdc,0x0a,0xff,0xde,0x0b,0xff,0xdf,0x0b,0xff,0xe1,0x0c,0xff,0xe2,0x0d,0xff,0xe4,0x0d,0xff,0xe5,0x0e,0xff,0xe7,0x0f,0xff,0xe9,0x10,0xff,0xea,0x11,0xff,0xec,0x13,0xff,0xed,0x15,0xff,0xef,0x17,0xff,0xf0,0x1a,0xff,0xf2,0x1f,0xff,0xf3,0x24,0xff,0xf5,0x2b,0xff,0xf6,0x33,0xff,0xf7,0x3c,0xff,0xf9,0x47,0xff,0xfa,0x54,0xff,0xfb,0x62,0xff,0xfc,0x72,0xff,0xfd,0x84,0xff,0xfe,0x96,0xff,0xfe,0xa8,0xff,0xfe,0xbb,0xff,0xff,0xcd,0xff,0xff,0xde,0xff,0xff,0xef,0xff,0xff,0xff};
	static constexpr std::array<uint8_t, 768> L04  = {0x00,0x00,0x00,0x07,0x00,0x00,0x0d,0x00,0x00,0x12,0x00,0x00,0x16,0x00,0x00,0x19,0x00,0x00,0x1c,0x00,0x00,0x1f,0x00,0x00,0x22,0x00,0x00,0x24,0x00,0x00,0x26,0x00,0x00,0x28,0x00,0x00,0x2a,0x00,0x00,0x2c,0x00,0x00,0x2e,0x00,0x00,0x30,0x00,0x00,0x32,0x00,0x00,0x33,0x00,0x00,0x35,0x00,0x00,0x36,0x00,0x00,0x38,0x00,0x00,0x39,0x00,0x00,0x3b,0x00,0x00,0x3c,0x00,0x00,0x3e,0x00,0x00,0x3f,0x00,0x00,0x40,0x00,0x00,0x42,0x01,0x00,0x43,0x01,0x00,0x45,0x01,0x00,0x46,0x01,0x00,0x48,0x01,0x00,0x49,0x01,0x00,0x4b,0x01,0x00,0x4c,0x01,0x00,0x4e,0x01,0x00,0x4f,0x01,0x00,0x51,0x01,0x00,0x52,0x01,0x00,0x54,0x01,0x00,0x55,0x01,0x00,0x57,0x01,0x00,0x58,0x01,0x00,0x5a,0x01,0x00,0x5b,0x01,0x00,0x5d,0x01,0x00,0x5e,0x01,0x00,0x60,0x01,0x00,0x61,0x01,0x00,0x63,0x01,0x00,0x64,0x01,0x00,0x66,0x01,0x00,0x67,0x01,0x00,0x69,0x01,0x00,0x6b,0x02,0x00,0x6c,0x02,0x00,0x6e,0x02,0x00,0x6f,0x02,0x00,0x71,0x02,0x00,0x72,0x02,0x00,0x74,0x02,0x00,0x76,0x02,0x00,0x77,0x02,0x00,0x79,0x02,0x00,0x7a,0x02,0x00,0x7c,0x02,0x00,0x7e,0x02,0x00,0x7f,0x02,0x00,0x81,0x02,0x00,0x83,0x02,0x00,0x84,0x03,0x00,0x86,0x03,0x00,0x87,0x03,0x00,0x89,0x03,0x00,0x8b,0x03,0x00,0x8c,0x03,0x00,0x8e,0x03,0x00,0x90,0x03,0x00,0x91,0x03,0x00,0x93,0x03,0x00,0x95,0x03,0x00,0x96,0x04,0x00,0x98,0x04,0x00,0x9a,0x04,0x00,0x9b,0x04,0x00,0x9d,0x04,0x00,0x9f,0x04,0x00,0xa0,0x04,0x00,0xa2,0x04,0x00,0xa4,0x04,0x00,0xa5,0x05,0x00,0xa7,0x05,0x00,0xa9,0x05,0x00,0xab,0x05,0x00,0xac,0x05,0x00,0xae,0x05,0x00,0xb0,0x06,0x00,0xb1,0x06,0x00,0xb3,0x06,0x00,0xb5,0x06,0x00,0xb7,0x06,0x00,0xb8,0x06,0x00,0xba,0x07,0x00,0xbc,0x07,0x00,0xbd,0x07,0x00,0xbf,0x07,0x00,0xc1,0x07,0x00,0xc3,0x08,0x00,0xc4,0x08,0x00,0xc6,0x08,0x00,0xc8,0x08,0x00,0xca,0x09,0x00,0xcb,0x09,0x00,0xcd,0x09,0x00,0xcf,0x09,0x00,0xd1,0x0a,0x00,0xd2,0x0a,0x00,0xd4,0x0a,0x00,0xd6,0x0b,0x00,0xd8,0x0b,0x00,0xd9,0x0c,0x00,0xdb,0x0c,0x00,0xdd,0x0c,0x00,0xdf,0x0d,0x00,0xe0,0x0d,0x00,0xe2,0x0e,0x00,0xe4,0x0f,0x00,0xe6,0x0f,0x00,0xe7,0x10,0x00,0xe9,0x11,0x00,0xeb,0x12,0x00,0xec,0x13,0x00,0xee,0x15,0x00,0xef,0x18,0x00,0xf0,0x1a,0x00,0xf1,0x1d,0x00,0xf2,0x21,0x00,0xf3,0x24,0x00,0xf4,0x27,0x00,0xf4,0x2a,0x00,0xf5,0x2e,0x00,0xf6,0x31,0x00,0xf6,0x34,0x00,0xf7,0x37,0x00,0xf7,0x3a,0x00,0xf7,0x3d,0x00,0xf8,0x3f,0x00,0xf8,0x42,0x00,0xf8,0x45,0x00,0xf9,0x48,0x00,0xf9,0x4a,0x00,0xf9,0x4d,0x00,0xf9,0x4f,0x00,0xfa,0x52,0x00,0xfa,0x54,0x00,0xfa,0x56,0x00,0xfa,0x59,0x00,0xfa,0x5b,0x00,0xfb,0x5d,0x00,0xfb,0x60,0x00,0xfb,0x62,0x00,0xfb,0x64,0x00,0xfb,0x66,0x00,0xfb,0x68,0x00,0xfc,0x6a,0x00,0xfc,0x6c,0x00,0xfc,0x6e,0x00,0xfc,0x70,0x00,0xfc,0x72,0x00,0xfc,0x74,0x00,0xfc,0x76,0x00,0xfc,0x78,0x00,0xfc,0x7a,0x00,0xfc,0x7c,0x00,0xfd,0x7e,0x00,0xfd,0x80,0x00,0xfd,0x82,0x00,0xfd,0x83,0x00,0xfd,0x85,0x00,0xfd,0x87,0x00,0xfd,0x89,0x00,0xfd,0x8b,0x00,0xfd,0x8c,0x00,0xfd,0x8e,0x00,0xfd,0x90,0x00,0xfd,0x92,0x00,0xfd,0x93,0x00,0xfe,0x95,0x00,0xfe,0x97,0x00,0xfe,0x99,0x00,0xfe,0x9a,0x00,0xfe,0x9c,0x00,0xfe,0x9e,0x00,0xfe,0x9f,0x00,0xfe,0xa1,0x00,0xfe,0xa3,0x00,0xfe,0xa4,0x00,0xfe,0xa6,0x00,0xfe,0xa8,0x00,0xfe,0xa9,0x00,0xfe,0xab,0x00,0xfe,0xad,0x00,0xfe,0xae,0x00,0xfe,0xb0,0x00,0xfe,0xb1,0x00,0xfe,0xb3,0x00,0xfe,0xb5,0x00,0xfe,0xb6,0x00,0xfe,0xb8,0x00,0xfe,0xb9,0x00,0xfe,0xbb,0x00,0xfe,0xbd,0x00,0xff,0xbe,0x00,0xff,0xc0,0x00,0xff,0xc1,0x00,0xff,0xc3,0x00,0xff,0xc4,0x00,0xff,0xc6,0x00,0xff,0xc7,0x00,0xff,0xc9,0x00,0xff,0xcb,0x00,0xff,0xcc,0x00,0xff,0xce,0x00,0xff,0xcf,0x00,0xff,0xd1,0x00,0xff,0xd2,0x00,0xff,0xd4,0x00,0xff,0xd5,0x00,0xff,0xd7,0x00,0xff,0xd8,0x00,0xff,0xda,0x00,0xff,0xdb,0x00,0xff,0xdd,0x00,0xff,0xde,0x00,0xff,0xe0,0x00,0xff,0xe1,0x00,0xff,0xe3,0x00,0xff,0xe4,0x00,0xff,0xe6,0x00,0xff,0xe7,0x00,0xff,0xe9,0x00,0xff,0xea,0x00,0xff,0xec,0x00,0xff,0xed,0x00,0xff,0xef,0x00,0xff,0xf0,0x00,0xff,0xf2,0x00,0xff,0xf3,0x00,0xff,0xf5,0x00,0xff,0xf6,0x00,0xff,0xf8,0x00,0xff,0xf9,0x00,0xff,0xfb,0x00,0xff,0xfc,0x00,0xff,0xfe,0x00,0xff,0xff,0x00};
	static constexpr std::array<uint8_t, 768> L05  = {0x01,0x15,0x06,0x01,0x16,0x06,0x02,0x17,0x06,0x02,0x18,0x06,0x03,0x19,0x06,0x04,0x19,0x06,0x04,0x1a,0x06,0x05,0x1b,0x06,0x05,0x1c,0x06,0x06,0x1c,0x06,0x07,0x1d,0x06,0x07,0x1e,0x06,0x08,0x1f,0x06,0x08,0x20,0x06,0x08,0x20,0x06,0x09,0x21,0x06,0x09,0x22,0x06,0x09,0x23,0x05,0x09,0x24,0x05,0x09,0x24,0x05,0x09,0x25,0x05,0x09,0x26,0x05,0x09,0x27,0x05,0x09,0x28,0x05,0x09,0x29,0x05,0x09,0x2a,0x05,0x09,0x2a,0x05,0x09,0x2b,0x05,0x09,0x2c,0x05,0x09,0x2d,0x05,0x09,0x2e,0x05,0x09,0x2f,0x05,0x09,0x30,0x05,0x08,0x31,0x05,0x08,0x31,0x05,0x08,0x32,0x05,0x08,0x33,0x05,0x08,0x34,0x05,0x09,0x35,0x05,0x09,0x36,0x05,0x09,0x37,0x05,0x09,0x38,0x05,0x09,0x38,0x05,0x09,0x39,0x05,0x0a,0x3a,0x05,0x0a,0x3b,0x05,0x0a,0x3c,0x05,0x0a,0x3d,0x05,0x0b,0x3e,0x05,0x0b,0x3f,0x05,0x0b,0x40,0x05,0x0b,0x40,0x05,0x0c,0x41,0x05,0x0c,0x42,0x05,0x0c,0x43,0x05,0x0d,0x44,0x05,0x0d,0x45,0x05,0x0d,0x46,0x05,0x0d,0x47,0x05,0x0e,0x48,0x05,0x0e,0x49,0x05,0x0e,0x49,0x05,0x0e,0x4a,0x05,0x0f,0x4b,0x05,0x0f,0x4c,0x05,0x0f,0x4d,0x05,0x0f,0x4e,0x05,0x10,0x4f,0x05,0x10,0x50,0x05,0x10,0x51,0x05,0x10,0x52,0x05,0x11,0x53,0x05,0x11,0x54,0x06,0x11,0x55,0x06,0x11,0x55,0x06,0x12,0x56,0x06,0x12,0x57,0x06,0x12,0x58,0x06,0x12,0x59,0x06,0x13,0x5a,0x06,0x13,0x5b,0x06,0x13,0x5c,0x06,0x13,0x5d,0x06,0x14,0x5e,0x06,0x14,0x5f,0x07,0x14,0x60,0x07,0x14,0x61,0x07,0x15,0x62,0x07,0x15,0x63,0x07,0x15,0x64,0x07,0x15,0x65,0x07,0x16,0x66,0x07,0x16,0x67,0x07,0x16,0x68,0x07,0x16,0x68,0x08,0x17,0x69,0x08,0x17,0x6a,0x08,0x17,0x6b,0x08,0x17,0x6c,0x08,0x18,0x6d,0x08,0x18,0x6e,0x08,0x18,0x6f,0x08,0x18,0x70,0x08,0x19,0x71,0x08,0x19,0x72,0x09,0x19,0x73,0x09,0x19,0x74,0x09,0x1a,0x75,0x09,0x1a,0x76,0x09,0x1a,0x77,0x09,0x1a,0x78,0x09,0x1b,0x79,0x09,0x1b,0x7a,0x09,0x1b,0x7b,0x0a,0x1b,0x7c,0x0a,0x1c,0x7d,0x0a,0x1c,0x7e,0x0a,0x1c,0x7f,0x0a,0x1c,0x80,0x0a,0x1d,0x81,0x0a,0x1d,0x82,0x0a,0x1d,0x83,0x0b,0x1e,0x84,0x0b,0x1e,0x85,0x0b,0x1e,0x86,0x0b,0x1e,0x87,0x0b,0x1f,0x88,0x0b,0x1f,0x89,0x0b,0x1f,0x8a,0x0b,0x1f,0x8b,0x0b,0x20,0x8c,0x0c,0x20,0x8d,0x0c,0x20,0x8e,0x0c,0x20,0x8f,0x0c,0x21,0x90,0x0c,0x21,0x91,0x0c,0x21,0x92,0x0c,0x21,0x93,0x0c,0x22,0x95,0x0d,0x22,0x96,0x0d,0x22,0x97,0x0d,0x22,0x98,0x0d,0x23,0x99,0x0d,0x23,0x9a,0x0d,0x23,0x9b,0x0d,0x23,0x9c,0x0d,0x24,0x9d,0x0d,0x24,0x9e,0x0e,0x24,0x9f,0x0e,0x25,0xa0,0x0e,0x25,0xa1,0x0e,0x25,0xa2,0x0e,0x25,0xa3,0x0e,0x26,0xa4,0x0e,0x26,0xa5,0x0e,0x26,0xa6,0x0e,0x26,0xa7,0x0f,0x27,0xa8,0x0f,0x27,0xa9,0x0f,0x27,0xaa,0x0f,0x27,0xac,0x0f,0x28,0xad,0x0f,0x28,0xae,0x0f,0x28,0xaf,0x0f,0x28,0xb0,0x10,0x29,0xb1,0x10,0x29,0xb2,0x10,0x29,0xb3,0x10,0x2a,0xb4,0x10,0x2a,0xb5,0x10,0x2a,0xb6,0x10,0x2a,0xb7,0x10,0x2b,0xb8,0x10,0x2b,0xb9,0x11,0x2b,0xba,0x11,0x2b,0xbc,0x11,0x2c,0xbd,0x11,0x2c,0xbe,0x11,0x2c,0xbf,0x11,0x2c,0xc0,0x11,0x2d,0xc1,0x11,0x2d,0xc2,0x11,0x2d,0xc3,0x12,0x2e,0xc4,0x12,0x2e,0xc5,0x12,0x2e,0xc6,0x12,0x2e,0xc7,0x12,0x2f,0xc9,0x12,0x2f,0xca,0x12,0x2f,0xcb,0x12,0x2f,0xcc,0x13,0x30,0xcd,0x13,0x30,0xce,0x13,0x30,0xcf,0x13,0x31,0xd0,0x13,0x31,0xd1,0x13,0x31,0xd2,0x13,0x31,0xd3,0x13,0x32,0xd5,0x13,0x32,0xd6,0x14,0x32,0xd7,0x14,0x32,0xd8,0x14,0x33,0xd9,0x14,0x33,0xda,0x14,0x33,0xdb,0x14,0x34,0xdc,0x14,0x34,0xdd,0x14,0x34,0xdf,0x14,0x34,0xe0,0x15,0x35,0xe1,0x15,0x35,0xe2,0x15,0x35,0xe3,0x15,0x35,0xe4,0x15,0x36,0xe5,0x15,0x37,0xe6,0x15,0x39,0xe7,0x15,0x3b,0xe8,0x15,0x3e,0xe9,0x15,0x41,0xea,0x16,0x44,0xeb,0x16,0x48,0xec,0x16,0x4b,0xed,0x16,0x4f,0xee,0x16,0x53,0xef,0x16,0x57,0xf0,0x16,0x5c,0xf0,0x16,0x60,0xf1,0x16,0x64,0xf2,0x16,0x68,0xf3,0x16,0x6c,0xf3,0x16,0x71,0xf4,0x15,0x75,0xf5,0x15,0x79,0xf6,0x15,0x7d,0xf6,0x15,0x81,0xf7,0x15,0x86,0xf8,0x15,0x8a,0xf8,0x15,0x8e,0xf9,0x15,0x92,0xf9,0x15,0x96,0xfa,0x15,0x9a,0xfb,0x15,0x9f,0xfb,0x15,0xa3,0xfc,0x15,0xa7,0xfc,0x15,0xab,0xfd,0x15,0xaf,0xfd,0x15,0xb3,0xfe,0x15,0xb7,0xfe,0x15,0xbb,0xff,0x15,0xc0,0xff,0x15,0xc4,0xff,0x15,0xc8,0xff,0x15,0xcc,0xff,0x15,0xd0,0xff,0x15,0xd4,0xff,0x15,0xd8,0xff,0x15};
	static constexpr std::array<uint8_t, 768> L06  = {0x00,0x01,0x4e,0x00,0x01,0x50,0x00,0x02,0x52,0x00,0x02,0x54,0x00,0x02,0x56,0x00,0x03,0x58,0x00,0x03,0x5a,0x00,0x03,0x5c,0x00,0x03,0x5e,0x00,0x03,0x60,0x01,0x03,0x62,0x02,0x03,0x64,0x02,0x03,0x66,0x03,0x03,0x68,0x04,0x02,0x6a,0x05,0x02,0x6c,0x05,0x02,0x6e,0x06,0x02,0x70,0x07,0x02,0x72,0x08,0x02,0x74,0x08,0x02,0x76,0x09,0x02,0x78,0x0a,0x02,0x7b,0x0b,0x02,0x7d,0x0b,0x02,0x7f,0x0c,0x02,0x81,0x0d,0x02,0x83,0x0d,0x02,0x85,0x0e,0x02,0x88,0x0e,0x01,0x8a,0x0f,0x01,0x8c,0x0f,0x01,0x8e,0x0f,0x01,0x90,0x10,0x01,0x93,0x10,0x01,0x95,0x10,0x01,0x97,0x10,0x01,0x99,0x10,0x02,0x9c,0x10,0x02,0x9e,0x10,0x02,0xa0,0x10,0x02,0xa2,0x0f,0x02,0xa5,0x0f,0x02,0xa7,0x0e,0x03,0xaa,0x0d,0x03,0xac,0x0d,0x03,0xae,0x0c,0x04,0xb1,0x0b,0x04,0xb3,0x0a,0x04,0xb5,0x0a,0x05,0xb7,0x09,0x05,0xb9,0x09,0x06,0xbc,0x08,0x07,0xbe,0x08,0x07,0xc0,0x08,0x08,0xc2,0x08,0x09,0xc4,0x08,0x0a,0xc6,0x08,0x0a,0xc8,0x08,0x0b,0xca,0x08,0x0c,0xcc,0x09,0x0d,0xce,0x09,0x0e,0xd0,0x0a,0x0f,0xd2,0x0b,0x10,0xd4,0x0c,0x11,0xd6,0x0d,0x12,0xd8,0x0e,0x12,0xd9,0x10,0x13,0xdb,0x11,0x14,0xdd,0x12,0x15,0xdf,0x13,0x16,0xe0,0x15,0x17,0xe2,0x16,0x18,0xe3,0x18,0x19,0xe5,0x19,0x1a,0xe7,0x1a,0x1c,0xe8,0x1b,0x1d,0xe9,0x1c,0x1e,0xeb,0x1d,0x1f,0xec,0x1f,0x21,0xed,0x20,0x22,0xee,0x21,0x24,0xf0,0x22,0x25,0xf1,0x23,0x26,0xf2,0x23,0x28,0xf3,0x24,0x29,0xf4,0x25,0x2b,0xf4,0x26,0x2d,0xf5,0x27,0x2e,0xf6,0x28,0x30,0xf7,0x28,0x31,0xf7,0x29,0x33,0xf8,0x2a,0x35,0xf8,0x2a,0x36,0xf9,0x2b,0x38,0xf9,0x2b,0x3a,0xfa,0x2c,0x3b,0xfa,0x2c,0x3d,0xfa,0x2d,0x3f,0xfa,0x2d,0x41,0xfb,0x2d,0x42,0xfb,0x2e,0x44,0xfb,0x2e,0x46,0xfb,0x2e,0x47,0xfb,0x2f,0x49,0xfb,0x2f,0x4b,0xfb,0x2f,0x4c,0xfb,0x2f,0x4e,0xfb,0x2f,0x4f,0xfb,0x2f,0x51,0xfb,0x2f,0x52,0xfc,0x30,0x54,0xfc,0x30,0x56,0xfc,0x30,0x57,0xfc,0x30,0x59,0xfc,0x30,0x5a,0xfc,0x30,0x5c,0xfc,0x30,0x5d,0xfc,0x2f,0x5e,0xfc,0x2f,0x60,0xfc,0x2f,0x61,0xfc,0x2f,0x63,0xfd,0x2f,0x64,0xfd,0x2f,0x66,0xfd,0x2e,0x67,0xfd,0x2e,0x69,0xfd,0x2e,0x6a,0xfd,0x2e,0x6b,0xfd,0x2d,0x6d,0xfd,0x2d,0x6e,0xfd,0x2d,0x70,0xfd,0x2c,0x71,0xfd,0x2c,0x72,0xfd,0x2c,0x74,0xfd,0x2c,0x75,0xfe,0x2c,0x76,0xfe,0x2b,0x78,0xfe,0x2b,0x79,0xfe,0x2b,0x7b,0xfe,0x2b,0x7c,0xfe,0x2b,0x7d,0xfe,0x2c,0x7e,0xfe,0x2c,0x80,0xfe,0x2c,0x81,0xfe,0x2c,0x82,0xfe,0x2c,0x84,0xfe,0x2d,0x85,0xfe,0x2d,0x86,0xfe,0x2d,0x87,0xfe,0x2e,0x89,0xfe,0x2e,0x8a,0xfe,0x2f,0x8b,0xfe,0x2f,0x8d,0xfe,0x30,0x8e,0xfe,0x30,0x8f,0xfe,0x31,0x90,0xfd,0x32,0x92,0xfd,0x32,0x93,0xfd,0x33,0x94,0xfd,0x33,0x95,0xfd,0x34,0x96,0xfd,0x34,0x98,0xfd,0x35,0x99,0xfd,0x35,0x9a,0xfd,0x35,0x9b,0xfd,0x35,0x9d,0xfd,0x36,0x9e,0xfd,0x36,0x9f,0xfd,0x36,0xa0,0xfd,0x36,0xa2,0xfd,0x36,0xa3,0xfd,0x36,0xa4,0xfd,0x36,0xa6,0xfd,0x36,0xa7,0xfd,0x35,0xa8,0xfd,0x35,0xa9,0xfc,0x35,0xab,0xfc,0x35,0xac,0xfc,0x34,0xad,0xfc,0x34,0xae,0xfc,0x33,0xb0,0xfc,0x33,0xb1,0xfc,0x32,0xb2,0xfc,0x31,0xb4,0xfc,0x31,0xb5,0xfc,0x30,0xb6,0xfc,0x2f,0xb7,0xfc,0x2e,0xb9,0xfc,0x2e,0xba,0xfc,0x2d,0xbb,0xfc,0x2c,0xbc,0xfc,0x2c,0xbe,0xfc,0x2b,0xbf,0xfc,0x2b,0xc0,0xfc,0x2a,0xc2,0xfc,0x2a,0xc3,0xfc,0x2a,0xc4,0xfc,0x29,0xc5,0xfc,0x29,0xc7,0xfc,0x29,0xc8,0xfc,0x29,0xc9,0xfb,0x29,0xca,0xfb,0x29,0xcb,0xfb,0x29,0xcd,0xfb,0x29,0xce,0xfb,0x29,0xcf,0xfb,0x29,0xd0,0xfb,0x2a,0xd2,0xfb,0x2a,0xd3,0xfb,0x2b,0xd4,0xfb,0x2b,0xd5,0xfb,0x2c,0xd6,0xfb,0x2c,0xd8,0xfa,0x2d,0xd9,0xfa,0x2f,0xda,0xfa,0x30,0xdb,0xfa,0x33,0xdc,0xfa,0x35,0xdd,0xfa,0x38,0xde,0xfa,0x3c,0xdf,0xfa,0x3f,0xe1,0xfa,0x42,0xe2,0xf9,0x46,0xe3,0xf9,0x49,0xe4,0xf9,0x4d,0xe5,0xf9,0x50,0xe5,0xf9,0x54,0xe6,0xf9,0x57,0xe7,0xf9,0x5b,0xe8,0xf9,0x5e,0xe9,0xf9,0x62,0xea,0xf8,0x65,0xeb,0xf8,0x69,0xec,0xf8,0x6c,0xed,0xf8,0x70,0xee,0xf8,0x73,0xef,0xf8,0x76,0xf0,0xf8,0x7a,0xf0,0xf8,0x7d,0xf1,0xf8,0x80,0xf2,0xf7,0x84,0xf3,0xf7,0x87,0xf4,0xf7,0x8a,0xf5,0xf7,0x8e,0xf5,0xf7,0x91,0xf6,0xf7,0x94,0xf7,0xf7,0x97,0xf8,0xf7,0x9a,0xf9,0xf6,0x9d,0xf9,0xf6,0xa1,0xfa,0xf6,0xa4,0xfb,0xf6,0xa7,0xfc,0xf6,0xaa,0xfd,0xf6,0xad,0xfd,0xf6,0xb0,0xfe,0xf6,0xb3,0xff,0xf6};
	static constexpr std::array<uint8_t, 768> L07  = {0x00,0x02,0x4b,0x00,0x03,0x4d,0x00,0x03,0x4f,0x00,0x04,0x51,0x00,0x04,0x53,0x00,0x04,0x55,0x00,0x05,0x58,0x00,0x05,0x5a,0x00,0x05,0x5c,0x00,0x05,0x5e,0x00,0x05,0x60,0x00,0x05,0x62,0x00,0x05,0x64,0x00,0x05,0x66,0x00,0x05,0x68,0x01,0x05,0x6a,0x01,0x05,0x6d,0x01,0x05,0x6f,0x01,0x05,0x71,0x02,0x05,0x73,0x02,0x05,0x75,0x02,0x05,0x77,0x03,0x05,0x79,0x03,0x05,0x7c,0x03,0x05,0x7e,0x04,0x05,0x80,0x04,0x05,0x82,0x04,0x05,0x84,0x04,0x06,0x87,0x05,0x06,0x89,0x05,0x06,0x8b,0x05,0x06,0x8d,0x05,0x06,0x90,0x06,0x06,0x92,0x06,0x06,0x94,0x06,0x06,0x96,0x06,0x06,0x99,0x06,0x06,0x9b,0x06,0x06,0x9d,0x06,0x06,0x9f,0x06,0x06,0xa2,0x06,0x07,0xa4,0x05,0x07,0xa6,0x05,0x07,0xa9,0x05,0x07,0xab,0x05,0x07,0xad,0x05,0x08,0xaf,0x05,0x08,0xb2,0x05,0x08,0xb4,0x05,0x08,0xb6,0x05,0x09,0xb8,0x06,0x09,0xba,0x06,0x0a,0xbd,0x07,0x0a,0xbf,0x08,0x0a,0xc1,0x09,0x0b,0xc3,0x0b,0x0b,0xc5,0x0c,0x0c,0xc7,0x0d,0x0c,0xc9,0x0f,0x0d,0xcb,0x10,0x0d,0xcd,0x12,0x0e,0xcf,0x13,0x0e,0xd1,0x15,0x0f,0xd3,0x16,0x0f,0xd5,0x18,0x10,0xd6,0x19,0x11,0xd8,0x1b,0x11,0xda,0x1d,0x12,0xdc,0x1e,0x12,0xde,0x20,0x13,0xdf,0x22,0x14,0xe1,0x24,0x14,0xe3,0x26,0x15,0xe4,0x28,0x15,0xe6,0x2a,0x16,0xe7,0x2c,0x16,0xe9,0x2f,0x17,0xea,0x31,0x17,0xec,0x34,0x18,0xed,0x37,0x18,0xee,0x39,0x19,0xef,0x3c,0x19,0xf0,0x3f,0x19,0xf2,0x42,0x1a,0xf3,0x45,0x1a,0xf4,0x48,0x1a,0xf5,0x4b,0x1b,0xf5,0x4d,0x1b,0xf6,0x50,0x1b,0xf7,0x53,0x1b,0xf8,0x56,0x1b,0xf8,0x59,0x1c,0xf9,0x5d,0x1c,0xfa,0x60,0x1c,0xfa,0x63,0x1c,0xfa,0x66,0x1c,0xfb,0x69,0x1c,0xfb,0x6c,0x1c,0xfb,0x6f,0x1c,0xfc,0x72,0x1c,0xfc,0x75,0x1c,0xfc,0x78,0x1c,0xfc,0x7b,0x1c,0xfc,0x7e,0x1c,0xfc,0x80,0x1c,0xfd,0x83,0x1c,0xfd,0x86,0x1c,0xfd,0x89,0x1c,0xfd,0x8b,0x1c,0xfd,0x8e,0x1c,0xfd,0x91,0x1c,0xfd,0x93,0x1d,0xfd,0x96,0x1d,0xfe,0x99,0x1d,0xfe,0x9b,0x1d,0xfe,0x9e,0x1d,0xfe,0xa0,0x1d,0xfe,0xa3,0x1d,0xfe,0xa5,0x1d,0xfe,0xa8,0x1d,0xfe,0xaa,0x1d,0xfe,0xad,0x1d,0xfe,0xaf,0x1d,0xfe,0xb1,0x1d,0xfe,0xb4,0x1d,0xfe,0xb6,0x1c,0xfe,0xb9,0x1c,0xfe,0xbb,0x1c,0xfe,0xbd,0x1d,0xfe,0xc0,0x1d,0xfe,0xc2,0x1d,0xfe,0xc4,0x1d,0xfe,0xc6,0x1e,0xfe,0xc8,0x1e,0xfe,0xca,0x1f,0xfe,0xcc,0x20,0xfe,0xce,0x21,0xfe,0xd0,0x22,0xfe,0xd2,0x23,0xfe,0xd4,0x24,0xfe,0xd6,0x25,0xfe,0xd7,0x26,0xfe,0xd9,0x27,0xfe,0xdb,0x29,0xfe,0xdc,0x2a,0xfe,0xde,0x2c,0xfe,0xe0,0x2d,0xfe,0xe1,0x2e,0xfe,0xe3,0x30,0xfe,0xe4,0x32,0xfe,0xe5,0x33,0xfe,0xe7,0x35,0xfe,0xe8,0x37,0xfe,0xe9,0x38,0xfe,0xeb,0x3a,0xfe,0xec,0x3c,0xfe,0xed,0x3e,0xfe,0xee,0x3f,0xfe,0xef,0x41,0xfe,0xf0,0x43,0xfe,0xf1,0x45,0xfe,0xf2,0x47,0xfe,0xf3,0x49,0xfe,0xf4,0x4b,0xfe,0xf5,0x4d,0xfe,0xf6,0x4f,0xfe,0xf7,0x51,0xfe,0xf8,0x53,0xfe,0xf8,0x55,0xfe,0xf9,0x57,0xfe,0xfa,0x59,0xfe,0xfa,0x5b,0xfe,0xfb,0x5d,0xfe,0xfb,0x5f,0xfe,0xfc,0x61,0xfe,0xfc,0x63,0xfe,0xfc,0x65,0xfe,0xfd,0x67,0xfe,0xfd,0x6a,0xfe,0xfd,0x6c,0xfd,0xfd,0x6e,0xfd,0xfe,0x70,0xfd,0xfe,0x72,0xfd,0xfe,0x74,0xfd,0xfe,0x76,0xfd,0xfe,0x78,0xfd,0xfe,0x7b,0xfd,0xfe,0x7d,0xfd,0xfe,0x7f,0xfd,0xfe,0x81,0xfd,0xfe,0x83,0xfd,0xfe,0x85,0xfd,0xfe,0x87,0xfd,0xfe,0x88,0xfd,0xfe,0x8a,0xfd,0xfe,0x8c,0xfd,0xfe,0x8e,0xfd,0xfe,0x90,0xfd,0xfe,0x92,0xfd,0xfe,0x94,0xfd,0xfe,0x95,0xfd,0xfe,0x97,0xfd,0xfe,0x99,0xfd,0xfe,0x9b,0xfd,0xfe,0x9c,0xfd,0xfe,0x9e,0xfd,0xfe,0xa0,0xfd,0xfe,0xa2,0xfd,0xfe,0xa3,0xfd,0xfe,0xa5,0xfd,0xfe,0xa7,0xfd,0xfe,0xa8,0xfd,0xfe,0xaa,0xfd,0xfe,0xac,0xfd,0xfe,0xad,0xfd,0xfe,0xaf,0xfd,0xfe,0xb1,0xfe,0xfe,0xb2,0xfe,0xfe,0xb4,0xfe,0xfe,0xb5,0xfe,0xfe,0xb7,0xfe,0xfe,0xb9,0xfe,0xfe,0xba,0xfe,0xfe,0xbc,0xfe,0xfe,0xbd,0xfe,0xfe,0xbf,0xfe,0xfe,0xc1,0xfe,0xfe,0xc2,0xfe,0xff,0xc4,0xfe,0xff,0xc5,0xfe,0xff,0xc7,0xfe,0xff,0xc8,0xfe,0xff,0xca,0xfe,0xff,0xcb,0xfe,0xff,0xcd,0xfe,0xff,0xce,0xfe,0xff,0xd0,0xfe,0xff,0xd1,0xfe,0xff,0xd3,0xfe,0xff,0xd4,0xfe,0xff,0xd6,0xfe,0xff,0xd7,0xfe,0xff,0xd9,0xfe,0xff,0xda,0xfe,0xff,0xdc,0xfe,0xff,0xdd,0xfe,0xff,0xdf,0xfe,0xff,0xe0,0xfe,0xff,0xe2,0xfe,0xff,0xe3,0xfe,0xff,0xe5,0xfe,0xfe,0xe6,0xfe,0xfe,0xe8,0xfe,0xfe,0xe9,0xfe,0xfe,0xeb,0xfe};
	static constexpr std::array<uint8_t, 768> L08  = {0x00,0x0f,0x5d,0x01,0x0f,0x5e,0x01,0x10,0x60,0x01,0x10,0x62,0x01,0x11,0x63,0x02,0x11,0x65,0x02,0x12,0x67,0x03,0x12,0x68,0x04,0x12,0x6a,0x05,0x13,0x6b,0x06,0x13,0x6d,0x07,0x14,0x6f,0x08,0x14,0x70,0x0a,0x15,0x72,0x0c,0x15,0x73,0x0d,0x15,0x75,0x0f,0x16,0x76,0x11,0x16,0x77,0x12,0x16,0x79,0x14,0x17,0x7a,0x16,0x17,0x7c,0x18,0x17,0x7d,0x19,0x18,0x7e,0x1b,0x18,0x80,0x1d,0x18,0x81,0x1f,0x19,0x82,0x21,0x19,0x83,0x23,0x19,0x85,0x25,0x19,0x86,0x27,0x1a,0x87,0x29,0x1a,0x88,0x2b,0x1a,0x89,0x2e,0x1a,0x8a,0x30,0x1a,0x8b,0x32,0x1b,0x8c,0x34,0x1b,0x8d,0x37,0x1b,0x8e,0x39,0x1b,0x8f,0x3b,0x1b,0x8f,0x3e,0x1b,0x90,0x40,0x1b,0x90,0x43,0x1a,0x91,0x46,0x1a,0x91,0x48,0x1a,0x92,0x4b,0x1a,0x92,0x4e,0x19,0x92,0x51,0x19,0x92,0x54,0x19,0x92,0x56,0x18,0x92,0x59,0x18,0x92,0x5c,0x17,0x92,0x5e,0x17,0x92,0x61,0x17,0x92,0x63,0x16,0x92,0x66,0x16,0x92,0x68,0x15,0x92,0x6b,0x15,0x92,0x6d,0x14,0x92,0x6f,0x14,0x92,0x72,0x13,0x92,0x74,0x13,0x92,0x76,0x12,0x91,0x79,0x12,0x91,0x7b,0x11,0x91,0x7d,0x11,0x91,0x7f,0x10,0x91,0x81,0x10,0x91,0x83,0x0f,0x90,0x86,0x0f,0x90,0x88,0x0e,0x90,0x8a,0x0e,0x90,0x8c,0x0d,0x8f,0x8e,0x0d,0x8f,0x90,0x0d,0x8f,0x92,0x0c,0x8e,0x94,0x0c,0x8e,0x96,0x0b,0x8e,0x98,0x0b,0x8d,0x9a,0x0b,0x8d,0x9c,0x0a,0x8c,0x9e,0x0a,0x8c,0xa0,0x0a,0x8c,0xa2,0x0a,0x8b,0xa3,0x0a,0x8b,0xa5,0x09,0x8a,0xa7,0x09,0x8a,0xa9,0x09,0x8a,0xab,0x09,0x89,0xad,0x09,0x89,0xae,0x0a,0x88,0xb0,0x0a,0x88,0xb2,0x0a,0x88,0xb4,0x0a,0x87,0xb6,0x0a,0x87,0xb7,0x0b,0x86,0xb9,0x0b,0x86,0xbb,0x0c,0x85,0xbd,0x0c,0x85,0xbe,0x0d,0x85,0xc0,0x0d,0x84,0xc2,0x0e,0x84,0xc3,0x0e,0x83,0xc5,0x0f,0x83,0xc7,0x10,0x82,0xc8,0x10,0x82,0xca,0x11,0x81,0xcc,0x12,0x81,0xcd,0x13,0x80,0xcf,0x14,0x80,0xd0,0x15,0x7f,0xd2,0x16,0x7f,0xd3,0x17,0x7e,0xd5,0x19,0x7d,0xd6,0x1a,0x7d,0xd8,0x1c,0x7c,0xd9,0x1d,0x7b,0xda,0x1f,0x7b,0xdc,0x20,0x7a,0xdd,0x22,0x79,0xde,0x23,0x78,0xdf,0x25,0x78,0xe0,0x27,0x77,0xe2,0x29,0x76,0xe3,0x2a,0x75,0xe4,0x2c,0x74,0xe5,0x2e,0x73,0xe6,0x30,0x72,0xe7,0x31,0x72,0xe8,0x33,0x71,0xe9,0x35,0x70,0xea,0x37,0x6f,0xeb,0x39,0x6e,0xec,0x3b,0x6c,0xed,0x3d,0x6b,0xed,0x3e,0x6a,0xee,0x40,0x69,0xef,0x42,0x68,0xf0,0x44,0x67,0xf0,0x46,0x66,0xf1,0x48,0x65,0xf2,0x4a,0x64,0xf2,0x4c,0x62,0xf3,0x4d,0x61,0xf3,0x4f,0x60,0xf4,0x51,0x5f,0xf4,0x53,0x5e,0xf5,0x55,0x5d,0xf5,0x57,0x5c,0xf6,0x58,0x5c,0xf6,0x5a,0x5b,0xf7,0x5c,0x5a,0xf7,0x5e,0x59,0xf7,0x60,0x58,0xf8,0x62,0x57,0xf8,0x64,0x56,0xf8,0x65,0x55,0xf8,0x67,0x55,0xf8,0x69,0x54,0xf9,0x6b,0x53,0xf9,0x6d,0x52,0xf9,0x6f,0x52,0xf9,0x70,0x51,0xf9,0x72,0x50,0xf9,0x74,0x4f,0xf9,0x76,0x4f,0xf9,0x78,0x4e,0xf9,0x7a,0x4d,0xf9,0x7b,0x4d,0xf9,0x7d,0x4c,0xf9,0x7f,0x4c,0xf9,0x81,0x4b,0xf9,0x82,0x4a,0xf9,0x84,0x4a,0xf9,0x86,0x49,0xf9,0x87,0x48,0xf9,0x89,0x48,0xf9,0x8a,0x47,0xf9,0x8c,0x46,0xf9,0x8e,0x46,0xf9,0x8f,0x45,0xf9,0x91,0x44,0xf9,0x92,0x44,0xf9,0x94,0x43,0xf9,0x95,0x42,0xf9,0x97,0x42,0xfa,0x98,0x41,0xfa,0x9a,0x41,0xfa,0x9b,0x40,0xfa,0x9d,0x3f,0xfa,0x9e,0x3f,0xfa,0x9f,0x3e,0xfa,0xa1,0x3d,0xfb,0xa2,0x3d,0xfb,0xa4,0x3c,0xfb,0xa5,0x3b,0xfb,0xa6,0x3b,0xfb,0xa8,0x3a,0xfc,0xa9,0x39,0xfc,0xab,0x39,0xfc,0xac,0x39,0xfc,0xad,0x38,0xfc,0xaf,0x38,0xfc,0xb0,0x38,0xfc,0xb1,0x38,0xfc,0xb3,0x38,0xfc,0xb4,0x38,0xfc,0xb6,0x38,0xfd,0xb7,0x38,0xfd,0xb8,0x38,0xfd,0xba,0x38,0xfd,0xbb,0x38,0xfd,0xbd,0x38,0xfd,0xbe,0x38,0xfd,0xbf,0x38,0xfd,0xc1,0x39,0xfd,0xc2,0x39,0xfc,0xc3,0x39,0xfc,0xc5,0x39,0xfc,0xc6,0x3a,0xfc,0xc8,0x3a,0xfc,0xc9,0x3a,0xfc,0xca,0x3b,0xfc,0xcc,0x3b,0xfc,0xcd,0x3b,0xfc,0xce,0x3c,0xfc,0xd0,0x3c,0xfc,0xd1,0x3d,0xfc,0xd3,0x3d,0xfb,0xd4,0x3e,0xfb,0xd5,0x3e,0xfb,0xd7,0x3f,0xfb,0xd8,0x3f,0xfb,0xd9,0x40,0xfb,0xdb,0x40,0xfb,0xdc,0x41,0xfa,0xde,0x41,0xfa,0xdf,0x42,0xfa,0xe0,0x42,0xfa,0xe2,0x43,0xfa,0xe3,0x43,0xf9,0xe4,0x44,0xf9,0xe6,0x45,0xf9,0xe7,0x45,0xf9,0xe8,0x46,0xf8,0xea,0x46,0xf8,0xeb,0x47,0xf8,0xed,0x48,0xf8,0xee,0x48,0xf7,0xef,0x49,0xf7,0xf1,0x4a,0xf7,0xf2,0x4a,0xf7,0xf3,0x4b,0xf6,0xf5,0x4c,0xf6,0xf6,0x4c,0xf6,0xf7,0x4d,0xf5,0xf9,0x4e};
	static constexpr std::array<uint8_t, 768> L09  = {0x05,0x00,0xac,0x06,0x02,0xac,0x06,0x05,0xac,0x07,0x08,0xad,0x07,0x0b,0xad,0x08,0x0e,0xad,0x08,0x10,0xae,0x08,0x12,0xae,0x09,0x14,0xae,0x09,0x16,0xaf,0x0a,0x18,0xaf,0x0a,0x1a,0xaf,0x0a,0x1c,0xb0,0x0b,0x1d,0xb0,0x0b,0x1f,0xb0,0x0b,0x20,0xb1,0x0c,0x22,0xb1,0x0c,0x23,0xb1,0x0c,0x25,0xb1,0x0c,0x26,0xb2,0x0d,0x28,0xb2,0x0d,0x29,0xb2,0x0d,0x2a,0xb2,0x0d,0x2c,0xb3,0x0d,0x2d,0xb3,0x0d,0x2e,0xb3,0x0d,0x30,0xb3,0x0e,0x31,0xb4,0x0e,0x32,0xb4,0x0e,0x33,0xb4,0x0e,0x35,0xb4,0x0e,0x36,0xb4,0x0e,0x37,0xb4,0x0e,0x38,0xb4,0x0e,0x3a,0xb5,0x0e,0x3b,0xb5,0x0e,0x3c,0xb5,0x0e,0x3d,0xb5,0x0e,0x3e,0xb5,0x0e,0x40,0xb5,0x0d,0x41,0xb5,0x0d,0x42,0xb5,0x0d,0x43,0xb5,0x0d,0x44,0xb5,0x0d,0x46,0xb5,0x0d,0x47,0xb5,0x0d,0x48,0xb5,0x0c,0x49,0xb5,0x0c,0x4a,0xb5,0x0c,0x4c,0xb4,0x0c,0x4d,0xb4,0x0b,0x4e,0xb4,0x0b,0x4f,0xb4,0x0b,0x50,0xb4,0x0a,0x51,0xb3,0x0a,0x53,0xb3,0x0a,0x54,0xb3,0x09,0x55,0xb2,0x09,0x56,0xb2,0x08,0x57,0xb1,0x08,0x59,0xb1,0x08,0x5a,0xb0,0x07,0x5b,0xaf,0x07,0x5c,0xae,0x06,0x5e,0xae,0x06,0x5f,0xad,0x06,0x60,0xac,0x06,0x61,0xaa,0x06,0x63,0xa9,0x07,0x64,0xa8,0x08,0x65,0xa7,0x0a,0x66,0xa5,0x0c,0x67,0xa4,0x0d,0x68,0xa3,0x0f,0x6a,0xa1,0x11,0x6b,0xa0,0x13,0x6c,0x9e,0x14,0x6d,0x9c,0x16,0x6e,0x9b,0x18,0x6f,0x99,0x19,0x71,0x98,0x1b,0x72,0x96,0x1d,0x73,0x94,0x1e,0x74,0x92,0x1f,0x75,0x91,0x21,0x76,0x8f,0x22,0x77,0x8d,0x23,0x78,0x8b,0x24,0x79,0x89,0x25,0x7a,0x87,0x26,0x7c,0x85,0x27,0x7d,0x83,0x28,0x7e,0x81,0x29,0x7f,0x7f,0x2a,0x80,0x7d,0x2b,0x81,0x7b,0x2c,0x82,0x79,0x2c,0x83,0x77,0x2d,0x84,0x75,0x2e,0x85,0x72,0x2e,0x86,0x70,0x2e,0x87,0x6e,0x2f,0x89,0x6c,0x2f,0x8a,0x69,0x30,0x8b,0x67,0x30,0x8c,0x64,0x30,0x8d,0x62,0x30,0x8e,0x60,0x30,0x8f,0x5d,0x31,0x90,0x5b,0x31,0x91,0x59,0x31,0x92,0x56,0x32,0x93,0x54,0x32,0x94,0x52,0x33,0x95,0x50,0x34,0x96,0x4e,0x34,0x97,0x4c,0x35,0x98,0x4a,0x36,0x99,0x48,0x37,0x9a,0x47,0x38,0x9b,0x45,0x39,0x9c,0x43,0x3a,0x9d,0x41,0x3b,0x9d,0x40,0x3c,0x9e,0x3e,0x3d,0x9f,0x3c,0x3e,0xa0,0x3b,0x40,0xa1,0x39,0x41,0xa2,0x37,0x42,0xa3,0x36,0x44,0xa4,0x34,0x45,0xa4,0x33,0x47,0xa5,0x31,0x48,0xa6,0x30,0x4a,0xa7,0x2e,0x4c,0xa8,0x2d,0x4d,0xa8,0x2c,0x4f,0xa9,0x2a,0x51,0xaa,0x29,0x52,0xab,0x27,0x54,0xac,0x26,0x56,0xac,0x24,0x58,0xad,0x23,0x59,0xae,0x22,0x5b,0xaf,0x20,0x5d,0xaf,0x1f,0x5f,0xb0,0x1e,0x61,0xb1,0x1c,0x63,0xb2,0x1b,0x65,0xb2,0x1a,0x67,0xb3,0x18,0x69,0xb4,0x17,0x6b,0xb4,0x16,0x6d,0xb5,0x14,0x6f,0xb6,0x13,0x71,0xb6,0x12,0x73,0xb7,0x10,0x75,0xb8,0x0f,0x77,0xb8,0x0e,0x79,0xb9,0x0c,0x7b,0xba,0x0b,0x7d,0xba,0x0a,0x7f,0xbb,0x08,0x82,0xbc,0x07,0x84,0xbc,0x06,0x86,0xbd,0x06,0x88,0xbe,0x05,0x8a,0xbe,0x04,0x8c,0xbf,0x04,0x8f,0xbf,0x03,0x91,0xc0,0x03,0x93,0xc0,0x03,0x95,0xc1,0x02,0x98,0xc2,0x02,0x9a,0xc2,0x02,0x9c,0xc3,0x02,0x9e,0xc3,0x02,0xa0,0xc4,0x03,0xa2,0xc4,0x03,0xa5,0xc5,0x03,0xa7,0xc6,0x03,0xa9,0xc6,0x03,0xab,0xc7,0x04,0xad,0xc7,0x04,0xaf,0xc8,0x04,0xb1,0xc8,0x05,0xb3,0xc9,0x05,0xb5,0xca,0x06,0xb7,0xca,0x06,0xb9,0xcb,0x07,0xbb,0xcb,0x08,0xbd,0xcc,0x09,0xbf,0xcc,0x0a,0xc1,0xcd,0x0b,0xc2,0xce,0x0c,0xc4,0xce,0x0d,0xc6,0xcf,0x0e,0xc8,0xcf,0x0f,0xca,0xd0,0x10,0xcc,0xd1,0x11,0xcd,0xd1,0x12,0xcf,0xd2,0x13,0xd1,0xd2,0x14,0xd3,0xd3,0x15,0xd4,0xd4,0x17,0xd6,0xd4,0x18,0xd8,0xd5,0x19,0xd9,0xd6,0x1a,0xdb,0xd6,0x1c,0xdd,0xd7,0x1d,0xde,0xd7,0x1e,0xe0,0xd8,0x20,0xe1,0xd9,0x21,0xe3,0xda,0x22,0xe4,0xda,0x24,0xe6,0xdb,0x25,0xe7,0xdc,0x27,0xe9,0xdc,0x28,0xea,0xdd,0x2a,0xeb,0xde,0x2c,0xec,0xdf,0x2d,0xee,0xdf,0x2f,0xef,0xe0,0x31,0xf0,0xe1,0x33,0xf1,0xe2,0x34,0xf2,0xe3,0x36,0xf3,0xe3,0x38,0xf3,0xe4,0x3b,0xf4,0xe5,0x3d,0xf5,0xe6,0x3f,0xf5,0xe7,0x42,0xf6,0xe8,0x45,0xf6,0xe9,0x48,0xf7,0xea,0x4b,0xf8,0xeb,0x4f,0xf8,0xec,0x53,0xf9,0xed,0x58,0xfa,0xed,0x5d,0xfa,0xee,0x62,0xfb,0xef,0x67,0xfc,0xf0,0x6d,0xfc,0xf1,0x73,0xfd,0xf1,0x79,0xfd,0xf2,0x80,0xfe,0xf3,0x87,0xfe,0xf3,0x8e,0xff,0xf4,0x96,0xff,0xf5,0x9f,0xff,0xf5,0xa8,0xff,0xf6,0xb1,0xff,0xf7,0xbb,0xff,0xf7,0xc6,0xfe,0xf8,0xd2,0xfd,0xf8,0xde,0xfb,0xf9,0xeb,0xf9,0xf9,0xf9};
	static constexpr std::array<uint8_t, 768> L10  = {0x66,0x9b,0x90,0x66,0x9b,0x8f,0x67,0x9b,0x8f,0x68,0x9b,0x8f,0x69,0x9c,0x8e,0x69,0x9c,0x8e,0x6a,0x9c,0x8d,0x6b,0x9c,0x8d,0x6b,0x9d,0x8c,0x6c,0x9d,0x8c,0x6d,0x9d,0x8b,0x6e,0x9d,0x8b,0x6e,0x9d,0x8a,0x6f,0x9e,0x8a,0x70,0x9e,0x89,0x71,0x9e,0x89,0x71,0x9e,0x89,0x72,0x9f,0x88,0x73,0x9f,0x88,0x74,0x9f,0x87,0x74,0x9f,0x87,0x75,0x9f,0x86,0x76,0xa0,0x86,0x77,0xa0,0x85,0x77,0xa0,0x85,0x78,0xa0,0x85,0x79,0xa1,0x84,0x7a,0xa1,0x84,0x7b,0xa1,0x83,0x7b,0xa1,0x83,0x7c,0xa1,0x82,0x7d,0xa2,0x82,0x7e,0xa2,0x81,0x7f,0xa2,0x81,0x7f,0xa2,0x81,0x80,0xa2,0x80,0x81,0xa2,0x80,0x82,0xa3,0x7f,0x83,0xa3,0x7f,0x84,0xa3,0x7f,0x84,0xa3,0x7e,0x85,0xa3,0x7e,0x86,0xa4,0x7d,0x87,0xa4,0x7d,0x88,0xa4,0x7d,0x89,0xa4,0x7c,0x8a,0xa4,0x7c,0x8b,0xa4,0x7b,0x8c,0xa4,0x7b,0x8c,0xa5,0x7b,0x8d,0xa5,0x7a,0x8e,0xa5,0x7a,0x8f,0xa5,0x7a,0x90,0xa5,0x79,0x91,0xa5,0x79,0x92,0xa5,0x78,0x93,0xa5,0x78,0x94,0xa6,0x78,0x95,0xa6,0x77,0x96,0xa6,0x77,0x97,0xa6,0x77,0x99,0xa6,0x76,0x9a,0xa6,0x76,0x9b,0xa6,0x76,0x9c,0xa6,0x76,0x9d,0xa6,0x75,0x9e,0xa6,0x75,0x9f,0xa6,0x75,0xa1,0xa6,0x74,0xa2,0xa6,0x74,0xa3,0xa6,0x74,0xa4,0xa6,0x74,0xa6,0xa6,0x73,0xa7,0xa6,0x73,0xa8,0xa6,0x73,0xaa,0xa6,0x73,0xab,0xa6,0x73,0xac,0xa6,0x72,0xae,0xa6,0x72,0xaf,0xa6,0x72,0xb1,0xa6,0x72,0xb2,0xa6,0x72,0xb3,0xa6,0x72,0xb4,0xa6,0x71,0xb6,0xa6,0x71,0xb7,0xa6,0x71,0xb8,0xa6,0x71,0xb9,0xa6,0x71,0xba,0xa6,0x71,0xbb,0xa6,0x70,0xbc,0xa6,0x70,0xbd,0xa6,0x70,0xbf,0xa6,0x70,0xc0,0xa6,0x70,0xc0,0xa6,0x6f,0xc1,0xa6,0x6f,0xc2,0xa6,0x6f,0xc3,0xa6,0x6f,0xc4,0xa6,0x6f,0xc5,0xa6,0x6f,0xc6,0xa6,0x6e,0xc7,0xa6,0x6e,0xc7,0xa6,0x6e,0xc8,0xa7,0x6e,0xc9,0xa7,0x6e,0xca,0xa7,0x6e,0xca,0xa7,0x6d,0xcb,0xa7,0x6d,0xcc,0xa7,0x6d,0xcc,0xa7,0x6d,0xcd,0xa7,0x6d,0xcd,0xa8,0x6d,0xce,0xa8,0x6c,0xcf,0xa8,0x6c,0xcf,0xa8,0x6c,0xd0,0xa8,0x6c,0xd0,0xa9,0x6c,0xd0,0xa9,0x6c,0xd1,0xa9,0x6b,0xd1,0xa9,0x6b,0xd2,0xaa,0x6b,0xd2,0xaa,0x6b,0xd2,0xaa,0x6b,0xd3,0xaa,0x6a,0xd3,0xab,0x6a,0xd3,0xab,0x6a,0xd4,0xab,0x6a,0xd4,0xac,0x6a,0xd4,0xac,0x6a,0xd4,0xac,0x69,0xd4,0xad,0x69,0xd5,0xad,0x69,0xd5,0xad,0x69,0xd5,0xad,0x69,0xd5,0xae,0x69,0xd5,0xae,0x69,0xd5,0xae,0x69,0xd6,0xaf,0x69,0xd6,0xaf,0x69,0xd6,0xaf,0x69,0xd6,0xb0,0x69,0xd6,0xb0,0x6a,0xd6,0xb0,0x6a,0xd7,0xb1,0x6a,0xd7,0xb1,0x6a,0xd7,0xb1,0x6a,0xd7,0xb2,0x6b,0xd7,0xb2,0x6b,0xd7,0xb2,0x6b,0xd7,0xb3,0x6c,0xd7,0xb3,0x6c,0xd8,0xb3,0x6d,0xd8,0xb4,0x6d,0xd8,0xb4,0x6d,0xd8,0xb4,0x6e,0xd8,0xb5,0x6e,0xd8,0xb5,0x6f,0xd8,0xb5,0x70,0xd8,0xb6,0x70,0xd8,0xb6,0x71,0xd8,0xb6,0x71,0xd8,0xb7,0x72,0xd8,0xb7,0x73,0xd8,0xb7,0x73,0xd9,0xb8,0x74,0xd9,0xb8,0x75,0xd9,0xb8,0x76,0xd9,0xb8,0x76,0xd9,0xb9,0x77,0xd9,0xb9,0x78,0xd9,0xb9,0x79,0xd9,0xba,0x7a,0xd9,0xba,0x7b,0xd9,0xba,0x7c,0xd9,0xbb,0x7d,0xd9,0xbb,0x7e,0xd9,0xbb,0x7f,0xd9,0xbc,0x80,0xd8,0xbc,0x81,0xd8,0xbc,0x82,0xd8,0xbd,0x83,0xd8,0xbd,0x84,0xd8,0xbd,0x85,0xd8,0xbe,0x87,0xd8,0xbe,0x88,0xd8,0xbe,0x89,0xd8,0xbf,0x8a,0xd8,0xbf,0x8b,0xd8,0xbf,0x8c,0xd8,0xc0,0x8d,0xd8,0xc0,0x8e,0xd8,0xc0,0x8f,0xd8,0xc1,0x90,0xd8,0xc1,0x91,0xd8,0xc1,0x92,0xd8,0xc2,0x94,0xd8,0xc2,0x95,0xd8,0xc2,0x96,0xd8,0xc3,0x97,0xd8,0xc3,0x98,0xd8,0xc3,0x99,0xd8,0xc4,0x9a,0xd8,0xc4,0x9b,0xd8,0xc4,0x9c,0xd7,0xc5,0x9d,0xd7,0xc5,0x9e,0xd7,0xc5,0x9f,0xd7,0xc5,0xa1,0xd7,0xc6,0xa2,0xd7,0xc6,0xa3,0xd7,0xc6,0xa4,0xd7,0xc7,0xa5,0xd7,0xc7,0xa6,0xd7,0xc7,0xa7,0xd7,0xc8,0xa8,0xd7,0xc8,0xa9,0xd7,0xc8,0xaa,0xd7,0xc9,0xab,0xd7,0xc9,0xac,0xd7,0xc9,0xad,0xd7,0xca,0xaf,0xd7,0xca,0xb0,0xd7,0xca,0xb1,0xd7,0xca,0xb2,0xd7,0xcb,0xb3,0xd7,0xcb,0xb4,0xd7,0xcb,0xb5,0xd6,0xcc,0xb6,0xd6,0xcc,0xb7,0xd6,0xcc,0xb8,0xd6,0xcd,0xb9,0xd6,0xcd,0xba,0xd6,0xcd,0xbb,0xd6,0xce,0xbd,0xd6,0xce,0xbe,0xd6,0xce,0xbf,0xd6,0xce,0xc0,0xd6,0xcf,0xc1,0xd6,0xcf,0xc2,0xd6,0xcf,0xc3,0xd6,0xd0,0xc4,0xd6,0xd0,0xc5,0xd5,0xd0,0xc6,0xd5,0xd1,0xc7,0xd5,0xd1,0xc8,0xd5,0xd1,0xc9,0xd5,0xd1,0xcb,0xd5,0xd2,0xcc,0xd5,0xd2,0xcd,0xd5,0xd2,0xce,0xd5,0xd3,0xcf,0xd5,0xd3,0xd0,0xd5,0xd3,0xd1,0xd4,0xd4,0xd2,0xd4,0xd4,0xd3,0xd4,0xd4,0xd4};
	static constexpr std::array<uint8_t, 768> L11  = {0x70,0xad,0x5c,0x71,0xad,0x5c,0x72,0xad,0x5c,0x74,0xad,0x5c,0x75,0xad,0x5c,0x76,0xad,0x5d,0x78,0xad,0x5d,0x79,0xad,0x5d,0x7a,0xae,0x5d,0x7c,0xae,0x5d,0x7d,0xae,0x5d,0x7e,0xae,0x5d,0x80,0xae,0x5d,0x81,0xae,0x5d,0x82,0xae,0x5e,0x83,0xae,0x5e,0x85,0xae,0x5e,0x86,0xae,0x5e,0x87,0xae,0x5e,0x88,0xae,0x5e,0x8a,0xae,0x5e,0x8b,0xae,0x5e,0x8c,0xae,0x5f,0x8d,0xaf,0x5f,0x8e,0xaf,0x5f,0x90,0xaf,0x5f,0x91,0xaf,0x5f,0x92,0xaf,0x5f,0x93,0xaf,0x5f,0x94,0xaf,0x5f,0x95,0xaf,0x5f,0x96,0xaf,0x60,0x98,0xaf,0x60,0x99,0xaf,0x60,0x9a,0xaf,0x60,0x9b,0xaf,0x60,0x9c,0xaf,0x60,0x9d,0xaf,0x60,0x9e,0xaf,0x60,0x9f,0xaf,0x61,0xa0,0xb0,0x61,0xa1,0xb0,0x61,0xa3,0xb0,0x61,0xa4,0xb0,0x61,0xa5,0xb0,0x61,0xa6,0xb0,0x61,0xa7,0xb0,0x61,0xa8,0xb0,0x62,0xa9,0xb0,0x62,0xaa,0xb0,0x62,0xab,0xb0,0x62,0xac,0xb0,0x62,0xad,0xb0,0x62,0xae,0xb0,0x62,0xaf,0xb0,0x62,0xb0,0xb0,0x63,0xb1,0xb0,0x63,0xb2,0xb0,0x63,0xb3,0xb0,0x63,0xb4,0xb1,0x63,0xb5,0xb1,0x63,0xb6,0xb1,0x63,0xb7,0xb1,0x64,0xb8,0xb1,0x64,0xb9,0xb1,0x64,0xba,0xb1,0x64,0xbb,0xb1,0x64,0xbc,0xb1,0x64,0xbd,0xb1,0x64,0xbe,0xb1,0x64,0xbf,0xb1,0x65,0xc0,0xb1,0x65,0xc1,0xb1,0x65,0xc1,0xb1,0x65,0xc2,0xb1,0x65,0xc3,0xb1,0x65,0xc4,0xb1,0x65,0xc5,0xb2,0x66,0xc6,0xb2,0x66,0xc7,0xb2,0x66,0xc8,0xb2,0x66,0xc9,0xb2,0x66,0xca,0xb2,0x66,0xca,0xb2,0x66,0xcb,0xb2,0x66,0xcc,0xb2,0x67,0xcd,0xb2,0x67,0xce,0xb2,0x67,0xcf,0xb2,0x67,0xcf,0xb2,0x67,0xd0,0xb2,0x67,0xd1,0xb2,0x67,0xd2,0xb3,0x68,0xd3,0xb3,0x68,0xd4,0xb3,0x68,0xd4,0xb3,0x68,0xd5,0xb3,0x68,0xd6,0xb3,0x68,0xd7,0xb3,0x68,0xd7,0xb3,0x69,0xd8,0xb3,0x69,0xd9,0xb3,0x69,0xda,0xb3,0x69,0xda,0xb4,0x69,0xdb,0xb4,0x69,0xdc,0xb4,0x69,0xdc,0xb4,0x6a,0xdd,0xb4,0x6a,0xde,0xb4,0x6a,0xde,0xb4,0x6a,0xdf,0xb4,0x6a,0xe0,0xb5,0x6a,0xe0,0xb5,0x6b,0xe1,0xb5,0x6b,0xe1,0xb5,0x6b,0xe2,0xb5,0x6b,0xe2,0xb5,0x6b,0xe3,0xb6,0x6b,0xe3,0xb6,0x6b,0xe4,0xb6,0x6c,0xe4,0xb6,0x6c,0xe5,0xb6,0x6c,0xe5,0xb7,0x6c,0xe5,0xb7,0x6c,0xe6,0xb7,0x6c,0xe6,0xb7,0x6d,0xe6,0xb8,0x6d,0xe6,0xb8,0x6d,0xe6,0xb8,0x6d,0xe6,0xb9,0x6d,0xe7,0xb9,0x6e,0xe7,0xb9,0x6e,0xe7,0xba,0x6e,0xe7,0xba,0x6e,0xe7,0xbb,0x6f,0xe7,0xbb,0x6f,0xe7,0xbb,0x6f,0xe7,0xbc,0x70,0xe7,0xbc,0x70,0xe7,0xbc,0x71,0xe7,0xbd,0x71,0xe7,0xbd,0x71,0xe7,0xbd,0x72,0xe7,0xbe,0x72,0xe7,0xbe,0x73,0xe7,0xbe,0x73,0xe7,0xbf,0x74,0xe7,0xbf,0x74,0xe7,0xc0,0x75,0xe7,0xc0,0x75,0xe7,0xc0,0x76,0xe7,0xc1,0x77,0xe7,0xc1,0x77,0xe7,0xc1,0x78,0xe7,0xc2,0x79,0xe7,0xc2,0x79,0xe7,0xc2,0x7a,0xe7,0xc3,0x7b,0xe7,0xc3,0x7c,0xe7,0xc3,0x7c,0xe7,0xc4,0x7d,0xe7,0xc4,0x7e,0xe7,0xc4,0x7f,0xe7,0xc5,0x7f,0xe7,0xc5,0x80,0xe7,0xc5,0x81,0xe7,0xc6,0x82,0xe7,0xc6,0x83,0xe7,0xc6,0x84,0xe7,0xc7,0x85,0xe7,0xc7,0x86,0xe7,0xc8,0x87,0xe7,0xc8,0x88,0xe7,0xc8,0x89,0xe7,0xc9,0x8a,0xe7,0xc9,0x8b,0xe7,0xc9,0x8c,0xe7,0xca,0x8d,0xe7,0xca,0x8e,0xe7,0xca,0x8f,0xe7,0xcb,0x90,0xe7,0xcb,0x91,0xe7,0xcb,0x93,0xe7,0xcc,0x94,0xe7,0xcc,0x95,0xe7,0xcc,0x96,0xe7,0xcd,0x97,0xe6,0xcd,0x98,0xe6,0xcd,0x99,0xe6,0xce,0x9a,0xe6,0xce,0x9b,0xe6,0xce,0x9c,0xe6,0xcf,0x9e,0xe6,0xcf,0x9f,0xe6,0xcf,0xa0,0xe6,0xd0,0xa1,0xe6,0xd0,0xa2,0xe6,0xd0,0xa3,0xe6,0xd0,0xa4,0xe6,0xd1,0xa5,0xe6,0xd1,0xa6,0xe6,0xd1,0xa7,0xe6,0xd2,0xa9,0xe6,0xd2,0xaa,0xe6,0xd2,0xab,0xe6,0xd3,0xac,0xe6,0xd3,0xad,0xe6,0xd3,0xae,0xe6,0xd4,0xaf,0xe6,0xd4,0xb0,0xe5,0xd4,0xb1,0xe5,0xd5,0xb2,0xe5,0xd5,0xb3,0xe5,0xd5,0xb5,0xe5,0xd6,0xb6,0xe5,0xd6,0xb7,0xe5,0xd6,0xb8,0xe5,0xd7,0xb9,0xe5,0xd7,0xba,0xe5,0xd7,0xbb,0xe5,0xd7,0xbc,0xe5,0xd8,0xbd,0xe5,0xd8,0xbe,0xe5,0xd8,0xbf,0xe5,0xd9,0xc1,0xe5,0xd9,0xc2,0xe5,0xd9,0xc3,0xe5,0xda,0xc4,0xe5,0xda,0xc5,0xe4,0xda,0xc6,0xe4,0xdb,0xc7,0xe4,0xdb,0xc8,0xe4,0xdb,0xc9,0xe4,0xdc,0xca,0xe4,0xdc,0xcb,0xe4,0xdc,0xcc,0xe4,0xdc,0xce,0xe4,0xdd,0xcf,0xe4,0xdd,0xd0,0xe4,0xdd,0xd1,0xe4,0xde,0xd2,0xe4,0xde,0xd3,0xe4,0xde,0xd4,0xe3,0xdf,0xd5,0xe3,0xdf,0xd6,0xe3,0xdf,0xd7,0xe3,0xe0,0xd8,0xe3,0xe0,0xda,0xe3,0xe0,0xdb,0xe3,0xe0,0xdc,0xe3,0xe1,0xdd,0xe3,0xe1,0xde,0xe3,0xe1,0xdf,0xe3,0xe2,0xe0,0xe2,0xe2,0xe1,0xe2,0xe2,0xe2};
	static constexpr std::array<uint8_t, 768> L12  = {0xf1,0xf1,0xf1,0xf0,0xf0,0xf1,0xef,0xf0,0xf0,0xee,0xef,0xf0,0xee,0xef,0xf0,0xed,0xee,0xf0,0xec,0xee,0xf0,0xeb,0xed,0xf0,0xea,0xed,0xf0,0xea,0xec,0xf0,0xe9,0xec,0xf0,0xe8,0xeb,0xf0,0xe7,0xeb,0xf0,0xe7,0xea,0xf0,0xe6,0xea,0xf0,0xe5,0xe9,0xf0,0xe4,0xe9,0xf0,0xe4,0xe9,0xef,0xe3,0xe8,0xef,0xe2,0xe8,0xef,0xe1,0xe7,0xef,0xe1,0xe7,0xef,0xe0,0xe6,0xef,0xdf,0xe6,0xef,0xde,0xe5,0xef,0xde,0xe5,0xef,0xdd,0xe4,0xef,0xdc,0xe4,0xef,0xdb,0xe3,0xef,0xda,0xe3,0xef,0xda,0xe2,0xee,0xd9,0xe2,0xee,0xd8,0xe1,0xee,0xd7,0xe1,0xee,0xd7,0xe1,0xee,0xd6,0xe0,0xee,0xd5,0xe0,0xee,0xd4,0xdf,0xee,0xd4,0xdf,0xee,0xd3,0xde,0xee,0xd2,0xde,0xee,0xd1,0xdd,0xee,0xd1,0xdd,0xed,0xd0,0xdc,0xed,0xcf,0xdc,0xed,0xce,0xdb,0xed,0xcd,0xdb,0xed,0xcd,0xda,0xed,0xcc,0xda,0xed,0xcb,0xd9,0xed,0xca,0xd9,0xed,0xca,0xd9,0xed,0xc9,0xd8,0xec,0xc8,0xd8,0xec,0xc7,0xd7,0xec,0xc7,0xd7,0xec,0xc6,0xd6,0xec,0xc5,0xd6,0xec,0xc4,0xd5,0xec,0xc4,0xd5,0xec,0xc3,0xd4,0xec,0xc2,0xd4,0xeb,0xc1,0xd3,0xeb,0xc0,0xd3,0xeb,0xc0,0xd2,0xeb,0xbf,0xd2,0xeb,0xbe,0xd2,0xeb,0xbd,0xd1,0xeb,0xbd,0xd1,0xeb,0xbc,0xd0,0xea,0xbb,0xd0,0xea,0xba,0xcf,0xea,0xba,0xcf,0xea,0xb9,0xce,0xea,0xb8,0xce,0xea,0xb7,0xcd,0xea,0xb7,0xcd,0xe9,0xb6,0xcc,0xe9,0xb5,0xcc,0xe9,0xb4,0xcc,0xe9,0xb4,0xcb,0xe9,0xb3,0xcb,0xe9,0xb2,0xca,0xe9,0xb1,0xca,0xe8,0xb1,0xc9,0xe8,0xb0,0xc9,0xe8,0xaf,0xc8,0xe8,0xae,0xc8,0xe8,0xae,0xc7,0xe7,0xad,0xc7,0xe7,0xac,0xc6,0xe7,0xab,0xc6,0xe7,0xab,0xc5,0xe7,0xaa,0xc5,0xe7,0xa9,0xc5,0xe6,0xa8,0xc4,0xe6,0xa8,0xc4,0xe6,0xa7,0xc3,0xe6,0xa6,0xc3,0xe6,0xa6,0xc2,0xe5,0xa5,0xc2,0xe5,0xa4,0xc1,0xe5,0xa3,0xc1,0xe5,0xa3,0xc0,0xe4,0xa2,0xc0,0xe4,0xa1,0xbf,0xe4,0xa1,0xbf,0xe4,0xa0,0xbf,0xe3,0x9f,0xbe,0xe3,0x9f,0xbe,0xe3,0x9e,0xbd,0xe2,0x9d,0xbd,0xe2,0x9d,0xbc,0xe2,0x9c,0xbc,0xe2,0x9b,0xbb,0xe1,0x9b,0xbb,0xe1,0x9a,0xba,0xe1,0x99,0xba,0xe0,0x99,0xb9,0xe0,0x98,0xb9,0xdf,0x98,0xb8,0xdf,0x97,0xb8,0xdf,0x96,0xb7,0xde,0x96,0xb7,0xde,0x95,0xb7,0xde,0x95,0xb6,0xdd,0x94,0xb6,0xdd,0x93,0xb5,0xdd,0x93,0xb5,0xdc,0x92,0xb4,0xdc,0x92,0xb4,0xdb,0x91,0xb3,0xdb,0x91,0xb3,0xdb,0x90,0xb2,0xda,0x8f,0xb2,0xda,0x8f,0xb1,0xd9,0x8e,0xb1,0xd9,0x8e,0xb0,0xd9,0x8d,0xb0,0xd8,0x8d,0xaf,0xd8,0x8c,0xaf,0xd7,0x8b,0xaf,0xd7,0x8b,0xae,0xd7,0x8a,0xae,0xd6,0x8a,0xad,0xd6,0x89,0xad,0xd5,0x89,0xac,0xd5,0x88,0xac,0xd4,0x88,0xab,0xd4,0x87,0xab,0xd4,0x87,0xaa,0xd3,0x86,0xaa,0xd3,0x85,0xa9,0xd2,0x85,0xa9,0xd2,0x84,0xa8,0xd1,0x84,0xa8,0xd1,0x83,0xa8,0xd0,0x83,0xa7,0xd0,0x82,0xa7,0xd0,0x82,0xa6,0xcf,0x81,0xa6,0xcf,0x81,0xa5,0xce,0x80,0xa5,0xce,0x80,0xa4,0xcd,0x7f,0xa4,0xcd,0x7f,0xa3,0xcc,0x7e,0xa3,0xcc,0x7e,0xa2,0xcb,0x7d,0xa2,0xcb,0x7d,0xa1,0xca,0x7c,0xa1,0xca,0x7c,0xa0,0xc9,0x7c,0xa0,0xc9,0x7b,0xa0,0xc8,0x7b,0x9f,0xc8,0x7a,0x9f,0xc7,0x79,0x9e,0xc7,0x79,0x9e,0xc7,0x78,0x9d,0xc6,0x78,0x9d,0xc6,0x77,0x9c,0xc5,0x77,0x9c,0xc5,0x76,0x9b,0xc5,0x76,0x9b,0xc4,0x75,0x9a,0xc4,0x74,0x9a,0xc3,0x74,0x9a,0xc3,0x73,0x99,0xc3,0x73,0x99,0xc2,0x72,0x98,0xc2,0x71,0x98,0xc2,0x71,0x97,0xc1,0x70,0x97,0xc1,0x6f,0x96,0xc1,0x6f,0x96,0xc0,0x6e,0x96,0xc0,0x6d,0x95,0xc0,0x6d,0x95,0xbf,0x6c,0x94,0xbf,0x6b,0x94,0xbf,0x6b,0x93,0xbe,0x6a,0x93,0xbe,0x69,0x92,0xbe,0x69,0x92,0xbe,0x68,0x91,0xbd,0x67,0x91,0xbd,0x67,0x91,0xbd,0x66,0x90,0xbc,0x65,0x90,0xbc,0x64,0x8f,0xbc,0x64,0x8f,0xbc,0x63,0x8e,0xbb,0x62,0x8e,0xbb,0x61,0x8e,0xbb,0x61,0x8d,0xbb,0x60,0x8d,0xba,0x5f,0x8c,0xba,0x5e,0x8c,0xba,0x5e,0x8b,0xba,0x5d,0x8b,0xb9,0x5c,0x8a,0xb9,0x5b,0x8a,0xb9,0x5a,0x8a,0xb9,0x5a,0x89,0xb8,0x59,0x89,0xb8,0x58,0x88,0xb8,0x57,0x88,0xb8,0x56,0x87,0xb8,0x55,0x87,0xb7,0x54,0x87,0xb7,0x54,0x86,0xb7,0x53,0x86,0xb7,0x52,0x85,0xb6,0x51,0x85,0xb6,0x50,0x84,0xb6,0x4f,0x84,0xb6,0x4e,0x84,0xb6,0x4d,0x83,0xb5,0x4c,0x83,0xb5,0x4b,0x82,0xb5,0x4a,0x82,0xb5,0x4a,0x81,0xb5,0x49,0x81,0xb4,0x48,0x81,0xb4,0x47,0x80,0xb4,0x46,0x80,0xb4,0x45,0x7f,0xb4,0x43,0x7f,0xb3,0x42,0x7e,0xb3,0x41,0x7e,0xb3,0x40,0x7e,0xb3,0x3f,0x7d,0xb3,0x3e,0x7d,0xb2,0x3d,0x7c,0xb2,0x3c,0x7c,0xb2,0x3b,0x7c,0xb2};
	static constexpr std::array<uint8_t, 768> L13  = {0x00,0x00,0x00,0x02,0x00,0x00,0x04,0x01,0x00,0x06,0x01,0x00,0x08,0x02,0x00,0x0a,0x02,0x00,0x0c,0x02,0x00,0x0e,0x03,0x00,0x10,0x03,0x00,0x12,0x03,0x00,0x13,0x04,0x00,0x15,0x04,0x00,0x16,0x04,0x00,0x17,0x04,0x00,0x19,0x05,0x00,0x1a,0x05,0x00,0x1b,0x05,0x00,0x1c,0x05,0x00,0x1e,0x06,0x00,0x1f,0x06,0x00,0x20,0x06,0x00,0x21,0x06,0x00,0x22,0x06,0x00,0x23,0x07,0x00,0x24,0x07,0x00,0x25,0x07,0x00,0x26,0x07,0x00,0x27,0x07,0x00,0x28,0x08,0x00,0x29,0x08,0x00,0x29,0x08,0x00,0x2a,0x08,0x00,0x2b,0x08,0x00,0x2c,0x08,0x00,0x2d,0x08,0x00,0x2e,0x09,0x00,0x2e,0x09,0x00,0x2f,0x09,0x00,0x30,0x09,0x00,0x31,0x09,0x00,0x32,0x09,0x00,0x32,0x0a,0x00,0x33,0x0a,0x00,0x34,0x0a,0x00,0x35,0x0a,0x00,0x35,0x0a,0x00,0x36,0x0a,0x00,0x37,0x0a,0x00,0x37,0x0a,0x00,0x38,0x0b,0x00,0x39,0x0b,0x00,0x3a,0x0b,0x00,0x3a,0x0b,0x00,0x3b,0x0b,0x00,0x3c,0x0b,0x00,0x3d,0x0b,0x00,0x3d,0x0c,0x00,0x3e,0x0c,0x00,0x3f,0x0c,0x00,0x40,0x0c,0x00,0x40,0x0c,0x00,0x41,0x0c,0x00,0x42,0x0c,0x00,0x43,0x0d,0x00,0x44,0x0d,0x00,0x44,0x0d,0x00,0x45,0x0d,0x00,0x46,0x0d,0x00,0x47,0x0d,0x00,0x47,0x0d,0x00,0x48,0x0e,0x00,0x49,0x0e,0x00,0x4a,0x0e,0x00,0x4a,0x0e,0x00,0x4b,0x0e,0x00,0x4c,0x0e,0x00,0x4d,0x0f,0x00,0x4e,0x0f,0x00,0x4e,0x0f,0x00,0x4f,0x0f,0x00,0x50,0x0f,0x00,0x51,0x0f,0x00,0x51,0x0f,0x00,0x52,0x10,0x00,0x53,0x10,0x00,0x54,0x10,0x00,0x55,0x10,0x00,0x55,0x10,0x00,0x56,0x10,0x00,0x57,0x10,0x00,0x58,0x11,0x00,0x58,0x11,0x00,0x59,0x11,0x00,0x5a,0x11,0x00,0x5b,0x11,0x00,0x5c,0x11,0x00,0x5c,0x11,0x00,0x5d,0x12,0x00,0x5e,0x12,0x00,0x5f,0x12,0x00,0x60,0x12,0x00,0x60,0x12,0x00,0x61,0x12,0x00,0x62,0x13,0x00,0x63,0x13,0x00,0x64,0x13,0x00,0x64,0x13,0x00,0x65,0x13,0x00,0x66,0x13,0x00,0x67,0x13,0x00,0x68,0x14,0x00,0x68,0x14,0x00,0x69,0x14,0x00,0x6a,0x14,0x00,0x6b,0x14,0x00,0x6c,0x14,0x00,0x6d,0x14,0x00,0x6d,0x15,0x00,0x6e,0x15,0x00,0x6f,0x15,0x00,0x70,0x15,0x00,0x71,0x15,0x00,0x71,0x15,0x00,0x72,0x16,0x00,0x73,0x16,0x00,0x74,0x16,0x00,0x75,0x16,0x00,0x76,0x16,0x00,0x76,0x16,0x00,0x77,0x17,0x00,0x78,0x17,0x00,0x79,0x17,0x00,0x7a,0x17,0x00,0x7a,0x17,0x00,0x7b,0x17,0x00,0x7c,0x17,0x00,0x7d,0x18,0x00,0x7e,0x18,0x00,0x7f,0x18,0x00,0x7f,0x18,0x00,0x80,0x18,0x00,0x81,0x18,0x00,0x82,0x19,0x00,0x83,0x19,0x00,0x84,0x19,0x00,0x84,0x19,0x00,0x85,0x19,0x00,0x86,0x19,0x00,0x87,0x19,0x00,0x88,0x1a,0x00,0x89,0x1a,0x00,0x8a,0x1a,0x00,0x8a,0x1a,0x00,0x8b,0x1a,0x00,0x8c,0x1a,0x00,0x8d,0x1b,0x00,0x8e,0x1b,0x00,0x8f,0x1b,0x00,0x8f,0x1b,0x00,0x90,0x1b,0x00,0x91,0x1b,0x00,0x92,0x1c,0x00,0x93,0x1c,0x00,0x94,0x1c,0x00,0x95,0x1c,0x00,0x95,0x1c,0x00,0x96,0x1c,0x00,0x97,0x1d,0x00,0x98,0x1d,0x00,0x99,0x1d,0x00,0x9a,0x1d,0x00,0x9b,0x1d,0x00,0x9b,0x1d,0x00,0x9c,0x1e,0x00,0x9d,0x1e,0x00,0x9e,0x1e,0x00,0x9f,0x1e,0x00,0xa0,0x1e,0x00,0xa1,0x1e,0x00,0xa1,0x1e,0x00,0xa2,0x1f,0x00,0xa3,0x1f,0x00,0xa4,0x1f,0x00,0xa5,0x1f,0x00,0xa6,0x1f,0x00,0xa7,0x1f,0x00,0xa8,0x20,0x00,0xa8,0x20,0x00,0xa9,0x20,0x00,0xaa,0x20,0x00,0xab,0x20,0x00,0xac,0x20,0x00,0xad,0x21,0x00,0xae,0x21,0x00,0xaf,0x21,0x00,0xaf,0x21,0x00,0xb0,0x21,0x00,0xb1,0x21,0x00,0xb2,0x22,0x00,0xb3,0x22,0x00,0xb4,0x22,0x00,0xb5,0x22,0x00,0xb6,0x22,0x00,0xb6,0x22,0x00,0xb7,0x23,0x00,0xb8,0x23,0x00,0xb9,0x23,0x00,0xba,0x23,0x00,0xbb,0x23,0x00,0xbc,0x23,0x00,0xbd,0x24,0x00,0xbe,0x24,0x00,0xbe,0x24,0x00,0xbf,0x24,0x00,0xc0,0x24,0x00,0xc1,0x24,0x00,0xc2,0x25,0x00,0xc3,0x25,0x00,0xc4,0x25,0x00,0xc5,0x25,0x00,0xc6,0x25,0x00,0xc7,0x26,0x00,0xc7,0x26,0x00,0xc8,0x26,0x00,0xc9,0x26,0x00,0xca,0x26,0x00,0xcb,0x26,0x00,0xcc,0x27,0x00,0xcd,0x27,0x00,0xce,0x27,0x00,0xcf,0x27,0x00,0xd0,0x27,0x00,0xd0,0x27,0x00,0xd1,0x28,0x00,0xd2,0x28,0x00,0xd3,0x28,0x00,0xd4,0x28,0x00,0xd5,0x28,0x00,0xd6,0x28,0x00,0xd7,0x29,0x00,0xd8,0x29,0x00,0xd9,0x29,0x00,0xda,0x29,0x00,0xda,0x29,0x00,0xdb,0x29,0x00,0xdc,0x2a,0x00,0xdd,0x2a,0x00,0xde,0x2a,0x00,0xdf,0x2a,0x00,0xe0,0x2a,0x00,0xe1,0x2a,0x00,0xe2,0x2b,0x00,0xe3,0x2b,0x00,0xe4,0x2b,0x00,0xe5,0x2b,0x00,0xe6,0x2b,0x00};
	static constexpr std::array<uint8_t, 768> L14  = {0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x02,0x00,0x00,0x03,0x00,0x00,0x04,0x00,0x00,0x05,0x00,0x00,0x06,0x00,0x00,0x06,0x00,0x00,0x07,0x00,0x00,0x08,0x00,0x00,0x09,0x00,0x00,0x0a,0x00,0x00,0x0b,0x00,0x00,0x0c,0x00,0x00,0x0d,0x00,0x00,0x0d,0x00,0x00,0x0e,0x00,0x00,0x0f,0x00,0x00,0x10,0x00,0x00,0x10,0x00,0x00,0x11,0x00,0x00,0x12,0x00,0x00,0x12,0x00,0x00,0x13,0x00,0x00,0x13,0x00,0x00,0x14,0x00,0x00,0x15,0x00,0x00,0x15,0x00,0x00,0x16,0x00,0x00,0x16,0x00,0x00,0x17,0x00,0x00,0x17,0x00,0x00,0x18,0x00,0x00,0x18,0x00,0x00,0x19,0x00,0x00,0x19,0x00,0x00,0x1a,0x00,0x00,0x1a,0x00,0x00,0x1a,0x00,0x00,0x1b,0x00,0x00,0x1b,0x00,0x00,0x1c,0x00,0x00,0x1c,0x00,0x00,0x1d,0x00,0x00,0x1d,0x00,0x00,0x1d,0x00,0x00,0x1e,0x00,0x00,0x1e,0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x1f,0x00,0x00,0x20,0x00,0x00,0x20,0x00,0x00,0x21,0x00,0x00,0x21,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x22,0x00,0x00,0x23,0x00,0x00,0x23,0x00,0x00,0x24,0x00,0x00,0x24,0x00,0x00,0x24,0x00,0x00,0x25,0x00,0x00,0x25,0x00,0x00,0x26,0x00,0x00,0x26,0x00,0x00,0x27,0x00,0x00,0x27,0x00,0x00,0x27,0x00,0x00,0x28,0x00,0x00,0x28,0x00,0x00,0x29,0x00,0x00,0x29,0x00,0x00,0x2a,0x00,0x00,0x2a,0x00,0x00,0x2a,0x00,0x00,0x2b,0x00,0x00,0x2b,0x00,0x00,0x2c,0x00,0x00,0x2c,0x00,0x00,0x2d,0x00,0x00,0x2d,0x00,0x00,0x2d,0x00,0x00,0x2e,0x00,0x00,0x2e,0x00,0x00,0x2f,0x00,0x00,0x2f,0x00,0x00,0x30,0x00,0x00,0x30,0x00,0x00,0x30,0x00,0x00,0x31,0x00,0x00,0x31,0x00,0x00,0x32,0x00,0x00,0x32,0x00,0x00,0x33,0x00,0x00,0x33,0x00,0x00,0x34,0x00,0x00,0x34,0x00,0x00,0x34,0x00,0x00,0x35,0x00,0x00,0x35,0x00,0x00,0x36,0x00,0x00,0x36,0x00,0x00,0x37,0x00,0x00,0x37,0x00,0x00,0x38,0x00,0x00,0x38,0x00,0x00,0x38,0x00,0x00,0x39,0x00,0x00,0x39,0x00,0x00,0x3a,0x00,0x00,0x3a,0x00,0x00,0x3b,0x00,0x00,0x3b,0x00,0x00,0x3c,0x00,0x00,0x3c,0x00,0x00,0x3c,0x00,0x00,0x3d,0x00,0x00,0x3d,0x00,0x00,0x3e,0x00,0x00,0x3e,0x00,0x00,0x3f,0x00,0x00,0x3f,0x00,0x00,0x40,0x00,0x00,0x40,0x00,0x00,0x41,0x00,0x00,0x41,0x00,0x00,0x41,0x00,0x00,0x42,0x00,0x00,0x42,0x00,0x00,0x43,0x00,0x00,0x43,0x00,0x00,0x44,0x00,0x00,0x44,0x00,0x00,0x45,0x00,0x00,0x45,0x00,0x00,0x46,0x00,0x00,0x46,0x00,0x00,0x47,0x00,0x00,0x47,0x00,0x00,0x47,0x00,0x00,0x48,0x00,0x00,0x48,0x00,0x00,0x49,0x00,0x00,0x49,0x00,0x00,0x4a,0x00,0x00,0x4a,0x00,0x00,0x4b,0x00,0x00,0x4b,0x00,0x00,0x4c,0x00,0x00,0x4c,0x00,0x00,0x4d,0x00,0x00,0x4d,0x00,0x00,0x4e,0x00,0x00,0x4e,0x00,0x00,0x4f,0x00,0x00,0x4f,0x00,0x00,0x4f,0x00,0x00,0x50,0x00,0x00,0x50,0x00,0x00,0x51,0x00,0x00,0x51,0x00,0x00,0x52,0x00,0x00,0x52,0x00,0x00,0x53,0x00,0x00,0x53,0x00,0x00,0x54,0x00,0x00,0x54,0x00,0x00,0x55,0x00,0x00,0x55,0x00,0x00,0x56,0x00,0x00,0x56,0x00,0x00,0x57,0x00,0x00,0x57,0x00,0x00,0x58,0x00,0x00,0x58,0x00,0x00,0x59,0x00,0x00,0x59,0x00,0x00,0x5a,0x00,0x00,0x5a,0x00,0x00,0x5a,0x00,0x00,0x5b,0x00,0x00,0x5b,0x00,0x00,0x5c,0x00,0x00,0x5c,0x00,0x00,0x5d,0x00,0x00,0x5d,0x00,0x00,0x5e,0x00,0x00,0x5e,0x00,0x00,0x5f,0x00,0x00,0x5f,0x00,0x00,0x60,0x00,0x00,0x60,0x00,0x00,0x61,0x00,0x00,0x61,0x00,0x00,0x62,0x00,0x00,0x62,0x00,0x00,0x63,0x00,0x00,0x63,0x00,0x00,0x64,0x00,0x00,0x64,0x00,0x00,0x65,0x00,0x00,0x65,0x00,0x00,0x66,0x00,0x00,0x66,0x00,0x00,0x67,0x00,0x00,0x67,0x00,0x00,0x68,0x00,0x00,0x68,0x00,0x00,0x69,0x00,0x00,0x69,0x00,0x00,0x6a,0x00,0x00,0x6a,0x00,0x00,0x6b,0x00,0x00,0x6b,0x00,0x00,0x6c,0x00,0x00,0x6c,0x00,0x00,0x6d,0x00,0x00,0x6d,0x00,0x00,0x6e,0x00,0x00,0x6e,0x00,0x00,0x6f,0x00,0x00,0x6f,0x00,0x00,0x70,0x00,0x00,0x70,0x00,0x00,0x71,0x00,0x00,0x71,0x00,0x00,0x72,0x00,0x00,0x72,0x00,0x00,0x73,0x00,0x00,0x73,0x00,0x00,0x74,0x00,0x00,0x74,0x00,0x00,0x75,0x00,0x00,0x75,0x00,0x00,0x76,0x00,0x00,0x76,0x00,0x00,0x77,0x00,0x00,0x77,0x00,0x00,0x78,0x00,0x00,0x78,0x00,0x00,0x79,0x00,0x00,0x79,0x00,0x00,0x7a,0x00,0x00,0x7a,0x00,0x00,0x7b,0x00,0x00,0x7b,0x00,0x00,0x7c,0x00,0x00,0x7c,0x00,0x00,0x7d,0x00,0x00,0x7d,0x00,0x00,0x7e,0x00,0x00,0x7e,0x00,0x00,0x7f,0x00,0x00,0x80,0x00};
	static constexpr std::array<uint8_t, 768> L15  = {0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x01,0x04,0x01,0x02,0x06,0x01,0x03,0x08,0x01,0x03,0x0a,0x01,0x04,0x0b,0x01,0x04,0x0d,0x02,0x05,0x0f,0x02,0x06,0x11,0x02,0x06,0x13,0x02,0x07,0x14,0x02,0x07,0x16,0x02,0x08,0x18,0x03,0x08,0x19,0x03,0x09,0x1b,0x03,0x09,0x1c,0x03,0x0a,0x1e,0x03,0x0a,0x1f,0x03,0x0b,0x21,0x03,0x0b,0x22,0x04,0x0c,0x23,0x04,0x0c,0x25,0x04,0x0d,0x26,0x04,0x0d,0x27,0x04,0x0d,0x28,0x04,0x0e,0x29,0x04,0x0e,0x2b,0x04,0x0e,0x2c,0x04,0x0f,0x2d,0x05,0x0f,0x2e,0x05,0x0f,0x2f,0x05,0x10,0x30,0x05,0x10,0x31,0x05,0x11,0x32,0x05,0x11,0x33,0x05,0x11,0x34,0x05,0x11,0x35,0x05,0x12,0x36,0x05,0x12,0x37,0x06,0x12,0x38,0x06,0x13,0x39,0x06,0x13,0x39,0x06,0x13,0x3a,0x06,0x14,0x3b,0x06,0x14,0x3c,0x06,0x14,0x3d,0x06,0x14,0x3e,0x06,0x15,0x3e,0x06,0x15,0x3f,0x06,0x15,0x40,0x06,0x15,0x41,0x07,0x16,0x42,0x07,0x16,0x43,0x07,0x16,0x43,0x07,0x17,0x44,0x07,0x17,0x45,0x07,0x17,0x46,0x07,0x17,0x47,0x07,0x18,0x48,0x07,0x18,0x48,0x07,0x18,0x49,0x07,0x18,0x4a,0x07,0x19,0x4b,0x08,0x19,0x4c,0x08,0x19,0x4d,0x08,0x1a,0x4e,0x08,0x1a,0x4e,0x08,0x1a,0x4f,0x08,0x1a,0x50,0x08,0x1b,0x51,0x08,0x1b,0x52,0x08,0x1b,0x53,0x08,0x1c,0x53,0x08,0x1c,0x54,0x09,0x1c,0x55,0x09,0x1c,0x56,0x09,0x1d,0x57,0x09,0x1d,0x58,0x09,0x1d,0x59,0x09,0x1e,0x5a,0x09,0x1e,0x5a,0x09,0x1e,0x5b,0x09,0x1e,0x5c,0x09,0x1f,0x5d,0x09,0x1f,0x5e,0x09,0x1f,0x5f,0x0a,0x20,0x60,0x0a,0x20,0x60,0x0a,0x20,0x61,0x0a,0x20,0x62,0x0a,0x21,0x63,0x0a,0x21,0x64,0x0a,0x21,0x65,0x0a,0x22,0x66,0x0a,0x22,0x67,0x0a,0x22,0x67,0x0a,0x22,0x68,0x0b,0x23,0x69,0x0b,0x23,0x6a,0x0b,0x23,0x6b,0x0b,0x24,0x6c,0x0b,0x24,0x6d,0x0b,0x24,0x6e,0x0b,0x24,0x6f,0x0b,0x25,0x6f,0x0b,0x25,0x70,0x0b,0x25,0x71,0x0b,0x26,0x72,0x0c,0x26,0x73,0x0c,0x26,0x74,0x0c,0x27,0x75,0x0c,0x27,0x76,0x0c,0x27,0x77,0x0c,0x27,0x77,0x0c,0x28,0x78,0x0c,0x28,0x79,0x0c,0x28,0x7a,0x0c,0x29,0x7b,0x0c,0x29,0x7c,0x0c,0x29,0x7d,0x0d,0x2a,0x7e,0x0d,0x2a,0x7f,0x0d,0x2a,0x80,0x0d,0x2a,0x81,0x0d,0x2b,0x81,0x0d,0x2b,0x82,0x0d,0x2b,0x83,0x0d,0x2c,0x84,0x0d,0x2c,0x85,0x0d,0x2c,0x86,0x0d,0x2d,0x87,0x0e,0x2d,0x88,0x0e,0x2d,0x89,0x0e,0x2d,0x8a,0x0e,0x2e,0x8b,0x0e,0x2e,0x8c,0x0e,0x2e,0x8c,0x0e,0x2f,0x8d,0x0e,0x2f,0x8e,0x0e,0x2f,0x8f,0x0e,0x30,0x90,0x0f,0x30,0x91,0x0f,0x30,0x92,0x0f,0x30,0x93,0x0f,0x31,0x94,0x0f,0x31,0x95,0x0f,0x31,0x96,0x0f,0x32,0x97,0x0f,0x32,0x98,0x0f,0x32,0x98,0x0f,0x33,0x99,0x0f,0x33,0x9a,0x10,0x33,0x9b,0x10,0x34,0x9c,0x10,0x34,0x9d,0x10,0x34,0x9e,0x10,0x34,0x9f,0x10,0x35,0xa0,0x10,0x35,0xa1,0x10,0x35,0xa2,0x10,0x36,0xa3,0x10,0x36,0xa4,0x10,0x36,0xa5,0x11,0x37,0xa6,0x11,0x37,0xa7,0x11,0x37,0xa8,0x11,0x38,0xa8,0x11,0x38,0xa9,0x11,0x38,0xaa,0x11,0x39,0xab,0x11,0x39,0xac,0x11,0x39,0xad,0x11,0x39,0xae,0x12,0x3a,0xaf,0x12,0x3a,0xb0,0x12,0x3a,0xb1,0x12,0x3b,0xb2,0x12,0x3b,0xb3,0x12,0x3b,0xb4,0x12,0x3c,0xb5,0x12,0x3c,0xb6,0x12,0x3c,0xb7,0x12,0x3d,0xb8,0x12,0x3d,0xb9,0x13,0x3d,0xba,0x13,0x3e,0xbb,0x13,0x3e,0xbc,0x13,0x3e,0xbd,0x13,0x3f,0xbe,0x13,0x3f,0xbe,0x13,0x3f,0xbf,0x13,0x40,0xc0,0x13,0x40,0xc1,0x13,0x40,0xc2,0x14,0x40,0xc3,0x14,0x41,0xc4,0x14,0x41,0xc5,0x14,0x41,0xc6,0x14,0x42,0xc7,0x14,0x42,0xc8,0x14,0x42,0xc9,0x14,0x43,0xca,0x14,0x43,0xcb,0x14,0x43,0xcc,0x15,0x44,0xcd,0x15,0x44,0xce,0x15,0x44,0xcf,0x15,0x45,0xd0,0x15,0x45,0xd1,0x15,0x45,0xd2,0x15,0x46,0xd3,0x15,0x46,0xd4,0x15,0x46,0xd5,0x15,0x47,0xd6,0x15,0x47,0xd7,0x16,0x47,0xd8,0x16,0x48,0xd9,0x16,0x48,0xda,0x16,0x48,0xdb,0x16,0x49,0xdc,0x16,0x49,0xdd,0x16,0x49,0xde,0x16,0x4a,0xdf,0x16,0x4a,0xe0,0x16,0x4a,0xe1,0x17,0x4b,0xe2,0x17,0x4b,0xe3,0x17,0x4b,0xe4,0x17,0x4c,0xe5,0x17,0x4c,0xe6,0x17,0x4c,0xe7,0x17,0x4c,0xe8,0x17,0x4d,0xe9,0x17,0x4d,0xea,0x17,0x4d,0xeb,0x18,0x4e,0xec,0x18,0x4e,0xed,0x18,0x4e,0xee,0x18,0x4f,0xef,0x18,0x4f,0xf0,0x18,0x4f,0xf1,0x18,0x50,0xf2,0x18,0x50,0xf3,0x18,0x50,0xf4,0x18,0x51,0xf5,0x19,0x51,0xf6,0x19,0x51,0xf7,0x19,0x52,0xf8,0x19,0x52,0xf9,0x19,0x52,0xfa,0x19,0x53,0xfb,0x19,0x53,0xfc,0x19,0x53,0xfd,0x19,0x54,0xfe,0x1a,0x54,0xff};
	static constexpr std::array<uint8_t, 768> L16  = {0x1b,0x1b,0x1b,0x1d,0x1b,0x20,0x1f,0x1b,0x24,0x20,0x1b,0x29,0x22,0x1b,0x2d,0x23,0x1b,0x31,0x24,0x1b,0x35,0x25,0x1b,0x3a,0x26,0x1b,0x3e,0x27,0x1b,0x42,0x27,0x1a,0x46,0x28,0x1a,0x4a,0x28,0x1a,0x4f,0x29,0x1a,0x53,0x29,0x1a,0x57,0x29,0x1a,0x5b,0x29,0x19,0x5f,0x29,0x19,0x63,0x29,0x19,0x66,0x29,0x19,0x6a,0x29,0x19,0x6e,0x28,0x19,0x72,0x28,0x19,0x75,0x27,0x19,0x79,0x27,0x19,0x7c,0x26,0x19,0x80,0x25,0x19,0x83,0x25,0x19,0x86,0x24,0x1a,0x89,0x23,0x1a,0x8c,0x22,0x1a,0x8f,0x21,0x1a,0x92,0x20,0x1b,0x95,0x1f,0x1b,0x98,0x1d,0x1c,0x9a,0x1c,0x1d,0x9d,0x1b,0x1d,0x9f,0x19,0x1e,0xa2,0x18,0x1f,0xa4,0x17,0x20,0xa6,0x15,0x20,0xa8,0x14,0x21,0xaa,0x12,0x22,0xac,0x11,0x23,0xad,0x0f,0x25,0xaf,0x0e,0x26,0xb0,0x0d,0x27,0xb1,0x0c,0x28,0xb2,0x0b,0x29,0xb3,0x0a,0x2b,0xb4,0x09,0x2c,0xb4,0x09,0x2e,0xb5,0x08,0x2f,0xb5,0x08,0x30,0xb6,0x08,0x32,0xb6,0x08,0x33,0xb6,0x07,0x35,0xb7,0x07,0x36,0xb7,0x07,0x37,0xb7,0x07,0x39,0xb7,0x07,0x3a,0xb8,0x07,0x3c,0xb8,0x07,0x3d,0xb8,0x07,0x3e,0xb8,0x07,0x40,0xb8,0x07,0x41,0xb8,0x07,0x42,0xb8,0x07,0x44,0xb8,0x07,0x45,0xb8,0x07,0x46,0xb8,0x07,0x48,0xb7,0x07,0x49,0xb7,0x07,0x4b,0xb7,0x07,0x4c,0xb7,0x07,0x4d,0xb6,0x07,0x4f,0xb6,0x07,0x50,0xb5,0x07,0x51,0xb5,0x07,0x53,0xb4,0x07,0x54,0xb4,0x07,0x56,0xb3,0x07,0x57,0xb2,0x07,0x58,0xb1,0x07,0x5a,0xb0,0x07,0x5b,0xaf,0x06,0x5d,0xae,0x06,0x5e,0xad,0x06,0x5f,0xac,0x06,0x61,0xab,0x06,0x62,0xaa,0x07,0x64,0xa8,0x08,0x65,0xa7,0x0a,0x66,0xa5,0x0c,0x68,0xa4,0x0e,0x69,0xa2,0x10,0x6a,0xa0,0x12,0x6c,0x9f,0x14,0x6d,0x9d,0x16,0x6e,0x9b,0x18,0x6f,0x99,0x1a,0x71,0x97,0x1b,0x72,0x95,0x1d,0x73,0x93,0x1f,0x74,0x91,0x20,0x76,0x8f,0x22,0x77,0x8d,0x23,0x78,0x8b,0x24,0x79,0x89,0x26,0x7b,0x87,0x27,0x7c,0x85,0x28,0x7d,0x82,0x29,0x7e,0x80,0x2a,0x80,0x7e,0x2b,0x81,0x7b,0x2c,0x82,0x79,0x2c,0x83,0x77,0x2d,0x84,0x74,0x2e,0x86,0x72,0x2e,0x87,0x6f,0x2f,0x88,0x6d,0x2f,0x89,0x6a,0x30,0x8b,0x67,0x30,0x8c,0x65,0x30,0x8d,0x62,0x30,0x8e,0x5f,0x31,0x8f,0x5c,0x31,0x91,0x5a,0x31,0x92,0x57,0x32,0x93,0x55,0x32,0x94,0x53,0x33,0x95,0x50,0x34,0x96,0x4e,0x34,0x97,0x4c,0x35,0x98,0x4a,0x36,0x99,0x48,0x37,0x9a,0x46,0x38,0x9b,0x44,0x3a,0x9c,0x42,0x3b,0x9d,0x40,0x3c,0x9e,0x3e,0x3d,0x9f,0x3c,0x3f,0xa0,0x3a,0x40,0xa1,0x38,0x42,0xa2,0x37,0x44,0xa3,0x35,0x45,0xa4,0x33,0x47,0xa5,0x31,0x49,0xa6,0x30,0x4a,0xa7,0x2e,0x4c,0xa8,0x2c,0x4e,0xa9,0x2b,0x50,0xaa,0x29,0x52,0xab,0x28,0x54,0xac,0x26,0x56,0xac,0x24,0x58,0xad,0x23,0x5a,0xae,0x21,0x5c,0xaf,0x20,0x5e,0xb0,0x1e,0x60,0xb1,0x1d,0x62,0xb1,0x1b,0x65,0xb2,0x1a,0x67,0xb3,0x18,0x69,0xb4,0x17,0x6b,0xb5,0x15,0x6e,0xb5,0x14,0x70,0xb6,0x12,0x72,0xb7,0x11,0x75,0xb8,0x0f,0x77,0xb8,0x0e,0x79,0xb9,0x0c,0x7c,0xba,0x0b,0x7e,0xbb,0x09,0x80,0xbb,0x08,0x83,0xbc,0x07,0x85,0xbd,0x06,0x88,0xbd,0x05,0x8a,0xbe,0x04,0x8d,0xbf,0x04,0x8f,0xbf,0x03,0x92,0xc0,0x03,0x94,0xc1,0x03,0x97,0xc1,0x02,0x99,0xc2,0x02,0x9c,0xc3,0x02,0x9e,0xc3,0x02,0xa1,0xc4,0x03,0xa3,0xc5,0x03,0xa5,0xc5,0x03,0xa8,0xc6,0x03,0xaa,0xc7,0x03,0xac,0xc7,0x04,0xaf,0xc8,0x04,0xb1,0xc8,0x05,0xb3,0xc9,0x05,0xb6,0xca,0x06,0xb8,0xca,0x07,0xba,0xcb,0x08,0xbc,0xcc,0x08,0xbe,0xcc,0x09,0xc0,0xcd,0x0b,0xc3,0xce,0x0c,0xc5,0xce,0x0d,0xc7,0xcf,0x0e,0xc9,0xd0,0x0f,0xcb,0xd0,0x10,0xcd,0xd1,0x12,0xcf,0xd2,0x13,0xd1,0xd2,0x14,0xd3,0xd3,0x16,0xd5,0xd4,0x17,0xd7,0xd5,0x18,0xd9,0xd5,0x1a,0xda,0xd6,0x1b,0xdc,0xd7,0x1d,0xde,0xd7,0x1e,0xe0,0xd8,0x20,0xe2,0xd9,0x21,0xe3,0xda,0x23,0xe5,0xda,0x24,0xe6,0xdb,0x26,0xe8,0xdc,0x28,0xea,0xdd,0x2a,0xeb,0xde,0x2b,0xec,0xdf,0x2d,0xee,0xdf,0x2f,0xef,0xe0,0x31,0xf0,0xe1,0x33,0xf1,0xe2,0x35,0xf2,0xe3,0x38,0xf3,0xe4,0x3a,0xf4,0xe5,0x3d,0xf5,0xe6,0x3f,0xf5,0xe7,0x42,0xf6,0xe8,0x46,0xf7,0xe9,0x49,0xf7,0xea,0x4e,0xf8,0xeb,0x52,0xf9,0xec,0x57,0xfa,0xed,0x5c,0xfa,0xee,0x62,0xfb,0xef,0x68,0xfc,0xf0,0x6f,0xfc,0xf1,0x76,0xfd,0xf2,0x7d,0xfe,0xf3,0x85,0xfe,0xf3,0x8d,0xff,0xf4,0x96,0xff,0xf5,0xa0,0xff,0xf6,0xaa,0xff,0xf6,0xb5,0xff,0xf7,0xc1,0xfe,0xf8,0xcd,0xfd,0xf8,0xdb,0xfc,0xf9,0xe9,0xf9,0xf9,0xf9};
	static constexpr std::array<uint8_t, 768> L17  = {0xff,0xff,0xff,0xff,0xfe,0xfc,0xfe,0xfd,0xf9,0xfe,0xfd,0xf7,0xfd,0xfc,0xf4,0xfd,0xfb,0xf1,0xfc,0xfa,0xee,0xfc,0xfa,0xeb,0xfb,0xf9,0xe9,0xfb,0xf8,0xe6,0xfa,0xf7,0xe3,0xfa,0xf7,0xe0,0xf9,0xf6,0xdd,0xf8,0xf5,0xdb,0xf8,0xf4,0xd8,0xf7,0xf3,0xd5,0xf7,0xf3,0xd2,0xf6,0xf2,0xcf,0xf6,0xf1,0xcd,0xf5,0xf0,0xca,0xf4,0xf0,0xc7,0xf4,0xef,0xc4,0xf3,0xee,0xc2,0xf2,0xed,0xbf,0xf2,0xec,0xbd,0xf2,0xeb,0xbb,0xf2,0xea,0xba,0xf2,0xe9,0xb8,0xf3,0xe8,0xb6,0xf3,0xe7,0xb4,0xf3,0xe6,0xb3,0xf3,0xe5,0xb1,0xf3,0xe4,0xaf,0xf3,0xe3,0xae,0xf3,0xe2,0xac,0xf3,0xe1,0xaa,0xf3,0xe0,0xa9,0xf2,0xdf,0xa7,0xf2,0xde,0xa5,0xf2,0xdd,0xa4,0xf2,0xdc,0xa2,0xf2,0xdb,0xa0,0xf2,0xda,0x9f,0xf2,0xd9,0x9d,0xf2,0xd7,0x9c,0xf2,0xd6,0x9a,0xf2,0xd5,0x98,0xf2,0xd4,0x97,0xf2,0xd3,0x96,0xf2,0xd2,0x94,0xf2,0xd1,0x93,0xf3,0xd0,0x92,0xf3,0xcf,0x91,0xf3,0xcd,0x90,0xf3,0xcc,0x8e,0xf3,0xcb,0x8d,0xf3,0xca,0x8c,0xf3,0xc9,0x8b,0xf3,0xc8,0x8a,0xf3,0xc6,0x88,0xf4,0xc5,0x87,0xf4,0xc4,0x86,0xf4,0xc3,0x85,0xf4,0xc2,0x84,0xf4,0xc1,0x83,0xf4,0xbf,0x81,0xf4,0xbe,0x80,0xf4,0xbd,0x7f,0xf4,0xbc,0x7e,0xf4,0xbb,0x7d,0xf4,0xba,0x7c,0xf4,0xb8,0x7b,0xf4,0xb7,0x7a,0xf4,0xb6,0x7a,0xf5,0xb5,0x79,0xf5,0xb3,0x78,0xf5,0xb2,0x77,0xf5,0xb1,0x77,0xf5,0xb0,0x76,0xf5,0xae,0x75,0xf5,0xad,0x75,0xf5,0xac,0x74,0xf5,0xab,0x73,0xf5,0xaa,0x73,0xf5,0xa8,0x72,0xf5,0xa7,0x71,0xf5,0xa6,0x70,0xf5,0xa4,0x70,0xf5,0xa3,0x6f,0xf5,0xa2,0x6e,0xf5,0xa1,0x6e,0xf5,0x9f,0x6d,0xf5,0x9e,0x6c,0xf5,0x9d,0x6c,0xf5,0x9c,0x6c,0xf5,0x9a,0x6b,0xf5,0x99,0x6b,0xf5,0x98,0x6b,0xf5,0x97,0x6b,0xf5,0x95,0x6a,0xf5,0x94,0x6a,0xf5,0x93,0x6a,0xf5,0x91,0x6a,0xf5,0x90,0x6a,0xf4,0x8f,0x69,0xf4,0x8d,0x69,0xf4,0x8c,0x69,0xf4,0x8b,0x69,0xf4,0x8a,0x69,0xf4,0x88,0x68,0xf4,0x87,0x68,0xf4,0x86,0x68,0xf4,0x84,0x68,0xf3,0x83,0x67,0xf3,0x81,0x67,0xf3,0x80,0x67,0xf3,0x7f,0x67,0xf3,0x7e,0x67,0xf2,0x7c,0x67,0xf2,0x7b,0x67,0xf2,0x7a,0x68,0xf2,0x78,0x68,0xf1,0x77,0x68,0xf1,0x76,0x68,0xf1,0x74,0x68,0xf0,0x73,0x68,0xf0,0x72,0x69,0xf0,0x70,0x69,0xef,0x6f,0x69,0xef,0x6e,0x69,0xef,0x6c,0x69,0xee,0x6b,0x6a,0xee,0x6a,0x6a,0xee,0x68,0x6a,0xed,0x67,0x6a,0xed,0x66,0x6a,0xed,0x64,0x6a,0xec,0x63,0x6a,0xec,0x61,0x6b,0xec,0x60,0x6b,0xeb,0x5f,0x6b,0xea,0x5d,0x6c,0xea,0x5c,0x6c,0xe9,0x5b,0x6d,0xe8,0x5a,0x6d,0xe8,0x58,0x6e,0xe7,0x57,0x6e,0xe7,0x56,0x6e,0xe6,0x55,0x6f,0xe5,0x53,0x6f,0xe5,0x52,0x70,0xe4,0x51,0x70,0xe3,0x4f,0x71,0xe3,0x4e,0x71,0xe2,0x4d,0x72,0xe1,0x4b,0x72,0xe1,0x4a,0x72,0xe0,0x49,0x73,0xe0,0x47,0x73,0xdf,0x46,0x74,0xde,0x44,0x74,0xde,0x43,0x75,0xdd,0x41,0x75,0xdc,0x40,0x75,0xdb,0x3f,0x76,0xda,0x3e,0x77,0xd9,0x3d,0x77,0xd8,0x3c,0x78,0xd7,0x3b,0x79,0xd6,0x3a,0x79,0xd5,0x38,0x7a,0xd4,0x37,0x7a,0xd3,0x36,0x7b,0xd2,0x35,0x7c,0xd1,0x34,0x7c,0xd0,0x33,0x7d,0xcf,0x32,0x7d,0xce,0x30,0x7e,0xcd,0x2f,0x7f,0xcc,0x2e,0x7f,0xcb,0x2d,0x80,0xca,0x2b,0x80,0xc9,0x2a,0x81,0xc8,0x29,0x82,0xc7,0x28,0x82,0xc5,0x26,0x83,0xc4,0x25,0x83,0xc3,0x25,0x84,0xc1,0x24,0x85,0xc0,0x23,0x85,0xbe,0x23,0x86,0xbd,0x22,0x87,0xbc,0x22,0x87,0xba,0x21,0x88,0xb9,0x20,0x89,0xb7,0x20,0x89,0xb6,0x1f,0x8a,0xb4,0x1f,0x8a,0xb3,0x1e,0x8b,0xb1,0x1d,0x8c,0xb0,0x1d,0x8c,0xae,0x1c,0x8d,0xad,0x1c,0x8e,0xab,0x1b,0x8e,0xaa,0x1b,0x8f,0xa8,0x1a,0x90,0xa7,0x19,0x90,0xa5,0x19,0x91,0xa3,0x18,0x92,0xa2,0x18,0x92,0xa0,0x18,0x93,0x9e,0x19,0x93,0x9c,0x19,0x94,0x9a,0x1a,0x94,0x98,0x1a,0x95,0x96,0x1a,0x96,0x94,0x1b,0x96,0x92,0x1b,0x97,0x90,0x1b,0x97,0x8e,0x1c,0x98,0x8c,0x1c,0x99,0x89,0x1c,0x99,0x87,0x1d,0x9a,0x85,0x1d,0x9a,0x83,0x1d,0x9b,0x81,0x1d,0x9b,0x7f,0x1e,0x9c,0x7c,0x1e,0x9d,0x7a,0x1e,0x9d,0x78,0x1e,0x9e,0x75,0x1f,0x9e,0x73,0x1f,0x9f,0x70,0x1f,0x9f,0x6e,0x20,0xa0,0x6b,0x21,0xa0,0x68,0x21,0xa0,0x65,0x22,0xa1,0x62,0x23,0xa1,0x5f,0x23,0xa2,0x5c,0x24,0xa2,0x59,0x24,0xa2,0x55,0x25,0xa3,0x52,0x25,0xa3,0x4e,0x26,0xa3,0x4b,0x26,0xa4,0x47,0x27,0xa4,0x43,0x27,0xa4,0x3e,0x27,0xa5,0x3a,0x28,0xa5,0x34,0x28,0xa6,0x2f,0x29,0xa6,0x29,0x29,0xa6,0x21,0x29,0xa7,0x18,0x2a,0xa7,0x0a,0x2a,0xa7,0x00,0x2a,0xa8};
	static constexpr std::array<uint8_t, 768> L18  = {0xff,0xff,0xff,0xfe,0xff,0xfc,0xfe,0xfe,0xfa,0xfd,0xfe,0xf7,0xfd,0xfd,0xf5,0xfc,0xfd,0xf2,0xfb,0xfc,0xef,0xfb,0xfc,0xed,0xfa,0xfb,0xea,0xfa,0xfb,0xe8,0xf9,0xfb,0xe5,0xf8,0xfa,0xe3,0xf8,0xfa,0xe0,0xf7,0xf9,0xdd,0xf6,0xf9,0xdb,0xf6,0xf8,0xd8,0xf5,0xf8,0xd6,0xf4,0xf7,0xd3,0xf4,0xf7,0xd0,0xf3,0xf7,0xce,0xf2,0xf6,0xcb,0xf2,0xf6,0xc9,0xf1,0xf5,0xc6,0xf0,0xf5,0xc4,0xf0,0xf4,0xc2,0xf0,0xf4,0xc0,0xef,0xf3,0xbf,0xef,0xf2,0xbd,0xef,0xf2,0xbc,0xef,0xf1,0xba,0xee,0xf0,0xb9,0xee,0xf0,0xb7,0xee,0xef,0xb6,0xee,0xee,0xb4,0xed,0xee,0xb3,0xed,0xed,0xb1,0xed,0xec,0xaf,0xec,0xec,0xae,0xec,0xeb,0xac,0xec,0xea,0xab,0xec,0xea,0xa9,0xeb,0xe9,0xa8,0xeb,0xe8,0xa6,0xeb,0xe8,0xa5,0xea,0xe7,0xa3,0xea,0xe6,0xa2,0xea,0xe6,0xa0,0xea,0xe5,0x9f,0xea,0xe4,0x9d,0xe9,0xe4,0x9c,0xe9,0xe3,0x9b,0xe9,0xe2,0x99,0xe9,0xe1,0x98,0xe9,0xe1,0x97,0xe9,0xe0,0x96,0xe9,0xdf,0x94,0xe9,0xdf,0x93,0xe8,0xde,0x92,0xe8,0xdd,0x90,0xe8,0xdc,0x8f,0xe8,0xdc,0x8e,0xe8,0xdb,0x8c,0xe8,0xda,0x8b,0xe8,0xda,0x8a,0xe7,0xd9,0x88,0xe7,0xd8,0x87,0xe7,0xd7,0x86,0xe7,0xd7,0x84,0xe7,0xd6,0x83,0xe7,0xd5,0x82,0xe6,0xd5,0x80,0xe6,0xd4,0x7f,0xe6,0xd3,0x7e,0xe6,0xd2,0x7d,0xe6,0xd1,0x7c,0xe6,0xd1,0x7b,0xe6,0xd0,0x79,0xe6,0xcf,0x78,0xe6,0xce,0x77,0xe6,0xce,0x76,0xe6,0xcd,0x75,0xe6,0xcc,0x74,0xe6,0xcb,0x72,0xe6,0xcb,0x71,0xe6,0xca,0x70,0xe6,0xc9,0x6f,0xe5,0xc8,0x6e,0xe5,0xc8,0x6d,0xe5,0xc7,0x6b,0xe5,0xc6,0x6a,0xe5,0xc5,0x69,0xe5,0xc4,0x68,0xe5,0xc4,0x67,0xe5,0xc3,0x66,0xe5,0xc2,0x65,0xe5,0xc1,0x64,0xe5,0xc1,0x63,0xe5,0xc0,0x62,0xe5,0xbf,0x61,0xe5,0xbe,0x60,0xe5,0xbd,0x5f,0xe5,0xbd,0x5e,0xe5,0xbc,0x5c,0xe4,0xbb,0x5b,0xe4,0xba,0x5a,0xe4,0xb9,0x59,0xe4,0xb9,0x58,0xe4,0xb8,0x57,0xe4,0xb7,0x56,0xe4,0xb6,0x55,0xe4,0xb5,0x54,0xe4,0xb5,0x53,0xe4,0xb4,0x52,0xe4,0xb3,0x51,0xe4,0xb2,0x50,0xe4,0xb1,0x4f,0xe4,0xb0,0x4e,0xe4,0xb0,0x4d,0xe4,0xaf,0x4c,0xe4,0xae,0x4c,0xe4,0xad,0x4b,0xe4,0xac,0x4a,0xe4,0xab,0x49,0xe4,0xab,0x48,0xe4,0xaa,0x47,0xe4,0xa9,0x46,0xe4,0xa8,0x45,0xe3,0xa7,0x45,0xe3,0xa6,0x44,0xe3,0xa6,0x43,0xe3,0xa5,0x42,0xe3,0xa4,0x41,0xe3,0xa3,0x40,0xe3,0xa2,0x3f,0xe3,0xa1,0x3e,0xe3,0xa1,0x3e,0xe3,0xa0,0x3d,0xe3,0x9f,0x3c,0xe3,0x9e,0x3b,0xe3,0x9d,0x3a,0xe3,0x9c,0x39,0xe3,0x9b,0x39,0xe3,0x9b,0x38,0xe3,0x9a,0x37,0xe3,0x99,0x37,0xe3,0x98,0x36,0xe3,0x97,0x35,0xe3,0x96,0x34,0xe3,0x95,0x34,0xe3,0x94,0x33,0xe2,0x93,0x32,0xe2,0x93,0x32,0xe2,0x92,0x31,0xe2,0x91,0x30,0xe2,0x90,0x2f,0xe2,0x8f,0x2f,0xe2,0x8e,0x2e,0xe2,0x8d,0x2d,0xe2,0x8c,0x2d,0xe2,0x8b,0x2c,0xe2,0x8b,0x2b,0xe2,0x8a,0x2a,0xe2,0x89,0x2a,0xe2,0x88,0x29,0xe2,0x87,0x29,0xe2,0x86,0x28,0xe2,0x85,0x28,0xe1,0x84,0x27,0xe1,0x83,0x27,0xe1,0x82,0x26,0xe1,0x81,0x26,0xe1,0x80,0x25,0xe1,0x7f,0x25,0xe1,0x7f,0x24,0xe1,0x7e,0x24,0xe1,0x7d,0x23,0xe1,0x7c,0x23,0xe1,0x7b,0x22,0xe1,0x7a,0x22,0xe1,0x79,0x21,0xe1,0x78,0x21,0xe0,0x77,0x20,0xe0,0x76,0x20,0xe0,0x75,0x1f,0xe0,0x74,0x1f,0xe0,0x73,0x1e,0xe0,0x72,0x1e,0xe0,0x71,0x1e,0xe0,0x70,0x1d,0xe0,0x6f,0x1d,0xe0,0x6e,0x1d,0xe0,0x6d,0x1d,0xdf,0x6c,0x1c,0xdf,0x6b,0x1c,0xdf,0x6a,0x1c,0xdf,0x69,0x1c,0xdf,0x68,0x1b,0xdf,0x67,0x1b,0xdf,0x66,0x1b,0xdf,0x65,0x1b,0xdf,0x64,0x1b,0xde,0x63,0x1a,0xde,0x62,0x1a,0xde,0x61,0x1a,0xde,0x60,0x1a,0xde,0x5f,0x19,0xde,0x5d,0x19,0xde,0x5c,0x19,0xde,0x5b,0x19,0xdd,0x5a,0x19,0xdd,0x59,0x19,0xdd,0x58,0x19,0xdd,0x57,0x19,0xdd,0x56,0x19,0xdd,0x55,0x19,0xdd,0x53,0x19,0xdc,0x52,0x19,0xdc,0x51,0x19,0xdc,0x50,0x19,0xdc,0x4f,0x19,0xdc,0x4e,0x19,0xdc,0x4c,0x19,0xdb,0x4b,0x19,0xdb,0x4a,0x19,0xdb,0x49,0x19,0xdb,0x47,0x19,0xdb,0x46,0x19,0xdb,0x45,0x19,0xda,0x43,0x19,0xda,0x42,0x19,0xda,0x41,0x19,0xda,0x3f,0x19,0xda,0x3e,0x19,0xda,0x3d,0x19,0xd9,0x3b,0x1a,0xd9,0x3a,0x1a,0xd9,0x38,0x1a,0xd9,0x37,0x1a,0xd9,0x35,0x1a,0xd8,0x34,0x1b,0xd8,0x32,0x1b,0xd8,0x30,0x1b,0xd8,0x2f,0x1b,0xd7,0x2d,0x1b,0xd7,0x2b,0x1b,0xd7,0x29,0x1c,0xd7,0x27,0x1c,0xd7,0x25,0x1c,0xd6,0x23,0x1c,0xd6,0x21,0x1c,0xd6,0x1f,0x1c,0xd6,0x1c,0x1d,0xd5,0x19,0x1d,0xd5,0x16,0x1d,0xd5,0x13,0x1d,0xd5,0x0f,0x1d};
	static constexpr std::array<uint8_t, 768> L19  = {0xff,0xff,0xff,0xfe,0xff,0xff,0xfc,0xfe,0xff,0xfb,0xfe,0xff,0xfa,0xfd,0xff,0xf9,0xfd,0xfe,0xf7,0xfc,0xfe,0xf6,0xfc,0xfe,0xf5,0xfb,0xfe,0xf4,0xfb,0xfe,0xf2,0xfa,0xfe,0xf1,0xfa,0xfe,0xf0,0xf9,0xfe,0xef,0xf9,0xfe,0xed,0xf8,0xfe,0xec,0xf8,0xfd,0xeb,0xf7,0xfd,0xe9,0xf7,0xfd,0xe8,0xf6,0xfd,0xe7,0xf6,0xfd,0xe6,0xf5,0xfd,0xe4,0xf5,0xfd,0xe3,0xf4,0xfd,0xe2,0xf4,0xfd,0xe1,0xf3,0xfd,0xe0,0xf3,0xfd,0xdf,0xf2,0xfd,0xde,0xf1,0xfd,0xdc,0xf1,0xfd,0xdb,0xf0,0xfd,0xda,0xf0,0xfd,0xd9,0xef,0xfd,0xd8,0xee,0xfd,0xd7,0xee,0xfd,0xd6,0xed,0xfd,0xd5,0xed,0xfd,0xd4,0xec,0xfd,0xd3,0xec,0xfd,0xd2,0xeb,0xfd,0xd1,0xea,0xfd,0xd0,0xea,0xfd,0xcf,0xe9,0xfe,0xce,0xe9,0xfe,0xcd,0xe8,0xfe,0xcc,0xe8,0xfe,0xcb,0xe7,0xfe,0xca,0xe6,0xfe,0xc9,0xe6,0xfe,0xc8,0xe5,0xfe,0xc8,0xe4,0xfe,0xc7,0xe4,0xfe,0xc6,0xe3,0xfe,0xc6,0xe2,0xfe,0xc5,0xe2,0xfe,0xc5,0xe1,0xfe,0xc4,0xe0,0xfe,0xc3,0xe0,0xfe,0xc3,0xdf,0xfe,0xc2,0xde,0xfe,0xc1,0xde,0xff,0xc1,0xdd,0xff,0xc0,0xdc,0xff,0xbf,0xdb,0xff,0xbf,0xdb,0xff,0xbe,0xda,0xff,0xbd,0xd9,0xff,0xbd,0xd9,0xff,0xbc,0xd8,0xff,0xbc,0xd7,0xff,0xbb,0xd7,0xff,0xba,0xd6,0xff,0xba,0xd5,0xff,0xba,0xd4,0xff,0xba,0xd4,0xff,0xba,0xd3,0xff,0xba,0xd2,0xff,0xba,0xd1,0xff,0xba,0xd0,0xfe,0xb9,0xd0,0xfe,0xb9,0xcf,0xfe,0xb9,0xce,0xfe,0xb9,0xcd,0xfe,0xb9,0xcc,0xfe,0xb9,0xcc,0xfe,0xb9,0xcb,0xfe,0xb9,0xca,0xfe,0xb8,0xc9,0xfe,0xb8,0xc9,0xfe,0xb8,0xc8,0xfd,0xb8,0xc7,0xfd,0xb8,0xc6,0xfd,0xb8,0xc5,0xfd,0xb8,0xc5,0xfd,0xb8,0xc4,0xfd,0xb8,0xc3,0xfd,0xb8,0xc2,0xfc,0xb9,0xc1,0xfc,0xb9,0xc0,0xfb,0xba,0xbf,0xfb,0xba,0xbe,0xfb,0xba,0xbd,0xfa,0xbb,0xbc,0xfa,0xbb,0xbc,0xfa,0xbb,0xbb,0xf9,0xbc,0xba,0xf9,0xbc,0xb9,0xf8,0xbc,0xb8,0xf8,0xbd,0xb7,0xf8,0xbd,0xb6,0xf7,0xbd,0xb5,0xf7,0xbe,0xb4,0xf7,0xbe,0xb3,0xf6,0xbe,0xb2,0xf6,0xbf,0xb1,0xf5,0xbf,0xb1,0xf5,0xbf,0xb0,0xf5,0xc0,0xaf,0xf4,0xc0,0xae,0xf4,0xc1,0xad,0xf3,0xc2,0xac,0xf2,0xc3,0xab,0xf1,0xc3,0xaa,0xf1,0xc4,0xa9,0xf0,0xc5,0xa8,0xef,0xc5,0xa6,0xee,0xc6,0xa5,0xee,0xc7,0xa4,0xed,0xc7,0xa3,0xec,0xc8,0xa2,0xeb,0xc9,0xa1,0xeb,0xc9,0xa0,0xea,0xca,0x9f,0xe9,0xca,0x9e,0xe8,0xcb,0x9d,0xe8,0xcc,0x9c,0xe7,0xcc,0x9b,0xe6,0xcd,0x9a,0xe5,0xcd,0x99,0xe5,0xce,0x98,0xe4,0xce,0x97,0xe3,0xcf,0x96,0xe2,0xd0,0x95,0xe1,0xd1,0x93,0xe0,0xd1,0x92,0xde,0xd2,0x91,0xdd,0xd3,0x90,0xdc,0xd4,0x8f,0xdb,0xd4,0x8e,0xda,0xd5,0x8d,0xd8,0xd6,0x8b,0xd7,0xd6,0x8a,0xd6,0xd7,0x89,0xd5,0xd8,0x88,0xd4,0xd8,0x87,0xd3,0xd9,0x86,0xd1,0xda,0x84,0xd0,0xda,0x83,0xcf,0xdb,0x82,0xce,0xdc,0x81,0xcd,0xdc,0x80,0xcc,0xdd,0x7e,0xca,0xdd,0x7d,0xc9,0xde,0x7c,0xc8,0xdf,0x7b,0xc7,0xdf,0x7a,0xc5,0xe0,0x78,0xc3,0xe0,0x77,0xc2,0xe1,0x76,0xc0,0xe1,0x75,0xbf,0xe2,0x74,0xbd,0xe2,0x72,0xbb,0xe3,0x71,0xba,0xe3,0x70,0xb8,0xe4,0x6f,0xb7,0xe4,0x6e,0xb5,0xe5,0x6c,0xb4,0xe5,0x6b,0xb2,0xe6,0x6a,0xb0,0xe6,0x68,0xaf,0xe7,0x67,0xad,0xe7,0x66,0xac,0xe8,0x65,0xaa,0xe8,0x63,0xa9,0xe8,0x62,0xa7,0xe9,0x60,0xa6,0xe9,0x5f,0xa4,0xe9,0x5e,0xa2,0xea,0x5d,0xa0,0xea,0x5c,0x9e,0xea,0x5a,0x9d,0xea,0x59,0x9b,0xea,0x58,0x99,0xeb,0x57,0x97,0xeb,0x55,0x95,0xeb,0x54,0x93,0xeb,0x53,0x91,0xeb,0x52,0x8f,0xeb,0x50,0x8d,0xeb,0x4f,0x8c,0xeb,0x4e,0x8a,0xec,0x4d,0x88,0xec,0x4b,0x86,0xec,0x4a,0x84,0xec,0x49,0x82,0xec,0x47,0x80,0xec,0x46,0x7e,0xec,0x44,0x7d,0xec,0x43,0x7b,0xec,0x42,0x79,0xec,0x40,0x77,0xec,0x3f,0x75,0xeb,0x3e,0x73,0xeb,0x3d,0x71,0xeb,0x3c,0x6f,0xea,0x3b,0x6c,0xea,0x3a,0x6a,0xea,0x39,0x68,0xea,0x38,0x66,0xe9,0x37,0x64,0xe9,0x36,0x62,0xe8,0x35,0x60,0xe8,0x34,0x5e,0xe8,0x33,0x5c,0xe7,0x32,0x5a,0xe7,0x31,0x58,0xe7,0x30,0x56,0xe6,0x2e,0x54,0xe6,0x2d,0x52,0xe5,0x2c,0x4f,0xe5,0x2b,0x4d,0xe5,0x2a,0x4b,0xe4,0x28,0x49,0xe4,0x27,0x47,0xe3,0x27,0x45,0xe2,0x27,0x43,0xe1,0x26,0x41,0xe0,0x26,0x3e,0xe0,0x26,0x3c,0xdf,0x26,0x3a,0xde,0x25,0x38,0xdd,0x25,0x35,0xdc,0x25,0x33,0xdb,0x24,0x31,0xdb,0x24,0x2f,0xda,0x24,0x2c,0xd9,0x24,0x2a,0xd8,0x23,0x27,0xd7,0x23,0x25,0xd6,0x23,0x23,0xd5,0x22,0x20,0xd5,0x22,0x1d,0xd4,0x22,0x1b,0xd3,0x22,0x18,0xd2,0x22,0x15,0xd1,0x21,0x12,0xd0,0x21,0x0e};
	static constexpr std::array<uint8_t, 768> L20  = {0x30,0x30,0x30,0x31,0x31,0x33,0x32,0x31,0x35,0x33,0x31,0x38,0x34,0x32,0x3b,0x35,0x32,0x3d,0x36,0x32,0x40,0x36,0x33,0x42,0x37,0x33,0x45,0x38,0x33,0x47,0x39,0x34,0x4a,0x39,0x34,0x4c,0x3a,0x34,0x4f,0x3b,0x35,0x51,0x3b,0x35,0x54,0x3c,0x36,0x56,0x3c,0x36,0x59,0x3d,0x36,0x5b,0x3d,0x37,0x5e,0x3e,0x37,0x60,0x3e,0x37,0x63,0x3f,0x38,0x65,0x3f,0x38,0x68,0x40,0x39,0x6a,0x40,0x39,0x6c,0x40,0x39,0x6f,0x41,0x3a,0x71,0x41,0x3a,0x74,0x41,0x3b,0x76,0x42,0x3b,0x78,0x42,0x3c,0x7b,0x42,0x3c,0x7d,0x42,0x3d,0x7f,0x42,0x3d,0x82,0x43,0x3e,0x84,0x43,0x3e,0x86,0x43,0x3f,0x89,0x43,0x3f,0x8b,0x43,0x40,0x8d,0x43,0x40,0x8f,0x43,0x41,0x91,0x43,0x41,0x93,0x43,0x42,0x96,0x43,0x42,0x98,0x43,0x43,0x9a,0x43,0x43,0x9c,0x43,0x44,0x9e,0x43,0x45,0xa0,0x43,0x45,0xa2,0x42,0x46,0xa4,0x42,0x47,0xa6,0x42,0x47,0xa8,0x42,0x48,0xa9,0x42,0x49,0xab,0x42,0x49,0xad,0x41,0x4a,0xaf,0x41,0x4b,0xb0,0x41,0x4b,0xb2,0x41,0x4c,0xb4,0x40,0x4d,0xb5,0x40,0x4e,0xb7,0x40,0x4e,0xb8,0x3f,0x4f,0xba,0x3f,0x50,0xbb,0x3f,0x51,0xbc,0x3e,0x52,0xbe,0x3e,0x53,0xbf,0x3d,0x53,0xc0,0x3d,0x54,0xc1,0x3d,0x55,0xc2,0x3c,0x56,0xc3,0x3c,0x57,0xc4,0x3b,0x58,0xc5,0x3b,0x59,0xc6,0x3a,0x5a,0xc6,0x3a,0x5b,0xc7,0x3a,0x5c,0xc8,0x39,0x5d,0xc8,0x39,0x5e,0xc8,0x38,0x60,0xc9,0x37,0x61,0xc9,0x37,0x62,0xc9,0x36,0x63,0xc9,0x36,0x64,0xc8,0x35,0x65,0xc8,0x34,0x67,0xc8,0x34,0x68,0xc7,0x33,0x69,0xc6,0x32,0x6b,0xc5,0x31,0x6c,0xc4,0x30,0x6e,0xc3,0x2f,0x6f,0xc1,0x2e,0x70,0xc0,0x2d,0x72,0xbe,0x2b,0x74,0xbb,0x2a,0x75,0xb9,0x29,0x77,0xb7,0x27,0x78,0xb5,0x26,0x7a,0xb3,0x25,0x7b,0xb0,0x24,0x7c,0xae,0x24,0x7e,0xac,0x23,0x7f,0xaa,0x22,0x80,0xa8,0x22,0x82,0xa6,0x22,0x83,0xa4,0x22,0x84,0xa1,0x22,0x85,0x9f,0x22,0x86,0x9d,0x23,0x88,0x9b,0x24,0x89,0x99,0x24,0x8a,0x97,0x25,0x8b,0x95,0x26,0x8c,0x93,0x28,0x8d,0x91,0x29,0x8e,0x8f,0x2a,0x8f,0x8d,0x2c,0x90,0x8b,0x2d,0x91,0x89,0x2f,0x92,0x87,0x31,0x93,0x85,0x33,0x94,0x83,0x35,0x95,0x81,0x37,0x96,0x7f,0x39,0x97,0x7d,0x3b,0x98,0x7b,0x3d,0x98,0x79,0x3f,0x99,0x78,0x42,0x9a,0x76,0x44,0x9b,0x74,0x46,0x9c,0x72,0x49,0x9d,0x70,0x4b,0x9d,0x6e,0x4e,0x9e,0x6c,0x50,0x9f,0x6a,0x53,0x9f,0x68,0x55,0xa0,0x67,0x58,0xa1,0x65,0x5b,0xa2,0x63,0x5d,0xa2,0x61,0x60,0xa3,0x5f,0x63,0xa3,0x5d,0x66,0xa4,0x5b,0x69,0xa5,0x59,0x6c,0xa5,0x57,0x6f,0xa6,0x56,0x71,0xa6,0x54,0x74,0xa7,0x52,0x77,0xa7,0x50,0x7a,0xa8,0x4e,0x7c,0xa8,0x4c,0x7f,0xa9,0x4a,0x82,0xa9,0x48,0x84,0xaa,0x47,0x87,0xaa,0x45,0x89,0xab,0x43,0x8c,0xab,0x41,0x8f,0xac,0x3f,0x91,0xac,0x3d,0x94,0xad,0x3b,0x96,0xad,0x3a,0x98,0xae,0x38,0x9b,0xae,0x36,0x9d,0xae,0x34,0xa0,0xaf,0x32,0xa2,0xaf,0x30,0xa5,0xb0,0x2e,0xa7,0xb0,0x2d,0xaa,0xb0,0x2b,0xac,0xb1,0x29,0xaf,0xb1,0x27,0xb1,0xb2,0x25,0xb4,0xb2,0x24,0xb6,0xb2,0x22,0xb9,0xb3,0x20,0xbb,0xb3,0x1e,0xbe,0xb3,0x1d,0xc0,0xb3,0x1b,0xc3,0xb4,0x19,0xc5,0xb4,0x18,0xc8,0xb4,0x17,0xcb,0xb4,0x15,0xcd,0xb5,0x14,0xd0,0xb5,0x13,0xd3,0xb5,0x13,0xd5,0xb5,0x12,0xd8,0xb5,0x12,0xdb,0xb5,0x12,0xdd,0xb6,0x12,0xe0,0xb6,0x13,0xe2,0xb6,0x13,0xe4,0xb6,0x13,0xe6,0xb7,0x13,0xe8,0xb7,0x13,0xe9,0xb8,0x14,0xeb,0xb8,0x14,0xec,0xb9,0x14,0xee,0xba,0x14,0xef,0xba,0x14,0xf0,0xbb,0x14,0xf1,0xbc,0x14,0xf2,0xbc,0x14,0xf3,0xbd,0x14,0xf4,0xbe,0x14,0xf5,0xbf,0x14,0xf6,0xc0,0x14,0xf7,0xc1,0x14,0xf7,0xc1,0x14,0xf8,0xc2,0x14,0xf9,0xc3,0x14,0xf9,0xc4,0x14,0xfa,0xc5,0x14,0xfa,0xc6,0x14,0xfb,0xc7,0x14,0xfb,0xc8,0x14,0xfc,0xc9,0x14,0xfc,0xca,0x14,0xfd,0xcb,0x13,0xfd,0xcc,0x13,0xfd,0xcd,0x13,0xfd,0xcf,0x13,0xfe,0xd0,0x13,0xfe,0xd1,0x13,0xfe,0xd2,0x13,0xfe,0xd3,0x13,0xfe,0xd4,0x12,0xfe,0xd5,0x12,0xff,0xd6,0x12,0xff,0xd8,0x12,0xff,0xd9,0x12,0xff,0xda,0x12,0xff,0xdb,0x11,0xff,0xdc,0x11,0xff,0xdd,0x11,0xff,0xdf,0x11,0xfe,0xe0,0x10,0xfe,0xe1,0x10,0xfe,0xe2,0x10,0xfe,0xe3,0x10,0xfe,0xe5,0x0f,0xfe,0xe6,0x0f,0xfe,0xe7,0x0f,0xfd,0xe8,0x0f,0xfd,0xea,0x0e,0xfd,0xeb,0x0e,0xfd,0xec,0x0e,0xfc,0xed,0x0d,0xfc,0xef,0x0d,0xfc,0xf0,0x0d,0xfb,0xf1,0x0c,0xfb,0xf2,0x0c,0xfa,0xf4,0x0c,0xfa,0xf5,0x0b,0xfa,0xf6,0x0b,0xf9,0xf7,0x0a,0xf9,0xf9,0x0a};

	// diverging
	static constexpr std::array<uint8_t, 768> D01  = {0x21,0x51,0xdb,0x25,0x52,0xdb,0x2a,0x53,0xdb,0x2e,0x54,0xdc,0x31,0x55,0xdc,0x35,0x56,0xdc,0x38,0x57,0xdc,0x3b,0x58,0xdc,0x3e,0x59,0xdd,0x41,0x5b,0xdd,0x43,0x5c,0xdd,0x46,0x5d,0xdd,0x48,0x5e,0xdd,0x4b,0x5f,0xde,0x4d,0x60,0xde,0x50,0x61,0xde,0x52,0x63,0xde,0x54,0x64,0xdf,0x56,0x65,0xdf,0x58,0x66,0xdf,0x5a,0x67,0xdf,0x5c,0x68,0xdf,0x5e,0x69,0xe0,0x60,0x6b,0xe0,0x62,0x6c,0xe0,0x64,0x6d,0xe0,0x66,0x6e,0xe0,0x68,0x6f,0xe1,0x69,0x70,0xe1,0x6b,0x72,0xe1,0x6d,0x73,0xe1,0x6f,0x74,0xe1,0x70,0x75,0xe2,0x72,0x76,0xe2,0x74,0x78,0xe2,0x75,0x79,0xe2,0x77,0x7a,0xe2,0x79,0x7b,0xe3,0x7a,0x7c,0xe3,0x7c,0x7e,0xe3,0x7d,0x7f,0xe3,0x7f,0x80,0xe3,0x81,0x81,0xe4,0x82,0x82,0xe4,0x84,0x84,0xe4,0x85,0x85,0xe4,0x87,0x86,0xe4,0x88,0x87,0xe5,0x8a,0x88,0xe5,0x8b,0x8a,0xe5,0x8d,0x8b,0xe5,0x8e,0x8c,0xe5,0x8f,0x8d,0xe5,0x91,0x8f,0xe6,0x92,0x90,0xe6,0x94,0x91,0xe6,0x95,0x92,0xe6,0x97,0x94,0xe6,0x98,0x95,0xe7,0x99,0x96,0xe7,0x9b,0x97,0xe7,0x9c,0x99,0xe7,0x9e,0x9a,0xe7,0x9f,0x9b,0xe7,0xa0,0x9c,0xe8,0xa2,0x9e,0xe8,0xa3,0x9f,0xe8,0xa4,0xa0,0xe8,0xa6,0xa1,0xe8,0xa7,0xa3,0xe8,0xa8,0xa4,0xe9,0xaa,0xa5,0xe9,0xab,0xa6,0xe9,0xac,0xa8,0xe9,0xae,0xa9,0xe9,0xaf,0xaa,0xe9,0xb0,0xac,0xea,0xb2,0xad,0xea,0xb3,0xae,0xea,0xb4,0xaf,0xea,0xb5,0xb1,0xea,0xb7,0xb2,0xea,0xb8,0xb3,0xeb,0xb9,0xb4,0xeb,0xbb,0xb6,0xeb,0xbc,0xb7,0xeb,0xbd,0xb8,0xeb,0xbe,0xba,0xeb,0xc0,0xbb,0xeb,0xc1,0xbc,0xec,0xc2,0xbe,0xec,0xc3,0xbf,0xec,0xc5,0xc0,0xec,0xc6,0xc1,0xec,0xc7,0xc3,0xec,0xc8,0xc4,0xec,0xca,0xc5,0xed,0xcb,0xc7,0xed,0xcc,0xc8,0xed,0xcd,0xc9,0xed,0xcf,0xcb,0xed,0xd0,0xcc,0xed,0xd1,0xcd,0xed,0xd2,0xcf,0xee,0xd3,0xd0,0xee,0xd5,0xd1,0xee,0xd6,0xd3,0xee,0xd7,0xd4,0xee,0xd8,0xd5,0xee,0xda,0xd7,0xee,0xdb,0xd8,0xee,0xdc,0xd9,0xef,0xdd,0xda,0xef,0xde,0xdc,0xef,0xe0,0xdd,0xef,0xe1,0xde,0xef,0xe2,0xe0,0xef,0xe3,0xe1,0xef,0xe4,0xe2,0xef,0xe5,0xe3,0xef,0xe6,0xe4,0xee,0xe7,0xe5,0xee,0xe8,0xe5,0xee,0xe9,0xe6,0xed,0xea,0xe7,0xed,0xeb,0xe7,0xec,0xec,0xe7,0xeb,0xed,0xe7,0xea,0xee,0xe7,0xe9,0xee,0xe7,0xe8,0xef,0xe6,0xe7,0xef,0xe6,0xe6,0xf0,0xe5,0xe4,0xf0,0xe4,0xe3,0xf1,0xe3,0xe1,0xf1,0xe2,0xdf,0xf1,0xe1,0xdd,0xf1,0xe0,0xdc,0xf1,0xde,0xda,0xf2,0xdd,0xd8,0xf2,0xdb,0xd6,0xf2,0xda,0xd4,0xf2,0xd8,0xd2,0xf2,0xd7,0xd0,0xf2,0xd5,0xce,0xf2,0xd4,0xcc,0xf2,0xd2,0xcb,0xf2,0xd1,0xc9,0xf2,0xcf,0xc7,0xf2,0xce,0xc5,0xf2,0xcc,0xc3,0xf1,0xcb,0xc1,0xf1,0xc9,0xbf,0xf1,0xc7,0xbd,0xf1,0xc6,0xbb,0xf1,0xc4,0xb9,0xf1,0xc3,0xb7,0xf1,0xc1,0xb5,0xf1,0xc0,0xb4,0xf0,0xbe,0xb2,0xf0,0xbd,0xb0,0xf0,0xbb,0xae,0xf0,0xb9,0xac,0xf0,0xb8,0xaa,0xf0,0xb6,0xa8,0xef,0xb5,0xa6,0xef,0xb3,0xa5,0xef,0xb2,0xa3,0xef,0xb0,0xa1,0xee,0xaf,0x9f,0xee,0xad,0x9d,0xee,0xac,0x9b,0xee,0xaa,0x99,0xed,0xa8,0x98,0xed,0xa7,0x96,0xed,0xa5,0x94,0xed,0xa4,0x92,0xec,0xa2,0x90,0xec,0xa1,0x8e,0xec,0x9f,0x8c,0xeb,0x9d,0x8b,0xeb,0x9c,0x89,0xeb,0x9a,0x87,0xea,0x99,0x85,0xea,0x97,0x83,0xea,0x96,0x82,0xe9,0x94,0x80,0xe9,0x93,0x7e,0xe8,0x91,0x7c,0xe8,0x8f,0x7a,0xe8,0x8e,0x79,0xe7,0x8c,0x77,0xe7,0x8b,0x75,0xe6,0x89,0x73,0xe6,0x88,0x71,0xe6,0x86,0x70,0xe5,0x84,0x6e,0xe5,0x83,0x6c,0xe4,0x81,0x6a,0xe4,0x80,0x69,0xe3,0x7e,0x67,0xe3,0x7c,0x65,0xe2,0x7b,0x63,0xe2,0x79,0x62,0xe1,0x78,0x60,0xe1,0x76,0x5e,0xe0,0x74,0x5c,0xe0,0x73,0x5b,0xdf,0x71,0x59,0xdf,0x6f,0x57,0xde,0x6e,0x55,0xde,0x6c,0x54,0xdd,0x6a,0x52,0xdd,0x69,0x50,0xdc,0x67,0x4f,0xdb,0x66,0x4d,0xdb,0x64,0x4b,0xda,0x62,0x49,0xda,0x60,0x48,0xd9,0x5f,0x46,0xd8,0x5d,0x44,0xd8,0x5b,0x43,0xd7,0x5a,0x41,0xd7,0x58,0x3f,0xd6,0x56,0x3e,0xd5,0x54,0x3c,0xd5,0x52,0x3a,0xd4,0x51,0x38,0xd3,0x4f,0x37,0xd3,0x4d,0x35,0xd2,0x4b,0x33,0xd1,0x49,0x32,0xd1,0x47,0x30,0xd0,0x45,0x2e,0xcf,0x44,0x2d,0xcf,0x42,0x2b,0xce,0x40,0x29,0xcd,0x3d,0x28,0xcd,0x3b,0x26,0xcc,0x39,0x24,0xcb,0x37,0x22,0xca,0x35,0x21,0xca,0x33,0x1f,0xc9,0x30,0x1d,0xc8,0x2e,0x1b,0xc8,0x2b,0x1a,0xc7,0x29,0x18,0xc6,0x26,0x16,0xc5,0x23,0x14,0xc5,0x20,0x12,0xc4,0x1c,0x10,0xc3,0x19,0x0e,0xc2,0x14,0x0c,0xc1,0x0f,0x0a,0xc1,0x09,0x08,0xc0,0x02,0x06};
	static constexpr std::array<uint8_t, 768> D01A = {0x17,0x29,0x72,0x18,0x2a,0x75,0x18,0x2b,0x78,0x19,0x2c,0x7b,0x19,0x2d,0x7e,0x19,0x2f,0x80,0x1a,0x30,0x83,0x1a,0x31,0x86,0x1a,0x32,0x89,0x1b,0x33,0x8c,0x1b,0x34,0x8f,0x1b,0x35,0x92,0x1c,0x36,0x95,0x1c,0x38,0x98,0x1c,0x39,0x9b,0x1c,0x3a,0x9e,0x1d,0x3b,0xa1,0x1d,0x3c,0xa4,0x1d,0x3d,0xa7,0x1e,0x3e,0xab,0x1e,0x40,0xae,0x1e,0x41,0xb1,0x1f,0x42,0xb4,0x1f,0x43,0xb7,0x20,0x44,0xba,0x20,0x46,0xbd,0x21,0x47,0xbf,0x22,0x48,0xc2,0x23,0x49,0xc5,0x24,0x4a,0xc8,0x25,0x4c,0xca,0x27,0x4d,0xcd,0x29,0x4e,0xcf,0x2b,0x50,0xd2,0x2d,0x51,0xd4,0x2f,0x52,0xd6,0x31,0x54,0xd8,0x34,0x55,0xd9,0x37,0x56,0xdb,0x39,0x58,0xdc,0x3c,0x59,0xde,0x3f,0x5b,0xdf,0x42,0x5c,0xe0,0x44,0x5d,0xe1,0x47,0x5f,0xe2,0x4a,0x60,0xe3,0x4d,0x62,0xe4,0x4f,0x63,0xe5,0x52,0x65,0xe6,0x55,0x66,0xe7,0x57,0x68,0xe8,0x5a,0x69,0xe9,0x5c,0x6b,0xea,0x5f,0x6c,0xeb,0x61,0x6e,0xeb,0x63,0x6f,0xec,0x66,0x71,0xed,0x68,0x73,0xee,0x6a,0x74,0xef,0x6d,0x76,0xf0,0x6f,0x77,0xf0,0x71,0x79,0xf1,0x73,0x7a,0xf2,0x75,0x7c,0xf3,0x77,0x7e,0xf4,0x7a,0x7f,0xf4,0x7c,0x81,0xf5,0x7e,0x82,0xf6,0x80,0x84,0xf7,0x82,0x85,0xf7,0x84,0x87,0xf8,0x86,0x89,0xf9,0x88,0x8a,0xf9,0x8a,0x8c,0xfa,0x8d,0x8e,0xfb,0x8f,0x8f,0xfb,0x91,0x91,0xfb,0x93,0x93,0xfc,0x95,0x94,0xfc,0x97,0x96,0xfc,0x99,0x98,0xfc,0x9b,0x99,0xfd,0x9d,0x9b,0xfd,0x9f,0x9d,0xfd,0xa1,0x9f,0xfd,0xa3,0xa0,0xfc,0xa5,0xa2,0xfc,0xa7,0xa4,0xfc,0xa9,0xa6,0xfc,0xab,0xa7,0xfc,0xad,0xa9,0xfc,0xaf,0xab,0xfc,0xb1,0xad,0xfb,0xb3,0xaf,0xfb,0xb5,0xb0,0xfb,0xb7,0xb2,0xfb,0xb9,0xb4,0xfa,0xbb,0xb6,0xfa,0xbd,0xb8,0xfa,0xbf,0xb9,0xfa,0xc0,0xbb,0xf9,0xc2,0xbd,0xf9,0xc4,0xbf,0xf9,0xc6,0xc1,0xf9,0xc8,0xc3,0xf8,0xc9,0xc4,0xf8,0xcb,0xc6,0xf8,0xcd,0xc8,0xf7,0xcf,0xca,0xf7,0xd0,0xcc,0xf7,0xd2,0xce,0xf7,0xd4,0xcf,0xf6,0xd6,0xd1,0xf6,0xd7,0xd3,0xf5,0xd9,0xd5,0xf5,0xdb,0xd7,0xf5,0xdc,0xd8,0xf4,0xde,0xda,0xf4,0xe0,0xdb,0xf3,0xe1,0xdd,0xf2,0xe3,0xde,0xf2,0xe5,0xdf,0xf1,0xe6,0xe1,0xf0,0xe8,0xe1,0xef,0xe9,0xe2,0xed,0xeb,0xe3,0xec,0xec,0xe3,0xea,0xed,0xe3,0xe9,0xef,0xe3,0xe7,0xf0,0xe2,0xe5,0xf1,0xe1,0xe3,0xf2,0xe1,0xe1,0xf3,0xdf,0xde,0xf4,0xde,0xdc,0xf5,0xdd,0xd9,0xf6,0xdb,0xd6,0xf7,0xd9,0xd4,0xf7,0xd7,0xd1,0xf8,0xd5,0xce,0xf9,0xd3,0xcb,0xf9,0xd1,0xc9,0xfa,0xcf,0xc6,0xfa,0xcd,0xc3,0xfa,0xca,0xc0,0xfb,0xc8,0xbd,0xfb,0xc6,0xba,0xfb,0xc3,0xb7,0xfc,0xc1,0xb5,0xfc,0xbf,0xb2,0xfc,0xbd,0xaf,0xfc,0xba,0xac,0xfc,0xb8,0xa9,0xfc,0xb6,0xa6,0xfd,0xb3,0xa4,0xfd,0xb1,0xa1,0xfd,0xaf,0x9e,0xfd,0xac,0x9b,0xfd,0xaa,0x98,0xfd,0xa7,0x96,0xfd,0xa5,0x93,0xfd,0xa3,0x90,0xfd,0xa0,0x8d,0xfd,0x9e,0x8b,0xfc,0x9c,0x88,0xfc,0x99,0x85,0xfc,0x97,0x82,0xfc,0x94,0x80,0xfc,0x92,0x7d,0xfb,0x90,0x7a,0xfb,0x8d,0x78,0xfb,0x8b,0x75,0xfa,0x88,0x73,0xfa,0x86,0x70,0xf9,0x84,0x6d,0xf9,0x81,0x6b,0xf8,0x7f,0x69,0xf8,0x7d,0x66,0xf7,0x7a,0x64,0xf6,0x78,0x61,0xf5,0x76,0x5f,0xf5,0x73,0x5d,0xf4,0x71,0x5b,0xf3,0x6f,0x58,0xf2,0x6d,0x56,0xf1,0x6b,0x54,0xf0,0x68,0x52,0xef,0x66,0x50,0xed,0x64,0x4e,0xec,0x62,0x4c,0xeb,0x60,0x4a,0xea,0x5e,0x48,0xe9,0x5b,0x46,0xe7,0x59,0x44,0xe6,0x57,0x42,0xe5,0x55,0x40,0xe4,0x53,0x3f,0xe2,0x50,0x3d,0xe1,0x4e,0x3b,0xe0,0x4c,0x39,0xdf,0x49,0x37,0xdd,0x47,0x35,0xdc,0x45,0x33,0xdb,0x42,0x31,0xd9,0x40,0x2f,0xd8,0x3d,0x2d,0xd7,0x3b,0x2c,0xd6,0x38,0x2a,0xd4,0x36,0x28,0xd3,0x33,0x26,0xd1,0x30,0x24,0xd0,0x2e,0x22,0xcf,0x2b,0x21,0xcd,0x28,0x1f,0xcc,0x25,0x1d,0xca,0x22,0x1b,0xc8,0x1f,0x1a,0xc7,0x1c,0x18,0xc5,0x19,0x17,0xc3,0x16,0x15,0xc1,0x13,0x14,0xbf,0x10,0x13,0xbd,0x0d,0x12,0xbb,0x0a,0x11,0xb9,0x07,0x10,0xb6,0x05,0x0f,0xb4,0x03,0x0e,0xb2,0x02,0x0d,0xaf,0x01,0x0d,0xad,0x00,0x0c,0xaa,0x00,0x0c,0xa7,0x00,0x0c,0xa5,0x00,0x0b,0xa2,0x00,0x0b,0x9f,0x01,0x0b,0x9d,0x01,0x0a,0x9a,0x02,0x0a,0x97,0x02,0x0a,0x95,0x02,0x0a,0x92,0x03,0x09,0x8f,0x03,0x09,0x8d,0x04,0x09,0x8a,0x04,0x08,0x87,0x04,0x08,0x85,0x05,0x08,0x82,0x05,0x07,0x80,0x05,0x07,0x7d,0x06,0x07,0x7a,0x06,0x06,0x78,0x06,0x06,0x75,0x06,0x05,0x73,0x07,0x05,0x70,0x07,0x04,0x6e,0x07,0x04,0x6b,0x07,0x03,0x69,0x07,0x03,0x66,0x07,0x02};
	static constexpr std::array<uint8_t, 768> D02  = {0x39,0x97,0x0e,0x3b,0x97,0x12,0x3d,0x98,0x15,0x3f,0x99,0x18,0x40,0x9a,0x1a,0x42,0x9a,0x1d,0x44,0x9b,0x1f,0x46,0x9c,0x22,0x48,0x9c,0x24,0x4a,0x9d,0x26,0x4b,0x9e,0x28,0x4d,0x9f,0x2a,0x4f,0x9f,0x2c,0x51,0xa0,0x2e,0x52,0xa1,0x30,0x54,0xa1,0x32,0x56,0xa2,0x34,0x57,0xa3,0x36,0x59,0xa4,0x38,0x5a,0xa4,0x39,0x5c,0xa5,0x3b,0x5e,0xa6,0x3d,0x5f,0xa6,0x3f,0x61,0xa7,0x41,0x62,0xa8,0x42,0x64,0xa9,0x44,0x65,0xa9,0x46,0x67,0xaa,0x47,0x68,0xab,0x49,0x6a,0xab,0x4b,0x6b,0xac,0x4d,0x6d,0xad,0x4e,0x6e,0xae,0x50,0x70,0xae,0x52,0x71,0xaf,0x53,0x73,0xb0,0x55,0x74,0xb0,0x57,0x76,0xb1,0x58,0x77,0xb2,0x5a,0x79,0xb2,0x5c,0x7a,0xb3,0x5d,0x7c,0xb4,0x5f,0x7d,0xb5,0x61,0x7e,0xb5,0x62,0x80,0xb6,0x64,0x81,0xb7,0x66,0x83,0xb7,0x67,0x84,0xb8,0x69,0x85,0xb9,0x6a,0x87,0xba,0x6c,0x88,0xba,0x6e,0x8a,0xbb,0x6f,0x8b,0xbc,0x71,0x8c,0xbc,0x73,0x8e,0xbd,0x74,0x8f,0xbe,0x76,0x91,0xbe,0x78,0x92,0xbf,0x79,0x93,0xc0,0x7b,0x95,0xc1,0x7c,0x96,0xc1,0x7e,0x97,0xc2,0x80,0x99,0xc3,0x81,0x9a,0xc3,0x83,0x9b,0xc4,0x85,0x9d,0xc5,0x86,0x9e,0xc5,0x88,0xa0,0xc6,0x8a,0xa1,0xc7,0x8b,0xa2,0xc8,0x8d,0xa4,0xc8,0x8e,0xa5,0xc9,0x90,0xa6,0xca,0x92,0xa8,0xca,0x93,0xa9,0xcb,0x95,0xaa,0xcc,0x97,0xac,0xcc,0x98,0xad,0xcd,0x9a,0xae,0xce,0x9c,0xb0,0xce,0x9d,0xb1,0xcf,0x9f,0xb2,0xd0,0xa1,0xb4,0xd1,0xa2,0xb5,0xd1,0xa4,0xb6,0xd2,0xa6,0xb8,0xd3,0xa7,0xb9,0xd3,0xa9,0xba,0xd4,0xab,0xbc,0xd5,0xac,0xbd,0xd5,0xae,0xbe,0xd6,0xb0,0xc0,0xd7,0xb1,0xc1,0xd8,0xb3,0xc2,0xd8,0xb5,0xc4,0xd9,0xb6,0xc5,0xda,0xb8,0xc6,0xda,0xba,0xc7,0xdb,0xbb,0xc9,0xdc,0xbd,0xca,0xdc,0xbf,0xcb,0xdd,0xc0,0xcd,0xde,0xc2,0xce,0xde,0xc4,0xcf,0xdf,0xc5,0xd1,0xe0,0xc7,0xd2,0xe0,0xc9,0xd3,0xe1,0xca,0xd5,0xe2,0xcc,0xd6,0xe3,0xce,0xd7,0xe3,0xcf,0xd9,0xe4,0xd1,0xda,0xe5,0xd3,0xdb,0xe5,0xd5,0xdc,0xe6,0xd6,0xde,0xe7,0xd8,0xdf,0xe7,0xda,0xe0,0xe8,0xdb,0xe1,0xe8,0xdd,0xe3,0xe9,0xde,0xe4,0xe9,0xe0,0xe5,0xea,0xe2,0xe6,0xea,0xe3,0xe7,0xeb,0xe4,0xe8,0xeb,0xe6,0xe9,0xeb,0xe7,0xea,0xeb,0xe8,0xea,0xeb,0xe9,0xeb,0xeb,0xea,0xec,0xeb,0xeb,0xec,0xea,0xec,0xec,0xea,0xed,0xed,0xe9,0xed,0xed,0xe9,0xee,0xed,0xe8,0xee,0xed,0xe7,0xef,0xed,0xe6,0xef,0xed,0xe5,0xef,0xed,0xe4,0xef,0xec,0xe3,0xef,0xec,0xe2,0xf0,0xec,0xe1,0xf0,0xec,0xe0,0xf0,0xeb,0xdf,0xf0,0xeb,0xde,0xf0,0xeb,0xdd,0xef,0xea,0xdc,0xef,0xea,0xda,0xef,0xea,0xd9,0xef,0xe9,0xd8,0xef,0xe9,0xd7,0xef,0xe9,0xd6,0xef,0xe8,0xd5,0xef,0xe8,0xd4,0xef,0xe7,0xd2,0xef,0xe7,0xd1,0xef,0xe7,0xd0,0xef,0xe6,0xcf,0xef,0xe6,0xce,0xef,0xe6,0xcd,0xee,0xe5,0xcc,0xee,0xe5,0xca,0xee,0xe4,0xc9,0xee,0xe4,0xc8,0xee,0xe4,0xc7,0xee,0xe3,0xc6,0xee,0xe3,0xc5,0xee,0xe2,0xc4,0xee,0xe2,0xc2,0xee,0xe2,0xc1,0xee,0xe1,0xc0,0xee,0xe1,0xbf,0xed,0xe0,0xbe,0xed,0xe0,0xbd,0xed,0xe0,0xbb,0xed,0xdf,0xba,0xed,0xdf,0xb9,0xed,0xde,0xb8,0xed,0xde,0xb7,0xed,0xde,0xb6,0xed,0xdd,0xb5,0xed,0xdd,0xb3,0xed,0xdc,0xb2,0xed,0xdc,0xb1,0xec,0xdb,0xb0,0xec,0xdb,0xaf,0xec,0xdb,0xae,0xec,0xda,0xad,0xec,0xda,0xab,0xec,0xd9,0xaa,0xec,0xd9,0xa9,0xec,0xd8,0xa8,0xec,0xd8,0xa7,0xec,0xd8,0xa6,0xeb,0xd7,0xa4,0xeb,0xd7,0xa3,0xeb,0xd6,0xa2,0xeb,0xd6,0xa1,0xeb,0xd5,0xa0,0xeb,0xd5,0x9f,0xeb,0xd4,0x9e,0xeb,0xd4,0x9c,0xeb,0xd3,0x9b,0xeb,0xd3,0x9a,0xea,0xd3,0x99,0xea,0xd2,0x98,0xea,0xd2,0x97,0xea,0xd1,0x95,0xea,0xd1,0x94,0xea,0xd0,0x93,0xea,0xd0,0x92,0xea,0xcf,0x91,0xea,0xcf,0x90,0xea,0xce,0x8e,0xe9,0xce,0x8d,0xe9,0xcd,0x8c,0xe9,0xcd,0x8b,0xe9,0xcc,0x8a,0xe9,0xcc,0x88,0xe9,0xcb,0x87,0xe9,0xcb,0x86,0xe9,0xca,0x85,0xe9,0xca,0x84,0xe8,0xc9,0x82,0xe8,0xc9,0x81,0xe8,0xc8,0x80,0xe8,0xc8,0x7f,0xe8,0xc7,0x7e,0xe8,0xc7,0x7c,0xe8,0xc6,0x7b,0xe8,0xc6,0x7a,0xe7,0xc5,0x79,0xe7,0xc5,0x78,0xe7,0xc4,0x76,0xe7,0xc4,0x75,0xe7,0xc3,0x74,0xe7,0xc3,0x73,0xe7,0xc2,0x72,0xe7,0xc2,0x70,0xe7,0xc1,0x6f,0xe6,0xc1,0x6e,0xe6,0xc0,0x6d,0xe6,0xbf,0x6b,0xe6,0xbf,0x6a,0xe6,0xbe,0x69,0xe6,0xbe,0x68,0xe6,0xbd,0x66,0xe6,0xbd,0x65,0xe5,0xbc,0x64,0xe5,0xbc,0x62,0xe5,0xbb,0x61,0xe5,0xba,0x60,0xe5,0xba,0x5e,0xe5,0xb9,0x5d,0xe5,0xb9,0x5c,0xe4,0xb8,0x5b,0xe4,0xb8,0x59,0xe4};
	static constexpr std::array<uint8_t, 768> D03  = {0x39,0x97,0x0e,0x3b,0x97,0x12,0x3d,0x98,0x15,0x3f,0x99,0x18,0x40,0x9a,0x1a,0x42,0x9a,0x1d,0x44,0x9b,0x1f,0x46,0x9c,0x22,0x48,0x9c,0x24,0x4a,0x9d,0x26,0x4b,0x9e,0x28,0x4d,0x9f,0x2a,0x4f,0x9f,0x2c,0x51,0xa0,0x2e,0x52,0xa1,0x30,0x54,0xa1,0x32,0x56,0xa2,0x34,0x57,0xa3,0x36,0x59,0xa4,0x38,0x5a,0xa4,0x39,0x5c,0xa5,0x3b,0x5e,0xa6,0x3d,0x5f,0xa6,0x3f,0x61,0xa7,0x41,0x62,0xa8,0x42,0x64,0xa9,0x44,0x65,0xa9,0x46,0x67,0xaa,0x47,0x68,0xab,0x49,0x6a,0xab,0x4b,0x6b,0xac,0x4d,0x6d,0xad,0x4e,0x6e,0xae,0x50,0x70,0xae,0x52,0x71,0xaf,0x53,0x73,0xb0,0x55,0x74,0xb0,0x57,0x76,0xb1,0x58,0x77,0xb2,0x5a,0x79,0xb2,0x5c,0x7a,0xb3,0x5d,0x7c,0xb4,0x5f,0x7d,0xb5,0x61,0x7e,0xb5,0x62,0x80,0xb6,0x64,0x81,0xb7,0x66,0x83,0xb7,0x67,0x84,0xb8,0x69,0x85,0xb9,0x6a,0x87,0xba,0x6c,0x88,0xba,0x6e,0x8a,0xbb,0x6f,0x8b,0xbc,0x71,0x8c,0xbc,0x73,0x8e,0xbd,0x74,0x8f,0xbe,0x76,0x91,0xbe,0x78,0x92,0xbf,0x79,0x93,0xc0,0x7b,0x95,0xc1,0x7c,0x96,0xc1,0x7e,0x97,0xc2,0x80,0x99,0xc3,0x81,0x9a,0xc3,0x83,0x9b,0xc4,0x85,0x9d,0xc5,0x86,0x9e,0xc5,0x88,0xa0,0xc6,0x8a,0xa1,0xc7,0x8b,0xa2,0xc8,0x8d,0xa4,0xc8,0x8e,0xa5,0xc9,0x90,0xa6,0xca,0x92,0xa8,0xca,0x93,0xa9,0xcb,0x95,0xaa,0xcc,0x97,0xac,0xcc,0x98,0xad,0xcd,0x9a,0xae,0xce,0x9c,0xb0,0xce,0x9d,0xb1,0xcf,0x9f,0xb2,0xd0,0xa1,0xb4,0xd1,0xa2,0xb5,0xd1,0xa4,0xb6,0xd2,0xa6,0xb8,0xd3,0xa7,0xb9,0xd3,0xa9,0xba,0xd4,0xab,0xbc,0xd5,0xac,0xbd,0xd5,0xae,0xbe,0xd6,0xb0,0xc0,0xd7,0xb1,0xc1,0xd8,0xb3,0xc2,0xd8,0xb5,0xc4,0xd9,0xb6,0xc5,0xda,0xb8,0xc6,0xda,0xba,0xc7,0xdb,0xbb,0xc9,0xdc,0xbd,0xca,0xdc,0xbf,0xcb,0xdd,0xc0,0xcd,0xde,0xc2,0xce,0xde,0xc4,0xcf,0xdf,0xc5,0xd1,0xe0,0xc7,0xd2,0xe0,0xc9,0xd3,0xe1,0xca,0xd5,0xe2,0xcc,0xd6,0xe3,0xce,0xd7,0xe3,0xcf,0xd9,0xe4,0xd1,0xda,0xe5,0xd3,0xdb,0xe5,0xd4,0xdc,0xe6,0xd6,0xde,0xe7,0xd8,0xdf,0xe7,0xd9,0xe0,0xe8,0xdb,0xe2,0xe8,0xdc,0xe3,0xe9,0xde,0xe4,0xe9,0xdf,0xe5,0xea,0xe1,0xe7,0xea,0xe2,0xe8,0xeb,0xe3,0xe9,0xeb,0xe4,0xea,0xeb,0xe5,0xeb,0xeb,0xe6,0xec,0xeb,0xe6,0xed,0xeb,0xe6,0xee,0xea,0xe6,0xef,0xea,0xe6,0xf0,0xe9,0xe6,0xf0,0xe9,0xe6,0xf1,0xe8,0xe5,0xf2,0xe7,0xe5,0xf2,0xe6,0xe4,0xf3,0xe6,0xe3,0xf3,0xe5,0xe2,0xf4,0xe4,0xe1,0xf4,0xe2,0xdf,0xf4,0xe1,0xde,0xf5,0xe0,0xdd,0xf5,0xdf,0xdc,0xf5,0xde,0xda,0xf6,0xdd,0xd9,0xf6,0xdb,0xd7,0xf6,0xda,0xd6,0xf6,0xd9,0xd5,0xf7,0xd8,0xd3,0xf7,0xd7,0xd2,0xf7,0xd5,0xd0,0xf7,0xd4,0xcf,0xf8,0xd3,0xce,0xf8,0xd2,0xcc,0xf8,0xd0,0xcb,0xf8,0xcf,0xc9,0xf8,0xce,0xc8,0xf8,0xcd,0xc6,0xf9,0xcc,0xc5,0xf9,0xca,0xc4,0xf9,0xc9,0xc2,0xf9,0xc8,0xc1,0xf9,0xc7,0xbf,0xf9,0xc5,0xbe,0xf9,0xc4,0xbd,0xf9,0xc3,0xbb,0xfa,0xc2,0xba,0xfa,0xc1,0xb8,0xfa,0xbf,0xb7,0xfa,0xbe,0xb6,0xfa,0xbd,0xb4,0xfa,0xbc,0xb3,0xfa,0xba,0xb1,0xfa,0xb9,0xb0,0xfa,0xb8,0xaf,0xfa,0xb7,0xad,0xfa,0xb5,0xac,0xfa,0xb4,0xab,0xfa,0xb3,0xa9,0xfa,0xb2,0xa8,0xfa,0xb0,0xa6,0xfa,0xaf,0xa5,0xfa,0xae,0xa4,0xfa,0xad,0xa2,0xfa,0xab,0xa1,0xfa,0xaa,0xa0,0xfa,0xa9,0x9e,0xfa,0xa8,0x9d,0xfa,0xa6,0x9c,0xfa,0xa5,0x9a,0xfa,0xa4,0x99,0xfa,0xa3,0x98,0xfa,0xa1,0x96,0xfa,0xa0,0x95,0xfa,0x9f,0x93,0xfa,0x9e,0x92,0xfa,0x9c,0x91,0xfa,0x9b,0x8f,0xfa,0x9a,0x8e,0xfa,0x99,0x8d,0xf9,0x97,0x8b,0xf9,0x96,0x8a,0xf9,0x95,0x89,0xf9,0x93,0x87,0xf9,0x92,0x86,0xf9,0x91,0x85,0xf9,0x90,0x84,0xf9,0x8e,0x82,0xf9,0x8d,0x81,0xf8,0x8c,0x80,0xf8,0x8a,0x7e,0xf8,0x89,0x7d,0xf8,0x88,0x7c,0xf8,0x86,0x7a,0xf8,0x85,0x79,0xf7,0x84,0x78,0xf7,0x82,0x76,0xf7,0x81,0x75,0xf7,0x80,0x74,0xf7,0x7e,0x73,0xf7,0x7d,0x71,0xf6,0x7c,0x70,0xf6,0x7a,0x6f,0xf6,0x79,0x6d,0xf6,0x78,0x6c,0xf6,0x76,0x6b,0xf5,0x75,0x6a,0xf5,0x74,0x68,0xf5,0x72,0x67,0xf5,0x71,0x66,0xf4,0x6f,0x64,0xf4,0x6e,0x63,0xf4,0x6d,0x62,0xf4,0x6b,0x61,0xf3,0x6a,0x5f,0xf3,0x68,0x5e,0xf3,0x67,0x5d,0xf3,0x65,0x5c,0xf2,0x64,0x5a,0xf2,0x62,0x59,0xf2,0x61,0x58,0xf2,0x5f,0x57,0xf1,0x5e,0x55,0xf1,0x5c,0x54,0xf1,0x5b,0x53,0xf0,0x59,0x52,0xf0,0x58,0x50,0xf0,0x56,0x4f,0xf0,0x55,0x4e,0xef,0x53,0x4d,0xef,0x51,0x4b,0xef,0x50,0x4a,0xee,0x4e,0x49,0xee,0x4c,0x48,0xee,0x4b,0x47,0xed,0x49,0x45,0xed,0x47,0x44};
	static constexpr std::array<uint8_t, 768> D04  = {0x19,0x81,0xfa,0x1a,0x80,0xf8,0x1c,0x80,0xf6,0x1d,0x7f,0xf4,0x1e,0x7e,0xf3,0x1f,0x7d,0xf1,0x20,0x7c,0xef,0x21,0x7b,0xed,0x22,0x7a,0xeb,0x23,0x79,0xe9,0x24,0x79,0xe7,0x25,0x78,0xe5,0x26,0x77,0xe3,0x26,0x76,0xe1,0x27,0x75,0xdf,0x28,0x74,0xdd,0x28,0x73,0xdb,0x29,0x72,0xd9,0x2a,0x72,0xd7,0x2a,0x71,0xd5,0x2b,0x70,0xd3,0x2b,0x6f,0xd1,0x2c,0x6e,0xd0,0x2c,0x6d,0xce,0x2c,0x6c,0xcc,0x2d,0x6c,0xca,0x2d,0x6b,0xc8,0x2e,0x6a,0xc6,0x2e,0x69,0xc4,0x2e,0x68,0xc2,0x2f,0x67,0xc0,0x2f,0x66,0xbf,0x2f,0x66,0xbd,0x2f,0x65,0xbb,0x30,0x64,0xb9,0x30,0x63,0xb7,0x30,0x62,0xb5,0x30,0x61,0xb3,0x30,0x61,0xb1,0x31,0x60,0xb0,0x31,0x5f,0xae,0x31,0x5e,0xac,0x31,0x5d,0xaa,0x31,0x5c,0xa8,0x31,0x5c,0xa6,0x31,0x5b,0xa4,0x31,0x5a,0xa3,0x32,0x59,0xa1,0x32,0x58,0x9f,0x32,0x57,0x9d,0x32,0x57,0x9b,0x32,0x56,0x9a,0x32,0x55,0x98,0x32,0x54,0x96,0x32,0x53,0x94,0x32,0x52,0x92,0x32,0x52,0x91,0x32,0x51,0x8f,0x32,0x50,0x8d,0x32,0x4f,0x8b,0x32,0x4e,0x89,0x31,0x4e,0x88,0x31,0x4d,0x86,0x31,0x4c,0x84,0x31,0x4b,0x82,0x31,0x4a,0x81,0x31,0x4a,0x7f,0x31,0x49,0x7d,0x31,0x48,0x7b,0x31,0x47,0x7a,0x30,0x46,0x78,0x30,0x46,0x76,0x30,0x45,0x74,0x30,0x44,0x73,0x30,0x43,0x71,0x30,0x42,0x6f,0x2f,0x42,0x6e,0x2f,0x41,0x6c,0x2f,0x40,0x6a,0x2f,0x3f,0x68,0x2f,0x3f,0x67,0x2e,0x3e,0x65,0x2e,0x3d,0x63,0x2e,0x3c,0x62,0x2e,0x3c,0x60,0x2d,0x3b,0x5e,0x2d,0x3a,0x5d,0x2d,0x39,0x5b,0x2c,0x38,0x59,0x2c,0x38,0x58,0x2c,0x37,0x56,0x2c,0x36,0x55,0x2b,0x35,0x53,0x2b,0x35,0x51,0x2b,0x34,0x50,0x2a,0x33,0x4e,0x2a,0x32,0x4c,0x2a,0x32,0x4b,0x29,0x31,0x49,0x29,0x30,0x48,0x29,0x2f,0x46,0x28,0x2f,0x44,0x28,0x2e,0x43,0x27,0x2d,0x41,0x27,0x2d,0x40,0x27,0x2c,0x3e,0x26,0x2b,0x3d,0x26,0x2a,0x3b,0x25,0x2a,0x3a,0x25,0x29,0x38,0x25,0x28,0x36,0x24,0x28,0x35,0x24,0x27,0x33,0x23,0x26,0x32,0x23,0x25,0x30,0x23,0x25,0x2f,0x22,0x24,0x2e,0x22,0x23,0x2c,0x22,0x23,0x2b,0x21,0x22,0x29,0x21,0x22,0x28,0x21,0x21,0x27,0x21,0x21,0x26,0x21,0x20,0x25,0x21,0x20,0x24,0x21,0x20,0x23,0x22,0x1f,0x22,0x22,0x1f,0x21,0x22,0x1f,0x21,0x23,0x1f,0x20,0x24,0x1f,0x20,0x25,0x1f,0x1f,0x26,0x1f,0x1f,0x27,0x20,0x1f,0x28,0x20,0x1f,0x29,0x20,0x1f,0x2a,0x20,0x1f,0x2b,0x21,0x1f,0x2d,0x21,0x1f,0x2e,0x22,0x1f,0x30,0x22,0x20,0x31,0x22,0x20,0x32,0x23,0x20,0x34,0x23,0x20,0x35,0x24,0x21,0x37,0x24,0x21,0x38,0x25,0x21,0x3a,0x25,0x21,0x3b,0x26,0x22,0x3d,0x26,0x22,0x3e,0x27,0x22,0x3f,0x27,0x23,0x41,0x27,0x23,0x42,0x28,0x23,0x44,0x28,0x23,0x45,0x29,0x24,0x47,0x29,0x24,0x48,0x2a,0x24,0x4a,0x2a,0x25,0x4b,0x2b,0x25,0x4d,0x2b,0x25,0x4e,0x2b,0x26,0x50,0x2c,0x26,0x51,0x2c,0x26,0x53,0x2d,0x26,0x54,0x2d,0x27,0x56,0x2e,0x27,0x57,0x2e,0x27,0x59,0x2e,0x28,0x5a,0x2f,0x28,0x5c,0x2f,0x28,0x5d,0x30,0x29,0x5f,0x30,0x29,0x60,0x31,0x29,0x62,0x31,0x29,0x63,0x31,0x2a,0x65,0x32,0x2a,0x66,0x32,0x2a,0x68,0x33,0x2b,0x6a,0x33,0x2b,0x6b,0x34,0x2b,0x6d,0x34,0x2b,0x6e,0x34,0x2c,0x70,0x35,0x2c,0x71,0x35,0x2c,0x73,0x36,0x2d,0x74,0x36,0x2d,0x76,0x36,0x2d,0x78,0x37,0x2e,0x79,0x37,0x2e,0x7b,0x38,0x2e,0x7c,0x38,0x2e,0x7e,0x38,0x2f,0x7f,0x39,0x2f,0x81,0x39,0x2f,0x83,0x3a,0x30,0x84,0x3a,0x30,0x86,0x3a,0x30,0x87,0x3b,0x30,0x89,0x3b,0x31,0x8a,0x3c,0x31,0x8c,0x3c,0x31,0x8e,0x3c,0x32,0x8f,0x3d,0x32,0x91,0x3d,0x32,0x92,0x3e,0x33,0x94,0x3e,0x33,0x96,0x3e,0x33,0x97,0x3f,0x33,0x99,0x3f,0x34,0x9b,0x40,0x34,0x9c,0x40,0x34,0x9e,0x40,0x35,0x9f,0x41,0x35,0xa1,0x41,0x35,0xa3,0x41,0x36,0xa4,0x42,0x36,0xa6,0x42,0x36,0xa8,0x43,0x36,0xa9,0x43,0x37,0xab,0x43,0x37,0xad,0x44,0x37,0xae,0x44,0x38,0xb0,0x44,0x38,0xb2,0x45,0x38,0xb3,0x45,0x38,0xb5,0x46,0x39,0xb7,0x46,0x39,0xb8,0x46,0x39,0xba,0x47,0x3a,0xbc,0x47,0x3a,0xbd,0x47,0x3a,0xbf,0x48,0x3b,0xc1,0x48,0x3b,0xc2,0x48,0x3b,0xc4,0x49,0x3b,0xc6,0x49,0x3c,0xc7,0x4a,0x3c,0xc9,0x4a,0x3c,0xcb,0x4a,0x3d,0xcc,0x4b,0x3d,0xce,0x4b,0x3d,0xd0,0x4b,0x3e,0xd1,0x4c,0x3e,0xd3,0x4c,0x3e,0xd5,0x4c,0x3e,0xd7,0x4d,0x3f,0xd8,0x4d,0x3f,0xda,0x4d,0x3f,0xdc,0x4e,0x40,0xdd,0x4e,0x40,0xdf,0x4e,0x40,0xe1,0x4f,0x41,0xe3,0x4f,0x41,0xe4,0x4f,0x41,0xe6,0x50,0x41};
	static constexpr std::array<uint8_t, 768> D06  = {0x0e,0x94,0xfa,0x11,0x93,0xf8,0x13,0x92,0xf6,0x15,0x91,0xf4,0x17,0x90,0xf2,0x18,0x8f,0xf0,0x1a,0x8e,0xee,0x1b,0x8c,0xec,0x1c,0x8b,0xea,0x1d,0x8a,0xe9,0x1f,0x89,0xe7,0x20,0x88,0xe5,0x21,0x87,0xe3,0x22,0x86,0xe1,0x22,0x85,0xdf,0x23,0x84,0xdd,0x24,0x83,0xdb,0x25,0x82,0xd9,0x26,0x81,0xd7,0x26,0x80,0xd5,0x27,0x7f,0xd3,0x27,0x7e,0xd1,0x28,0x7d,0xcf,0x29,0x7c,0xcd,0x29,0x7b,0xcc,0x2a,0x7a,0xca,0x2a,0x79,0xc8,0x2b,0x78,0xc6,0x2b,0x77,0xc4,0x2b,0x76,0xc2,0x2c,0x75,0xc0,0x2c,0x74,0xbe,0x2c,0x73,0xbc,0x2d,0x72,0xbb,0x2d,0x71,0xb9,0x2d,0x70,0xb7,0x2e,0x6f,0xb5,0x2e,0x6e,0xb3,0x2e,0x6d,0xb1,0x2e,0x6c,0xaf,0x2f,0x6b,0xad,0x2f,0x6a,0xac,0x2f,0x69,0xaa,0x2f,0x68,0xa8,0x2f,0x67,0xa6,0x2f,0x66,0xa4,0x30,0x65,0xa2,0x30,0x64,0xa1,0x30,0x63,0x9f,0x30,0x62,0x9d,0x30,0x61,0x9b,0x30,0x60,0x99,0x30,0x5f,0x98,0x30,0x5e,0x96,0x30,0x5d,0x94,0x30,0x5c,0x92,0x30,0x5b,0x90,0x30,0x5a,0x8f,0x30,0x59,0x8d,0x30,0x58,0x8b,0x30,0x57,0x89,0x30,0x57,0x87,0x30,0x56,0x86,0x30,0x55,0x84,0x30,0x54,0x82,0x30,0x53,0x80,0x30,0x52,0x7f,0x30,0x51,0x7d,0x30,0x50,0x7b,0x30,0x4f,0x79,0x2f,0x4e,0x78,0x2f,0x4d,0x76,0x2f,0x4c,0x74,0x2f,0x4b,0x73,0x2f,0x4a,0x71,0x2f,0x49,0x6f,0x2f,0x48,0x6d,0x2e,0x48,0x6c,0x2e,0x47,0x6a,0x2e,0x46,0x68,0x2e,0x45,0x67,0x2e,0x44,0x65,0x2d,0x43,0x63,0x2d,0x42,0x62,0x2d,0x41,0x60,0x2d,0x40,0x5e,0x2c,0x3f,0x5d,0x2c,0x3e,0x5b,0x2c,0x3e,0x59,0x2c,0x3d,0x58,0x2b,0x3c,0x56,0x2b,0x3b,0x54,0x2b,0x3a,0x53,0x2a,0x39,0x51,0x2a,0x38,0x4f,0x2a,0x37,0x4e,0x2a,0x36,0x4c,0x29,0x36,0x4b,0x29,0x35,0x49,0x29,0x34,0x47,0x28,0x33,0x46,0x28,0x32,0x44,0x27,0x31,0x43,0x27,0x30,0x41,0x27,0x30,0x40,0x26,0x2f,0x3e,0x26,0x2e,0x3c,0x26,0x2d,0x3b,0x25,0x2c,0x39,0x25,0x2b,0x38,0x24,0x2a,0x36,0x24,0x2a,0x35,0x23,0x29,0x33,0x23,0x28,0x32,0x23,0x27,0x30,0x22,0x26,0x2f,0x22,0x26,0x2d,0x22,0x25,0x2c,0x21,0x24,0x2b,0x21,0x24,0x29,0x21,0x23,0x28,0x20,0x22,0x27,0x20,0x22,0x26,0x20,0x21,0x25,0x20,0x21,0x23,0x20,0x21,0x23,0x20,0x21,0x22,0x21,0x20,0x21,0x21,0x20,0x20,0x21,0x20,0x20,0x22,0x21,0x1f,0x23,0x21,0x1f,0x23,0x21,0x1e,0x24,0x22,0x1e,0x25,0x22,0x1e,0x26,0x22,0x1e,0x26,0x23,0x1e,0x27,0x24,0x1e,0x28,0x24,0x1e,0x29,0x25,0x1e,0x2a,0x26,0x1e,0x2c,0x26,0x1e,0x2d,0x27,0x1e,0x2e,0x28,0x1e,0x2f,0x29,0x1e,0x30,0x29,0x1e,0x31,0x2a,0x1e,0x32,0x2b,0x1e,0x33,0x2c,0x1e,0x34,0x2d,0x1f,0x35,0x2d,0x1f,0x36,0x2e,0x1f,0x38,0x2f,0x1f,0x39,0x30,0x1f,0x3a,0x31,0x1f,0x3b,0x31,0x1f,0x3c,0x32,0x1f,0x3d,0x33,0x1f,0x3e,0x34,0x1f,0x3f,0x35,0x20,0x41,0x35,0x20,0x42,0x36,0x20,0x43,0x37,0x20,0x44,0x38,0x20,0x45,0x39,0x20,0x46,0x3a,0x20,0x47,0x3a,0x20,0x48,0x3b,0x20,0x4a,0x3c,0x20,0x4b,0x3d,0x20,0x4c,0x3e,0x20,0x4d,0x3f,0x21,0x4e,0x3f,0x21,0x4f,0x40,0x21,0x50,0x41,0x21,0x52,0x42,0x21,0x53,0x43,0x21,0x54,0x44,0x21,0x55,0x45,0x21,0x56,0x45,0x21,0x57,0x46,0x21,0x58,0x47,0x21,0x5a,0x48,0x21,0x5b,0x49,0x21,0x5c,0x4a,0x21,0x5d,0x4b,0x21,0x5e,0x4b,0x21,0x5f,0x4c,0x21,0x61,0x4d,0x21,0x62,0x4e,0x21,0x63,0x4f,0x21,0x64,0x50,0x21,0x65,0x51,0x21,0x67,0x52,0x21,0x68,0x52,0x21,0x69,0x53,0x21,0x6a,0x54,0x21,0x6b,0x55,0x21,0x6c,0x56,0x21,0x6e,0x57,0x21,0x6f,0x58,0x21,0x70,0x59,0x21,0x71,0x5a,0x21,0x72,0x5a,0x21,0x74,0x5b,0x21,0x75,0x5c,0x21,0x76,0x5d,0x21,0x77,0x5e,0x21,0x78,0x5f,0x21,0x7a,0x60,0x21,0x7b,0x61,0x21,0x7c,0x62,0x21,0x7d,0x63,0x21,0x7f,0x63,0x21,0x80,0x64,0x21,0x81,0x65,0x21,0x82,0x66,0x21,0x83,0x67,0x21,0x85,0x68,0x20,0x86,0x69,0x20,0x87,0x6a,0x20,0x88,0x6b,0x20,0x8a,0x6c,0x20,0x8b,0x6d,0x20,0x8c,0x6e,0x20,0x8d,0x6e,0x20,0x8e,0x6f,0x20,0x90,0x70,0x20,0x91,0x71,0x1f,0x92,0x72,0x1f,0x93,0x73,0x1f,0x95,0x74,0x1f,0x96,0x75,0x1f,0x97,0x76,0x1f,0x98,0x77,0x1f,0x9a,0x78,0x1e,0x9b,0x79,0x1e,0x9c,0x7a,0x1e,0x9d,0x7b,0x1e,0x9f,0x7c,0x1e,0xa0,0x7d,0x1e,0xa1,0x7e,0x1d,0xa3,0x7e,0x1d,0xa4,0x7f,0x1d,0xa5,0x80,0x1d,0xa6,0x81,0x1d,0xa8,0x82,0x1c,0xa9,0x83,0x1c,0xaa,0x84,0x1c,0xab,0x85,0x1c,0xad,0x86,0x1b,0xae,0x87,0x1b,0xaf,0x88,0x1b,0xb1,0x89,0x1b,0xb2,0x8a,0x1a,0xb3,0x8b,0x1a};
	static constexpr std::array<uint8_t, 768> D07  = {0x14,0x31,0xc1,0x18,0x32,0xc1,0x1c,0x33,0xc1,0x1f,0x33,0xc0,0x22,0x34,0xc0,0x25,0x35,0xc0,0x28,0x36,0xbf,0x2a,0x36,0xbf,0x2d,0x37,0xbf,0x2f,0x38,0xbe,0x31,0x39,0xbe,0x33,0x39,0xbe,0x35,0x3a,0xbd,0x36,0x3b,0xbd,0x38,0x3b,0xbc,0x3a,0x3c,0xbc,0x3b,0x3d,0xbc,0x3d,0x3e,0xbb,0x3f,0x3e,0xbb,0x40,0x3f,0xbb,0x42,0x40,0xba,0x43,0x41,0xba,0x44,0x41,0xba,0x46,0x42,0xb9,0x47,0x43,0xb9,0x48,0x44,0xb9,0x4a,0x44,0xb8,0x4b,0x45,0xb8,0x4c,0x46,0xb7,0x4d,0x46,0xb7,0x4e,0x47,0xb7,0x4f,0x48,0xb6,0x51,0x49,0xb6,0x52,0x49,0xb6,0x53,0x4a,0xb5,0x54,0x4b,0xb5,0x55,0x4c,0xb5,0x56,0x4c,0xb4,0x57,0x4d,0xb4,0x58,0x4e,0xb4,0x59,0x4f,0xb3,0x5a,0x4f,0xb3,0x5b,0x50,0xb2,0x5c,0x51,0xb2,0x5d,0x51,0xb2,0x5e,0x52,0xb1,0x5e,0x53,0xb1,0x5f,0x54,0xb1,0x60,0x54,0xb0,0x61,0x55,0xb0,0x62,0x56,0xaf,0x63,0x57,0xaf,0x64,0x57,0xaf,0x64,0x58,0xae,0x65,0x59,0xae,0x66,0x5a,0xae,0x67,0x5a,0xad,0x68,0x5b,0xad,0x68,0x5c,0xad,0x69,0x5d,0xac,0x6a,0x5d,0xac,0x6b,0x5e,0xab,0x6b,0x5f,0xab,0x6c,0x60,0xab,0x6d,0x60,0xaa,0x6e,0x61,0xaa,0x6e,0x62,0xa9,0x6f,0x63,0xa9,0x70,0x63,0xa9,0x70,0x64,0xa8,0x71,0x65,0xa8,0x72,0x66,0xa8,0x73,0x66,0xa7,0x73,0x67,0xa7,0x74,0x68,0xa6,0x75,0x69,0xa6,0x75,0x69,0xa6,0x76,0x6a,0xa5,0x76,0x6b,0xa5,0x77,0x6c,0xa5,0x78,0x6c,0xa4,0x78,0x6d,0xa4,0x79,0x6e,0xa3,0x7a,0x6f,0xa3,0x7a,0x6f,0xa3,0x7b,0x70,0xa2,0x7b,0x71,0xa2,0x7c,0x72,0xa1,0x7d,0x72,0xa1,0x7d,0x73,0xa1,0x7e,0x74,0xa0,0x7e,0x75,0xa0,0x7f,0x75,0x9f,0x7f,0x76,0x9f,0x80,0x77,0x9f,0x81,0x78,0x9e,0x81,0x78,0x9e,0x82,0x79,0x9d,0x82,0x7a,0x9d,0x83,0x7b,0x9d,0x83,0x7b,0x9c,0x84,0x7c,0x9c,0x84,0x7d,0x9b,0x85,0x7e,0x9b,0x85,0x7f,0x9b,0x86,0x7f,0x9a,0x86,0x80,0x9a,0x87,0x81,0x99,0x87,0x82,0x99,0x88,0x82,0x98,0x88,0x83,0x98,0x89,0x84,0x98,0x89,0x85,0x97,0x8a,0x85,0x97,0x8a,0x86,0x96,0x8b,0x87,0x96,0x8b,0x88,0x96,0x8c,0x88,0x95,0x8c,0x89,0x95,0x8d,0x8a,0x94,0x8d,0x8b,0x94,0x8e,0x8c,0x93,0x8e,0x8c,0x93,0x8f,0x8d,0x93,0x8f,0x8e,0x92,0x8f,0x8f,0x92,0x90,0x8f,0x91,0x90,0x90,0x91,0x91,0x91,0x90,0x92,0x91,0x90,0x93,0x92,0x8f,0x94,0x93,0x8e,0x95,0x93,0x8e,0x96,0x94,0x8d,0x97,0x95,0x8d,0x98,0x95,0x8c,0x99,0x96,0x8b,0x9a,0x96,0x8b,0x9b,0x97,0x8a,0x9c,0x98,0x8a,0x9d,0x98,0x89,0x9e,0x99,0x88,0x9f,0x99,0x88,0xa0,0x9a,0x87,0xa1,0x9b,0x86,0xa2,0x9b,0x86,0xa3,0x9c,0x85,0xa4,0x9d,0x85,0xa5,0x9d,0x84,0xa6,0x9e,0x83,0xa7,0x9e,0x83,0xa8,0x9f,0x82,0xa9,0xa0,0x81,0xaa,0xa0,0x81,0xaa,0xa1,0x80,0xab,0xa2,0x7f,0xac,0xa2,0x7f,0xad,0xa3,0x7e,0xae,0xa3,0x7d,0xaf,0xa4,0x7d,0xb0,0xa5,0x7c,0xb1,0xa5,0x7b,0xb2,0xa6,0x7b,0xb3,0xa7,0x7a,0xb3,0xa7,0x79,0xb4,0xa8,0x79,0xb5,0xa9,0x78,0xb6,0xa9,0x77,0xb7,0xaa,0x77,0xb8,0xaa,0x76,0xb9,0xab,0x75,0xba,0xac,0x75,0xba,0xac,0x74,0xbb,0xad,0x73,0xbc,0xae,0x73,0xbd,0xae,0x72,0xbe,0xaf,0x71,0xbf,0xb0,0x70,0xc0,0xb0,0x70,0xc0,0xb1,0x6f,0xc1,0xb2,0x6e,0xc2,0xb2,0x6d,0xc3,0xb3,0x6d,0xc4,0xb4,0x6c,0xc5,0xb4,0x6b,0xc6,0xb5,0x6a,0xc6,0xb5,0x6a,0xc7,0xb6,0x69,0xc8,0xb7,0x68,0xc9,0xb7,0x67,0xca,0xb8,0x67,0xcb,0xb9,0x66,0xcb,0xb9,0x65,0xcc,0xba,0x64,0xcd,0xbb,0x63,0xce,0xbb,0x63,0xcf,0xbc,0x62,0xcf,0xbd,0x61,0xd0,0xbd,0x60,0xd1,0xbe,0x5f,0xd2,0xbf,0x5e,0xd3,0xbf,0x5e,0xd4,0xc0,0x5d,0xd4,0xc1,0x5c,0xd5,0xc1,0x5b,0xd6,0xc2,0x5a,0xd7,0xc3,0x59,0xd8,0xc3,0x58,0xd8,0xc4,0x57,0xd9,0xc5,0x56,0xda,0xc5,0x56,0xdb,0xc6,0x55,0xdc,0xc7,0x54,0xdc,0xc7,0x53,0xdd,0xc8,0x52,0xde,0xc9,0x51,0xdf,0xc9,0x50,0xdf,0xca,0x4f,0xe0,0xcb,0x4e,0xe1,0xcb,0x4d,0xe2,0xcc,0x4c,0xe3,0xcd,0x4b,0xe3,0xcd,0x49,0xe4,0xce,0x48,0xe5,0xcf,0x47,0xe6,0xcf,0x46,0xe7,0xd0,0x45,0xe7,0xd1,0x44,0xe8,0xd1,0x43,0xe9,0xd2,0x41,0xea,0xd3,0x40,0xea,0xd3,0x3f,0xeb,0xd4,0x3e,0xec,0xd5,0x3c,0xed,0xd6,0x3b,0xed,0xd6,0x39,0xee,0xd7,0x38,0xef,0xd8,0x37,0xf0,0xd8,0x35,0xf1,0xd9,0x33,0xf1,0xda,0x32,0xf2,0xda,0x30,0xf3,0xdb,0x2e,0xf4,0xdc,0x2d,0xf4,0xdc,0x2b,0xf5,0xdd,0x29,0xf6,0xde,0x27,0xf7,0xde,0x25,0xf7,0xdf,0x22,0xf8,0xe0,0x20,0xf9,0xe0,0x1d,0xfa,0xe1,0x1a,0xfa,0xe2,0x17,0xfb,0xe3,0x13,0xfc,0xe3,0x0f,0xfd,0xe4,0x09};
	static constexpr std::array<uint8_t, 768> D08  = {0x00,0x2a,0xd7,0x00,0x2b,0xd6,0x00,0x2b,0xd5,0x00,0x2c,0xd4,0x00,0x2c,0xd4,0x00,0x2d,0xd3,0x00,0x2d,0xd2,0x00,0x2e,0xd1,0x07,0x2e,0xd0,0x0d,0x2f,0xcf,0x13,0x2f,0xce,0x17,0x30,0xcd,0x1b,0x30,0xcc,0x1e,0x31,0xcb,0x21,0x31,0xca,0x23,0x32,0xc9,0x26,0x32,0xc9,0x28,0x33,0xc8,0x2a,0x33,0xc7,0x2c,0x34,0xc6,0x2e,0x34,0xc5,0x2f,0x35,0xc4,0x31,0x35,0xc3,0x33,0x36,0xc2,0x34,0x36,0xc1,0x36,0x37,0xc0,0x37,0x37,0xbf,0x38,0x38,0xbf,0x3a,0x38,0xbe,0x3b,0x39,0xbd,0x3c,0x39,0xbc,0x3d,0x39,0xbb,0x3e,0x3a,0xba,0x40,0x3a,0xb9,0x41,0x3b,0xb8,0x42,0x3b,0xb7,0x43,0x3c,0xb6,0x44,0x3c,0xb5,0x45,0x3d,0xb5,0x45,0x3d,0xb4,0x46,0x3e,0xb3,0x47,0x3e,0xb2,0x48,0x3f,0xb1,0x49,0x3f,0xb0,0x4a,0x40,0xaf,0x4a,0x40,0xae,0x4b,0x40,0xad,0x4c,0x41,0xac,0x4d,0x41,0xac,0x4d,0x42,0xab,0x4e,0x42,0xaa,0x4f,0x43,0xa9,0x4f,0x43,0xa8,0x50,0x44,0xa7,0x51,0x44,0xa6,0x51,0x45,0xa5,0x52,0x45,0xa4,0x52,0x46,0xa3,0x53,0x46,0xa3,0x54,0x46,0xa2,0x54,0x47,0xa1,0x55,0x47,0xa0,0x55,0x48,0x9f,0x56,0x48,0x9e,0x56,0x49,0x9d,0x57,0x49,0x9c,0x57,0x4a,0x9b,0x58,0x4a,0x9b,0x58,0x4a,0x9a,0x58,0x4b,0x99,0x59,0x4b,0x98,0x59,0x4c,0x97,0x5a,0x4c,0x96,0x5a,0x4d,0x95,0x5b,0x4d,0x94,0x5b,0x4e,0x93,0x5b,0x4e,0x92,0x5c,0x4e,0x92,0x5c,0x4f,0x91,0x5c,0x4f,0x90,0x5d,0x50,0x8f,0x5d,0x50,0x8e,0x5d,0x51,0x8d,0x5e,0x51,0x8c,0x5e,0x52,0x8b,0x5e,0x52,0x8a,0x5e,0x52,0x8a,0x5f,0x53,0x89,0x5f,0x53,0x88,0x5f,0x54,0x87,0x60,0x54,0x86,0x60,0x55,0x85,0x60,0x55,0x84,0x60,0x56,0x83,0x60,0x56,0x82,0x61,0x56,0x82,0x61,0x57,0x81,0x61,0x57,0x80,0x61,0x58,0x7f,0x62,0x58,0x7e,0x62,0x59,0x7d,0x62,0x59,0x7c,0x62,0x59,0x7b,0x62,0x5a,0x7a,0x62,0x5a,0x7a,0x63,0x5b,0x79,0x63,0x5b,0x78,0x63,0x5c,0x77,0x63,0x5c,0x76,0x63,0x5c,0x75,0x63,0x5d,0x74,0x63,0x5d,0x73,0x63,0x5e,0x72,0x63,0x5e,0x71,0x64,0x5f,0x71,0x64,0x5f,0x70,0x64,0x5f,0x6f,0x64,0x60,0x6e,0x64,0x60,0x6d,0x64,0x61,0x6c,0x64,0x61,0x6b,0x64,0x62,0x6a,0x64,0x62,0x69,0x64,0x62,0x68,0x64,0x63,0x67,0x64,0x63,0x67,0x64,0x64,0x66,0x64,0x64,0x65,0x65,0x64,0x64,0x67,0x64,0x63,0x69,0x64,0x63,0x6a,0x64,0x62,0x6c,0x64,0x61,0x6e,0x64,0x61,0x6f,0x63,0x60,0x71,0x63,0x60,0x72,0x63,0x5f,0x74,0x63,0x5e,0x75,0x63,0x5e,0x77,0x63,0x5d,0x78,0x63,0x5c,0x7a,0x62,0x5c,0x7b,0x62,0x5b,0x7d,0x62,0x5b,0x7e,0x62,0x5a,0x80,0x62,0x59,0x81,0x62,0x59,0x83,0x61,0x58,0x84,0x61,0x57,0x86,0x61,0x57,0x87,0x61,0x56,0x88,0x61,0x56,0x8a,0x60,0x55,0x8b,0x60,0x54,0x8c,0x60,0x54,0x8e,0x60,0x53,0x8f,0x60,0x52,0x90,0x5f,0x52,0x92,0x5f,0x51,0x93,0x5f,0x51,0x94,0x5f,0x50,0x96,0x5e,0x4f,0x97,0x5e,0x4f,0x98,0x5e,0x4e,0x9a,0x5e,0x4d,0x9b,0x5d,0x4d,0x9c,0x5d,0x4c,0x9e,0x5d,0x4b,0x9f,0x5d,0x4b,0xa0,0x5c,0x4a,0xa1,0x5c,0x49,0xa3,0x5c,0x49,0xa4,0x5b,0x48,0xa5,0x5b,0x48,0xa6,0x5b,0x47,0xa8,0x5b,0x46,0xa9,0x5a,0x46,0xaa,0x5a,0x45,0xab,0x5a,0x44,0xad,0x59,0x44,0xae,0x59,0x43,0xaf,0x59,0x42,0xb0,0x58,0x42,0xb1,0x58,0x41,0xb3,0x58,0x40,0xb4,0x57,0x40,0xb5,0x57,0x3f,0xb6,0x56,0x3e,0xb7,0x56,0x3e,0xb9,0x56,0x3d,0xba,0x55,0x3c,0xbb,0x55,0x3c,0xbc,0x54,0x3b,0xbd,0x54,0x3a,0xbf,0x54,0x3a,0xc0,0x53,0x39,0xc1,0x53,0x38,0xc2,0x52,0x38,0xc3,0x52,0x37,0xc5,0x51,0x36,0xc6,0x51,0x35,0xc7,0x50,0x35,0xc8,0x50,0x34,0xc9,0x4f,0x33,0xca,0x4f,0x33,0xcc,0x4e,0x32,0xcd,0x4e,0x31,0xce,0x4d,0x30,0xcf,0x4d,0x30,0xd0,0x4c,0x2f,0xd1,0x4c,0x2e,0xd2,0x4b,0x2e,0xd4,0x4a,0x2d,0xd5,0x4a,0x2c,0xd6,0x49,0x2b,0xd7,0x49,0x2b,0xd8,0x48,0x2a,0xd9,0x47,0x29,0xda,0x47,0x28,0xdc,0x46,0x27,0xdd,0x45,0x27,0xde,0x45,0x26,0xdf,0x44,0x25,0xe0,0x43,0x24,0xe1,0x42,0x23,0xe2,0x41,0x23,0xe4,0x41,0x22,0xe5,0x40,0x21,0xe6,0x3f,0x20,0xe7,0x3e,0x1f,0xe8,0x3d,0x1e,0xe9,0x3c,0x1d,0xea,0x3b,0x1c,0xeb,0x3a,0x1b,0xed,0x3a,0x1b,0xee,0x38,0x1a,0xef,0x37,0x19,0xf0,0x36,0x18,0xf1,0x35,0x16,0xf2,0x34,0x15,0xf3,0x33,0x14,0xf4,0x32,0x13,0xf6,0x30,0x12,0xf7,0x2f,0x11,0xf8,0x2e,0x0f,0xf9,0x2c,0x0e,0xfa,0x2b,0x0d,0xfb,0x29,0x0b,0xfc,0x28,0x09,0xfd,0x26,0x08,0xff,0x24,0x06,0xff,0x22,0x05,0xff,0x20,0x03,0xff,0x1e,0x01,0xff,0x1b,0x00,0xff,0x19,0x00};
	static constexpr std::array<uint8_t, 768> D09  = {0x24,0x80,0xff,0x29,0x81,0xff,0x2e,0x81,0xff,0x32,0x82,0xff,0x36,0x83,0xff,0x3a,0x84,0xff,0x3e,0x85,0xff,0x41,0x86,0xff,0x44,0x87,0xff,0x47,0x87,0xff,0x4a,0x88,0xfe,0x4d,0x89,0xfe,0x4f,0x8a,0xfe,0x52,0x8b,0xfe,0x54,0x8c,0xfe,0x57,0x8d,0xfe,0x59,0x8e,0xfe,0x5b,0x8e,0xfe,0x5e,0x8f,0xfe,0x60,0x90,0xfe,0x62,0x91,0xfe,0x64,0x92,0xfe,0x66,0x93,0xfe,0x68,0x94,0xfe,0x6a,0x95,0xfe,0x6c,0x96,0xfe,0x6e,0x96,0xfe,0x70,0x97,0xfe,0x72,0x98,0xfe,0x74,0x99,0xfe,0x76,0x9a,0xfe,0x77,0x9b,0xfe,0x79,0x9c,0xfe,0x7b,0x9d,0xfe,0x7d,0x9e,0xfe,0x7e,0x9f,0xfe,0x80,0x9f,0xfe,0x82,0xa0,0xfe,0x83,0xa1,0xfe,0x85,0xa2,0xfe,0x87,0xa3,0xfe,0x88,0xa4,0xfe,0x8a,0xa5,0xfe,0x8b,0xa6,0xfe,0x8d,0xa7,0xfe,0x8f,0xa8,0xfe,0x90,0xa9,0xfe,0x92,0xaa,0xfe,0x93,0xab,0xfe,0x95,0xab,0xfe,0x96,0xac,0xfe,0x98,0xad,0xfe,0x99,0xae,0xfe,0x9b,0xaf,0xfe,0x9c,0xb0,0xfe,0x9d,0xb1,0xfe,0x9f,0xb2,0xfe,0xa0,0xb3,0xfe,0xa2,0xb4,0xfe,0xa3,0xb5,0xfe,0xa5,0xb6,0xfe,0xa6,0xb7,0xfd,0xa7,0xb8,0xfd,0xa9,0xb9,0xfd,0xaa,0xba,0xfd,0xab,0xbb,0xfd,0xad,0xbb,0xfd,0xae,0xbc,0xfd,0xaf,0xbd,0xfd,0xb1,0xbe,0xfd,0xb2,0xbf,0xfd,0xb3,0xc0,0xfd,0xb5,0xc1,0xfd,0xb6,0xc2,0xfd,0xb7,0xc3,0xfd,0xb9,0xc4,0xfd,0xba,0xc5,0xfd,0xbb,0xc6,0xfd,0xbd,0xc7,0xfd,0xbe,0xc8,0xfd,0xbf,0xc9,0xfd,0xc0,0xca,0xfd,0xc2,0xcb,0xfd,0xc3,0xcc,0xfc,0xc4,0xcd,0xfc,0xc6,0xce,0xfc,0xc7,0xcf,0xfc,0xc8,0xd0,0xfc,0xc9,0xd1,0xfc,0xcb,0xd2,0xfc,0xcc,0xd3,0xfc,0xcd,0xd4,0xfc,0xce,0xd5,0xfc,0xcf,0xd6,0xfc,0xd1,0xd7,0xfc,0xd2,0xd8,0xfc,0xd3,0xd9,0xfc,0xd4,0xda,0xfc,0xd6,0xdb,0xfc,0xd7,0xdc,0xfc,0xd8,0xdd,0xfb,0xd9,0xde,0xfb,0xda,0xdf,0xfb,0xdc,0xe0,0xfb,0xdd,0xe1,0xfb,0xde,0xe2,0xfb,0xdf,0xe3,0xfb,0xe0,0xe4,0xfb,0xe2,0xe5,0xfb,0xe3,0xe6,0xfb,0xe4,0xe7,0xfb,0xe5,0xe8,0xfb,0xe6,0xe9,0xfb,0xe7,0xea,0xfb,0xe9,0xeb,0xfa,0xea,0xec,0xfa,0xeb,0xed,0xfa,0xec,0xee,0xfa,0xed,0xef,0xfa,0xee,0xf0,0xfa,0xf0,0xf1,0xfa,0xf1,0xf2,0xfa,0xf2,0xf3,0xfa,0xf3,0xf4,0xfa,0xf4,0xf5,0xf9,0xf5,0xf6,0xf9,0xf7,0xf6,0xf9,0xf8,0xf7,0xf8,0xf9,0xf6,0xf7,0xf9,0xf6,0xf5,0xfa,0xf5,0xf4,0xfa,0xf4,0xf2,0xfa,0xf2,0xf0,0xfb,0xf1,0xef,0xfb,0xf0,0xed,0xfb,0xef,0xec,0xfb,0xed,0xea,0xfc,0xec,0xe8,0xfc,0xeb,0xe7,0xfc,0xea,0xe5,0xfc,0xe8,0xe3,0xfc,0xe7,0xe2,0xfc,0xe6,0xe0,0xfc,0xe5,0xdf,0xfd,0xe3,0xdd,0xfd,0xe2,0xdb,0xfd,0xe1,0xda,0xfd,0xdf,0xd8,0xfd,0xde,0xd7,0xfd,0xdd,0xd5,0xfd,0xdc,0xd3,0xfd,0xda,0xd2,0xfd,0xd9,0xd0,0xfd,0xd8,0xcf,0xfe,0xd7,0xcd,0xfe,0xd5,0xcb,0xfe,0xd4,0xca,0xfe,0xd3,0xc8,0xfe,0xd2,0xc7,0xfe,0xd0,0xc5,0xfe,0xcf,0xc3,0xfe,0xce,0xc2,0xfe,0xcd,0xc0,0xfe,0xcb,0xbf,0xfe,0xca,0xbd,0xfe,0xc9,0xbc,0xfe,0xc7,0xba,0xfe,0xc6,0xb9,0xfe,0xc5,0xb7,0xfe,0xc4,0xb5,0xfe,0xc2,0xb4,0xfe,0xc1,0xb2,0xfd,0xc0,0xb1,0xfd,0xbf,0xaf,0xfd,0xbd,0xae,0xfd,0xbc,0xac,0xfd,0xbb,0xab,0xfd,0xba,0xa9,0xfd,0xb8,0xa7,0xfd,0xb7,0xa6,0xfd,0xb6,0xa4,0xfd,0xb4,0xa3,0xfd,0xb3,0xa1,0xfc,0xb2,0xa0,0xfc,0xb1,0x9e,0xfc,0xaf,0x9d,0xfc,0xae,0x9b,0xfc,0xad,0x9a,0xfc,0xac,0x98,0xfc,0xaa,0x97,0xfb,0xa9,0x95,0xfb,0xa8,0x94,0xfb,0xa6,0x92,0xfb,0xa5,0x91,0xfb,0xa4,0x8f,0xfb,0xa3,0x8e,0xfa,0xa1,0x8c,0xfa,0xa0,0x8b,0xfa,0x9f,0x89,0xfa,0x9e,0x88,0xf9,0x9c,0x86,0xf9,0x9b,0x85,0xf9,0x9a,0x83,0xf9,0x98,0x82,0xf9,0x97,0x80,0xf8,0x96,0x7f,0xf8,0x94,0x7d,0xf8,0x93,0x7c,0xf8,0x92,0x7a,0xf7,0x91,0x79,0xf7,0x8f,0x77,0xf7,0x8e,0x76,0xf6,0x8d,0x74,0xf6,0x8b,0x73,0xf6,0x8a,0x71,0xf6,0x89,0x70,0xf5,0x87,0x6e,0xf5,0x86,0x6d,0xf5,0x85,0x6b,0xf4,0x83,0x6a,0xf4,0x82,0x69,0xf4,0x81,0x67,0xf3,0x7f,0x66,0xf3,0x7e,0x64,0xf3,0x7d,0x63,0xf2,0x7b,0x61,0xf2,0x7a,0x60,0xf2,0x79,0x5e,0xf1,0x77,0x5d,0xf1,0x76,0x5c,0xf1,0x75,0x5a,0xf0,0x73,0x59,0xf0,0x72,0x57,0xf0,0x71,0x56,0xef,0x6f,0x54,0xef,0x6e,0x53,0xee,0x6c,0x52,0xee,0x6b,0x50,0xee,0x6a,0x4f,0xed,0x68,0x4d,0xed,0x67,0x4c,0xec,0x65,0x4a,0xec,0x64,0x49,0xec,0x62,0x48,0xeb,0x61,0x46,0xeb,0x60,0x45,0xea,0x5e,0x43,0xea,0x5d,0x42,0xe9,0x5b,0x41,0xe9,0x5a,0x3f,0xe9,0x58,0x3e,0xe8,0x57,0x3c,0xe8,0x55,0x3b,0xe7,0x53,0x3a,0xe7,0x52,0x38,0xe6,0x50,0x37};
	static constexpr std::array<uint8_t, 768> D10  = {0x00,0xd9,0xff,0x00,0xd9,0xff,0x0e,0xda,0xff,0x1a,0xda,0xff,0x22,0xda,0xff,0x28,0xda,0xff,0x2e,0xdb,0xff,0x33,0xdb,0xff,0x37,0xdb,0xff,0x3b,0xdc,0xff,0x3f,0xdc,0xff,0x43,0xdc,0xff,0x46,0xdd,0xff,0x49,0xdd,0xff,0x4d,0xdd,0xff,0x50,0xde,0xff,0x52,0xde,0xff,0x55,0xde,0xff,0x58,0xdf,0xff,0x5b,0xdf,0xff,0x5d,0xdf,0xff,0x60,0xdf,0xff,0x62,0xe0,0xff,0x64,0xe0,0xff,0x67,0xe0,0xff,0x69,0xe1,0xff,0x6b,0xe1,0xff,0x6d,0xe1,0xff,0x6f,0xe2,0xff,0x72,0xe2,0xff,0x74,0xe2,0xff,0x76,0xe2,0xff,0x78,0xe3,0xff,0x7a,0xe3,0xff,0x7b,0xe3,0xff,0x7d,0xe4,0xff,0x7f,0xe4,0xff,0x81,0xe4,0xff,0x83,0xe5,0xff,0x85,0xe5,0xff,0x86,0xe5,0xff,0x88,0xe6,0xff,0x8a,0xe6,0xff,0x8c,0xe6,0xff,0x8d,0xe6,0xff,0x8f,0xe7,0xff,0x91,0xe7,0xff,0x92,0xe7,0xff,0x94,0xe8,0xff,0x96,0xe8,0xff,0x97,0xe8,0xff,0x99,0xe9,0xff,0x9b,0xe9,0xff,0x9c,0xe9,0xff,0x9e,0xe9,0xff,0x9f,0xea,0xff,0xa1,0xea,0xff,0xa2,0xea,0xff,0xa4,0xeb,0xff,0xa5,0xeb,0xff,0xa7,0xeb,0xff,0xa8,0xec,0xff,0xaa,0xec,0xff,0xab,0xec,0xff,0xad,0xec,0xff,0xae,0xed,0xff,0xb0,0xed,0xff,0xb1,0xed,0xff,0xb3,0xee,0xff,0xb4,0xee,0xff,0xb5,0xee,0xff,0xb7,0xef,0xff,0xb8,0xef,0xff,0xba,0xef,0xff,0xbb,0xef,0xff,0xbc,0xf0,0xff,0xbe,0xf0,0xff,0xbf,0xf0,0xff,0xc0,0xf1,0xff,0xc2,0xf1,0xff,0xc3,0xf1,0xff,0xc5,0xf1,0xff,0xc6,0xf2,0xff,0xc7,0xf2,0xff,0xc9,0xf2,0xff,0xca,0xf3,0xff,0xcb,0xf3,0xff,0xcd,0xf3,0xff,0xce,0xf4,0xff,0xcf,0xf4,0xff,0xd0,0xf4,0xff,0xd2,0xf4,0xff,0xd3,0xf5,0xff,0xd4,0xf5,0xff,0xd6,0xf5,0xff,0xd7,0xf6,0xff,0xd8,0xf6,0xff,0xd9,0xf6,0xff,0xdb,0xf6,0xff,0xdc,0xf7,0xff,0xdd,0xf7,0xff,0xde,0xf7,0xff,0xe0,0xf8,0xff,0xe1,0xf8,0xff,0xe2,0xf8,0xff,0xe3,0xf8,0xff,0xe5,0xf9,0xff,0xe6,0xf9,0xff,0xe7,0xf9,0xff,0xe8,0xfa,0xff,0xea,0xfa,0xff,0xeb,0xfa,0xff,0xec,0xfb,0xff,0xed,0xfb,0xff,0xee,0xfb,0xff,0xf0,0xfb,0xff,0xf1,0xfc,0xff,0xf2,0xfc,0xff,0xf3,0xfc,0xff,0xf5,0xfd,0xff,0xf6,0xfd,0xff,0xf7,0xfd,0xff,0xf8,0xfd,0xff,0xf9,0xfe,0xff,0xfb,0xfe,0xff,0xfc,0xfe,0xff,0xfd,0xfe,0xff,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,0xfe,0xff,0xff,0xfd,0xff,0xff,0xfd,0xff,0xff,0xfc,0xfe,0xff,0xfb,0xfe,0xff,0xfb,0xfe,0xff,0xfa,0xfe,0xff,0xfa,0xfe,0xff,0xf9,0xfe,0xff,0xf8,0xfe,0xff,0xf8,0xfe,0xff,0xf7,0xfe,0xff,0xf6,0xfd,0xff,0xf6,0xfd,0xff,0xf5,0xfd,0xff,0xf5,0xfd,0xff,0xf4,0xfd,0xff,0xf3,0xfd,0xff,0xf3,0xfd,0xff,0xf2,0xfd,0xff,0xf1,0xfd,0xff,0xf1,0xfc,0xff,0xf0,0xfc,0xff,0xef,0xfc,0xff,0xef,0xfc,0xff,0xee,0xfc,0xff,0xee,0xfc,0xff,0xed,0xfc,0xff,0xec,0xfc,0xff,0xec,0xfc,0xff,0xeb,0xfb,0xff,0xea,0xfb,0xff,0xea,0xfb,0xff,0xe9,0xfb,0xff,0xe9,0xfb,0xff,0xe8,0xfb,0xff,0xe7,0xfb,0xff,0xe7,0xfb,0xff,0xe6,0xfb,0xff,0xe5,0xfa,0xff,0xe5,0xfa,0xff,0xe4,0xfa,0xff,0xe4,0xfa,0xff,0xe3,0xfa,0xfe,0xe2,0xfa,0xfe,0xe2,0xfa,0xfe,0xe1,0xfa,0xfe,0xe0,0xfa,0xfe,0xe0,0xf9,0xfe,0xdf,0xf9,0xfe,0xde,0xf9,0xfe,0xde,0xf9,0xfe,0xdd,0xf9,0xfe,0xdd,0xf9,0xfe,0xdc,0xf9,0xfe,0xdb,0xf9,0xfe,0xdb,0xf8,0xfe,0xda,0xf8,0xfe,0xd9,0xf8,0xfe,0xd9,0xf8,0xfe,0xd8,0xf8,0xfe,0xd8,0xf8,0xfe,0xd7,0xf8,0xfe,0xd6,0xf8,0xfe,0xd6,0xf8,0xfe,0xd5,0xf7,0xfe,0xd4,0xf7,0xfe,0xd4,0xf7,0xfe,0xd3,0xf7,0xfe,0xd2,0xf7,0xfe,0xd2,0xf7,0xfd,0xd1,0xf7,0xfd,0xd1,0xf7,0xfd,0xd0,0xf6,0xfd,0xcf,0xf6,0xfd,0xcf,0xf6,0xfd,0xce,0xf6,0xfd,0xcd,0xf6,0xfd,0xcd,0xf6,0xfd,0xcc,0xf6,0xfd,0xcb,0xf6,0xfd,0xcb,0xf6,0xfd,0xca,0xf5,0xfd,0xc9,0xf5,0xfd,0xc9,0xf5,0xfd,0xc8,0xf5,0xfd,0xc8,0xf5,0xfd,0xc7,0xf5,0xfd,0xc6,0xf5,0xfd,0xc6,0xf5,0xfc,0xc5,0xf4,0xfc,0xc4,0xf4,0xfc,0xc4,0xf4,0xfc,0xc3,0xf4,0xfc,0xc2,0xf4,0xfc,0xc2,0xf4,0xfc,0xc1,0xf4,0xfc,0xc0,0xf4,0xfc,0xc0,0xf4,0xfc,0xbf,0xf3,0xfc,0xbf,0xf3,0xfc,0xbe,0xf3,0xfc,0xbd,0xf3,0xfc,0xbd,0xf3,0xfc,0xbc,0xf3,0xfb,0xbb,0xf3,0xfb,0xbb,0xf3,0xfb,0xba,0xf2,0xfb,0xb9,0xf2,0xfb,0xb9,0xf2,0xfb,0xb8,0xf2,0xfb,0xb7,0xf2,0xfb,0xb7,0xf2,0xfb,0xb6,0xf2,0xfb,0xb5,0xf2,0xfb,0xb5,0xf1,0xfb,0xb4,0xf1,0xfb,0xb3,0xf1,0xfb,0xb3,0xf1,0xfa,0xb2,0xf1,0xfa,0xb1,0xf1,0xfa,0xb1,0xf1,0xfa,0xb0,0xf1,0xfa,0xaf,0xf0,0xfa,0xaf,0xf0,0xfa,0xae,0xf0,0xfa,0xae,0xf0};
	static constexpr std::array<uint8_t, 768> D11  = {0x00,0xb6,0xff,0x00,0xb6,0xff,0x00,0xb6,0xff,0x00,0xb6,0xff,0x06,0xb6,0xff,0x11,0xb6,0xff,0x19,0xb6,0xfe,0x1f,0xb6,0xfd,0x24,0xb6,0xfd,0x28,0xb6,0xfc,0x2c,0xb5,0xfb,0x2f,0xb5,0xfb,0x33,0xb5,0xfa,0x36,0xb5,0xf9,0x39,0xb5,0xf9,0x3b,0xb5,0xf8,0x3e,0xb5,0xf7,0x40,0xb5,0xf6,0x43,0xb5,0xf6,0x45,0xb5,0xf5,0x47,0xb5,0xf4,0x49,0xb4,0xf4,0x4b,0xb4,0xf3,0x4d,0xb4,0xf2,0x4f,0xb4,0xf2,0x51,0xb4,0xf1,0x52,0xb4,0xf0,0x54,0xb4,0xf0,0x56,0xb4,0xef,0x57,0xb4,0xee,0x59,0xb4,0xed,0x5a,0xb4,0xed,0x5c,0xb3,0xec,0x5d,0xb3,0xeb,0x5f,0xb3,0xeb,0x60,0xb3,0xea,0x62,0xb3,0xe9,0x63,0xb3,0xe9,0x64,0xb3,0xe8,0x66,0xb3,0xe7,0x67,0xb3,0xe7,0x68,0xb3,0xe6,0x69,0xb3,0xe5,0x6b,0xb2,0xe5,0x6c,0xb2,0xe4,0x6d,0xb2,0xe3,0x6e,0xb2,0xe3,0x6f,0xb2,0xe2,0x70,0xb2,0xe1,0x71,0xb2,0xe0,0x73,0xb2,0xe0,0x74,0xb2,0xdf,0x75,0xb2,0xde,0x76,0xb2,0xde,0x77,0xb1,0xdd,0x78,0xb1,0xdc,0x79,0xb1,0xdc,0x7a,0xb1,0xdb,0x7b,0xb1,0xda,0x7c,0xb1,0xda,0x7d,0xb1,0xd9,0x7e,0xb1,0xd8,0x7e,0xb1,0xd8,0x7f,0xb1,0xd7,0x80,0xb1,0xd6,0x81,0xb0,0xd6,0x82,0xb0,0xd5,0x83,0xb0,0xd4,0x84,0xb0,0xd3,0x85,0xb0,0xd3,0x85,0xb0,0xd2,0x86,0xb0,0xd1,0x87,0xb0,0xd1,0x88,0xb0,0xd0,0x89,0xb0,0xcf,0x8a,0xb0,0xcf,0x8a,0xb0,0xce,0x8b,0xaf,0xcd,0x8c,0xaf,0xcd,0x8d,0xaf,0xcc,0x8d,0xaf,0xcb,0x8e,0xaf,0xcb,0x8f,0xaf,0xca,0x90,0xaf,0xc9,0x90,0xaf,0xc9,0x91,0xaf,0xc8,0x92,0xaf,0xc7,0x93,0xaf,0xc7,0x93,0xae,0xc6,0x94,0xae,0xc5,0x95,0xae,0xc4,0x95,0xae,0xc4,0x96,0xae,0xc3,0x97,0xae,0xc2,0x97,0xae,0xc2,0x98,0xae,0xc1,0x99,0xae,0xc0,0x99,0xae,0xc0,0x9a,0xae,0xbf,0x9b,0xae,0xbe,0x9b,0xad,0xbe,0x9c,0xad,0xbd,0x9d,0xad,0xbc,0x9d,0xad,0xbc,0x9e,0xad,0xbb,0x9e,0xad,0xba,0x9f,0xad,0xba,0xa0,0xad,0xb9,0xa0,0xad,0xb8,0xa1,0xad,0xb8,0xa1,0xad,0xb7,0xa2,0xac,0xb6,0xa3,0xac,0xb6,0xa3,0xac,0xb5,0xa4,0xac,0xb4,0xa4,0xac,0xb4,0xa5,0xac,0xb3,0xa5,0xac,0xb2,0xa6,0xac,0xb2,0xa7,0xac,0xb1,0xa7,0xac,0xb0,0xa8,0xac,0xb0,0xa8,0xab,0xaf,0xa9,0xab,0xae,0xaa,0xab,0xae,0xaa,0xab,0xad,0xab,0xab,0xac,0xab,0xab,0xac,0xac,0xab,0xab,0xad,0xab,0xab,0xad,0xaa,0xaa,0xae,0xaa,0xaa,0xaf,0xaa,0xa9,0xaf,0xaa,0xa9,0xb0,0xaa,0xa8,0xb1,0xaa,0xa7,0xb2,0xa9,0xa7,0xb2,0xa9,0xa6,0xb3,0xa9,0xa6,0xb4,0xa9,0xa5,0xb4,0xa9,0xa5,0xb5,0xa9,0xa4,0xb6,0xa8,0xa4,0xb6,0xa8,0xa3,0xb7,0xa8,0xa3,0xb8,0xa8,0xa2,0xb9,0xa8,0xa2,0xb9,0xa7,0xa2,0xba,0xa7,0xa1,0xbb,0xa7,0xa1,0xbb,0xa7,0xa0,0xbc,0xa7,0xa0,0xbd,0xa7,0x9f,0xbd,0xa6,0x9f,0xbe,0xa6,0x9e,0xbf,0xa6,0x9e,0xbf,0xa6,0x9d,0xc0,0xa6,0x9d,0xc1,0xa5,0x9c,0xc1,0xa5,0x9c,0xc2,0xa5,0x9b,0xc3,0xa5,0x9b,0xc3,0xa5,0x9a,0xc4,0xa4,0x9a,0xc5,0xa4,0x99,0xc5,0xa4,0x99,0xc6,0xa4,0x98,0xc6,0xa4,0x98,0xc7,0xa3,0x97,0xc8,0xa3,0x97,0xc8,0xa3,0x96,0xc9,0xa3,0x96,0xca,0xa3,0x95,0xca,0xa2,0x95,0xcb,0xa2,0x94,0xcb,0xa2,0x94,0xcc,0xa2,0x93,0xcd,0xa2,0x93,0xcd,0xa1,0x92,0xce,0xa1,0x92,0xce,0xa1,0x91,0xcf,0xa1,0x91,0xd0,0xa1,0x90,0xd0,0xa0,0x90,0xd1,0xa0,0x90,0xd1,0xa0,0x8f,0xd2,0xa0,0x8f,0xd3,0xa0,0x8e,0xd3,0x9f,0x8e,0xd4,0x9f,0x8d,0xd4,0x9f,0x8d,0xd5,0x9f,0x8c,0xd5,0x9f,0x8c,0xd6,0x9e,0x8b,0xd7,0x9e,0x8b,0xd7,0x9e,0x8a,0xd8,0x9e,0x8a,0xd8,0x9e,0x89,0xd9,0x9d,0x89,0xd9,0x9d,0x88,0xda,0x9d,0x88,0xdb,0x9d,0x87,0xdb,0x9c,0x87,0xdc,0x9c,0x86,0xdc,0x9c,0x86,0xdd,0x9c,0x85,0xdd,0x9c,0x85,0xde,0x9b,0x84,0xde,0x9b,0x84,0xdf,0x9b,0x83,0xe0,0x9b,0x83,0xe0,0x9a,0x82,0xe1,0x9a,0x82,0xe1,0x9a,0x81,0xe2,0x9a,0x81,0xe2,0x9a,0x80,0xe3,0x99,0x80,0xe3,0x99,0x7f,0xe4,0x99,0x7f,0xe4,0x99,0x7e,0xe5,0x98,0x7e,0xe5,0x98,0x7d,0xe6,0x98,0x7d,0xe6,0x98,0x7d,0xe7,0x98,0x7c,0xe7,0x97,0x7c,0xe8,0x97,0x7b,0xe9,0x97,0x7b,0xe9,0x97,0x7a,0xea,0x96,0x7a,0xea,0x96,0x79,0xeb,0x96,0x79,0xeb,0x96,0x78,0xec,0x95,0x78,0xec,0x95,0x77,0xed,0x95,0x77,0xed,0x95,0x76,0xee,0x95,0x76,0xee,0x94,0x75,0xef,0x94,0x75,0xef,0x94,0x74,0xf0,0x94,0x74,0xf0,0x93,0x73,0xf1,0x93,0x73,0xf1,0x93,0x72,0xf2,0x93,0x72,0xf2,0x92,0x71,0xf3,0x92,0x71,0xf3,0x92,0x70,0xf4,0x92,0x70,0xf4,0x91,0x6f,0xf5,0x91,0x6f,0xf5,0x91,0x6e,0xf5,0x91,0x6e,0xf6,0x90,0x6d,0xf6,0x90,0x6d};
	static constexpr std::array<uint8_t, 768> D12  = {0x00,0xc9,0xff,0x00,0xc8,0xff,0x00,0xc8,0xfe,0x00,0xc8,0xfe,0x00,0xc8,0xfd,0x00,0xc8,0xfd,0x00,0xc8,0xfc,0x0d,0xc8,0xfc,0x17,0xc8,0xfb,0x1d,0xc8,0xfa,0x23,0xc7,0xfa,0x28,0xc7,0xf9,0x2c,0xc7,0xf9,0x30,0xc7,0xf8,0x33,0xc7,0xf8,0x37,0xc7,0xf7,0x3a,0xc7,0xf7,0x3d,0xc7,0xf6,0x40,0xc6,0xf5,0x42,0xc6,0xf5,0x45,0xc6,0xf4,0x47,0xc6,0xf4,0x49,0xc6,0xf3,0x4c,0xc6,0xf3,0x4e,0xc6,0xf2,0x50,0xc6,0xf1,0x52,0xc5,0xf1,0x54,0xc5,0xf0,0x56,0xc5,0xf0,0x57,0xc5,0xef,0x59,0xc5,0xef,0x5b,0xc5,0xee,0x5d,0xc5,0xee,0x5e,0xc5,0xed,0x60,0xc5,0xec,0x62,0xc4,0xec,0x63,0xc4,0xeb,0x65,0xc4,0xeb,0x66,0xc4,0xea,0x68,0xc4,0xea,0x69,0xc4,0xe9,0x6b,0xc4,0xe9,0x6c,0xc4,0xe8,0x6d,0xc3,0xe7,0x6f,0xc3,0xe7,0x70,0xc3,0xe6,0x71,0xc3,0xe6,0x73,0xc3,0xe5,0x74,0xc3,0xe5,0x75,0xc3,0xe4,0x76,0xc3,0xe4,0x78,0xc2,0xe3,0x79,0xc2,0xe2,0x7a,0xc2,0xe2,0x7b,0xc2,0xe1,0x7c,0xc2,0xe1,0x7d,0xc2,0xe0,0x7e,0xc2,0xe0,0x80,0xc2,0xdf,0x81,0xc1,0xdf,0x82,0xc1,0xde,0x83,0xc1,0xdd,0x84,0xc1,0xdd,0x85,0xc1,0xdc,0x86,0xc1,0xdc,0x87,0xc1,0xdb,0x88,0xc1,0xdb,0x89,0xc0,0xda,0x8a,0xc0,0xda,0x8b,0xc0,0xd9,0x8c,0xc0,0xd8,0x8d,0xc0,0xd8,0x8e,0xc0,0xd7,0x8f,0xc0,0xd7,0x90,0xc0,0xd6,0x91,0xbf,0xd6,0x92,0xbf,0xd5,0x92,0xbf,0xd5,0x93,0xbf,0xd4,0x94,0xbf,0xd3,0x95,0xbf,0xd3,0x96,0xbf,0xd2,0x97,0xbf,0xd2,0x98,0xbe,0xd1,0x99,0xbe,0xd1,0x99,0xbe,0xd0,0x9a,0xbe,0xd0,0x9b,0xbe,0xcf,0x9c,0xbe,0xcf,0x9d,0xbe,0xce,0x9e,0xbe,0xcd,0x9e,0xbd,0xcd,0x9f,0xbd,0xcc,0xa0,0xbd,0xcc,0xa1,0xbd,0xcb,0xa2,0xbd,0xcb,0xa2,0xbd,0xca,0xa3,0xbd,0xca,0xa4,0xbd,0xc9,0xa5,0xbc,0xc8,0xa5,0xbc,0xc8,0xa6,0xbc,0xc7,0xa7,0xbc,0xc7,0xa8,0xbc,0xc6,0xa8,0xbc,0xc6,0xa9,0xbc,0xc5,0xaa,0xbb,0xc5,0xab,0xbb,0xc4,0xab,0xbb,0xc3,0xac,0xbb,0xc3,0xad,0xbb,0xc2,0xad,0xbb,0xc2,0xae,0xbb,0xc1,0xaf,0xbb,0xc1,0xaf,0xba,0xc0,0xb0,0xba,0xc0,0xb1,0xba,0xbf,0xb2,0xba,0xbf,0xb2,0xba,0xbe,0xb3,0xba,0xbe,0xb3,0xba,0xbd,0xb4,0xb9,0xbd,0xb5,0xb9,0xbd,0xb5,0xb9,0xbc,0xb6,0xb9,0xbc,0xb7,0xb9,0xbc,0xb7,0xb9,0xbb,0xb8,0xb9,0xbb,0xb8,0xb8,0xbb,0xb9,0xb8,0xbb,0xb9,0xb8,0xbb,0xba,0xb8,0xbb,0xba,0xb8,0xbb,0xbb,0xb8,0xbb,0xbb,0xb7,0xbb,0xbc,0xb7,0xbc,0xbc,0xb7,0xbc,0xbd,0xb7,0xbc,0xbd,0xb7,0xbc,0xbe,0xb7,0xbd,0xbe,0xb6,0xbd,0xbf,0xb6,0xbd,0xbf,0xb6,0xbe,0xc0,0xb6,0xbe,0xc0,0xb6,0xbe,0xc0,0xb6,0xbf,0xc1,0xb5,0xbf,0xc1,0xb5,0xbf,0xc2,0xb5,0xc0,0xc2,0xb5,0xc0,0xc3,0xb5,0xc0,0xc3,0xb4,0xc1,0xc4,0xb4,0xc1,0xc4,0xb4,0xc1,0xc4,0xb4,0xc2,0xc5,0xb4,0xc2,0xc5,0xb4,0xc2,0xc6,0xb3,0xc3,0xc6,0xb3,0xc3,0xc7,0xb3,0xc3,0xc7,0xb3,0xc4,0xc7,0xb3,0xc4,0xc8,0xb2,0xc4,0xc8,0xb2,0xc5,0xc9,0xb2,0xc5,0xc9,0xb2,0xc5,0xca,0xb2,0xc6,0xca,0xb2,0xc6,0xca,0xb1,0xc6,0xcb,0xb1,0xc7,0xcb,0xb1,0xc7,0xcc,0xb1,0xc7,0xcc,0xb1,0xc8,0xcd,0xb0,0xc8,0xcd,0xb0,0xc8,0xcd,0xb0,0xc9,0xce,0xb0,0xc9,0xce,0xb0,0xc9,0xcf,0xaf,0xca,0xcf,0xaf,0xca,0xcf,0xaf,0xca,0xd0,0xaf,0xcb,0xd0,0xaf,0xcb,0xd1,0xae,0xcb,0xd1,0xae,0xcc,0xd2,0xae,0xcc,0xd2,0xae,0xcc,0xd2,0xae,0xcd,0xd3,0xad,0xcd,0xd3,0xad,0xcd,0xd4,0xad,0xce,0xd4,0xad,0xce,0xd4,0xad,0xce,0xd5,0xac,0xcf,0xd5,0xac,0xcf,0xd6,0xac,0xcf,0xd6,0xac,0xd0,0xd6,0xac,0xd0,0xd7,0xab,0xd0,0xd7,0xab,0xd1,0xd8,0xab,0xd1,0xd8,0xab,0xd1,0xd9,0xab,0xd2,0xd9,0xaa,0xd2,0xd9,0xaa,0xd2,0xda,0xaa,0xd3,0xda,0xaa,0xd3,0xdb,0xa9,0xd4,0xdb,0xa9,0xd4,0xdb,0xa9,0xd4,0xdc,0xa9,0xd5,0xdc,0xa9,0xd5,0xdd,0xa8,0xd5,0xdd,0xa8,0xd6,0xdd,0xa8,0xd6,0xde,0xa8,0xd6,0xde,0xa8,0xd7,0xdf,0xa7,0xd7,0xdf,0xa7,0xd7,0xdf,0xa7,0xd8,0xe0,0xa7,0xd8,0xe0,0xa6,0xd8,0xe1,0xa6,0xd9,0xe1,0xa6,0xd9,0xe1,0xa6,0xd9,0xe2,0xa6,0xda,0xe2,0xa5,0xda,0xe3,0xa5,0xda,0xe3,0xa5,0xdb,0xe3,0xa5,0xdb,0xe4,0xa4,0xdb,0xe4,0xa4,0xdc,0xe4,0xa4,0xdc,0xe5,0xa4,0xdc,0xe5,0xa4,0xdd,0xe6,0xa3,0xdd,0xe6,0xa3,0xdd,0xe6,0xa3,0xde,0xe7,0xa3,0xde,0xe7,0xa2,0xde,0xe8,0xa2,0xdf,0xe8,0xa2,0xdf,0xe8,0xa2,0xdf,0xe9,0xa1,0xe0,0xe9,0xa1,0xe0,0xea,0xa1,0xe0,0xea,0xa1,0xe1,0xea,0xa0,0xe1,0xeb,0xa0,0xe1,0xeb,0xa0,0xe2,0xeb,0xa0,0xe2,0xec,0x9f,0xe2,0xec,0x9f,0xe3,0xed,0x9f,0xe3,0xed,0x9f,0xe3,0xed,0x9e,0xe4};
	static constexpr std::array<uint8_t, 768> D13  = {0x11,0x2d,0x68,0x12,0x2e,0x6a,0x13,0x2f,0x6c,0x14,0x31,0x6e,0x15,0x32,0x70,0x16,0x33,0x73,0x17,0x34,0x75,0x18,0x36,0x77,0x19,0x37,0x79,0x1a,0x38,0x7b,0x1b,0x39,0x7d,0x1c,0x3b,0x7f,0x1d,0x3c,0x82,0x1e,0x3d,0x84,0x1f,0x3f,0x86,0x20,0x40,0x88,0x21,0x41,0x8a,0x22,0x43,0x8c,0x23,0x44,0x8e,0x24,0x45,0x90,0x25,0x47,0x93,0x25,0x48,0x95,0x26,0x49,0x97,0x27,0x4b,0x99,0x28,0x4c,0x9b,0x29,0x4e,0x9d,0x2a,0x4f,0x9f,0x2a,0x51,0xa1,0x2b,0x52,0xa3,0x2c,0x53,0xa5,0x2d,0x55,0xa8,0x2d,0x56,0xaa,0x2e,0x58,0xac,0x2f,0x59,0xae,0x2f,0x5b,0xb0,0x30,0x5c,0xb2,0x31,0x5e,0xb4,0x31,0x5f,0xb6,0x32,0x61,0xb8,0x32,0x62,0xba,0x33,0x64,0xbc,0x33,0x65,0xbe,0x34,0x67,0xc0,0x34,0x69,0xc2,0x35,0x6a,0xc3,0x35,0x6c,0xc5,0x36,0x6d,0xc7,0x36,0x6f,0xc9,0x36,0x71,0xcb,0x36,0x72,0xcd,0x36,0x74,0xcf,0x36,0x76,0xd0,0x37,0x77,0xd2,0x37,0x79,0xd4,0x36,0x7b,0xd6,0x36,0x7d,0xd7,0x36,0x7e,0xd9,0x36,0x80,0xdb,0x35,0x82,0xdc,0x35,0x84,0xde,0x35,0x86,0xdf,0x34,0x87,0xe1,0x34,0x89,0xe2,0x33,0x8b,0xe4,0x33,0x8d,0xe5,0x32,0x8f,0xe6,0x32,0x91,0xe7,0x32,0x92,0xe9,0x32,0x94,0xea,0x32,0x96,0xeb,0x32,0x98,0xec,0x33,0x9a,0xed,0x33,0x9b,0xee,0x34,0x9d,0xef,0x36,0x9f,0xf0,0x37,0xa1,0xf1,0x39,0xa3,0xf2,0x3b,0xa4,0xf3,0x3d,0xa6,0xf4,0x40,0xa8,0xf5,0x42,0xa9,0xf5,0x45,0xab,0xf6,0x48,0xad,0xf7,0x4b,0xaf,0xf7,0x4e,0xb0,0xf8,0x51,0xb2,0xf8,0x54,0xb3,0xf9,0x57,0xb5,0xf9,0x5b,0xb7,0xfa,0x5e,0xb8,0xfa,0x62,0xba,0xfa,0x65,0xbb,0xfb,0x69,0xbd,0xfb,0x6d,0xbf,0xfb,0x71,0xc0,0xfb,0x74,0xc2,0xfb,0x78,0xc3,0xfb,0x7c,0xc5,0xfc,0x80,0xc6,0xfb,0x84,0xc8,0xfb,0x88,0xc9,0xfb,0x8c,0xca,0xfb,0x90,0xcc,0xfb,0x94,0xcd,0xfb,0x98,0xcf,0xfb,0x9c,0xd0,0xfa,0xa0,0xd2,0xfa,0xa4,0xd3,0xfa,0xa7,0xd4,0xf9,0xab,0xd6,0xf9,0xaf,0xd7,0xf9,0xb3,0xd9,0xf8,0xb7,0xda,0xf8,0xbb,0xdb,0xf7,0xbe,0xdd,0xf7,0xc2,0xde,0xf7,0xc6,0xdf,0xf6,0xc9,0xe1,0xf6,0xcd,0xe2,0xf5,0xd0,0xe3,0xf5,0xd3,0xe5,0xf4,0xd6,0xe6,0xf3,0xd9,0xe7,0xf3,0xdb,0xe8,0xf2,0xdd,0xe9,0xf1,0xde,0xea,0xf0,0xdf,0xea,0xef,0xdf,0xeb,0xee,0xdf,0xeb,0xec,0xde,0xeb,0xeb,0xdd,0xeb,0xe9,0xdb,0xeb,0xe7,0xd8,0xea,0xe6,0xd5,0xea,0xe4,0xd2,0xe9,0xe2,0xcf,0xe8,0xe0,0xcb,0xe7,0xde,0xc7,0xe6,0xdc,0xc3,0xe5,0xda,0xbf,0xe4,0xd8,0xbb,0xe3,0xd6,0xb7,0xe2,0xd4,0xb3,0xe1,0xd2,0xaf,0xe0,0xd1,0xab,0xdf,0xcf,0xa6,0xde,0xcd,0xa2,0xdd,0xcb,0x9e,0xdc,0xc9,0x9a,0xda,0xc7,0x96,0xd9,0xc5,0x91,0xd8,0xc3,0x8d,0xd7,0xc1,0x89,0xd6,0xbf,0x85,0xd5,0xbd,0x81,0xd3,0xbb,0x7d,0xd2,0xb9,0x79,0xd1,0xb6,0x75,0xd0,0xb4,0x71,0xce,0xb2,0x6d,0xcd,0xb0,0x69,0xcc,0xae,0x65,0xca,0xac,0x62,0xc9,0xa9,0x5e,0xc8,0xa7,0x5a,0xc6,0xa5,0x57,0xc5,0xa3,0x53,0xc4,0xa0,0x50,0xc2,0x9e,0x4d,0xc1,0x9c,0x49,0xbf,0x99,0x46,0xbe,0x97,0x43,0xbc,0x94,0x40,0xbb,0x92,0x3e,0xb9,0x8f,0x3b,0xb8,0x8d,0x38,0xb6,0x8a,0x36,0xb5,0x88,0x33,0xb3,0x85,0x31,0xb2,0x83,0x2f,0xb0,0x80,0x2d,0xaf,0x7d,0x2c,0xad,0x7b,0x2a,0xac,0x78,0x29,0xaa,0x75,0x28,0xa8,0x73,0x27,0xa7,0x70,0x26,0xa5,0x6d,0x25,0xa4,0x6b,0x25,0xa2,0x68,0x25,0xa0,0x65,0x24,0x9f,0x62,0x24,0x9d,0x60,0x24,0x9b,0x5d,0x24,0x9a,0x5a,0x24,0x98,0x58,0x24,0x96,0x55,0x24,0x95,0x53,0x23,0x93,0x50,0x23,0x92,0x4e,0x23,0x90,0x4c,0x23,0x8e,0x49,0x22,0x8d,0x47,0x22,0x8b,0x45,0x22,0x89,0x43,0x21,0x88,0x41,0x21,0x86,0x3f,0x20,0x85,0x3d,0x20,0x83,0x3b,0x1f,0x81,0x39,0x1f,0x80,0x37,0x1e,0x7e,0x36,0x1e,0x7d,0x34,0x1d,0x7b,0x32,0x1c,0x79,0x31,0x1c,0x78,0x2f,0x1b,0x76,0x2d,0x1a,0x75,0x2c,0x1a,0x73,0x2a,0x19,0x71,0x29,0x18,0x70,0x27,0x18,0x6e,0x26,0x17,0x6d,0x25,0x16,0x6b,0x23,0x16,0x6a,0x22,0x15,0x68,0x20,0x14,0x66,0x1f,0x13,0x65,0x1e,0x12,0x63,0x1d,0x12,0x62,0x1b,0x11,0x60,0x1a,0x10,0x5f,0x19,0x0f,0x5d,0x18,0x0e,0x5c,0x17,0x0e,0x5a,0x16,0x0d,0x59,0x15,0x0c,0x57,0x13,0x0b,0x56,0x12,0x0a,0x54,0x11,0x09,0x53,0x10,0x08,0x51,0x0f,0x08,0x50,0x0e,0x07,0x4e,0x0d,0x06,0x4d,0x0d,0x05,0x4b,0x0c,0x05,0x4a,0x0b,0x04,0x48,0x0a,0x03,0x47,0x09,0x03,0x45,0x08,0x02,0x44,0x07,0x02,0x42,0x07,0x01,0x41,0x06,0x01,0x3f,0x05,0x01,0x3e,0x04,0x00,0x3c,0x03,0x00,0x3b,0x02,0x00,0x3a,0x02};

	// rainbow
	static constexpr std::array<uint8_t, 768> R1   = {0x00,0x30,0xf5,0x00,0x34,0xf2,0x00,0x37,0xee,0x00,0x3b,0xeb,0x03,0x3e,0xe7,0x09,0x42,0xe4,0x0e,0x45,0xe1,0x12,0x48,0xdd,0x14,0x4a,0xda,0x16,0x4d,0xd6,0x17,0x50,0xd3,0x18,0x52,0xcf,0x19,0x55,0xcc,0x19,0x57,0xc8,0x19,0x5a,0xc5,0x19,0x5c,0xc1,0x19,0x5e,0xbe,0x19,0x60,0xbb,0x18,0x63,0xb7,0x18,0x65,0xb4,0x18,0x67,0xb1,0x17,0x69,0xad,0x17,0x6a,0xaa,0x18,0x6c,0xa7,0x18,0x6e,0xa4,0x19,0x70,0xa0,0x1b,0x71,0x9d,0x1c,0x73,0x9a,0x1e,0x75,0x97,0x20,0x76,0x94,0x22,0x78,0x91,0x24,0x79,0x8e,0x27,0x7a,0x8b,0x29,0x7c,0x88,0x2b,0x7d,0x85,0x2d,0x7e,0x82,0x2f,0x80,0x7f,0x31,0x81,0x7c,0x33,0x82,0x79,0x35,0x84,0x76,0x36,0x85,0x73,0x38,0x86,0x70,0x39,0x88,0x6d,0x3a,0x89,0x6a,0x3b,0x8a,0x67,0x3c,0x8b,0x63,0x3d,0x8d,0x60,0x3e,0x8e,0x5d,0x3e,0x8f,0x5a,0x3f,0x91,0x57,0x3f,0x92,0x53,0x40,0x93,0x50,0x40,0x95,0x4d,0x40,0x96,0x4a,0x41,0x97,0x46,0x41,0x99,0x43,0x41,0x9a,0x3f,0x41,0x9b,0x3c,0x42,0x9c,0x38,0x42,0x9e,0x35,0x43,0x9f,0x32,0x44,0xa0,0x2e,0x45,0xa1,0x2b,0x46,0xa2,0x28,0x47,0xa3,0x25,0x49,0xa4,0x22,0x4b,0xa5,0x1f,0x4d,0xa6,0x1c,0x4f,0xa7,0x1a,0x52,0xa8,0x18,0x54,0xa9,0x16,0x57,0xaa,0x14,0x5a,0xab,0x13,0x5d,0xac,0x12,0x60,0xad,0x11,0x63,0xad,0x11,0x66,0xae,0x10,0x69,0xaf,0x10,0x6c,0xb0,0x10,0x6f,0xb0,0x10,0x72,0xb1,0x11,0x75,0xb2,0x11,0x79,0xb3,0x11,0x7c,0xb3,0x12,0x7f,0xb4,0x12,0x82,0xb5,0x13,0x84,0xb6,0x13,0x87,0xb6,0x14,0x8a,0xb7,0x14,0x8d,0xb8,0x14,0x90,0xb8,0x15,0x93,0xb9,0x15,0x96,0xba,0x16,0x99,0xba,0x16,0x9b,0xbb,0x17,0x9e,0xbc,0x17,0xa1,0xbc,0x18,0xa4,0xbd,0x18,0xa6,0xbe,0x19,0xa9,0xbe,0x19,0xac,0xbf,0x19,0xaf,0xc0,0x1a,0xb1,0xc0,0x1a,0xb4,0xc1,0x1b,0xb7,0xc2,0x1b,0xba,0xc2,0x1c,0xbc,0xc3,0x1c,0xbf,0xc3,0x1d,0xc2,0xc4,0x1d,0xc4,0xc5,0x1e,0xc7,0xc5,0x1e,0xca,0xc6,0x1e,0xcc,0xc7,0x1f,0xcf,0xc7,0x1f,0xd2,0xc8,0x20,0xd4,0xc8,0x20,0xd7,0xc9,0x21,0xd9,0xc9,0x21,0xdc,0xca,0x22,0xdf,0xca,0x22,0xe1,0xca,0x22,0xe3,0xcb,0x23,0xe6,0xcb,0x23,0xe8,0xcb,0x23,0xea,0xcb,0x24,0xec,0xcb,0x24,0xee,0xcb,0x24,0xf0,0xcb,0x24,0xf1,0xca,0x24,0xf3,0xca,0x24,0xf4,0xc9,0x24,0xf5,0xc8,0x24,0xf6,0xc8,0x24,0xf7,0xc7,0x24,0xf8,0xc5,0x24,0xf8,0xc4,0x24,0xf9,0xc3,0x24,0xf9,0xc2,0x23,0xf9,0xc0,0x23,0xfa,0xbf,0x23,0xfa,0xbe,0x23,0xfa,0xbc,0x22,0xfa,0xbb,0x22,0xfa,0xb9,0x22,0xfa,0xb8,0x21,0xfa,0xb6,0x21,0xfa,0xb4,0x21,0xfa,0xb3,0x20,0xf9,0xb1,0x20,0xf9,0xb0,0x20,0xf9,0xae,0x1f,0xf9,0xad,0x1f,0xf9,0xab,0x1f,0xf9,0xa9,0x1e,0xf9,0xa8,0x1e,0xf9,0xa6,0x1e,0xf8,0xa5,0x1d,0xf8,0xa3,0x1d,0xf8,0xa1,0x1d,0xf8,0xa0,0x1d,0xf8,0x9e,0x1c,0xf8,0x9d,0x1c,0xf8,0x9b,0x1c,0xf7,0x99,0x1b,0xf7,0x98,0x1b,0xf7,0x96,0x1b,0xf7,0x94,0x1a,0xf7,0x93,0x1a,0xf6,0x91,0x1a,0xf6,0x8f,0x1a,0xf6,0x8e,0x19,0xf6,0x8c,0x19,0xf6,0x8a,0x19,0xf5,0x89,0x18,0xf5,0x87,0x18,0xf5,0x85,0x18,0xf5,0x84,0x18,0xf4,0x82,0x17,0xf4,0x80,0x17,0xf4,0x7f,0x17,0xf4,0x7d,0x17,0xf4,0x7b,0x16,0xf3,0x79,0x16,0xf3,0x77,0x16,0xf3,0x76,0x16,0xf3,0x74,0x15,0xf2,0x72,0x15,0xf2,0x70,0x15,0xf2,0x6e,0x15,0xf1,0x6d,0x15,0xf1,0x6b,0x15,0xf1,0x69,0x15,0xf1,0x67,0x15,0xf0,0x65,0x15,0xf0,0x64,0x16,0xf0,0x62,0x16,0xf0,0x60,0x17,0xf0,0x5f,0x18,0xf0,0x5d,0x1a,0xf0,0x5c,0x1b,0xf0,0x5a,0x1d,0xf0,0x59,0x1f,0xf0,0x58,0x21,0xf0,0x57,0x24,0xf0,0x57,0x26,0xf1,0x56,0x29,0xf1,0x56,0x2c,0xf2,0x56,0x2f,0xf2,0x56,0x33,0xf3,0x56,0x36,0xf3,0x57,0x3a,0xf4,0x58,0x3e,0xf5,0x58,0x41,0xf5,0x59,0x45,0xf6,0x5a,0x49,0xf7,0x5b,0x4d,0xf7,0x5c,0x52,0xf8,0x5e,0x56,0xf9,0x5f,0x5a,0xf9,0x60,0x5e,0xfa,0x61,0x62,0xfb,0x63,0x66,0xfb,0x64,0x6a,0xfc,0x65,0x6f,0xfc,0x67,0x73,0xfd,0x68,0x77,0xfd,0x69,0x7b,0xfe,0x6b,0x80,0xfe,0x6c,0x84,0xff,0x6d,0x88,0xff,0x6f,0x8c,0xff,0x70,0x91,0xff,0x72,0x95,0xff,0x73,0x99,0xff,0x74,0x9d,0xff,0x76,0xa2,0xff,0x77,0xa6,0xff,0x78,0xaa,0xff,0x7a,0xaf,0xff,0x7b,0xb3,0xff,0x7d,0xb7,0xff,0x7e,0xbc,0xff,0x7f,0xc0,0xff,0x81,0xc4,0xff,0x82,0xc9,0xff,0x84,0xcd,0xff,0x85,0xd2,0xff,0x86,0xd6,0xff,0x88,0xdb,0xff,0x89,0xdf,0xff,0x8b,0xe3,0xff,0x8c,0xe8,0xff,0x8d,0xec,0xfe,0x8f,0xf1,0xfe,0x90,0xf5,0xfd,0x92,0xfa};
	static constexpr std::array<uint8_t, 768> R2   = {0x00,0x34,0xf5,0x00,0x37,0xf3,0x00,0x3a,0xf0,0x00,0x3c,0xed,0x00,0x3f,0xea,0x00,0x41,0xe7,0x00,0x44,0xe5,0x00,0x46,0xe2,0x00,0x48,0xdf,0x00,0x4a,0xdc,0x00,0x4d,0xd9,0x00,0x4f,0xd6,0x00,0x51,0xd4,0x00,0x53,0xd1,0x00,0x55,0xce,0x00,0x57,0xcb,0x00,0x59,0xc9,0x00,0x5a,0xc6,0x00,0x5c,0xc3,0x00,0x5e,0xc0,0x00,0x60,0xbd,0x00,0x62,0xbb,0x00,0x63,0xb8,0x00,0x65,0xb5,0x00,0x67,0xb2,0x00,0x68,0xb0,0x00,0x6a,0xad,0x00,0x6c,0xaa,0x00,0x6d,0xa7,0x00,0x6f,0xa5,0x00,0x70,0xa2,0x00,0x71,0xa0,0x00,0x73,0x9d,0x00,0x74,0x9a,0x00,0x75,0x98,0x01,0x76,0x95,0x08,0x77,0x93,0x0e,0x78,0x91,0x14,0x7a,0x8e,0x18,0x7b,0x8c,0x1c,0x7c,0x89,0x20,0x7d,0x87,0x23,0x7e,0x85,0x26,0x7f,0x82,0x29,0x80,0x80,0x2b,0x81,0x7e,0x2d,0x82,0x7b,0x2f,0x83,0x79,0x31,0x84,0x76,0x33,0x85,0x74,0x34,0x86,0x72,0x35,0x87,0x6f,0x37,0x88,0x6d,0x38,0x89,0x6a,0x39,0x8a,0x68,0x3a,0x8b,0x65,0x3b,0x8c,0x63,0x3b,0x8d,0x60,0x3c,0x8e,0x5e,0x3d,0x8f,0x5b,0x3d,0x90,0x58,0x3e,0x91,0x56,0x3e,0x92,0x53,0x3e,0x93,0x50,0x3f,0x94,0x4e,0x3f,0x95,0x4b,0x3f,0x96,0x48,0x3f,0x98,0x45,0x3f,0x99,0x42,0x3f,0x9a,0x3f,0x3f,0x9b,0x3c,0x3f,0x9c,0x39,0x3f,0x9d,0x35,0x3f,0x9e,0x32,0x3f,0x9f,0x2f,0x3f,0xa0,0x2b,0x3f,0xa1,0x28,0x40,0xa2,0x24,0x40,0xa3,0x21,0x41,0xa4,0x1e,0x42,0xa5,0x1b,0x44,0xa6,0x18,0x46,0xa6,0x16,0x48,0xa7,0x14,0x4a,0xa8,0x12,0x4d,0xa9,0x10,0x4f,0xa9,0x10,0x52,0xaa,0x0f,0x55,0xab,0x0f,0x57,0xab,0x0f,0x5a,0xac,0x0f,0x5d,0xac,0x0f,0x60,0xad,0x10,0x62,0xae,0x10,0x65,0xae,0x11,0x68,0xaf,0x11,0x6a,0xaf,0x12,0x6d,0xb0,0x12,0x6f,0xb1,0x12,0x72,0xb1,0x13,0x74,0xb2,0x13,0x77,0xb2,0x14,0x79,0xb3,0x14,0x7c,0xb4,0x15,0x7e,0xb4,0x15,0x81,0xb5,0x16,0x83,0xb5,0x16,0x85,0xb6,0x17,0x88,0xb6,0x17,0x8a,0xb7,0x18,0x8c,0xb7,0x18,0x8f,0xb8,0x19,0x91,0xb9,0x19,0x93,0xb9,0x1a,0x96,0xba,0x1a,0x98,0xba,0x1a,0x9a,0xbb,0x1b,0x9c,0xbb,0x1b,0x9f,0xbc,0x1c,0xa1,0xbc,0x1c,0xa3,0xbd,0x1d,0xa5,0xbe,0x1d,0xa8,0xbe,0x1e,0xaa,0xbf,0x1e,0xac,0xbf,0x1f,0xae,0xc0,0x1f,0xb0,0xc0,0x1f,0xb3,0xc1,0x20,0xb5,0xc1,0x20,0xb7,0xc2,0x21,0xb9,0xc2,0x21,0xbb,0xc3,0x22,0xbe,0xc3,0x22,0xc0,0xc4,0x23,0xc2,0xc4,0x23,0xc4,0xc5,0x23,0xc6,0xc5,0x24,0xc8,0xc6,0x24,0xcb,0xc6,0x25,0xcd,0xc7,0x25,0xcf,0xc7,0x26,0xd1,0xc8,0x26,0xd3,0xc8,0x27,0xd5,0xc9,0x27,0xd7,0xc9,0x27,0xda,0xca,0x28,0xdc,0xca,0x28,0xde,0xcb,0x29,0xe0,0xcb,0x29,0xe2,0xcb,0x2a,0xe4,0xcc,0x2a,0xe6,0xcc,0x2b,0xe8,0xcd,0x2b,0xea,0xcd,0x2b,0xec,0xcd,0x2c,0xee,0xcd,0x2c,0xf0,0xcd,0x2c,0xf2,0xcd,0x2c,0xf4,0xcd,0x2c,0xf5,0xcd,0x2c,0xf6,0xcc,0x2c,0xf8,0xcc,0x2c,0xf9,0xcb,0x2c,0xf9,0xca,0x2c,0xfa,0xc9,0x2b,0xfb,0xc8,0x2b,0xfb,0xc7,0x2a,0xfc,0xc5,0x2a,0xfc,0xc4,0x29,0xfc,0xc3,0x29,0xfc,0xc2,0x28,0xfd,0xc0,0x28,0xfd,0xbf,0x27,0xfd,0xbe,0x27,0xfd,0xbc,0x26,0xfd,0xbb,0x26,0xfd,0xba,0x25,0xfe,0xb8,0x25,0xfe,0xb7,0x24,0xfe,0xb5,0x23,0xfe,0xb4,0x23,0xfe,0xb3,0x22,0xfe,0xb1,0x22,0xfe,0xb0,0x21,0xfe,0xaf,0x21,0xff,0xad,0x20,0xff,0xac,0x1f,0xff,0xaa,0x1f,0xff,0xa9,0x1e,0xff,0xa8,0x1e,0xff,0xa6,0x1d,0xff,0xa5,0x1d,0xff,0xa3,0x1c,0xff,0xa2,0x1c,0xff,0xa1,0x1b,0xff,0x9f,0x1a,0xff,0x9e,0x1a,0xff,0x9c,0x19,0xff,0x9b,0x19,0xff,0x99,0x18,0xff,0x98,0x18,0xff,0x96,0x17,0xff,0x95,0x16,0xff,0x93,0x16,0xff,0x92,0x15,0xff,0x91,0x15,0xff,0x8f,0x14,0xff,0x8e,0x14,0xff,0x8c,0x13,0xff,0x8b,0x12,0xff,0x89,0x12,0xff,0x88,0x11,0xff,0x86,0x11,0xff,0x84,0x10,0xff,0x83,0x10,0xff,0x81,0x0f,0xff,0x80,0x0e,0xff,0x7e,0x0e,0xff,0x7d,0x0d,0xff,0x7b,0x0d,0xff,0x79,0x0c,0xff,0x78,0x0b,0xff,0x76,0x0b,0xff,0x74,0x0a,0xff,0x73,0x0a,0xff,0x71,0x09,0xff,0x6f,0x08,0xff,0x6e,0x08,0xff,0x6c,0x07,0xff,0x6a,0x07,0xff,0x69,0x06,0xff,0x67,0x06,0xff,0x65,0x05,0xff,0x63,0x05,0xff,0x61,0x04,0xff,0x5f,0x04,0xff,0x5e,0x03,0xff,0x5c,0x03,0xff,0x5a,0x03,0xff,0x58,0x02,0xfe,0x56,0x02,0xfe,0x54,0x02,0xfe,0x52,0x01,0xfe,0x4f,0x01,0xfe,0x4d,0x01,0xfe,0x4b,0x00,0xfe,0x49,0x00,0xfe,0x46,0x00,0xfe,0x44,0x00,0xfd,0x41,0x00,0xfd,0x3f,0x00,0xfd,0x3c,0x00,0xfd,0x39,0x00,0xfd,0x36,0x00,0xfd,0x33,0x00,0xfd,0x30,0x00};
	static constexpr std::array<uint8_t, 768> R3   = {0x08,0x5c,0xf8,0x0f,0x5f,0xf4,0x13,0x61,0xf1,0x17,0x63,0xed,0x19,0x65,0xe9,0x1b,0x67,0xe5,0x1c,0x6a,0xe1,0x1d,0x6c,0xde,0x1d,0x6e,0xda,0x1e,0x70,0xd6,0x1d,0x72,0xd2,0x1d,0x74,0xce,0x1c,0x75,0xcb,0x1b,0x77,0xc7,0x19,0x79,0xc3,0x18,0x7b,0xbf,0x16,0x7d,0xbb,0x14,0x7e,0xb8,0x13,0x80,0xb4,0x12,0x82,0xb0,0x12,0x83,0xac,0x13,0x85,0xa8,0x14,0x86,0xa4,0x17,0x88,0xa0,0x1a,0x89,0x9c,0x1d,0x8a,0x98,0x20,0x8c,0x93,0x23,0x8d,0x8f,0x27,0x8e,0x8b,0x2a,0x8f,0x86,0x2d,0x90,0x82,0x2f,0x92,0x7e,0x31,0x93,0x79,0x34,0x94,0x75,0x35,0x95,0x70,0x37,0x96,0x6c,0x38,0x97,0x67,0x39,0x98,0x62,0x3a,0x9a,0x5e,0x3b,0x9b,0x59,0x3b,0x9c,0x54,0x3b,0x9d,0x50,0x3c,0x9e,0x4b,0x3c,0x9f,0x46,0x3c,0xa0,0x42,0x3d,0xa1,0x3d,0x3d,0xa2,0x39,0x3e,0xa3,0x35,0x3f,0xa4,0x31,0x41,0xa5,0x2e,0x42,0xa6,0x2b,0x44,0xa7,0x28,0x47,0xa8,0x26,0x49,0xa8,0x24,0x4c,0xa9,0x22,0x4e,0xaa,0x21,0x51,0xaa,0x20,0x54,0xab,0x20,0x57,0xac,0x1f,0x5a,0xac,0x1f,0x5c,0xad,0x1e,0x5f,0xae,0x1e,0x62,0xae,0x1e,0x65,0xaf,0x1e,0x67,0xaf,0x1d,0x6a,0xb0,0x1d,0x6c,0xb1,0x1d,0x6f,0xb1,0x1d,0x72,0xb2,0x1d,0x74,0xb2,0x1d,0x77,0xb3,0x1c,0x79,0xb4,0x1c,0x7b,0xb4,0x1c,0x7e,0xb5,0x1c,0x80,0xb5,0x1b,0x83,0xb6,0x1b,0x85,0xb6,0x1b,0x87,0xb7,0x1b,0x8a,0xb8,0x1b,0x8c,0xb8,0x1a,0x8e,0xb9,0x1a,0x91,0xb9,0x1a,0x93,0xba,0x1a,0x95,0xba,0x19,0x97,0xbb,0x19,0x9a,0xbb,0x19,0x9c,0xbc,0x19,0x9e,0xbd,0x18,0xa0,0xbd,0x18,0xa3,0xbe,0x18,0xa5,0xbe,0x18,0xa7,0xbf,0x17,0xa9,0xbf,0x17,0xab,0xc0,0x17,0xae,0xc0,0x16,0xb0,0xc1,0x16,0xb2,0xc1,0x16,0xb4,0xc2,0x15,0xb6,0xc2,0x15,0xb8,0xc3,0x15,0xbb,0xc3,0x14,0xbd,0xc4,0x14,0xbf,0xc5,0x14,0xc1,0xc5,0x13,0xc3,0xc6,0x13,0xc5,0xc6,0x13,0xc7,0xc7,0x12,0xca,0xc7,0x12,0xcc,0xc8,0x12,0xce,0xc8,0x11,0xd0,0xc9,0x11,0xd2,0xc9,0x10,0xd4,0xca,0x10,0xd6,0xca,0x0f,0xd8,0xcb,0x0f,0xdb,0xcb,0x0e,0xdd,0xcb,0x0e,0xdf,0xcc,0x0e,0xe1,0xcc,0x0e,0xe3,0xcd,0x0e,0xe5,0xcd,0x0e,0xe7,0xcd,0x0f,0xe9,0xce,0x10,0xeb,0xce,0x12,0xed,0xce,0x14,0xef,0xcd,0x16,0xf1,0xcd,0x19,0xf3,0xcd,0x1c,0xf4,0xcc,0x1f,0xf6,0xcb,0x23,0xf7,0xca,0x26,0xf8,0xc9,0x29,0xf9,0xc8,0x2d,0xf9,0xc7,0x30,0xfa,0xc6,0x33,0xfa,0xc5,0x36,0xfb,0xc3,0x39,0xfb,0xc2,0x3c,0xfc,0xc0,0x3f,0xfc,0xbf,0x41,0xfc,0xbe,0x44,0xfc,0xbc,0x46,0xfc,0xbb,0x48,0xfd,0xb9,0x4b,0xfd,0xb8,0x4d,0xfd,0xb6,0x4f,0xfd,0xb5,0x51,0xfd,0xb3,0x53,0xfd,0xb2,0x55,0xfe,0xb0,0x57,0xfe,0xaf,0x59,0xfe,0xad,0x5b,0xfe,0xac,0x5d,0xfe,0xaa,0x5f,0xfe,0xa9,0x61,0xfe,0xa7,0x63,0xfe,0xa6,0x65,0xfe,0xa4,0x66,0xfe,0xa3,0x68,0xfe,0xa1,0x6a,0xfe,0xa0,0x6c,0xff,0x9e,0x6d,0xff,0x9d,0x6f,0xff,0x9b,0x71,0xff,0x9a,0x72,0xff,0x98,0x74,0xff,0x97,0x75,0xff,0x95,0x77,0xff,0x93,0x79,0xff,0x92,0x7a,0xff,0x90,0x7c,0xff,0x8f,0x7d,0xff,0x8d,0x7f,0xfe,0x8b,0x80,0xfe,0x8a,0x82,0xfe,0x88,0x84,0xfe,0x86,0x85,0xfe,0x85,0x87,0xfe,0x83,0x88,0xfe,0x81,0x8a,0xfe,0x80,0x8b,0xfe,0x7e,0x8c,0xfe,0x7c,0x8e,0xfe,0x7a,0x8f,0xfd,0x79,0x91,0xfd,0x77,0x92,0xfd,0x75,0x94,0xfd,0x73,0x95,0xfd,0x71,0x97,0xfd,0x70,0x98,0xfd,0x6e,0x99,0xfc,0x6c,0x9b,0xfc,0x6a,0x9c,0xfc,0x68,0x9e,0xfc,0x66,0x9f,0xfc,0x64,0xa0,0xfb,0x62,0xa2,0xfb,0x60,0xa3,0xfb,0x5e,0xa4,0xfb,0x5c,0xa5,0xfa,0x5a,0xa6,0xfa,0x58,0xa7,0xfa,0x56,0xa8,0xfa,0x54,0xa8,0xf9,0x52,0xa8,0xf9,0x50,0xa8,0xf9,0x4e,0xa7,0xf8,0x4c,0xa6,0xf8,0x4a,0xa5,0xf8,0x49,0xa3,0xf7,0x47,0xa1,0xf7,0x46,0x9e,0xf7,0x44,0x9c,0xf6,0x43,0x99,0xf6,0x42,0x96,0xf6,0x40,0x92,0xf5,0x3f,0x8f,0xf5,0x3e,0x8c,0xf4,0x3d,0x88,0xf4,0x3c,0x85,0xf3,0x3a,0x82,0xf3,0x39,0x7e,0xf2,0x38,0x7b,0xf1,0x37,0x78,0xf1,0x36,0x74,0xf0,0x34,0x71,0xf0,0x33,0x6d,0xef,0x32,0x6a,0xee,0x31,0x67,0xee,0x2f,0x63,0xed,0x2e,0x60,0xec,0x2d,0x5d,0xeb,0x2c,0x59,0xeb,0x2a,0x56,0xea,0x29,0x53,0xe9,0x28,0x4f,0xe8,0x26,0x4c,0xe8,0x25,0x49,0xe7,0x24,0x45,0xe6,0x22,0x42,0xe5,0x21,0x3f,0xe4,0x20,0x3b,0xe3,0x1e,0x38,0xe2,0x1d,0x35,0xe2,0x1b,0x31,0xe1,0x1a,0x2e,0xe0,0x18,0x2a,0xdf,0x16,0x26,0xde,0x14,0x23,0xdd,0x13,0x1f,0xdc,0x11,0x1b,0xdb,0x0f,0x17,0xda,0x0c,0x12,0xd9,0x0a,0x0c,0xd8,0x07,0x06,0xd7,0x05,0x00};
	static constexpr std::array<uint8_t, 768> R4   = {0x04,0x00,0x6c,0x04,0x00,0x6f,0x04,0x00,0x72,0x04,0x00,0x75,0x04,0x00,0x78,0x04,0x00,0x7b,0x04,0x00,0x7e,0x04,0x00,0x81,0x04,0x00,0x84,0x05,0x00,0x87,0x05,0x00,0x8a,0x05,0x00,0x8d,0x05,0x00,0x91,0x05,0x00,0x94,0x05,0x00,0x97,0x05,0x01,0x9a,0x05,0x01,0x9c,0x05,0x01,0x9f,0x05,0x02,0xa2,0x06,0x02,0xa5,0x06,0x03,0xa7,0x06,0x04,0xaa,0x06,0x06,0xac,0x07,0x07,0xaf,0x07,0x09,0xb1,0x08,0x0b,0xb3,0x08,0x0d,0xb5,0x09,0x0f,0xb7,0x09,0x11,0xb9,0x0a,0x13,0xbb,0x0a,0x15,0xbd,0x0b,0x17,0xbf,0x0b,0x18,0xc1,0x0c,0x1a,0xc3,0x0c,0x1c,0xc5,0x0c,0x1d,0xc7,0x0d,0x1f,0xc9,0x0d,0x20,0xcb,0x0e,0x22,0xcd,0x0e,0x24,0xcf,0x0e,0x25,0xd1,0x0f,0x27,0xd2,0x0f,0x28,0xd4,0x0f,0x2a,0xd6,0x10,0x2b,0xd8,0x10,0x2c,0xda,0x10,0x2e,0xdc,0x10,0x2f,0xde,0x11,0x31,0xe0,0x11,0x32,0xe2,0x11,0x34,0xe4,0x11,0x35,0xe6,0x12,0x37,0xe8,0x12,0x38,0xe9,0x12,0x3a,0xeb,0x13,0x3b,0xed,0x14,0x3d,0xee,0x14,0x3f,0xef,0x15,0x41,0xf0,0x17,0x43,0xf0,0x18,0x45,0xf0,0x19,0x47,0xef,0x1b,0x4a,0xee,0x1c,0x4d,0xed,0x1d,0x50,0xeb,0x1e,0x53,0xe8,0x1f,0x56,0xe5,0x1f,0x59,0xe2,0x20,0x5c,0xde,0x1f,0x5f,0xda,0x1f,0x62,0xd6,0x1d,0x65,0xd2,0x1c,0x68,0xce,0x1a,0x6a,0xca,0x17,0x6d,0xc5,0x14,0x70,0xc1,0x11,0x73,0xbc,0x0d,0x75,0xb8,0x09,0x78,0xb3,0x07,0x7a,0xae,0x05,0x7d,0xaa,0x06,0x7f,0xa5,0x08,0x81,0xa0,0x0c,0x83,0x9b,0x10,0x85,0x96,0x15,0x87,0x90,0x19,0x89,0x8b,0x1d,0x8b,0x85,0x21,0x8d,0x80,0x24,0x8e,0x7a,0x27,0x90,0x74,0x2a,0x92,0x6e,0x2b,0x94,0x68,0x2d,0x95,0x62,0x2e,0x97,0x5c,0x2f,0x99,0x56,0x30,0x9b,0x50,0x30,0x9c,0x4a,0x30,0x9e,0x44,0x31,0xa0,0x3e,0x31,0xa1,0x38,0x32,0xa3,0x32,0x33,0xa4,0x2c,0x35,0xa6,0x27,0x37,0xa7,0x22,0x39,0xa9,0x1d,0x3c,0xaa,0x19,0x3f,0xab,0x15,0x43,0xad,0x11,0x46,0xae,0x0e,0x4a,0xaf,0x0c,0x4e,0xb0,0x0a,0x52,0xb1,0x08,0x56,0xb2,0x08,0x5a,0xb3,0x07,0x5d,0xb4,0x06,0x61,0xb5,0x06,0x65,0xb6,0x06,0x68,0xb7,0x06,0x6c,0xb8,0x06,0x6f,0xba,0x05,0x73,0xbb,0x05,0x76,0xbc,0x05,0x7a,0xbd,0x05,0x7d,0xbe,0x05,0x80,0xbf,0x05,0x83,0xc0,0x05,0x87,0xc1,0x05,0x8a,0xc2,0x04,0x8d,0xc3,0x04,0x90,0xc4,0x04,0x93,0xc5,0x04,0x96,0xc6,0x04,0x9a,0xc7,0x04,0x9d,0xc8,0x04,0xa0,0xc9,0x04,0xa3,0xca,0x04,0xa6,0xcb,0x03,0xa9,0xcc,0x03,0xac,0xcd,0x03,0xaf,0xce,0x03,0xb2,0xcf,0x03,0xb5,0xd0,0x03,0xb8,0xd1,0x03,0xbb,0xd2,0x03,0xbe,0xd3,0x02,0xc1,0xd4,0x02,0xc4,0xd5,0x02,0xc7,0xd6,0x02,0xca,0xd7,0x02,0xcd,0xd8,0x02,0xd0,0xd9,0x02,0xd3,0xd9,0x02,0xd6,0xda,0x02,0xd9,0xdb,0x02,0xdc,0xdc,0x02,0xdf,0xdd,0x02,0xe1,0xde,0x02,0xe4,0xde,0x02,0xe7,0xdf,0x02,0xea,0xdf,0x02,0xec,0xdf,0x02,0xee,0xdf,0x02,0xf0,0xde,0x03,0xf2,0xde,0x03,0xf4,0xdd,0x04,0xf5,0xdc,0x05,0xf7,0xda,0x05,0xf8,0xd9,0x06,0xf8,0xd7,0x07,0xf9,0xd6,0x07,0xfa,0xd4,0x08,0xfa,0xd2,0x09,0xfa,0xd0,0x0a,0xfa,0xce,0x0b,0xfb,0xcc,0x0b,0xfb,0xca,0x0c,0xfb,0xc8,0x0d,0xfb,0xc6,0x0d,0xfb,0xc4,0x0e,0xfb,0xc2,0x0e,0xfb,0xc0,0x0f,0xfb,0xbe,0x0f,0xfb,0xbc,0x10,0xfc,0xba,0x10,0xfc,0xb8,0x11,0xfc,0xb6,0x11,0xfc,0xb4,0x12,0xfc,0xb2,0x12,0xfc,0xb0,0x13,0xfc,0xae,0x13,0xfc,0xac,0x13,0xfc,0xa9,0x14,0xfc,0xa7,0x14,0xfc,0xa5,0x14,0xfc,0xa3,0x15,0xfc,0xa1,0x15,0xfc,0x9f,0x15,0xfc,0x9d,0x15,0xfc,0x9a,0x15,0xfc,0x98,0x16,0xfc,0x96,0x16,0xfc,0x94,0x16,0xfc,0x91,0x16,0xfc,0x8f,0x15,0xfc,0x8d,0x15,0xfc,0x8a,0x15,0xfc,0x88,0x15,0xfc,0x86,0x14,0xfc,0x83,0x14,0xfd,0x80,0x14,0xfd,0x7e,0x13,0xfd,0x7b,0x13,0xfd,0x79,0x13,0xfd,0x76,0x12,0xfe,0x73,0x12,0xfe,0x70,0x11,0xfe,0x6e,0x11,0xfe,0x6b,0x11,0xfe,0x68,0x10,0xfe,0x65,0x10,0xfe,0x62,0x10,0xfe,0x5f,0x0f,0xfe,0x5b,0x0f,0xfe,0x58,0x0f,0xfe,0x55,0x0e,0xfe,0x51,0x0e,0xfe,0x4e,0x0e,0xfe,0x4a,0x0e,0xfe,0x47,0x0e,0xfe,0x43,0x0d,0xfd,0x3f,0x0d,0xfd,0x3c,0x0d,0xfc,0x38,0x0d,0xfb,0x35,0x0d,0xfa,0x32,0x0d,0xf9,0x2f,0x0d,0xf8,0x2c,0x0d,0xf6,0x29,0x0d,0xf5,0x27,0x0d,0xf3,0x24,0x0d,0xf1,0x22,0x0d,0xf0,0x20,0x0d,0xee,0x1f,0x0d,0xec,0x1d,0x0d,0xea,0x1b,0x0d,0xe8,0x19,0x0d,0xe6,0x17,0x0d,0xe4,0x16,0x0d,0xe2,0x14,0x0d,0xe0,0x12,0x0d,0xde,0x10,0x0d,0xdc,0x0d,0x0d,0xdb,0x0b,0x0d,0xd9,0x08,0x0d,0xd7,0x05,0x0d};

	// cyclic
	static constexpr std::array<uint8_t, 768> C1   = {0xf9,0x85,0xf8,0xfa,0x84,0xf6,0xfb,0x83,0xf3,0xfc,0x82,0xf1,0xfc,0x81,0xee,0xfd,0x7f,0xeb,0xfd,0x7e,0xe8,0xfd,0x7c,0xe5,0xfd,0x7a,0xe2,0xfd,0x78,0xde,0xfd,0x76,0xdb,0xfc,0x74,0xd7,0xfc,0x72,0xd4,0xfb,0x70,0xd0,0xfb,0x6d,0xcc,0xfa,0x6b,0xc8,0xfa,0x69,0xc5,0xf9,0x67,0xc1,0xf8,0x64,0xbd,0xf7,0x62,0xb9,0xf7,0x5f,0xb5,0xf6,0x5d,0xb2,0xf5,0x5b,0xae,0xf4,0x58,0xaa,0xf3,0x56,0xa6,0xf2,0x54,0xa3,0xf1,0x51,0x9f,0xf0,0x4f,0x9b,0xef,0x4c,0x97,0xee,0x4a,0x94,0xed,0x48,0x90,0xec,0x46,0x8c,0xea,0x43,0x88,0xe9,0x41,0x84,0xe8,0x3f,0x81,0xe6,0x3d,0x7d,0xe5,0x3b,0x79,0xe3,0x39,0x75,0xe1,0x37,0x71,0xe0,0x35,0x6d,0xde,0x33,0x6a,0xdc,0x31,0x66,0xda,0x2f,0x62,0xd9,0x2d,0x5e,0xd7,0x2c,0x5a,0xd5,0x2a,0x56,0xd3,0x28,0x53,0xd1,0x26,0x4f,0xcf,0x24,0x4b,0xcd,0x23,0x47,0xcb,0x21,0x44,0xc9,0x1f,0x40,0xc7,0x1e,0x3c,0xc6,0x1c,0x39,0xc4,0x1b,0x35,0xc2,0x19,0x32,0xc0,0x18,0x2e,0xbe,0x17,0x2b,0xbd,0x17,0x27,0xbb,0x17,0x24,0xba,0x17,0x21,0xb9,0x17,0x1e,0xb8,0x18,0x1b,0xb7,0x19,0x19,0xb6,0x1b,0x16,0xb5,0x1d,0x14,0xb5,0x1f,0x11,0xb5,0x21,0x0f,0xb5,0x23,0x0d,0xb5,0x26,0x0c,0xb5,0x29,0x0a,0xb6,0x2b,0x08,0xb6,0x2e,0x07,0xb7,0x31,0x06,0xb8,0x33,0x06,0xb8,0x36,0x05,0xb9,0x39,0x05,0xba,0x3b,0x05,0xbb,0x3e,0x04,0xbc,0x41,0x04,0xbd,0x43,0x04,0xbe,0x46,0x04,0xbf,0x48,0x04,0xc0,0x4b,0x04,0xc1,0x4d,0x04,0xc2,0x50,0x04,0xc3,0x52,0x04,0xc4,0x54,0x04,0xc5,0x57,0x04,0xc6,0x59,0x05,0xc7,0x5c,0x05,0xc8,0x5e,0x05,0xc9,0x60,0x05,0xca,0x63,0x05,0xca,0x65,0x05,0xcb,0x67,0x05,0xcc,0x6a,0x05,0xcd,0x6c,0x05,0xce,0x6f,0x05,0xce,0x71,0x05,0xcf,0x73,0x05,0xd0,0x76,0x05,0xd0,0x78,0x05,0xd1,0x7a,0x05,0xd1,0x7d,0x05,0xd2,0x7f,0x04,0xd2,0x81,0x04,0xd3,0x84,0x04,0xd3,0x86,0x04,0xd4,0x89,0x04,0xd4,0x8b,0x04,0xd5,0x8d,0x04,0xd5,0x8f,0x04,0xd6,0x92,0x04,0xd6,0x94,0x05,0xd6,0x96,0x05,0xd6,0x98,0x06,0xd7,0x9b,0x07,0xd7,0x9d,0x08,0xd7,0x9f,0x0a,0xd7,0xa0,0x0d,0xd6,0xa2,0x0f,0xd6,0xa4,0x12,0xd5,0xa5,0x15,0xd5,0xa7,0x18,0xd4,0xa8,0x1c,0xd2,0xa9,0x1f,0xd1,0xaa,0x23,0xd0,0xaa,0x27,0xce,0xaa,0x2b,0xcc,0xab,0x2f,0xca,0xab,0x33,0xc7,0xaa,0x37,0xc5,0xaa,0x3b,0xc2,0xa9,0x3f,0xbf,0xa9,0x43,0xbc,0xa8,0x46,0xb9,0xa7,0x4a,0xb6,0xa6,0x4e,0xb3,0xa5,0x52,0xaf,0xa4,0x55,0xac,0xa3,0x59,0xa9,0xa1,0x5c,0xa5,0xa0,0x60,0xa1,0x9f,0x63,0x9d,0x9e,0x66,0x9a,0x9d,0x69,0x96,0x9b,0x6d,0x92,0x9a,0x70,0x8e,0x99,0x73,0x89,0x98,0x76,0x85,0x96,0x79,0x81,0x95,0x7c,0x7c,0x94,0x7f,0x77,0x93,0x82,0x73,0x91,0x85,0x6e,0x90,0x88,0x69,0x8f,0x8b,0x63,0x8d,0x8e,0x5e,0x8c,0x91,0x59,0x8b,0x94,0x53,0x89,0x97,0x4e,0x88,0x9a,0x48,0x86,0x9d,0x43,0x84,0xa0,0x3e,0x83,0xa3,0x39,0x81,0xa6,0x34,0x7f,0xa9,0x2f,0x7d,0xac,0x2b,0x7b,0xaf,0x28,0x79,0xb2,0x25,0x76,0xb5,0x23,0x74,0xb8,0x22,0x71,0xbb,0x22,0x6f,0xbe,0x22,0x6c,0xc1,0x22,0x69,0xc5,0x24,0x66,0xc8,0x25,0x63,0xcb,0x26,0x60,0xce,0x28,0x5d,0xd1,0x29,0x5a,0xd4,0x2b,0x57,0xd7,0x2d,0x54,0xda,0x2e,0x51,0xdd,0x30,0x4e,0xe0,0x31,0x4b,0xe3,0x33,0x49,0xe5,0x35,0x46,0xe8,0x37,0x44,0xea,0x39,0x42,0xec,0x3c,0x40,0xee,0x3e,0x3f,0xf0,0x41,0x3e,0xf2,0x44,0x3d,0xf3,0x47,0x3d,0xf4,0x49,0x3d,0xf5,0x4c,0x3d,0xf6,0x4f,0x3e,0xf7,0x52,0x3f,0xf7,0x55,0x40,0xf8,0x58,0x41,0xf8,0x5b,0x43,0xf9,0x5e,0x45,0xf9,0x61,0x47,0xf9,0x63,0x49,0xf9,0x66,0x4b,0xf9,0x69,0x4d,0xf9,0x6b,0x4f,0xf9,0x6e,0x51,0xf9,0x70,0x53,0xf9,0x73,0x55,0xf9,0x75,0x57,0xf9,0x77,0x59,0xf9,0x7a,0x5b,0xfa,0x7c,0x5d,0xfa,0x7f,0x5e,0xfa,0x82,0x60,0xfa,0x84,0x62,0xfa,0x87,0x64,0xfa,0x8a,0x65,0xfa,0x8d,0x67,0xfa,0x90,0x69,0xfa,0x93,0x6a,0xfa,0x96,0x6b,0xfb,0x99,0x6d,0xfb,0x9c,0x6e,0xfb,0xa0,0x6f,0xfb,0xa3,0x71,0xfb,0xa7,0x72,0xfc,0xaa,0x73,0xfc,0xae,0x74,0xfc,0xb1,0x75,0xfc,0xb5,0x76,0xfd,0xb9,0x77,0xfd,0xbc,0x78,0xfd,0xc0,0x79,0xfe,0xc3,0x7a,0xfe,0xc7,0x7b,0xfe,0xca,0x7c,0xff,0xce,0x7d,0xff,0xd1,0x7e,0xff,0xd5,0x7f,0xff,0xd8,0x80,0xff,0xdb,0x81,0xff,0xdf,0x82,0xff,0xe2,0x83,0xff,0xe5,0x84,0xff,0xe8,0x84,0xff,0xea,0x85,0xff,0xed,0x85,0xff,0xf0,0x86,0xfe,0xf2,0x86,0xfd,0xf4,0x86,0xfc,0xf6,0x86,0xfb,0xf7,0x85,0xf9};
	static constexpr std::array<uint8_t, 768> C2   = {0xef,0x55,0xf2,0xf1,0x57,0xf0,0xf2,0x5a,0xef,0xf3,0x5d,0xed,0xf5,0x5f,0xeb,0xf6,0x62,0xe9,0xf6,0x65,0xe7,0xf7,0x68,0xe5,0xf8,0x6b,0xe2,0xf9,0x6f,0xe0,0xf9,0x72,0xde,0xfa,0x75,0xdb,0xfa,0x78,0xd9,0xfa,0x7b,0xd6,0xfb,0x7e,0xd3,0xfb,0x81,0xd1,0xfb,0x84,0xce,0xfb,0x87,0xcb,0xfb,0x8a,0xc9,0xfc,0x8d,0xc6,0xfc,0x90,0xc3,0xfc,0x93,0xc0,0xfc,0x95,0xbe,0xfc,0x98,0xbb,0xfc,0x9b,0xb8,0xfc,0x9e,0xb5,0xfc,0xa0,0xb3,0xfc,0xa3,0xb0,0xfc,0xa6,0xad,0xfc,0xa8,0xaa,0xfc,0xab,0xa7,0xfc,0xad,0xa5,0xfc,0xb0,0xa2,0xfb,0xb2,0x9f,0xfb,0xb5,0x9c,0xfb,0xb7,0x99,0xfb,0xb9,0x96,0xfc,0xbc,0x93,0xfc,0xbe,0x90,0xfc,0xc0,0x8d,0xfc,0xc3,0x8a,0xfc,0xc5,0x87,0xfc,0xc7,0x84,0xfc,0xc9,0x81,0xfc,0xcc,0x7e,0xfc,0xce,0x7b,0xfc,0xd0,0x78,0xfc,0xd2,0x75,0xfc,0xd4,0x71,0xfc,0xd6,0x6e,0xfc,0xd8,0x6b,0xfc,0xda,0x67,0xfc,0xdd,0x64,0xfb,0xdf,0x60,0xfb,0xe0,0x5c,0xfb,0xe2,0x58,0xfa,0xe4,0x55,0xfa,0xe6,0x51,0xf9,0xe7,0x4d,0xf8,0xe9,0x49,0xf7,0xea,0x45,0xf5,0xeb,0x41,0xf4,0xec,0x3d,0xf2,0xed,0x39,0xf1,0xee,0x35,0xef,0xee,0x32,0xed,0xee,0x2e,0xea,0xef,0x2b,0xe8,0xee,0x28,0xe6,0xee,0x25,0xe3,0xee,0x23,0xe1,0xed,0x21,0xde,0xed,0x1f,0xdb,0xec,0x1d,0xd8,0xeb,0x1b,0xd6,0xea,0x1a,0xd3,0xe9,0x19,0xd0,0xe8,0x18,0xcd,0xe7,0x18,0xca,0xe6,0x17,0xc7,0xe5,0x16,0xc4,0xe4,0x16,0xc1,0xe3,0x15,0xbe,0xe2,0x15,0xbb,0xe1,0x15,0xb8,0xe0,0x14,0xb5,0xdf,0x14,0xb2,0xde,0x13,0xaf,0xdd,0x13,0xac,0xdc,0x13,0xa9,0xda,0x12,0xa6,0xd9,0x12,0xa3,0xd8,0x12,0xa0,0xd7,0x11,0x9d,0xd6,0x11,0x9a,0xd5,0x11,0x97,0xd4,0x10,0x94,0xd3,0x10,0x91,0xd2,0x10,0x8d,0xd0,0x0f,0x8a,0xcf,0x0f,0x87,0xce,0x0f,0x84,0xcd,0x0e,0x81,0xcc,0x0e,0x7d,0xcb,0x0e,0x7a,0xca,0x0d,0x77,0xc8,0x0d,0x73,0xc7,0x0d,0x70,0xc6,0x0d,0x6c,0xc5,0x0c,0x69,0xc4,0x0c,0x65,0xc3,0x0c,0x62,0xc2,0x0c,0x5e,0xc0,0x0c,0x5a,0xbf,0x0c,0x56,0xbe,0x0c,0x53,0xbd,0x0d,0x4f,0xbc,0x0e,0x4b,0xba,0x0f,0x48,0xb9,0x10,0x44,0xb8,0x12,0x41,0xb7,0x14,0x3e,0xb5,0x16,0x3b,0xb4,0x19,0x38,0xb3,0x1b,0x36,0xb1,0x1e,0x34,0xb0,0x21,0x33,0xae,0x25,0x32,0xad,0x28,0x32,0xab,0x2c,0x32,0xa9,0x2f,0x32,0xa8,0x33,0x33,0xa6,0x37,0x35,0xa4,0x3b,0x36,0xa3,0x3f,0x38,0xa1,0x42,0x39,0x9f,0x46,0x3b,0x9d,0x4a,0x3c,0x9b,0x4e,0x3e,0x99,0x52,0x3f,0x98,0x56,0x40,0x96,0x59,0x41,0x94,0x5d,0x42,0x92,0x61,0x43,0x90,0x64,0x44,0x8e,0x68,0x44,0x8c,0x6b,0x45,0x8a,0x6f,0x45,0x89,0x72,0x45,0x87,0x76,0x45,0x85,0x79,0x45,0x83,0x7d,0x45,0x81,0x80,0x44,0x7f,0x84,0x44,0x7d,0x87,0x43,0x7b,0x8a,0x42,0x79,0x8e,0x41,0x78,0x91,0x40,0x76,0x94,0x3f,0x74,0x97,0x3e,0x72,0x9b,0x3c,0x70,0x9e,0x3b,0x6e,0xa1,0x39,0x6c,0xa4,0x38,0x6a,0xa7,0x36,0x68,0xaa,0x34,0x66,0xad,0x33,0x64,0xb0,0x31,0x61,0xb3,0x30,0x5f,0xb6,0x2f,0x5d,0xb9,0x2d,0x5b,0xbb,0x2c,0x58,0xbe,0x2b,0x56,0xc1,0x2a,0x53,0xc3,0x2a,0x51,0xc6,0x29,0x4e,0xc8,0x28,0x4c,0xcb,0x27,0x49,0xcd,0x27,0x46,0xd0,0x26,0x43,0xd2,0x26,0x40,0xd5,0x25,0x3e,0xd7,0x25,0x3b,0xd9,0x24,0x38,0xdb,0x24,0x35,0xde,0x25,0x32,0xe0,0x25,0x2f,0xe2,0x26,0x2c,0xe4,0x28,0x29,0xe5,0x29,0x27,0xe7,0x2c,0x24,0xe9,0x2e,0x22,0xea,0x31,0x20,0xec,0x34,0x1e,0xed,0x37,0x1d,0xee,0x3b,0x1c,0xef,0x3e,0x1b,0xf0,0x42,0x1b,0xf1,0x45,0x1b,0xf2,0x49,0x1b,0xf2,0x4d,0x1c,0xf3,0x50,0x1c,0xf3,0x54,0x1d,0xf4,0x57,0x1f,0xf4,0x5a,0x20,0xf5,0x5e,0x21,0xf5,0x61,0x23,0xf6,0x64,0x24,0xf6,0x67,0x26,0xf6,0x6a,0x27,0xf7,0x6d,0x29,0xf7,0x70,0x2a,0xf7,0x73,0x2c,0xf8,0x75,0x2d,0xf8,0x78,0x2e,0xf8,0x7b,0x30,0xf9,0x7e,0x31,0xf9,0x80,0x32,0xf9,0x83,0x34,0xfa,0x86,0x35,0xfa,0x89,0x36,0xfa,0x8c,0x37,0xfa,0x8f,0x38,0xfb,0x91,0x39,0xfb,0x94,0x3a,0xfb,0x98,0x3b,0xfb,0x9b,0x3c,0xfb,0x9e,0x3d,0xfb,0xa1,0x3e,0xfb,0xa4,0x3e,0xfb,0xa7,0x3f,0xfb,0xab,0x40,0xfb,0xae,0x40,0xfb,0xb1,0x41,0xfb,0xb5,0x41,0xfb,0xb8,0x42,0xfb,0xbb,0x42,0xfb,0xbf,0x43,0xfb,0xc2,0x43,0xfb,0xc5,0x44,0xfb,0xc8,0x44,0xfa,0xcb,0x45,0xfa,0xcf,0x45,0xfa,0xd2,0x46,0xfa,0xd5,0x46,0xfa,0xd8,0x47,0xf9,0xdb,0x48,0xf9,0xdd,0x48,0xf9,0xe0,0x49,0xf8,0xe3,0x4b,0xf8,0xe5,0x4c,0xf7,0xe7,0x4d,0xf6,0xe9,0x4f,0xf5,0xec,0x51,0xf4,0xed,0x53,0xf3};
	static constexpr std::array<uint8_t, 768> C3   = {0xe1,0xd7,0xda,0xe2,0xd7,0xd8,0xe3,0xd6,0xd6,0xe4,0xd5,0xd4,0xe5,0xd4,0xd1,0xe6,0xd2,0xcf,0xe7,0xd1,0xcc,0xe8,0xcf,0xc9,0xe9,0xcd,0xc6,0xea,0xcb,0xc3,0xea,0xc9,0xc0,0xeb,0xc7,0xbd,0xec,0xc5,0xba,0xec,0xc2,0xb7,0xed,0xc0,0xb4,0xed,0xbd,0xb0,0xee,0xbb,0xad,0xee,0xb9,0xaa,0xee,0xb6,0xa7,0xef,0xb4,0xa4,0xef,0xb1,0xa0,0xef,0xaf,0x9d,0xef,0xac,0x9a,0xf0,0xaa,0x97,0xf0,0xa7,0x94,0xf0,0xa5,0x90,0xf0,0xa2,0x8d,0xf0,0xa0,0x8a,0xf0,0x9d,0x87,0xf0,0x9b,0x84,0xf0,0x98,0x81,0xf0,0x96,0x7e,0xf0,0x93,0x7a,0xf0,0x91,0x77,0xf0,0x8e,0x74,0xf0,0x8b,0x71,0xef,0x89,0x6e,0xef,0x86,0x6b,0xef,0x84,0x68,0xef,0x81,0x65,0xee,0x7e,0x62,0xee,0x7c,0x5f,0xee,0x79,0x5c,0xed,0x76,0x59,0xed,0x74,0x56,0xed,0x71,0x53,0xec,0x6e,0x50,0xec,0x6b,0x4d,0xeb,0x69,0x4a,0xeb,0x66,0x47,0xea,0x63,0x44,0xea,0x60,0x41,0xe9,0x5d,0x3e,0xe8,0x5a,0x3b,0xe8,0x57,0x38,0xe7,0x55,0x35,0xe6,0x52,0x33,0xe5,0x4f,0x30,0xe4,0x4c,0x2d,0xe3,0x49,0x2b,0xe1,0x47,0x29,0xe0,0x44,0x26,0xde,0x42,0x24,0xdc,0x40,0x23,0xda,0x3e,0x21,0xd8,0x3c,0x20,0xd6,0x3a,0x1e,0xd4,0x39,0x1d,0xd1,0x38,0x1c,0xcf,0x37,0x1c,0xcc,0x36,0x1b,0xc9,0x35,0x1b,0xc6,0x34,0x1a,0xc3,0x34,0x1a,0xc0,0x34,0x1a,0xbd,0x33,0x1a,0xba,0x33,0x1a,0xb7,0x33,0x1a,0xb4,0x33,0x1a,0xb1,0x32,0x1b,0xae,0x32,0x1b,0xab,0x32,0x1b,0xa7,0x32,0x1b,0xa4,0x32,0x1b,0xa1,0x31,0x1b,0x9e,0x31,0x1b,0x9b,0x31,0x1c,0x98,0x31,0x1c,0x94,0x31,0x1c,0x91,0x30,0x1c,0x8e,0x30,0x1c,0x8b,0x30,0x1c,0x88,0x2f,0x1c,0x85,0x2f,0x1c,0x82,0x2f,0x1c,0x7f,0x2e,0x1c,0x7c,0x2e,0x1c,0x79,0x2e,0x1d,0x76,0x2d,0x1d,0x73,0x2d,0x1d,0x70,0x2c,0x1d,0x6d,0x2c,0x1d,0x6a,0x2c,0x1d,0x67,0x2b,0x1d,0x64,0x2b,0x1d,0x61,0x2a,0x1d,0x5e,0x2a,0x1d,0x5b,0x29,0x1d,0x58,0x29,0x1d,0x55,0x28,0x1d,0x52,0x28,0x1d,0x4f,0x27,0x1d,0x4c,0x26,0x1d,0x49,0x26,0x1d,0x47,0x25,0x1d,0x44,0x25,0x1d,0x41,0x24,0x1d,0x3e,0x24,0x1d,0x3c,0x23,0x1d,0x39,0x23,0x1e,0x37,0x22,0x1e,0x34,0x22,0x1f,0x32,0x22,0x1f,0x30,0x21,0x20,0x2e,0x21,0x21,0x2d,0x21,0x22,0x2b,0x21,0x23,0x2a,0x21,0x25,0x29,0x22,0x26,0x28,0x22,0x28,0x27,0x22,0x2a,0x27,0x23,0x2c,0x27,0x23,0x2e,0x27,0x24,0x31,0x27,0x25,0x33,0x27,0x26,0x36,0x27,0x27,0x39,0x27,0x28,0x3c,0x28,0x29,0x3f,0x28,0x2a,0x42,0x29,0x2b,0x45,0x29,0x2c,0x48,0x2a,0x2d,0x4b,0x2a,0x2e,0x4f,0x2b,0x30,0x52,0x2b,0x31,0x55,0x2c,0x32,0x59,0x2c,0x33,0x5c,0x2d,0x35,0x60,0x2d,0x36,0x63,0x2e,0x37,0x66,0x2e,0x38,0x6a,0x2f,0x3a,0x6d,0x2f,0x3b,0x71,0x2f,0x3c,0x74,0x2f,0x3d,0x78,0x30,0x3f,0x7c,0x30,0x40,0x7f,0x30,0x41,0x83,0x30,0x42,0x86,0x30,0x44,0x8a,0x30,0x45,0x8e,0x30,0x46,0x91,0x30,0x48,0x95,0x30,0x49,0x99,0x30,0x4a,0x9c,0x2f,0x4c,0xa0,0x2f,0x4d,0xa4,0x2f,0x4e,0xa8,0x2e,0x50,0xab,0x2e,0x51,0xaf,0x2d,0x52,0xb3,0x2c,0x54,0xb7,0x2c,0x55,0xbb,0x2b,0x56,0xbf,0x2a,0x58,0xc2,0x29,0x59,0xc6,0x28,0x5a,0xca,0x27,0x5c,0xce,0x26,0x5d,0xd2,0x25,0x5f,0xd5,0x24,0x60,0xd9,0x24,0x61,0xdd,0x23,0x63,0xe0,0x23,0x64,0xe3,0x23,0x66,0xe7,0x24,0x67,0xea,0x25,0x69,0xec,0x27,0x6a,0xef,0x29,0x6c,0xf1,0x2c,0x6d,0xf4,0x2f,0x6f,0xf5,0x33,0x70,0xf7,0x37,0x72,0xf9,0x3b,0x73,0xfa,0x3f,0x75,0xfb,0x44,0x76,0xfb,0x48,0x78,0xfc,0x4c,0x7a,0xfc,0x51,0x7b,0xfc,0x55,0x7d,0xfc,0x59,0x7f,0xfc,0x5d,0x80,0xfc,0x61,0x82,0xfc,0x65,0x84,0xfc,0x68,0x85,0xfc,0x6c,0x87,0xfb,0x6f,0x89,0xfb,0x73,0x8b,0xfa,0x76,0x8c,0xfa,0x79,0x8e,0xfa,0x7d,0x90,0xf9,0x80,0x92,0xf9,0x83,0x93,0xf8,0x86,0x95,0xf8,0x88,0x97,0xf7,0x8b,0x99,0xf7,0x8e,0x9b,0xf6,0x91,0x9c,0xf6,0x93,0x9e,0xf5,0x96,0xa0,0xf5,0x99,0xa2,0xf5,0x9b,0xa4,0xf4,0x9e,0xa5,0xf4,0xa0,0xa7,0xf3,0xa3,0xa9,0xf3,0xa5,0xab,0xf2,0xa8,0xad,0xf2,0xaa,0xaf,0xf1,0xac,0xb1,0xf1,0xaf,0xb2,0xf0,0xb1,0xb4,0xf0,0xb3,0xb6,0xef,0xb5,0xb8,0xef,0xb8,0xba,0xee,0xba,0xbc,0xee,0xbc,0xbe,0xed,0xbe,0xc0,0xed,0xc0,0xc1,0xec,0xc2,0xc3,0xeb,0xc4,0xc5,0xeb,0xc6,0xc7,0xea,0xc9,0xc9,0xea,0xcb,0xcb,0xe9,0xcd,0xcc,0xe8,0xce,0xce,0xe8,0xd0,0xd0,0xe7,0xd2,0xd1,0xe6,0xd4,0xd3,0xe5,0xd6,0xd4,0xe4,0xd8,0xd5,0xe3,0xd9,0xd6,0xe2,0xdb,0xd7,0xe1,0xdc,0xd7,0xe0,0xde,0xd7,0xde,0xdf,0xd7,0xdc};
	static constexpr std::array<uint8_t, 768> C4   = {0xdf,0xd5,0xd8,0xe0,0xd5,0xd6,0xe1,0xd4,0xd4,0xe2,0xd3,0xd2,0xe3,0xd1,0xcf,0xe3,0xd0,0xcc,0xe4,0xce,0xc9,0xe5,0xcc,0xc6,0xe5,0xca,0xc3,0xe5,0xc8,0xc0,0xe6,0xc5,0xbd,0xe6,0xc3,0xb9,0xe6,0xc0,0xb6,0xe6,0xbd,0xb2,0xe6,0xbb,0xaf,0xe6,0xb8,0xab,0xe6,0xb5,0xa8,0xe6,0xb2,0xa4,0xe6,0xb0,0xa1,0xe6,0xad,0x9d,0xe6,0xaa,0x9a,0xe6,0xa7,0x96,0xe5,0xa4,0x93,0xe5,0xa2,0x8f,0xe5,0x9f,0x8c,0xe5,0x9c,0x88,0xe4,0x99,0x85,0xe4,0x96,0x81,0xe3,0x93,0x7e,0xe3,0x91,0x7b,0xe2,0x8e,0x77,0xe2,0x8b,0x74,0xe1,0x88,0x70,0xe1,0x85,0x6d,0xe0,0x82,0x6a,0xe0,0x7f,0x66,0xdf,0x7c,0x63,0xde,0x7a,0x60,0xdd,0x77,0x5c,0xdd,0x74,0x59,0xdc,0x71,0x56,0xdb,0x6e,0x52,0xda,0x6b,0x4f,0xda,0x68,0x4c,0xd9,0x65,0x48,0xd8,0x62,0x45,0xd7,0x5e,0x42,0xd6,0x5b,0x3f,0xd5,0x58,0x3c,0xd4,0x55,0x38,0xd3,0x52,0x35,0xd2,0x4f,0x32,0xd1,0x4c,0x2f,0xd0,0x48,0x2c,0xcf,0x45,0x29,0xce,0x42,0x26,0xcd,0x3f,0x24,0xcd,0x3c,0x21,0xcc,0x3a,0x1f,0xcb,0x37,0x1d,0xca,0x35,0x1b,0xca,0x33,0x19,0xca,0x32,0x18,0xc9,0x31,0x17,0xc9,0x31,0x17,0xc9,0x31,0x17,0xc9,0x31,0x18,0xca,0x32,0x18,0xca,0x34,0x1a,0xcb,0x36,0x1b,0xcb,0x38,0x1d,0xcc,0x3a,0x1f,0xcd,0x3d,0x22,0xce,0x40,0x24,0xcf,0x43,0x27,0xcf,0x46,0x2a,0xd0,0x49,0x2d,0xd1,0x4c,0x30,0xd2,0x50,0x33,0xd3,0x53,0x36,0xd4,0x56,0x39,0xd5,0x59,0x3c,0xd6,0x5c,0x40,0xd7,0x5f,0x43,0xd8,0x62,0x46,0xd9,0x65,0x49,0xda,0x69,0x4d,0xdb,0x6c,0x50,0xdb,0x6f,0x53,0xdc,0x72,0x56,0xdd,0x74,0x5a,0xde,0x77,0x5d,0xde,0x7a,0x60,0xdf,0x7d,0x64,0xe0,0x80,0x67,0xe0,0x83,0x6a,0xe1,0x86,0x6e,0xe1,0x89,0x71,0xe2,0x8c,0x75,0xe3,0x8f,0x78,0xe3,0x91,0x7b,0xe3,0x94,0x7f,0xe4,0x97,0x82,0xe4,0x9a,0x86,0xe5,0x9d,0x89,0xe5,0xa0,0x8d,0xe5,0xa2,0x90,0xe6,0xa5,0x94,0xe6,0xa8,0x97,0xe6,0xab,0x9b,0xe6,0xae,0x9e,0xe6,0xb0,0xa2,0xe6,0xb3,0xa5,0xe6,0xb6,0xa9,0xe6,0xb9,0xac,0xe6,0xbb,0xb0,0xe6,0xbe,0xb3,0xe6,0xc0,0xb7,0xe6,0xc3,0xba,0xe5,0xc5,0xbe,0xe5,0xc7,0xc1,0xe4,0xca,0xc4,0xe3,0xcb,0xc7,0xe2,0xcd,0xcb,0xe1,0xcf,0xcd,0xe0,0xd0,0xd0,0xdf,0xd1,0xd3,0xde,0xd1,0xd5,0xdc,0xd2,0xd7,0xdb,0xd2,0xd9,0xd9,0xd1,0xdb,0xd7,0xd1,0xdd,0xd5,0xd0,0xde,0xd3,0xcf,0xdf,0xd1,0xce,0xe0,0xcf,0xcc,0xe1,0xcd,0xcb,0xe2,0xca,0xc9,0xe2,0xc8,0xc7,0xe3,0xc6,0xc5,0xe3,0xc3,0xc3,0xe4,0xc1,0xc1,0xe4,0xbe,0xbf,0xe4,0xbc,0xbd,0xe4,0xb9,0xbb,0xe4,0xb7,0xb8,0xe4,0xb4,0xb6,0xe5,0xb2,0xb4,0xe5,0xaf,0xb2,0xe5,0xad,0xaf,0xe5,0xaa,0xad,0xe5,0xa7,0xab,0xe5,0xa5,0xa9,0xe5,0xa2,0xa7,0xe5,0x9f,0xa4,0xe5,0x9d,0xa2,0xe5,0x9a,0xa0,0xe5,0x97,0x9e,0xe5,0x94,0x9c,0xe5,0x91,0x99,0xe5,0x8f,0x97,0xe5,0x8c,0x95,0xe5,0x89,0x93,0xe5,0x86,0x91,0xe5,0x83,0x8f,0xe5,0x7f,0x8d,0xe5,0x7c,0x8a,0xe5,0x79,0x88,0xe5,0x76,0x86,0xe5,0x72,0x84,0xe5,0x6f,0x82,0xe5,0x6b,0x80,0xe5,0x68,0x7e,0xe5,0x64,0x7c,0xe5,0x60,0x7a,0xe5,0x5c,0x78,0xe5,0x58,0x76,0xe5,0x54,0x74,0xe5,0x4f,0x72,0xe5,0x4b,0x70,0xe5,0x46,0x6e,0xe5,0x41,0x6d,0xe5,0x3c,0x6b,0xe5,0x37,0x6a,0xe5,0x32,0x68,0xe5,0x2d,0x67,0xe5,0x28,0x66,0xe5,0x23,0x65,0xe5,0x1f,0x64,0xe5,0x1c,0x64,0xe5,0x1a,0x63,0xe5,0x19,0x63,0xe5,0x1a,0x63,0xe5,0x1d,0x64,0xe5,0x20,0x64,0xe5,0x24,0x65,0xe5,0x29,0x66,0xe5,0x2e,0x67,0xe5,0x33,0x68,0xe5,0x38,0x6a,0xe5,0x3d,0x6b,0xe5,0x42,0x6d,0xe5,0x47,0x6f,0xe5,0x4c,0x71,0xe5,0x50,0x72,0xe5,0x55,0x74,0xe5,0x59,0x76,0xe5,0x5d,0x78,0xe5,0x61,0x7a,0xe5,0x65,0x7c,0xe5,0x68,0x7e,0xe5,0x6c,0x80,0xe5,0x70,0x83,0xe5,0x73,0x85,0xe5,0x76,0x87,0xe5,0x7a,0x89,0xe5,0x7d,0x8b,0xe5,0x80,0x8d,0xe5,0x83,0x8f,0xe5,0x86,0x91,0xe5,0x89,0x93,0xe5,0x8c,0x96,0xe5,0x8f,0x98,0xe5,0x92,0x9a,0xe5,0x95,0x9c,0xe5,0x98,0x9e,0xe5,0x9b,0xa0,0xe5,0x9d,0xa3,0xe5,0xa0,0xa5,0xe5,0xa3,0xa7,0xe5,0xa5,0xa9,0xe5,0xa8,0xab,0xe5,0xab,0xae,0xe5,0xad,0xb0,0xe5,0xb0,0xb2,0xe5,0xb2,0xb4,0xe5,0xb5,0xb7,0xe5,0xb7,0xb9,0xe4,0xba,0xbb,0xe4,0xbc,0xbd,0xe4,0xbf,0xc0,0xe4,0xc1,0xc2,0xe4,0xc4,0xc4,0xe4,0xc6,0xc6,0xe4,0xc8,0xc8,0xe3,0xcb,0xca,0xe3,0xcd,0xcc,0xe3,0xcf,0xce,0xe2,0xd1,0xd0,0xe2,0xd3,0xd1,0xe1,0xd5,0xd2,0xe0,0xd7,0xd3,0xe0,0xd9,0xd4,0xdf,0xda,0xd5,0xdd,0xdc,0xd5,0xdc,0xdd,0xd5,0xda};
	static constexpr std::array<uint8_t, 768> C5   = {0x78,0x78,0x78,0x79,0x79,0x79,0x7a,0x7a,0x7a,0x7b,0x7b,0x7b,0x7d,0x7d,0x7d,0x7e,0x7e,0x7e,0x7f,0x7f,0x7f,0x81,0x81,0x81,0x82,0x82,0x82,0x83,0x83,0x83,0x85,0x85,0x85,0x86,0x86,0x86,0x87,0x87,0x87,0x89,0x89,0x89,0x8a,0x8a,0x8a,0x8c,0x8c,0x8c,0x8d,0x8d,0x8d,0x8e,0x8e,0x8e,0x90,0x90,0x90,0x91,0x91,0x91,0x93,0x93,0x93,0x94,0x94,0x94,0x95,0x95,0x95,0x97,0x97,0x97,0x98,0x98,0x98,0x9a,0x9a,0x9a,0x9b,0x9b,0x9b,0x9d,0x9d,0x9d,0x9e,0x9e,0x9e,0x9f,0x9f,0x9f,0xa1,0xa1,0xa1,0xa2,0xa2,0xa2,0xa4,0xa4,0xa4,0xa5,0xa5,0xa5,0xa7,0xa7,0xa7,0xa8,0xa8,0xa8,0xaa,0xaa,0xaa,0xab,0xab,0xab,0xac,0xac,0xac,0xae,0xae,0xae,0xaf,0xaf,0xaf,0xb1,0xb1,0xb1,0xb2,0xb2,0xb2,0xb4,0xb4,0xb4,0xb5,0xb5,0xb5,0xb7,0xb7,0xb7,0xb8,0xb8,0xb8,0xba,0xba,0xba,0xbb,0xbb,0xbb,0xbc,0xbd,0xbd,0xbe,0xbe,0xbe,0xbf,0xbf,0xbf,0xc1,0xc1,0xc1,0xc2,0xc2,0xc2,0xc3,0xc3,0xc3,0xc4,0xc4,0xc4,0xc6,0xc6,0xc6,0xc7,0xc7,0xc7,0xc8,0xc8,0xc8,0xc8,0xc8,0xc8,0xc9,0xc9,0xc9,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xca,0xc9,0xc9,0xc9,0xc9,0xc9,0xc9,0xc8,0xc8,0xc8,0xc7,0xc7,0xc7,0xc6,0xc6,0xc6,0xc5,0xc5,0xc5,0xc4,0xc4,0xc4,0xc2,0xc2,0xc2,0xc1,0xc1,0xc1,0xc0,0xc0,0xc0,0xbe,0xbe,0xbe,0xbd,0xbd,0xbd,0xbb,0xbb,0xbb,0xba,0xba,0xba,0xb8,0xb9,0xb9,0xb7,0xb7,0xb7,0xb6,0xb6,0xb6,0xb4,0xb4,0xb4,0xb3,0xb3,0xb3,0xb1,0xb1,0xb1,0xb0,0xb0,0xb0,0xae,0xae,0xae,0xad,0xad,0xad,0xab,0xab,0xab,0xaa,0xaa,0xaa,0xa8,0xa8,0xa8,0xa7,0xa7,0xa7,0xa6,0xa6,0xa6,0xa4,0xa4,0xa4,0xa3,0xa3,0xa3,0xa1,0xa1,0xa1,0xa0,0xa0,0xa0,0x9e,0x9e,0x9e,0x9d,0x9d,0x9d,0x9b,0x9c,0x9c,0x9a,0x9a,0x9a,0x99,0x99,0x99,0x97,0x97,0x97,0x96,0x96,0x96,0x94,0x94,0x94,0x93,0x93,0x93,0x92,0x92,0x92,0x90,0x90,0x90,0x8f,0x8f,0x8f,0x8d,0x8d,0x8d,0x8c,0x8c,0x8c,0x8b,0x8b,0x8b,0x89,0x89,0x89,0x88,0x88,0x88,0x86,0x86,0x86,0x85,0x85,0x85,0x84,0x84,0x84,0x82,0x82,0x82,0x81,0x81,0x81,0x7f,0x7f,0x7f,0x7e,0x7e,0x7e,0x7d,0x7d,0x7d,0x7b,0x7b,0x7b,0x7a,0x7a,0x7a,0x79,0x79,0x79,0x77,0x77,0x77,0x76,0x76,0x76,0x75,0x75,0x75,0x73,0x73,0x73,0x72,0x72,0x72,0x70,0x70,0x70,0x6f,0x6f,0x6f,0x6e,0x6e,0x6e,0x6c,0x6c,0x6c,0x6b,0x6b,0x6b,0x6a,0x6a,0x6a,0x68,0x68,0x68,0x67,0x67,0x67,0x66,0x66,0x66,0x64,0x64,0x64,0x63,0x63,0x63,0x62,0x62,0x62,0x61,0x61,0x61,0x5f,0x5f,0x5f,0x5e,0x5e,0x5e,0x5d,0x5d,0x5d,0x5b,0x5b,0x5b,0x5a,0x5a,0x5a,0x59,0x59,0x59,0x57,0x57,0x57,0x56,0x56,0x56,0x55,0x55,0x55,0x54,0x54,0x54,0x52,0x52,0x52,0x51,0x51,0x51,0x50,0x50,0x50,0x4e,0x4e,0x4e,0x4d,0x4d,0x4d,0x4c,0x4c,0x4c,0x4b,0x4b,0x4b,0x49,0x49,0x49,0x48,0x48,0x48,0x47,0x47,0x47,0x46,0x46,0x46,0x44,0x44,0x44,0x43,0x43,0x43,0x42,0x42,0x42,0x41,0x41,0x41,0x40,0x40,0x40,0x3e,0x3e,0x3e,0x3d,0x3d,0x3d,0x3c,0x3c,0x3c,0x3b,0x3b,0x3b,0x3a,0x3a,0x3a,0x38,0x38,0x38,0x37,0x37,0x37,0x36,0x36,0x36,0x35,0x35,0x35,0x34,0x34,0x34,0x33,0x33,0x33,0x32,0x32,0x32,0x31,0x31,0x31,0x30,0x30,0x30,0x2f,0x2f,0x2f,0x2f,0x2f,0x2f,0x2e,0x2e,0x2e,0x2e,0x2e,0x2e,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2d,0x2e,0x2e,0x2e,0x2e,0x2e,0x2e,0x2f,0x2f,0x2f,0x2f,0x2f,0x2f,0x30,0x30,0x30,0x31,0x31,0x31,0x32,0x32,0x32,0x33,0x33,0x33,0x34,0x34,0x34,0x35,0x35,0x35,0x36,0x36,0x36,0x37,0x37,0x37,0x38,0x38,0x38,0x39,0x39,0x39,0x3a,0x3a,0x3a,0x3c,0x3c,0x3c,0x3d,0x3d,0x3d,0x3e,0x3e,0x3e,0x3f,0x3f,0x3f,0x40,0x41,0x40,0x42,0x42,0x42,0x43,0x43,0x43,0x44,0x44,0x44,0x45,0x45,0x45,0x47,0x47,0x47,0x48,0x48,0x48,0x49,0x49,0x49,0x4a,0x4a,0x4a,0x4c,0x4c,0x4c,0x4d,0x4d,0x4d,0x4e,0x4e,0x4e,0x4f,0x4f,0x4f,0x51,0x51,0x51,0x52,0x52,0x52,0x53,0x53,0x53,0x55,0x55,0x55,0x56,0x56,0x56,0x57,0x57,0x57,0x58,0x58,0x58,0x5a,0x5a,0x5a,0x5b,0x5b,0x5b,0x5c,0x5c,0x5c,0x5e,0x5e,0x5e,0x5f,0x5f,0x5f,0x60,0x60,0x60,0x61,0x62,0x62,0x63,0x63,0x63,0x64,0x64,0x64,0x65,0x65,0x65,0x67,0x67,0x67,0x68,0x68,0x68,0x69,0x69,0x69,0x6b,0x6b,0x6b,0x6c,0x6c,0x6c,0x6d,0x6d,0x6d,0x6f,0x6f,0x6f,0x70,0x70,0x70,0x71,0x71,0x71,0x72,0x72,0x72,0x74,0x74,0x74,0x75,0x75,0x75,0x76,0x76,0x76};
	static constexpr std::array<uint8_t, 768> C6   = {0xf7,0x37,0x1a,0xf6,0x38,0x17,0xf6,0x3a,0x15,0xf6,0x3d,0x12,0xf7,0x40,0x10,0xf7,0x44,0x0e,0xf7,0x48,0x0c,0xf8,0x4c,0x0a,0xf8,0x50,0x08,0xf8,0x55,0x07,0xf9,0x59,0x06,0xf9,0x5e,0x05,0xfa,0x62,0x04,0xfb,0x67,0x03,0xfb,0x6b,0x02,0xfc,0x70,0x02,0xfc,0x74,0x01,0xfd,0x78,0x01,0xfd,0x7d,0x00,0xfe,0x81,0x00,0xfe,0x85,0x00,0xfe,0x89,0x00,0xff,0x8d,0x00,0xff,0x91,0x00,0xff,0x95,0x00,0xff,0x99,0x00,0xff,0x9d,0x00,0xff,0xa1,0x00,0xff,0xa5,0x00,0xff,0xa8,0x00,0xff,0xac,0x00,0xff,0xb0,0x00,0xff,0xb3,0x00,0xff,0xb7,0x00,0xff,0xba,0x00,0xff,0xbd,0x00,0xfe,0xc1,0x00,0xfd,0xc3,0x00,0xfc,0xc6,0x00,0xfb,0xc9,0x00,0xf9,0xcb,0x00,0xf7,0xcd,0x00,0xf5,0xce,0x00,0xf2,0xd0,0x00,0xef,0xd0,0x00,0xec,0xd1,0x00,0xe9,0xd1,0x00,0xe5,0xd1,0x00,0xe1,0xd1,0x00,0xdd,0xd0,0x00,0xd9,0xd0,0x00,0xd5,0xcf,0x00,0xd1,0xcd,0x00,0xcc,0xcc,0x00,0xc8,0xcb,0x00,0xc3,0xc9,0x00,0xbf,0xc7,0x00,0xba,0xc5,0x00,0xb5,0xc4,0x00,0xb1,0xc2,0x00,0xac,0xc0,0x00,0xa7,0xbe,0x00,0xa2,0xbc,0x00,0x9e,0xba,0x00,0x99,0xb8,0x00,0x94,0xb6,0x00,0x8f,0xb4,0x00,0x8a,0xb2,0x01,0x86,0xb0,0x01,0x81,0xae,0x02,0x7c,0xac,0x02,0x77,0xaa,0x03,0x72,0xa9,0x03,0x6d,0xa7,0x04,0x68,0xa5,0x06,0x64,0xa3,0x07,0x5f,0xa1,0x09,0x5a,0xa0,0x0b,0x55,0x9e,0x0d,0x51,0x9d,0x10,0x4c,0x9c,0x12,0x48,0x9b,0x15,0x44,0x9a,0x18,0x40,0x9a,0x1b,0x3c,0x99,0x1e,0x39,0x99,0x22,0x36,0x99,0x26,0x33,0x9a,0x29,0x31,0x9b,0x2d,0x2f,0x9b,0x31,0x2d,0x9d,0x36,0x2c,0x9e,0x3a,0x2b,0xa0,0x3e,0x2b,0xa1,0x43,0x2b,0xa3,0x48,0x2b,0xa5,0x4c,0x2c,0xa7,0x51,0x2c,0xaa,0x56,0x2d,0xac,0x5b,0x2e,0xae,0x60,0x2e,0xb1,0x65,0x2f,0xb3,0x6a,0x30,0xb5,0x6f,0x30,0xb8,0x74,0x31,0xba,0x79,0x31,0xbd,0x7e,0x32,0xbf,0x83,0x32,0xc2,0x88,0x32,0xc4,0x8d,0x32,0xc7,0x92,0x32,0xca,0x97,0x32,0xcc,0x9c,0x32,0xcf,0xa1,0x32,0xd1,0xa6,0x31,0xd4,0xab,0x30,0xd6,0xb1,0x30,0xd8,0xb6,0x2f,0xdb,0xbb,0x2e,0xdd,0xc0,0x2d,0xdf,0xc5,0x2c,0xe1,0xca,0x2b,0xe3,0xce,0x2a,0xe4,0xd3,0x28,0xe6,0xd7,0x27,0xe7,0xdc,0x27,0xe8,0xe0,0x26,0xe8,0xe4,0x25,0xe8,0xe7,0x25,0xe8,0xeb,0x25,0xe8,0xee,0x26,0xe7,0xf0,0x26,0xe6,0xf3,0x27,0xe4,0xf5,0x28,0xe3,0xf7,0x29,0xe1,0xf9,0x2a,0xdf,0xfa,0x2b,0xdc,0xfb,0x2c,0xda,0xfc,0x2d,0xd7,0xfd,0x2e,0xd4,0xfe,0x2f,0xd1,0xfe,0x2f,0xce,0xff,0x30,0xcb,0xff,0x31,0xc8,0xff,0x31,0xc5,0xff,0x31,0xc2,0xff,0x31,0xbf,0xff,0x31,0xbc,0xff,0x31,0xb8,0xff,0x31,0xb5,0xff,0x30,0xb2,0xff,0x30,0xaf,0xff,0x2f,0xac,0xff,0x2e,0xa9,0xff,0x2d,0xa6,0xff,0x2c,0xa3,0xff,0x2b,0xa0,0xff,0x2a,0x9d,0xff,0x29,0x9a,0xff,0x28,0x97,0xff,0x28,0x94,0xff,0x27,0x91,0xff,0x28,0x8f,0xff,0x28,0x8c,0xff,0x29,0x8a,0xff,0x2b,0x88,0xff,0x2e,0x86,0xff,0x31,0x84,0xff,0x35,0x83,0xff,0x39,0x82,0xff,0x3e,0x81,0xff,0x43,0x80,0xff,0x48,0x80,0xff,0x4d,0x80,0xff,0x53,0x81,0xff,0x59,0x81,0xff,0x5e,0x82,0xff,0x64,0x83,0xff,0x69,0x84,0xff,0x6f,0x86,0xff,0x74,0x88,0xff,0x7a,0x89,0xff,0x7f,0x8b,0xff,0x84,0x8d,0xff,0x89,0x8f,0xff,0x8e,0x91,0xff,0x93,0x93,0xff,0x98,0x96,0xff,0x9d,0x98,0xff,0xa1,0x9a,0xff,0xa6,0x9c,0xff,0xaa,0x9f,0xff,0xae,0xa1,0xff,0xb3,0xa3,0xff,0xb7,0xa5,0xff,0xbb,0xa8,0xff,0xbf,0xaa,0xff,0xc4,0xac,0xff,0xc8,0xae,0xff,0xcc,0xb1,0xff,0xd0,0xb3,0xff,0xd4,0xb5,0xff,0xd8,0xb7,0xff,0xdb,0xb8,0xff,0xdf,0xba,0xff,0xe3,0xbc,0xff,0xe7,0xbd,0xfd,0xea,0xbe,0xfc,0xee,0xbf,0xfa,0xf1,0xbf,0xf7,0xf4,0xbf,0xf5,0xf7,0xbf,0xf2,0xfa,0xbe,0xee,0xfc,0xbd,0xea,0xff,0xbc,0xe7,0xff,0xbb,0xe2,0xff,0xb9,0xde,0xff,0xb7,0xd9,0xff,0xb4,0xd4,0xff,0xb2,0xcf,0xff,0xaf,0xca,0xff,0xac,0xc5,0xff,0xa9,0xbf,0xff,0xa5,0xba,0xff,0xa2,0xb4,0xff,0x9e,0xaf,0xff,0x9b,0xa9,0xff,0x97,0xa4,0xff,0x94,0x9e,0xff,0x90,0x99,0xff,0x8c,0x93,0xff,0x88,0x8e,0xff,0x85,0x89,0xff,0x81,0x83,0xff,0x7d,0x7e,0xff,0x79,0x79,0xff,0x75,0x73,0xff,0x71,0x6e,0xff,0x6d,0x69,0xff,0x69,0x64,0xff,0x65,0x5e,0xff,0x61,0x59,0xff,0x5c,0x54,0xff,0x58,0x4f,0xff,0x54,0x4a,0xff,0x50,0x45,0xfe,0x4c,0x41,0xfd,0x48,0x3c,0xfc,0x44,0x38,0xfb,0x41,0x33,0xfa,0x3d,0x2f,0xf9,0x3b,0x2b,0xf8,0x38,0x27,0xf8,0x37,0x24,0xf7,0x36,0x20,0xf7,0x36,0x1d};
	static constexpr std::array<uint8_t, 768> C7   = {0xe9,0xe4,0x19,0xeb,0xe3,0x1f,0xec,0xe2,0x26,0xee,0xe1,0x2b,0xef,0xdf,0x31,0xf0,0xde,0x37,0xf1,0xdc,0x3c,0xf2,0xda,0x41,0xf4,0xd8,0x46,0xf5,0xd5,0x4b,0xf6,0xd3,0x50,0xf6,0xd1,0x54,0xf7,0xcf,0x58,0xf8,0xcc,0x5c,0xf9,0xca,0x61,0xfa,0xc8,0x64,0xfb,0xc5,0x68,0xfb,0xc3,0x6c,0xfc,0xc1,0x70,0xfd,0xbe,0x73,0xfd,0xbc,0x77,0xfe,0xba,0x7a,0xff,0xb7,0x7e,0xff,0xb5,0x81,0xff,0xb2,0x84,0xff,0xb0,0x87,0xff,0xad,0x8b,0xff,0xab,0x8e,0xff,0xa8,0x91,0xff,0xa6,0x94,0xff,0xa3,0x97,0xff,0xa1,0x9a,0xff,0x9e,0x9d,0xff,0x9b,0xa0,0xff,0x99,0xa3,0xff,0x96,0xa6,0xff,0x93,0xa9,0xff,0x90,0xac,0xff,0x8e,0xaf,0xff,0x8b,0xb2,0xff,0x88,0xb5,0xff,0x85,0xb8,0xff,0x82,0xbb,0xff,0x7f,0xbe,0xff,0x7c,0xc1,0xff,0x79,0xc4,0xff,0x76,0xc7,0xff,0x72,0xc9,0xff,0x6f,0xcc,0xff,0x6c,0xcf,0xff,0x68,0xd2,0xff,0x65,0xd5,0xff,0x61,0xd8,0xff,0x5d,0xdb,0xff,0x5a,0xdd,0xff,0x56,0xe0,0xff,0x52,0xe3,0xff,0x4e,0xe6,0xff,0x4a,0xe9,0xff,0x47,0xeb,0xff,0x44,0xee,0xff,0x41,0xf0,0xfe,0x3f,0xf3,0xfd,0x3f,0xf5,0xfc,0x3f,0xf7,0xfb,0x40,0xf8,0xf9,0x42,0xfa,0xf8,0x45,0xfb,0xf7,0x48,0xfc,0xf5,0x4c,0xfd,0xf4,0x51,0xfd,0xf2,0x55,0xfe,0xf1,0x5a,0xfe,0xef,0x5e,0xfe,0xee,0x62,0xfe,0xec,0x67,0xfe,0xeb,0x6b,0xfe,0xe9,0x6f,0xfe,0xe7,0x73,0xfe,0xe6,0x77,0xfe,0xe4,0x7a,0xfe,0xe2,0x7e,0xfe,0xe0,0x81,0xfe,0xde,0x85,0xfe,0xdd,0x88,0xfe,0xdb,0x8b,0xfe,0xd9,0x8f,0xfe,0xd7,0x92,0xfe,0xd5,0x95,0xfe,0xd3,0x98,0xfe,0xd1,0x9b,0xfe,0xcf,0x9e,0xfe,0xcc,0xa1,0xfe,0xca,0xa4,0xfe,0xc8,0xa7,0xfe,0xc6,0xa9,0xfe,0xc3,0xac,0xfe,0xc1,0xaf,0xfe,0xbe,0xb2,0xfe,0xbc,0xb4,0xfe,0xb9,0xb7,0xfe,0xb7,0xba,0xfe,0xb4,0xbc,0xfe,0xb1,0xbf,0xfd,0xae,0xc1,0xfd,0xab,0xc4,0xfd,0xa8,0xc6,0xfd,0xa5,0xc9,0xfd,0xa2,0xcb,0xfd,0x9e,0xce,0xfd,0x9b,0xd0,0xfd,0x97,0xd3,0xfd,0x93,0xd5,0xfd,0x8f,0xd8,0xfd,0x8b,0xda,0xfd,0x87,0xdc,0xfd,0x82,0xdf,0xfd,0x7e,0xe1,0xfc,0x79,0xe3,0xfc,0x73,0xe5,0xfc,0x6e,0xe8,0xfc,0x68,0xea,0xfb,0x62,0xec,0xfb,0x5c,0xed,0xfa,0x55,0xef,0xf9,0x4f,0xf0,0xf8,0x48,0xf2,0xf6,0x41,0xf3,0xf5,0x3b,0xf3,0xf3,0x35,0xf3,0xf0,0x30,0xf3,0xee,0x2c,0xf3,0xeb,0x29,0xf3,0xe8,0x27,0xf2,0xe5,0x26,0xf1,0xe2,0x26,0xf0,0xdf,0x26,0xef,0xdb,0x27,0xee,0xd8,0x28,0xed,0xd5,0x29,0xec,0xd1,0x2b,0xea,0xce,0x2c,0xe9,0xca,0x2d,0xe8,0xc7,0x2e,0xe6,0xc3,0x2f,0xe5,0xc0,0x30,0xe4,0xbd,0x31,0xe3,0xb9,0x31,0xe1,0xb6,0x32,0xe0,0xb2,0x32,0xdf,0xaf,0x33,0xdd,0xac,0x33,0xdc,0xa8,0x33,0xdb,0xa5,0x34,0xda,0xa2,0x34,0xd8,0x9e,0x34,0xd7,0x9b,0x34,0xd6,0x97,0x34,0xd5,0x94,0x34,0xd3,0x91,0x33,0xd2,0x8d,0x33,0xd1,0x8a,0x33,0xcf,0x87,0x32,0xce,0x83,0x32,0xcd,0x80,0x31,0xcc,0x7c,0x31,0xca,0x79,0x30,0xc9,0x76,0x30,0xc8,0x72,0x2f,0xc7,0x6f,0x2e,0xc5,0x6c,0x2d,0xc4,0x68,0x2c,0xc3,0x65,0x2b,0xc2,0x61,0x2a,0xc0,0x5e,0x29,0xbf,0x5a,0x28,0xbe,0x57,0x27,0xbd,0x53,0x25,0xbb,0x50,0x24,0xba,0x4c,0x22,0xb9,0x48,0x21,0xb8,0x45,0x1f,0xb7,0x41,0x1e,0xb5,0x3d,0x1c,0xb4,0x39,0x1b,0xb3,0x35,0x1a,0xb2,0x31,0x1a,0xb1,0x2d,0x1b,0xb1,0x29,0x1c,0xb0,0x25,0x1e,0xaf,0x21,0x20,0xaf,0x1c,0x23,0xaf,0x18,0x27,0xaf,0x14,0x2b,0xaf,0x10,0x2f,0xaf,0x0c,0x33,0xb0,0x08,0x37,0xb1,0x05,0x3b,0xb1,0x02,0x3f,0xb2,0x00,0x44,0xb3,0x00,0x48,0xb4,0x00,0x4c,0xb5,0x00,0x4f,0xb6,0x00,0x53,0xb7,0x00,0x57,0xb8,0x00,0x5a,0xb9,0x00,0x5e,0xba,0x00,0x61,0xbb,0x00,0x65,0xbc,0x00,0x68,0xbd,0x00,0x6b,0xbe,0x00,0x6e,0xbf,0x00,0x72,0xc0,0x00,0x75,0xc1,0x00,0x78,0xc2,0x00,0x7b,0xc3,0x00,0x7e,0xc4,0x00,0x81,0xc5,0x00,0x84,0xc6,0x00,0x87,0xc7,0x00,0x8a,0xc8,0x00,0x8d,0xc9,0x00,0x90,0xca,0x00,0x93,0xcb,0x00,0x95,0xcc,0x00,0x98,0xcd,0x00,0x9b,0xce,0x00,0x9e,0xcf,0x00,0xa1,0xd0,0x00,0xa4,0xd1,0x00,0xa6,0xd2,0x00,0xa9,0xd3,0x00,0xac,0xd4,0x00,0xaf,0xd5,0x00,0xb2,0xd6,0x00,0xb4,0xd7,0x00,0xb7,0xd8,0x00,0xba,0xd9,0x00,0xbd,0xda,0x00,0xbf,0xdb,0x00,0xc2,0xdc,0x00,0xc5,0xdd,0x00,0xc7,0xde,0x00,0xca,0xde,0x00,0xcd,0xdf,0x00,0xd0,0xe0,0x00,0xd2,0xe1,0x00,0xd5,0xe2,0x00,0xd7,0xe3,0x00,0xda,0xe4,0x00,0xdc,0xe4,0x00,0xdf,0xe5,0x00,0xe1,0xe5,0x00,0xe3,0xe5,0x03,0xe5,0xe5,0x0b,0xe7,0xe5,0x12};

	// isoluminant
	static constexpr std::array<uint8_t, 768> I1   = {0x37,0xb7,0xec,0x38,0xb7,0xeb,0x38,0xb7,0xea,0x39,0xb7,0xea,0x39,0xb7,0xe9,0x3a,0xb7,0xe8,0x3b,0xb8,0xe7,0x3b,0xb8,0xe6,0x3c,0xb8,0xe5,0x3c,0xb8,0xe4,0x3d,0xb8,0xe3,0x3d,0xb8,0xe3,0x3e,0xb8,0xe2,0x3e,0xb8,0xe1,0x3f,0xb8,0xe0,0x3f,0xb8,0xdf,0x40,0xb8,0xde,0x40,0xb8,0xdd,0x41,0xb8,0xdc,0x42,0xb8,0xdc,0x42,0xb9,0xdb,0x43,0xb9,0xda,0x43,0xb9,0xd9,0x44,0xb9,0xd8,0x44,0xb9,0xd7,0x45,0xb9,0xd6,0x45,0xb9,0xd5,0x45,0xb9,0xd4,0x46,0xb9,0xd4,0x46,0xb9,0xd3,0x47,0xb9,0xd2,0x47,0xb9,0xd1,0x48,0xb9,0xd0,0x48,0xb9,0xcf,0x49,0xb9,0xce,0x49,0xb9,0xcd,0x4a,0xba,0xcc,0x4a,0xba,0xcb,0x4b,0xba,0xcb,0x4b,0xba,0xca,0x4c,0xba,0xc9,0x4c,0xba,0xc8,0x4d,0xba,0xc7,0x4d,0xba,0xc6,0x4e,0xba,0xc5,0x4e,0xba,0xc4,0x4f,0xba,0xc3,0x4f,0xba,0xc2,0x50,0xba,0xc1,0x50,0xba,0xc1,0x50,0xba,0xc0,0x51,0xba,0xbf,0x51,0xba,0xbe,0x52,0xba,0xbd,0x52,0xba,0xbc,0x53,0xbb,0xbb,0x53,0xbb,0xba,0x54,0xbb,0xb9,0x54,0xbb,0xb8,0x55,0xbb,0xb7,0x55,0xbb,0xb6,0x56,0xbb,0xb5,0x56,0xbb,0xb4,0x57,0xbb,0xb3,0x57,0xbb,0xb3,0x58,0xbb,0xb2,0x58,0xbb,0xb1,0x59,0xbb,0xb0,0x59,0xbb,0xaf,0x5a,0xbb,0xae,0x5b,0xbb,0xad,0x5b,0xbb,0xac,0x5c,0xbb,0xab,0x5c,0xbb,0xaa,0x5d,0xbb,0xa9,0x5d,0xbb,0xa8,0x5e,0xbb,0xa7,0x5e,0xbb,0xa6,0x5f,0xbb,0xa5,0x60,0xbb,0xa4,0x60,0xbb,0xa3,0x61,0xbb,0xa2,0x61,0xbb,0xa1,0x62,0xbb,0xa0,0x62,0xbb,0x9f,0x63,0xbb,0x9e,0x64,0xbb,0x9d,0x64,0xbb,0x9c,0x65,0xbb,0x9b,0x66,0xbb,0x9a,0x66,0xbb,0x99,0x67,0xbb,0x98,0x68,0xbb,0x97,0x68,0xbb,0x97,0x69,0xbb,0x96,0x6a,0xbb,0x95,0x6a,0xbb,0x94,0x6b,0xbb,0x93,0x6c,0xbb,0x92,0x6d,0xbb,0x91,0x6d,0xbb,0x90,0x6e,0xbb,0x8f,0x6f,0xbb,0x8e,0x70,0xbb,0x8d,0x71,0xbb,0x8c,0x71,0xbb,0x8b,0x72,0xbb,0x8a,0x73,0xba,0x89,0x74,0xba,0x88,0x75,0xba,0x87,0x76,0xba,0x86,0x76,0xba,0x85,0x77,0xba,0x84,0x78,0xba,0x83,0x79,0xba,0x82,0x7a,0xba,0x81,0x7b,0xba,0x80,0x7c,0xba,0x7f,0x7d,0xb9,0x7e,0x7e,0xb9,0x7d,0x7f,0xb9,0x7c,0x80,0xb9,0x7c,0x81,0xb9,0x7b,0x82,0xb9,0x7a,0x83,0xb9,0x79,0x84,0xb8,0x78,0x85,0xb8,0x77,0x86,0xb8,0x77,0x87,0xb8,0x76,0x88,0xb8,0x75,0x89,0xb8,0x74,0x8a,0xb8,0x73,0x8b,0xb7,0x73,0x8c,0xb7,0x72,0x8e,0xb7,0x71,0x8f,0xb7,0x71,0x90,0xb7,0x70,0x91,0xb6,0x6f,0x92,0xb6,0x6f,0x93,0xb6,0x6e,0x94,0xb6,0x6d,0x95,0xb6,0x6d,0x96,0xb5,0x6c,0x97,0xb5,0x6c,0x98,0xb5,0x6b,0x99,0xb5,0x6b,0x9a,0xb4,0x6a,0x9b,0xb4,0x6a,0x9d,0xb4,0x69,0x9e,0xb4,0x69,0x9f,0xb3,0x68,0xa0,0xb3,0x68,0xa1,0xb3,0x67,0xa2,0xb3,0x67,0xa3,0xb2,0x66,0xa4,0xb2,0x66,0xa5,0xb2,0x65,0xa6,0xb2,0x65,0xa7,0xb1,0x64,0xa8,0xb1,0x64,0xa9,0xb1,0x64,0xaa,0xb1,0x63,0xab,0xb0,0x63,0xac,0xb0,0x63,0xad,0xb0,0x62,0xae,0xb0,0x62,0xaf,0xaf,0x62,0xb0,0xaf,0x61,0xb1,0xaf,0x61,0xb2,0xaf,0x61,0xb3,0xae,0x60,0xb4,0xae,0x60,0xb5,0xae,0x60,0xb5,0xad,0x60,0xb6,0xad,0x5f,0xb7,0xad,0x5f,0xb8,0xac,0x5f,0xb9,0xac,0x5f,0xba,0xac,0x5f,0xbb,0xac,0x5f,0xbc,0xab,0x5e,0xbd,0xab,0x5e,0xbe,0xab,0x5e,0xbf,0xaa,0x5e,0xc0,0xaa,0x5e,0xc1,0xaa,0x5e,0xc2,0xa9,0x5e,0xc2,0xa9,0x5e,0xc3,0xa9,0x5e,0xc4,0xa8,0x5e,0xc5,0xa8,0x5d,0xc6,0xa8,0x5d,0xc7,0xa8,0x5d,0xc8,0xa7,0x5d,0xc9,0xa7,0x5d,0xc9,0xa7,0x5d,0xca,0xa6,0x5e,0xcb,0xa6,0x5e,0xcc,0xa6,0x5e,0xcd,0xa5,0x5e,0xce,0xa5,0x5e,0xcf,0xa5,0x5e,0xcf,0xa4,0x5e,0xd0,0xa4,0x5e,0xd1,0xa4,0x5e,0xd2,0xa3,0x5e,0xd3,0xa3,0x5e,0xd3,0xa2,0x5e,0xd4,0xa2,0x5f,0xd5,0xa2,0x5f,0xd6,0xa1,0x5f,0xd7,0xa1,0x5f,0xd8,0xa1,0x5f,0xd8,0xa0,0x5f,0xd9,0xa0,0x60,0xda,0xa0,0x60,0xdb,0x9f,0x60,0xdb,0x9f,0x60,0xdc,0x9f,0x60,0xdd,0x9e,0x61,0xde,0x9e,0x61,0xdf,0x9d,0x61,0xdf,0x9d,0x61,0xe0,0x9d,0x62,0xe1,0x9c,0x62,0xe2,0x9c,0x62,0xe2,0x9c,0x63,0xe3,0x9b,0x63,0xe4,0x9b,0x63,0xe4,0x9a,0x63,0xe5,0x9a,0x64,0xe6,0x9a,0x64,0xe7,0x99,0x64,0xe7,0x99,0x65,0xe8,0x99,0x65,0xe9,0x98,0x65,0xea,0x98,0x66,0xea,0x97,0x66,0xeb,0x97,0x66,0xec,0x97,0x67,0xec,0x96,0x67,0xed,0x96,0x67,0xee,0x95,0x68,0xee,0x95,0x68,0xef,0x95,0x68,0xf0,0x94,0x69,0xf0,0x94,0x69,0xf1,0x93,0x6a,0xf2,0x93,0x6a,0xf2,0x93,0x6a,0xf3,0x92,0x6b,0xf4,0x92,0x6b,0xf4,0x91,0x6c,0xf5,0x91,0x6c,0xf6,0x91,0x6c,0xf6,0x90,0x6d};
	static constexpr std::array<uint8_t, 768> I2   = {0x70,0xd1,0xff,0x70,0xd2,0xff,0x70,0xd2,0xff,0x70,0xd2,0xff,0x70,0xd2,0xff,0x70,0xd2,0xfe,0x70,0xd2,0xfe,0x70,0xd2,0xfd,0x70,0xd2,0xfc,0x70,0xd2,0xfb,0x70,0xd2,0xfa,0x70,0xd2,0xfa,0x71,0xd3,0xf9,0x71,0xd3,0xf8,0x71,0xd3,0xf7,0x71,0xd3,0xf7,0x71,0xd3,0xf6,0x71,0xd3,0xf5,0x71,0xd3,0xf4,0x71,0xd3,0xf3,0x71,0xd3,0xf3,0x71,0xd3,0xf2,0x71,0xd3,0xf1,0x72,0xd4,0xf0,0x72,0xd4,0xef,0x72,0xd4,0xee,0x72,0xd4,0xee,0x72,0xd4,0xed,0x72,0xd4,0xec,0x72,0xd4,0xeb,0x72,0xd4,0xea,0x73,0xd4,0xea,0x73,0xd4,0xe9,0x73,0xd4,0xe8,0x73,0xd4,0xe7,0x73,0xd4,0xe6,0x73,0xd5,0xe5,0x73,0xd5,0xe5,0x74,0xd5,0xe4,0x74,0xd5,0xe3,0x74,0xd5,0xe2,0x74,0xd5,0xe1,0x74,0xd5,0xe1,0x74,0xd5,0xe0,0x74,0xd5,0xdf,0x75,0xd5,0xde,0x75,0xd5,0xdd,0x75,0xd5,0xdc,0x75,0xd5,0xdb,0x75,0xd5,0xdb,0x76,0xd5,0xda,0x76,0xd6,0xd9,0x76,0xd6,0xd8,0x76,0xd6,0xd7,0x76,0xd6,0xd6,0x77,0xd6,0xd6,0x77,0xd6,0xd5,0x77,0xd6,0xd4,0x77,0xd6,0xd3,0x77,0xd6,0xd2,0x78,0xd6,0xd1,0x78,0xd6,0xd0,0x78,0xd6,0xd0,0x78,0xd6,0xcf,0x79,0xd6,0xce,0x79,0xd6,0xcd,0x79,0xd6,0xcc,0x7a,0xd6,0xcb,0x7a,0xd6,0xca,0x7a,0xd6,0xc9,0x7a,0xd6,0xc9,0x7b,0xd6,0xc8,0x7b,0xd7,0xc7,0x7b,0xd7,0xc6,0x7c,0xd7,0xc5,0x7c,0xd7,0xc4,0x7c,0xd7,0xc3,0x7d,0xd7,0xc2,0x7d,0xd7,0xc1,0x7d,0xd7,0xc1,0x7e,0xd7,0xc0,0x7e,0xd7,0xbf,0x7e,0xd7,0xbe,0x7f,0xd7,0xbd,0x7f,0xd7,0xbc,0x80,0xd7,0xbb,0x80,0xd7,0xba,0x81,0xd7,0xb9,0x81,0xd7,0xb8,0x81,0xd7,0xb8,0x82,0xd7,0xb7,0x82,0xd7,0xb6,0x83,0xd7,0xb5,0x83,0xd7,0xb4,0x84,0xd7,0xb3,0x84,0xd7,0xb2,0x85,0xd7,0xb1,0x85,0xd7,0xb0,0x86,0xd7,0xaf,0x86,0xd7,0xae,0x87,0xd7,0xad,0x88,0xd7,0xac,0x88,0xd7,0xac,0x89,0xd7,0xab,0x89,0xd7,0xaa,0x8a,0xd7,0xa9,0x8b,0xd7,0xa8,0x8b,0xd7,0xa7,0x8c,0xd7,0xa6,0x8d,0xd6,0xa5,0x8d,0xd6,0xa4,0x8e,0xd6,0xa3,0x8f,0xd6,0xa2,0x90,0xd6,0xa1,0x90,0xd6,0xa0,0x91,0xd6,0xa0,0x92,0xd6,0x9f,0x93,0xd6,0x9e,0x93,0xd6,0x9d,0x94,0xd6,0x9c,0x95,0xd6,0x9b,0x96,0xd6,0x9a,0x97,0xd5,0x99,0x98,0xd5,0x99,0x99,0xd5,0x98,0x9a,0xd5,0x97,0x9a,0xd5,0x96,0x9b,0xd5,0x95,0x9c,0xd5,0x94,0x9d,0xd5,0x94,0x9e,0xd4,0x93,0x9f,0xd4,0x92,0xa0,0xd4,0x91,0xa1,0xd4,0x90,0xa2,0xd4,0x90,0xa3,0xd4,0x8f,0xa4,0xd3,0x8e,0xa5,0xd3,0x8e,0xa6,0xd3,0x8d,0xa7,0xd3,0x8c,0xa8,0xd3,0x8c,0xa9,0xd3,0x8b,0xaa,0xd2,0x8a,0xab,0xd2,0x8a,0xac,0xd2,0x89,0xad,0xd2,0x88,0xae,0xd2,0x88,0xaf,0xd1,0x87,0xb0,0xd1,0x87,0xb1,0xd1,0x86,0xb2,0xd1,0x86,0xb3,0xd1,0x85,0xb4,0xd0,0x85,0xb5,0xd0,0x84,0xb6,0xd0,0x84,0xb7,0xd0,0x83,0xb8,0xcf,0x83,0xb9,0xcf,0x82,0xba,0xcf,0x82,0xbb,0xcf,0x81,0xbc,0xcf,0x81,0xbd,0xce,0x80,0xbe,0xce,0x80,0xbf,0xce,0x7f,0xc0,0xce,0x7f,0xc1,0xcd,0x7f,0xc2,0xcd,0x7e,0xc3,0xcd,0x7e,0xc4,0xcd,0x7d,0xc5,0xcc,0x7d,0xc5,0xcc,0x7d,0xc6,0xcc,0x7c,0xc7,0xcc,0x7c,0xc8,0xcb,0x7c,0xc9,0xcb,0x7b,0xca,0xcb,0x7b,0xcb,0xcb,0x7b,0xcc,0xca,0x7a,0xcd,0xca,0x7a,0xce,0xca,0x7a,0xcf,0xca,0x79,0xd0,0xc9,0x79,0xd1,0xc9,0x79,0xd1,0xc9,0x79,0xd2,0xc9,0x78,0xd3,0xc8,0x78,0xd4,0xc8,0x78,0xd5,0xc8,0x78,0xd6,0xc7,0x77,0xd7,0xc7,0x77,0xd8,0xc7,0x77,0xd9,0xc7,0x77,0xd9,0xc6,0x77,0xda,0xc6,0x77,0xdb,0xc6,0x76,0xdc,0xc5,0x76,0xdd,0xc5,0x76,0xde,0xc5,0x76,0xdf,0xc5,0x76,0xe0,0xc4,0x76,0xe0,0xc4,0x76,0xe1,0xc4,0x76,0xe2,0xc3,0x76,0xe3,0xc3,0x76,0xe4,0xc3,0x76,0xe5,0xc2,0x76,0xe5,0xc2,0x76,0xe6,0xc2,0x76,0xe7,0xc2,0x76,0xe8,0xc1,0x76,0xe9,0xc1,0x76,0xe9,0xc1,0x76,0xea,0xc0,0x76,0xeb,0xc0,0x76,0xec,0xc0,0x76,0xed,0xbf,0x76,0xed,0xbf,0x76,0xee,0xbf,0x76,0xef,0xbe,0x76,0xf0,0xbe,0x77,0xf1,0xbe,0x77,0xf1,0xbd,0x77,0xf2,0xbd,0x77,0xf3,0xbd,0x77,0xf4,0xbc,0x77,0xf4,0xbc,0x78,0xf5,0xbc,0x78,0xf6,0xbc,0x78,0xf7,0xbb,0x78,0xf7,0xbb,0x79,0xf8,0xbb,0x79,0xf9,0xba,0x79,0xf9,0xba,0x79,0xfa,0xba,0x7a,0xfb,0xb9,0x7a,0xfc,0xb9,0x7a,0xfc,0xb9,0x7a,0xfd,0xb8,0x7b,0xfe,0xb8,0x7b,0xfe,0xb8,0x7b,0xff,0xb7,0x7c,0xff,0xb7,0x7c,0xff,0xb7,0x7c,0xff,0xb6,0x7d,0xff,0xb6,0x7d,0xff,0xb6,0x7d,0xff,0xb5,0x7e,0xff,0xb5,0x7e,0xff,0xb5,0x7f,0xff,0xb4,0x7f,0xff,0xb4,0x7f,0xff,0xb4,0x80,0xff,0xb3,0x80,0xff,0xb3,0x81,0xff,0xb3,0x81,0xff,0xb2,0x81};
	static constexpr std::array<uint8_t, 768> I3   = {0x14,0xba,0xe6,0x19,0xb9,0xe6,0x1d,0xb9,0xe6,0x20,0xb9,0xe6,0x23,0xb9,0xe6,0x26,0xb9,0xe6,0x29,0xb9,0xe6,0x2c,0xb8,0xe7,0x2e,0xb8,0xe7,0x30,0xb8,0xe7,0x33,0xb8,0xe7,0x35,0xb8,0xe7,0x37,0xb8,0xe7,0x39,0xb8,0xe7,0x3b,0xb7,0xe8,0x3c,0xb7,0xe8,0x3e,0xb7,0xe8,0x40,0xb7,0xe8,0x42,0xb7,0xe8,0x43,0xb7,0xe8,0x45,0xb6,0xe8,0x46,0xb6,0xe8,0x48,0xb6,0xe9,0x4a,0xb6,0xe9,0x4b,0xb6,0xe9,0x4c,0xb6,0xe9,0x4e,0xb6,0xe9,0x4f,0xb5,0xe9,0x51,0xb5,0xe9,0x52,0xb5,0xe9,0x53,0xb5,0xe9,0x55,0xb5,0xe9,0x56,0xb5,0xea,0x57,0xb4,0xea,0x59,0xb4,0xea,0x5a,0xb4,0xea,0x5b,0xb4,0xea,0x5c,0xb4,0xea,0x5d,0xb4,0xea,0x5f,0xb3,0xea,0x60,0xb3,0xea,0x61,0xb3,0xea,0x62,0xb3,0xeb,0x63,0xb3,0xeb,0x64,0xb2,0xeb,0x66,0xb2,0xeb,0x67,0xb2,0xeb,0x68,0xb2,0xeb,0x69,0xb2,0xeb,0x6a,0xb2,0xeb,0x6b,0xb1,0xeb,0x6c,0xb1,0xeb,0x6d,0xb1,0xeb,0x6e,0xb1,0xeb,0x6f,0xb1,0xeb,0x70,0xb1,0xeb,0x71,0xb0,0xec,0x72,0xb0,0xec,0x73,0xb0,0xec,0x74,0xb0,0xec,0x75,0xb0,0xec,0x76,0xaf,0xec,0x77,0xaf,0xec,0x78,0xaf,0xec,0x79,0xaf,0xec,0x7a,0xaf,0xec,0x7b,0xae,0xec,0x7c,0xae,0xec,0x7d,0xae,0xec,0x7e,0xae,0xec,0x7f,0xae,0xec,0x80,0xae,0xec,0x81,0xad,0xec,0x82,0xad,0xec,0x83,0xad,0xec,0x84,0xad,0xec,0x85,0xad,0xec,0x86,0xac,0xec,0x87,0xac,0xec,0x88,0xac,0xec,0x89,0xac,0xec,0x8a,0xac,0xec,0x8b,0xab,0xec,0x8b,0xab,0xec,0x8c,0xab,0xec,0x8d,0xab,0xec,0x8e,0xaa,0xec,0x8f,0xaa,0xec,0x90,0xaa,0xec,0x91,0xaa,0xec,0x92,0xaa,0xec,0x93,0xa9,0xec,0x94,0xa9,0xec,0x95,0xa9,0xec,0x95,0xa9,0xeb,0x96,0xa9,0xeb,0x97,0xa8,0xeb,0x98,0xa8,0xeb,0x99,0xa8,0xeb,0x9a,0xa8,0xeb,0x9b,0xa7,0xeb,0x9c,0xa7,0xeb,0x9c,0xa7,0xeb,0x9d,0xa7,0xeb,0x9e,0xa7,0xea,0x9f,0xa6,0xea,0xa0,0xa6,0xea,0xa1,0xa6,0xea,0xa2,0xa6,0xea,0xa3,0xa5,0xea,0xa3,0xa5,0xe9,0xa4,0xa5,0xe9,0xa5,0xa5,0xe9,0xa6,0xa5,0xe9,0xa7,0xa4,0xe9,0xa8,0xa4,0xe8,0xa9,0xa4,0xe8,0xa9,0xa4,0xe8,0xaa,0xa3,0xe8,0xab,0xa3,0xe7,0xac,0xa3,0xe7,0xad,0xa3,0xe7,0xae,0xa3,0xe7,0xaf,0xa2,0xe6,0xaf,0xa2,0xe6,0xb0,0xa2,0xe6,0xb1,0xa2,0xe5,0xb2,0xa1,0xe5,0xb3,0xa1,0xe5,0xb3,0xa1,0xe4,0xb4,0xa1,0xe4,0xb5,0xa1,0xe4,0xb6,0xa0,0xe3,0xb7,0xa0,0xe3,0xb7,0xa0,0xe3,0xb8,0xa0,0xe2,0xb9,0x9f,0xe2,0xba,0x9f,0xe2,0xba,0x9f,0xe1,0xbb,0x9f,0xe1,0xbc,0x9f,0xe0,0xbd,0x9e,0xe0,0xbd,0x9e,0xe0,0xbe,0x9e,0xdf,0xbf,0x9e,0xdf,0xc0,0x9e,0xdf,0xc0,0x9d,0xde,0xc1,0x9d,0xde,0xc2,0x9d,0xdd,0xc3,0x9d,0xdd,0xc3,0x9c,0xdd,0xc4,0x9c,0xdc,0xc5,0x9c,0xdc,0xc5,0x9c,0xdb,0xc6,0x9c,0xdb,0xc7,0x9b,0xdb,0xc7,0x9b,0xda,0xc8,0x9b,0xda,0xc9,0x9b,0xd9,0xc9,0x9a,0xd9,0xca,0x9a,0xd8,0xcb,0x9a,0xd8,0xcb,0x9a,0xd8,0xcc,0x9a,0xd7,0xcd,0x99,0xd7,0xcd,0x99,0xd6,0xce,0x99,0xd6,0xcf,0x99,0xd5,0xcf,0x99,0xd5,0xd0,0x98,0xd5,0xd1,0x98,0xd4,0xd1,0x98,0xd4,0xd2,0x98,0xd3,0xd3,0x97,0xd3,0xd3,0x97,0xd2,0xd4,0x97,0xd2,0xd4,0x97,0xd2,0xd5,0x97,0xd1,0xd6,0x96,0xd1,0xd6,0x96,0xd0,0xd7,0x96,0xd0,0xd7,0x96,0xcf,0xd8,0x95,0xcf,0xd9,0x95,0xce,0xd9,0x95,0xce,0xda,0x95,0xce,0xda,0x95,0xcd,0xdb,0x94,0xcd,0xdc,0x94,0xcc,0xdc,0x94,0xcc,0xdd,0x94,0xcb,0xdd,0x94,0xcb,0xde,0x93,0xca,0xde,0x93,0xca,0xdf,0x93,0xca,0xe0,0x93,0xc9,0xe0,0x92,0xc9,0xe1,0x92,0xc8,0xe1,0x92,0xc8,0xe2,0x92,0xc7,0xe2,0x92,0xc7,0xe3,0x91,0xc6,0xe3,0x91,0xc6,0xe4,0x91,0xc5,0xe5,0x91,0xc5,0xe5,0x90,0xc4,0xe6,0x90,0xc4,0xe6,0x90,0xc4,0xe7,0x90,0xc3,0xe7,0x90,0xc3,0xe8,0x8f,0xc2,0xe8,0x8f,0xc2,0xe9,0x8f,0xc1,0xe9,0x8f,0xc1,0xea,0x8e,0xc0,0xea,0x8e,0xc0,0xeb,0x8e,0xbf,0xeb,0x8e,0xbf,0xec,0x8e,0xbe,0xec,0x8d,0xbe,0xed,0x8d,0xbe,0xed,0x8d,0xbd,0xee,0x8d,0xbd,0xee,0x8c,0xbc,0xef,0x8c,0xbc,0xef,0x8c,0xbb,0xf0,0x8c,0xbb,0xf0,0x8b,0xba,0xf1,0x8b,0xba,0xf1,0x8b,0xb9,0xf2,0x8b,0xb9,0xf2,0x8b,0xb8,0xf3,0x8a,0xb8,0xf3,0x8a,0xb7,0xf4,0x8a,0xb7,0xf4,0x8a,0xb6,0xf5,0x89,0xb6,0xf5,0x89,0xb5,0xf6,0x89,0xb5,0xf6,0x89,0xb5,0xf7,0x88,0xb4,0xf7,0x88,0xb4,0xf8,0x88,0xb3,0xf8,0x88,0xb3,0xf9,0x88,0xb2,0xf9,0x87,0xb2,0xf9,0x87,0xb1,0xfa,0x87,0xb1,0xfa,0x87,0xb0,0xfb,0x86,0xb0,0xfb,0x86,0xaf,0xfc,0x86,0xaf,0xfc,0x86,0xae,0xfd,0x85,0xae,0xfd,0x85,0xad,0xfe,0x85,0xad};

	// maps for the color blind
	static constexpr std::array<uint8_t, 768> CBL1 = {0x11,0x11,0x11,0x11,0x12,0x13,0x12,0x13,0x15,0x12,0x13,0x17,0x13,0x14,0x19,0x13,0x15,0x1b,0x13,0x16,0x1d,0x14,0x16,0x1f,0x14,0x17,0x20,0x14,0x18,0x22,0x14,0x18,0x24,0x14,0x19,0x26,0x14,0x1a,0x28,0x14,0x1a,0x2a,0x14,0x1b,0x2c,0x14,0x1c,0x2e,0x14,0x1d,0x2f,0x14,0x1d,0x31,0x13,0x1e,0x33,0x13,0x1f,0x35,0x13,0x1f,0x37,0x13,0x20,0x39,0x12,0x21,0x3a,0x12,0x22,0x3c,0x12,0x22,0x3e,0x11,0x23,0x40,0x11,0x24,0x42,0x11,0x25,0x44,0x10,0x25,0x45,0x10,0x26,0x47,0x0f,0x27,0x49,0x0e,0x28,0x4b,0x0e,0x28,0x4d,0x0d,0x29,0x4e,0x0c,0x2a,0x50,0x0c,0x2b,0x52,0x0b,0x2b,0x54,0x0a,0x2c,0x55,0x09,0x2d,0x57,0x08,0x2e,0x59,0x07,0x2e,0x5a,0x06,0x2f,0x5c,0x06,0x30,0x5e,0x05,0x31,0x5f,0x04,0x31,0x61,0x03,0x32,0x63,0x02,0x33,0x64,0x02,0x34,0x66,0x01,0x35,0x67,0x00,0x35,0x69,0x00,0x36,0x6b,0x00,0x37,0x6c,0x00,0x38,0x6e,0x00,0x38,0x6f,0x00,0x39,0x71,0x00,0x3a,0x72,0x00,0x3b,0x73,0x00,0x3c,0x75,0x00,0x3c,0x76,0x00,0x3d,0x77,0x00,0x3e,0x79,0x00,0x3f,0x7a,0x00,0x40,0x7b,0x00,0x40,0x7d,0x01,0x41,0x7e,0x03,0x42,0x7f,0x04,0x43,0x80,0x05,0x44,0x81,0x07,0x44,0x82,0x09,0x45,0x83,0x0b,0x46,0x84,0x0d,0x47,0x85,0x0f,0x48,0x86,0x11,0x48,0x87,0x13,0x49,0x88,0x15,0x4a,0x89,0x18,0x4b,0x8a,0x1a,0x4c,0x8a,0x1c,0x4c,0x8b,0x1e,0x4d,0x8c,0x20,0x4e,0x8c,0x22,0x4f,0x8d,0x24,0x50,0x8d,0x26,0x50,0x8e,0x28,0x51,0x8e,0x2a,0x52,0x8e,0x2d,0x53,0x8e,0x2f,0x54,0x8f,0x31,0x54,0x8f,0x33,0x55,0x8f,0x35,0x56,0x8f,0x37,0x57,0x8f,0x3a,0x58,0x8e,0x3c,0x59,0x8e,0x3e,0x59,0x8e,0x40,0x5a,0x8d,0x43,0x5b,0x8d,0x45,0x5c,0x8c,0x47,0x5d,0x8b,0x49,0x5e,0x8b,0x4b,0x5e,0x8a,0x4d,0x5f,0x89,0x4f,0x60,0x89,0x51,0x61,0x88,0x53,0x62,0x87,0x55,0x63,0x87,0x57,0x64,0x86,0x59,0x64,0x85,0x5a,0x65,0x85,0x5c,0x66,0x84,0x5e,0x67,0x83,0x5f,0x68,0x83,0x61,0x69,0x82,0x63,0x6a,0x81,0x64,0x6a,0x80,0x66,0x6b,0x80,0x68,0x6c,0x7f,0x69,0x6d,0x7e,0x6b,0x6e,0x7e,0x6c,0x6f,0x7d,0x6e,0x70,0x7c,0x6f,0x71,0x7b,0x71,0x71,0x7b,0x72,0x72,0x7a,0x74,0x73,0x79,0x75,0x74,0x79,0x77,0x75,0x78,0x78,0x76,0x77,0x7a,0x77,0x76,0x7b,0x78,0x76,0x7c,0x79,0x75,0x7e,0x79,0x74,0x7f,0x7a,0x73,0x81,0x7b,0x73,0x82,0x7c,0x72,0x83,0x7d,0x71,0x85,0x7e,0x70,0x86,0x7f,0x6f,0x88,0x80,0x6f,0x89,0x81,0x6e,0x8a,0x81,0x6d,0x8c,0x82,0x6c,0x8d,0x83,0x6b,0x8e,0x84,0x6b,0x90,0x85,0x6a,0x91,0x86,0x69,0x92,0x87,0x68,0x94,0x88,0x67,0x95,0x89,0x67,0x96,0x8a,0x66,0x98,0x8a,0x65,0x99,0x8b,0x64,0x9a,0x8c,0x63,0x9c,0x8d,0x62,0x9d,0x8e,0x61,0x9e,0x8f,0x60,0xa0,0x90,0x60,0xa1,0x91,0x5f,0xa2,0x92,0x5e,0xa4,0x93,0x5d,0xa5,0x94,0x5c,0xa6,0x94,0x5b,0xa7,0x95,0x5b,0xa9,0x96,0x5a,0xaa,0x97,0x5a,0xab,0x98,0x59,0xac,0x99,0x59,0xad,0x9a,0x59,0xaf,0x9b,0x59,0xb0,0x9c,0x59,0xb1,0x9d,0x59,0xb2,0x9e,0x59,0xb3,0x9f,0x59,0xb4,0x9f,0x59,0xb5,0xa0,0x5a,0xb6,0xa1,0x5a,0xb7,0xa2,0x5a,0xb8,0xa3,0x5b,0xb9,0xa4,0x5b,0xba,0xa5,0x5c,0xbb,0xa6,0x5d,0xbc,0xa7,0x5e,0xbd,0xa8,0x5e,0xbf,0xa9,0x5f,0xc0,0xaa,0x60,0xc1,0xab,0x61,0xc1,0xac,0x62,0xc2,0xad,0x63,0xc3,0xae,0x64,0xc4,0xaf,0x65,0xc5,0xb0,0x67,0xc6,0xb0,0x68,0xc7,0xb1,0x69,0xc8,0xb2,0x6a,0xc9,0xb3,0x6c,0xca,0xb4,0x6d,0xcb,0xb5,0x6e,0xcc,0xb6,0x70,0xcd,0xb7,0x71,0xce,0xb8,0x73,0xcf,0xb9,0x75,0xcf,0xba,0x76,0xd0,0xbb,0x78,0xd1,0xbc,0x79,0xd2,0xbd,0x7b,0xd3,0xbe,0x7d,0xd4,0xbf,0x7f,0xd5,0xc0,0x80,0xd5,0xc1,0x82,0xd6,0xc2,0x84,0xd7,0xc3,0x86,0xd8,0xc4,0x88,0xd9,0xc5,0x8a,0xd9,0xc6,0x8c,0xda,0xc7,0x8d,0xdb,0xc8,0x8f,0xdc,0xc9,0x91,0xdd,0xca,0x94,0xdd,0xcb,0x96,0xde,0xcc,0x98,0xdf,0xcd,0x9a,0xdf,0xce,0x9c,0xe0,0xcf,0x9e,0xe1,0xd0,0xa0,0xe2,0xd1,0xa2,0xe2,0xd2,0xa5,0xe3,0xd3,0xa7,0xe4,0xd4,0xa9,0xe4,0xd5,0xab,0xe5,0xd6,0xae,0xe5,0xd7,0xb0,0xe6,0xd8,0xb2,0xe7,0xd9,0xb5,0xe7,0xda,0xb7,0xe8,0xdb,0xba,0xe8,0xdc,0xbc,0xe9,0xdd,0xbf,0xe9,0xde,0xc1,0xea,0xdf,0xc3,0xea,0xe0,0xc6,0xeb,0xe1,0xc9,0xeb,0xe2,0xcb,0xec,0xe3,0xce,0xec,0xe4,0xd0,0xed,0xe5,0xd3,0xed,0xe6,0xd5,0xee,0xe7,0xd8,0xee,0xe8,0xdb,0xee,0xe9,0xdd,0xef,0xea,0xe0,0xef,0xeb,0xe3,0xef,0xec,0xe6,0xf0,0xed,0xe8,0xf0,0xee,0xeb,0xf0,0xf0,0xee,0xf1,0xf1,0xf1};
	static constexpr std::array<uint8_t, 768> CBL2 = {0x11,0x11,0x11,0x11,0x12,0x13,0x12,0x13,0x15,0x13,0x13,0x17,0x13,0x14,0x18,0x14,0x15,0x1a,0x14,0x16,0x1c,0x14,0x17,0x1d,0x15,0x17,0x1f,0x15,0x18,0x21,0x15,0x19,0x22,0x16,0x19,0x24,0x16,0x1a,0x26,0x16,0x1b,0x27,0x16,0x1b,0x29,0x16,0x1c,0x2b,0x16,0x1d,0x2d,0x16,0x1e,0x2e,0x17,0x1e,0x30,0x17,0x1f,0x32,0x17,0x20,0x34,0x17,0x21,0x36,0x17,0x21,0x37,0x17,0x22,0x39,0x17,0x23,0x3b,0x16,0x24,0x3d,0x16,0x24,0x3f,0x16,0x25,0x40,0x16,0x26,0x42,0x16,0x27,0x44,0x16,0x27,0x46,0x15,0x28,0x48,0x15,0x29,0x4a,0x15,0x2a,0x4b,0x14,0x2b,0x4d,0x14,0x2b,0x4f,0x14,0x2c,0x51,0x13,0x2d,0x53,0x13,0x2e,0x54,0x13,0x2e,0x56,0x12,0x2f,0x58,0x12,0x30,0x5a,0x12,0x31,0x5b,0x11,0x32,0x5d,0x11,0x32,0x5f,0x11,0x33,0x60,0x10,0x34,0x62,0x10,0x35,0x63,0x10,0x36,0x65,0x10,0x36,0x67,0x10,0x37,0x68,0x10,0x38,0x6a,0x10,0x39,0x6b,0x0f,0x3a,0x6d,0x0f,0x3b,0x6e,0x0f,0x3b,0x70,0x0f,0x3c,0x71,0x0f,0x3d,0x73,0x0f,0x3e,0x74,0x0f,0x3f,0x76,0x0f,0x3f,0x77,0x0f,0x40,0x79,0x0f,0x41,0x7a,0x0f,0x42,0x7c,0x0f,0x43,0x7e,0x0f,0x44,0x7f,0x0f,0x44,0x81,0x0f,0x45,0x82,0x0f,0x46,0x84,0x0f,0x47,0x85,0x0f,0x48,0x87,0x0f,0x49,0x88,0x0f,0x49,0x8a,0x0f,0x4a,0x8b,0x0f,0x4b,0x8d,0x0f,0x4c,0x8e,0x0f,0x4d,0x90,0x0f,0x4e,0x92,0x0f,0x4f,0x93,0x0f,0x4f,0x95,0x0e,0x50,0x96,0x0e,0x51,0x98,0x0e,0x52,0x99,0x0e,0x53,0x9b,0x0e,0x54,0x9d,0x0e,0x55,0x9e,0x0e,0x56,0xa0,0x0e,0x56,0xa1,0x0d,0x57,0xa3,0x0d,0x58,0xa5,0x0d,0x59,0xa6,0x0d,0x5a,0xa8,0x0d,0x5b,0xa9,0x0d,0x5c,0xab,0x0c,0x5c,0xad,0x0c,0x5d,0xae,0x0c,0x5e,0xb0,0x0c,0x5f,0xb2,0x0b,0x60,0xb3,0x0b,0x61,0xb5,0x0b,0x62,0xb6,0x0a,0x63,0xb8,0x0a,0x64,0xba,0x0a,0x64,0xbb,0x09,0x65,0xbd,0x09,0x66,0xbf,0x09,0x67,0xc0,0x08,0x68,0xc2,0x08,0x69,0xc4,0x07,0x6a,0xc5,0x07,0x6b,0xc7,0x07,0x6c,0xc9,0x06,0x6d,0xca,0x06,0x6d,0xcc,0x05,0x6e,0xce,0x05,0x6f,0xcf,0x04,0x70,0xd1,0x04,0x71,0xd3,0x03,0x72,0xd4,0x03,0x73,0xd6,0x02,0x74,0xd8,0x02,0x75,0xd9,0x01,0x76,0xdb,0x01,0x77,0xdd,0x00,0x78,0xde,0x00,0x78,0xe0,0x00,0x79,0xe2,0x01,0x7a,0xe3,0x01,0x7b,0xe5,0x02,0x7c,0xe6,0x03,0x7d,0xe8,0x05,0x7e,0xe9,0x07,0x7f,0xeb,0x0b,0x80,0xec,0x0e,0x81,0xed,0x12,0x82,0xee,0x16,0x83,0xef,0x1a,0x84,0xf0,0x1f,0x84,0xf1,0x23,0x85,0xf2,0x28,0x86,0xf2,0x2d,0x87,0xf2,0x31,0x88,0xf2,0x36,0x89,0xf2,0x3b,0x8a,0xf2,0x40,0x8b,0xf1,0x45,0x8c,0xf0,0x4a,0x8d,0xef,0x4f,0x8d,0xee,0x54,0x8e,0xec,0x59,0x8f,0xea,0x5d,0x90,0xe8,0x62,0x91,0xe6,0x67,0x92,0xe4,0x6b,0x93,0xe2,0x6f,0x94,0xdf,0x73,0x95,0xdc,0x77,0x96,0xd9,0x7b,0x97,0xd6,0x7f,0x98,0xd4,0x83,0x99,0xd0,0x86,0x9a,0xcd,0x89,0x9b,0xca,0x8d,0x9b,0xc7,0x90,0x9c,0xc4,0x93,0x9d,0xc1,0x96,0x9e,0xbd,0x98,0x9f,0xba,0x9b,0xa0,0xb7,0x9e,0xa1,0xb4,0xa0,0xa2,0xb1,0xa3,0xa3,0xae,0xa5,0xa4,0xaa,0xa8,0xa5,0xa7,0xaa,0xa6,0xa4,0xac,0xa7,0xa1,0xaf,0xa8,0x9e,0xb1,0xa9,0x9b,0xb3,0xaa,0x98,0xb5,0xab,0x95,0xb7,0xac,0x92,0xb9,0xad,0x8f,0xbb,0xae,0x8c,0xbd,0xaf,0x89,0xbf,0xb0,0x86,0xc1,0xb1,0x83,0xc3,0xb2,0x80,0xc5,0xb3,0x7d,0xc7,0xb4,0x7a,0xc9,0xb5,0x77,0xca,0xb6,0x74,0xcc,0xb7,0x71,0xce,0xb8,0x6d,0xd0,0xb8,0x6a,0xd1,0xb9,0x67,0xd3,0xba,0x64,0xd5,0xbb,0x60,0xd6,0xbc,0x5d,0xd8,0xbd,0x5a,0xda,0xbe,0x56,0xdb,0xbf,0x52,0xdd,0xc0,0x4f,0xde,0xc1,0x4b,0xe0,0xc2,0x48,0xe1,0xc3,0x44,0xe3,0xc4,0x40,0xe4,0xc5,0x3c,0xe5,0xc6,0x39,0xe7,0xc7,0x35,0xe8,0xc8,0x31,0xe9,0xc9,0x2e,0xeb,0xca,0x2a,0xec,0xcb,0x27,0xed,0xcc,0x25,0xef,0xcd,0x23,0xf0,0xce,0x22,0xf1,0xcf,0x22,0xf2,0xd0,0x23,0xf3,0xd1,0x25,0xf4,0xd2,0x27,0xf5,0xd3,0x2b,0xf6,0xd4,0x2f,0xf7,0xd6,0x34,0xf8,0xd7,0x39,0xf9,0xd8,0x3e,0xfa,0xd9,0x44,0xfb,0xda,0x4a,0xfb,0xdb,0x50,0xfc,0xdc,0x56,0xfd,0xdd,0x5d,0xfd,0xde,0x63,0xfe,0xdf,0x6a,0xfe,0xe0,0x70,0xff,0xe1,0x77,0xff,0xe2,0x7e,0xff,0xe3,0x84,0xff,0xe4,0x8b,0xff,0xe5,0x92,0xff,0xe6,0x98,0xff,0xe7,0x9f,0xff,0xe8,0xa5,0xff,0xe9,0xab,0xff,0xeb,0xb1,0xff,0xec,0xb7,0xfe,0xed,0xbd,0xfe,0xee,0xc3,0xfe,0xef,0xc9,0xfd,0xf0,0xce,0xfd,0xf1,0xd3,0xfd,0xf2,0xd8,0xfd,0xf3,0xdd,0xfc,0xf5,0xe2,0xfc,0xf6,0xe7,0xfc,0xf7,0xeb,0xfc,0xf8,0xef,0xfc,0xf9,0xf3};
	static constexpr std::array<uint8_t, 768> CBC1 = {0x3e,0x87,0xea,0x41,0x88,0xeb,0x44,0x8a,0xed,0x47,0x8b,0xed,0x4b,0x8c,0xee,0x4f,0x8e,0xef,0x53,0x8f,0xef,0x57,0x91,0xf0,0x5a,0x93,0xf0,0x5e,0x94,0xf0,0x62,0x96,0xf0,0x66,0x97,0xf0,0x69,0x99,0xf0,0x6d,0x9a,0xf1,0x70,0x9c,0xf1,0x74,0x9e,0xf1,0x77,0x9f,0xf1,0x7a,0xa1,0xf1,0x7d,0xa2,0xf1,0x80,0xa4,0xf1,0x83,0xa6,0xf1,0x86,0xa7,0xf1,0x89,0xa9,0xf1,0x8c,0xab,0xf2,0x8f,0xac,0xf2,0x92,0xae,0xf2,0x95,0xb0,0xf2,0x97,0xb1,0xf2,0x9a,0xb3,0xf2,0x9d,0xb5,0xf2,0x9f,0xb6,0xf2,0xa2,0xb8,0xf2,0xa5,0xba,0xf2,0xa7,0xbb,0xf2,0xaa,0xbd,0xf2,0xac,0xbf,0xf3,0xaf,0xc1,0xf3,0xb2,0xc2,0xf3,0xb4,0xc4,0xf3,0xb7,0xc6,0xf3,0xb9,0xc7,0xf3,0xbb,0xc9,0xf3,0xbe,0xcb,0xf3,0xc0,0xcd,0xf3,0xc3,0xce,0xf3,0xc5,0xd0,0xf3,0xc8,0xd2,0xf3,0xca,0xd3,0xf3,0xcc,0xd5,0xf3,0xcf,0xd7,0xf3,0xd1,0xd9,0xf3,0xd3,0xda,0xf3,0xd6,0xdc,0xf3,0xd8,0xde,0xf3,0xda,0xe0,0xf3,0xdd,0xe1,0xf3,0xdf,0xe3,0xf3,0xe1,0xe4,0xf2,0xe3,0xe6,0xf2,0xe5,0xe7,0xf1,0xe6,0xe8,0xf0,0xe8,0xe9,0xef,0xe9,0xea,0xed,0xea,0xea,0xeb,0xeb,0xea,0xe9,0xec,0xea,0xe7,0xec,0xe9,0xe4,0xec,0xe8,0xe1,0xec,0xe7,0xde,0xeb,0xe6,0xdb,0xeb,0xe5,0xd8,0xea,0xe3,0xd5,0xe9,0xe2,0xd1,0xe8,0xe0,0xce,0xe7,0xde,0xca,0xe6,0xdd,0xc7,0xe5,0xdb,0xc3,0xe3,0xd9,0xc0,0xe2,0xd8,0xbc,0xe1,0xd6,0xb9,0xe0,0xd4,0xb6,0xdf,0xd2,0xb2,0xde,0xd0,0xaf,0xdc,0xcf,0xab,0xdb,0xcd,0xa8,0xda,0xcb,0xa4,0xd9,0xca,0xa1,0xd7,0xc8,0x9e,0xd6,0xc6,0x9a,0xd5,0xc4,0x97,0xd3,0xc3,0x93,0xd2,0xc1,0x90,0xd1,0xbf,0x8d,0xcf,0xbe,0x89,0xce,0xbc,0x86,0xcd,0xba,0x83,0xcb,0xb8,0x7f,0xca,0xb7,0x7c,0xc9,0xb5,0x78,0xc7,0xb3,0x75,0xc6,0xb2,0x72,0xc5,0xb0,0x6e,0xc3,0xae,0x6b,0xc2,0xad,0x68,0xc0,0xab,0x64,0xbf,0xa9,0x61,0xbd,0xa8,0x5d,0xbc,0xa6,0x5a,0xba,0xa4,0x57,0xb9,0xa3,0x53,0xb7,0xa1,0x50,0xb6,0x9f,0x4c,0xb4,0x9e,0x49,0xb3,0x9c,0x45,0xb1,0x9b,0x42,0xb0,0x99,0x3e,0xae,0x97,0x3b,0xad,0x96,0x37,0xab,0x94,0x33,0xa9,0x92,0x30,0xa8,0x91,0x2c,0xa6,0x8f,0x28,0xa5,0x8e,0x24,0xa3,0x8c,0x21,0xa1,0x8b,0x1d,0xa0,0x89,0x1a,0x9e,0x87,0x17,0x9c,0x86,0x14,0x9a,0x84,0x12,0x99,0x83,0x10,0x97,0x81,0x0f,0x95,0x80,0x0f,0x93,0x7e,0x0f,0x91,0x7c,0x0f,0x90,0x7b,0x10,0x8e,0x79,0x10,0x8c,0x78,0x11,0x8a,0x76,0x13,0x88,0x75,0x14,0x86,0x73,0x15,0x85,0x72,0x16,0x83,0x70,0x17,0x81,0x6f,0x18,0x7f,0x6d,0x18,0x7d,0x6c,0x19,0x7c,0x6a,0x1a,0x7a,0x69,0x1b,0x78,0x67,0x1c,0x76,0x65,0x1c,0x74,0x64,0x1d,0x73,0x63,0x1d,0x71,0x61,0x1e,0x6f,0x60,0x1f,0x6d,0x5e,0x1f,0x6b,0x5d,0x20,0x6a,0x5b,0x20,0x68,0x5a,0x21,0x66,0x58,0x21,0x64,0x57,0x21,0x63,0x55,0x22,0x61,0x54,0x22,0x5f,0x52,0x23,0x5d,0x51,0x23,0x5c,0x4f,0x23,0x5a,0x4e,0x24,0x58,0x4d,0x24,0x56,0x4b,0x24,0x54,0x4a,0x24,0x53,0x48,0x25,0x51,0x47,0x25,0x4f,0x46,0x25,0x4e,0x44,0x25,0x4c,0x43,0x26,0x4a,0x41,0x26,0x48,0x40,0x26,0x47,0x3f,0x26,0x45,0x3d,0x26,0x43,0x3c,0x27,0x41,0x3b,0x27,0x40,0x39,0x27,0x3e,0x38,0x27,0x3c,0x37,0x27,0x3a,0x35,0x27,0x39,0x34,0x28,0x37,0x33,0x28,0x36,0x32,0x28,0x34,0x31,0x29,0x33,0x30,0x2a,0x32,0x2f,0x2b,0x31,0x2f,0x2c,0x30,0x2e,0x2d,0x2f,0x2e,0x2e,0x2f,0x2e,0x30,0x2e,0x2f,0x32,0x2e,0x2f,0x34,0x2e,0x30,0x36,0x2e,0x31,0x38,0x2f,0x32,0x3b,0x2f,0x33,0x3d,0x30,0x34,0x40,0x30,0x35,0x43,0x31,0x36,0x45,0x32,0x37,0x48,0x32,0x39,0x4b,0x33,0x3a,0x4e,0x34,0x3c,0x51,0x34,0x3d,0x53,0x35,0x3e,0x56,0x35,0x40,0x59,0x36,0x41,0x5c,0x37,0x42,0x5f,0x37,0x44,0x62,0x38,0x45,0x65,0x38,0x47,0x68,0x39,0x48,0x6b,0x39,0x49,0x6e,0x39,0x4b,0x71,0x3a,0x4c,0x74,0x3a,0x4e,0x77,0x3a,0x4f,0x7a,0x3b,0x51,0x7d,0x3b,0x52,0x80,0x3b,0x54,0x83,0x3c,0x55,0x86,0x3c,0x56,0x89,0x3c,0x58,0x8c,0x3c,0x59,0x8f,0x3c,0x5b,0x93,0x3c,0x5c,0x96,0x3c,0x5e,0x99,0x3c,0x5f,0x9c,0x3c,0x61,0x9f,0x3c,0x62,0xa3,0x3c,0x64,0xa6,0x3c,0x65,0xa9,0x3c,0x67,0xac,0x3c,0x68,0xaf,0x3c,0x6a,0xb3,0x3c,0x6b,0xb6,0x3b,0x6d,0xb9,0x3b,0x6f,0xbc,0x3b,0x70,0xc0,0x3a,0x72,0xc3,0x3a,0x73,0xc6,0x39,0x75,0xca,0x39,0x76,0xcd,0x38,0x78,0xd0,0x38,0x79,0xd3,0x38,0x7b,0xd7,0x37,0x7c,0xda,0x37,0x7e,0xdd,0x37,0x7f,0xdf,0x38,0x81,0xe2,0x39,0x82,0xe4,0x3a,0x84,0xe6,0x3c,0x85,0xe8};
	static constexpr std::array<uint8_t, 768> CBC2 = {0xee,0xed,0xec,0xee,0xed,0xea,0xee,0xec,0xe8,0xee,0xeb,0xe5,0xee,0xea,0xe2,0xed,0xe9,0xdf,0xed,0xe8,0xdc,0xec,0xe6,0xd9,0xeb,0xe5,0xd5,0xea,0xe3,0xd2,0xe9,0xe1,0xce,0xe8,0xdf,0xca,0xe7,0xde,0xc7,0xe6,0xdc,0xc3,0xe5,0xda,0xbf,0xe4,0xd8,0xbc,0xe2,0xd6,0xb8,0xe1,0xd5,0xb4,0xe0,0xd3,0xb1,0xdf,0xd1,0xad,0xde,0xcf,0xa9,0xdc,0xce,0xa6,0xdb,0xcc,0xa2,0xda,0xca,0x9e,0xd9,0xc8,0x9b,0xd7,0xc7,0x97,0xd6,0xc5,0x94,0xd5,0xc3,0x90,0xd4,0xc1,0x8c,0xd2,0xc0,0x89,0xd1,0xbe,0x85,0xd0,0xbc,0x82,0xce,0xba,0x7e,0xcd,0xb9,0x7b,0xcb,0xb7,0x77,0xca,0xb5,0x73,0xc9,0xb4,0x70,0xc7,0xb2,0x6c,0xc6,0xb0,0x69,0xc4,0xae,0x65,0xc3,0xad,0x61,0xc1,0xab,0x5e,0xc0,0xa9,0x5a,0xbe,0xa8,0x56,0xbd,0xa6,0x53,0xbb,0xa4,0x4f,0xba,0xa3,0x4b,0xb8,0xa1,0x48,0xb7,0x9f,0x44,0xb5,0x9e,0x40,0xb4,0x9c,0x3c,0xb2,0x9a,0x38,0xb0,0x99,0x34,0xaf,0x97,0x30,0xad,0x96,0x2c,0xac,0x94,0x27,0xaa,0x93,0x23,0xa9,0x91,0x1e,0xa7,0x90,0x19,0xa6,0x8e,0x14,0xa5,0x8d,0x0f,0xa4,0x8d,0x0a,0xa3,0x8c,0x06,0xa3,0x8b,0x03,0xa3,0x8b,0x02,0xa3,0x8b,0x02,0xa3,0x8b,0x04,0xa4,0x8c,0x07,0xa4,0x8d,0x0c,0xa5,0x8e,0x11,0xa6,0x8f,0x16,0xa8,0x90,0x1b,0xa9,0x91,0x1f,0xab,0x93,0x24,0xac,0x94,0x28,0xae,0x96,0x2d,0xaf,0x98,0x31,0xb1,0x99,0x35,0xb2,0x9b,0x39,0xb4,0x9c,0x3d,0xb6,0x9e,0x41,0xb7,0xa0,0x45,0xb9,0xa1,0x49,0xba,0xa3,0x4c,0xbc,0xa5,0x50,0xbd,0xa6,0x54,0xbf,0xa8,0x57,0xc0,0xaa,0x5b,0xc2,0xab,0x5f,0xc3,0xad,0x62,0xc5,0xaf,0x66,0xc6,0xb1,0x6a,0xc8,0xb2,0x6d,0xc9,0xb4,0x71,0xca,0xb6,0x74,0xcc,0xb7,0x78,0xcd,0xb9,0x7c,0xcf,0xbb,0x7f,0xd0,0xbd,0x83,0xd1,0xbe,0x86,0xd3,0xc0,0x8a,0xd4,0xc2,0x8d,0xd5,0xc3,0x91,0xd6,0xc5,0x95,0xd8,0xc7,0x98,0xd9,0xc9,0x9c,0xda,0xcb,0x9f,0xdc,0xcc,0xa3,0xdd,0xce,0xa7,0xde,0xd0,0xaa,0xdf,0xd2,0xae,0xe0,0xd3,0xb2,0xe2,0xd5,0xb5,0xe3,0xd7,0xb9,0xe4,0xd9,0xbd,0xe5,0xda,0xc0,0xe6,0xdc,0xc4,0xe7,0xde,0xc8,0xe8,0xe0,0xcb,0xe9,0xe1,0xcf,0xea,0xe3,0xd3,0xeb,0xe5,0xd6,0xec,0xe6,0xda,0xec,0xe7,0xdd,0xec,0xe8,0xe0,0xec,0xe9,0xe3,0xec,0xea,0xe6,0xec,0xea,0xe9,0xeb,0xea,0xeb,0xea,0xea,0xed,0xe9,0xea,0xef,0xe7,0xe9,0xf0,0xe6,0xe8,0xf2,0xe4,0xe7,0xf3,0xe2,0xe5,0xf3,0xe0,0xe4,0xf4,0xdd,0xe2,0xf4,0xdb,0xe1,0xf5,0xd9,0xdf,0xf5,0xd6,0xdd,0xf5,0xd4,0xdb,0xf5,0xd2,0xda,0xf5,0xcf,0xd8,0xf6,0xcd,0xd6,0xf6,0xca,0xd4,0xf6,0xc8,0xd3,0xf6,0xc5,0xd1,0xf6,0xc3,0xcf,0xf6,0xc0,0xcd,0xf6,0xbe,0xcc,0xf6,0xbb,0xca,0xf6,0xb8,0xc8,0xf7,0xb6,0xc6,0xf7,0xb3,0xc5,0xf7,0xb1,0xc3,0xf7,0xae,0xc1,0xf7,0xab,0xbf,0xf7,0xa8,0xbe,0xf7,0xa6,0xbc,0xf7,0xa3,0xba,0xf7,0xa0,0xb9,0xf7,0x9d,0xb7,0xf7,0x9a,0xb5,0xf7,0x97,0xb3,0xf7,0x94,0xb2,0xf8,0x91,0xb0,0xf8,0x8e,0xae,0xf8,0x8b,0xad,0xf8,0x88,0xab,0xf8,0x85,0xa9,0xf8,0x82,0xa8,0xf8,0x7e,0xa6,0xf8,0x7b,0xa4,0xf8,0x78,0xa3,0xf8,0x74,0xa1,0xf8,0x70,0x9f,0xf8,0x6d,0x9e,0xf8,0x69,0x9c,0xf8,0x65,0x9b,0xf8,0x61,0x99,0xf8,0x5d,0x97,0xf8,0x58,0x96,0xf8,0x54,0x94,0xf8,0x4f,0x93,0xf8,0x4b,0x92,0xf8,0x46,0x90,0xf8,0x42,0x8f,0xf8,0x3e,0x8e,0xf8,0x3b,0x8d,0xf8,0x38,0x8d,0xf8,0x37,0x8c,0xf8,0x36,0x8c,0xf8,0x37,0x8c,0xf8,0x39,0x8d,0xf8,0x3b,0x8d,0xf8,0x3f,0x8e,0xf8,0x43,0x8f,0xf8,0x47,0x91,0xf8,0x4c,0x92,0xf8,0x50,0x93,0xf8,0x55,0x95,0xf8,0x59,0x96,0xf8,0x5e,0x98,0xf8,0x62,0x99,0xf8,0x66,0x9b,0xf8,0x6a,0x9d,0xf8,0x6e,0x9e,0xf8,0x71,0xa0,0xf8,0x75,0xa1,0xf8,0x78,0xa3,0xf8,0x7c,0xa5,0xf8,0x7f,0xa6,0xf8,0x82,0xa8,0xf8,0x86,0xaa,0xf8,0x89,0xab,0xf8,0x8c,0xad,0xf8,0x8f,0xaf,0xf8,0x92,0xb0,0xf8,0x95,0xb2,0xf8,0x98,0xb4,0xf7,0x9b,0xb5,0xf7,0x9e,0xb7,0xf7,0xa1,0xb9,0xf7,0xa3,0xbb,0xf7,0xa6,0xbc,0xf7,0xa9,0xbe,0xf7,0xac,0xc0,0xf7,0xae,0xc1,0xf7,0xb1,0xc3,0xf7,0xb4,0xc5,0xf7,0xb6,0xc7,0xf7,0xb9,0xc8,0xf7,0xbc,0xca,0xf6,0xbe,0xcc,0xf6,0xc1,0xce,0xf6,0xc3,0xcf,0xf6,0xc6,0xd1,0xf6,0xc8,0xd3,0xf6,0xcb,0xd5,0xf6,0xcd,0xd7,0xf6,0xd0,0xd8,0xf6,0xd2,0xda,0xf5,0xd5,0xdc,0xf5,0xd7,0xde,0xf5,0xd9,0xdf,0xf5,0xdc,0xe1,0xf5,0xde,0xe3,0xf5,0xe0,0xe5,0xf4,0xe3,0xe6,0xf4,0xe5,0xe8,0xf4,0xe7,0xe9,0xf3,0xe8,0xea,0xf3,0xea,0xeb,0xf2,0xeb,0xec,0xf1,0xed,0xed,0xf0,0xed,0xed,0xee};
	static constexpr std::array<uint8_t, 768> CBD1 = {0x3a,0x90,0xfe,0x3e,0x91,0xfe,0x41,0x92,0xfe,0x44,0x92,0xfe,0x46,0x93,0xfe,0x49,0x94,0xfe,0x4c,0x94,0xfe,0x4e,0x95,0xfe,0x50,0x96,0xfe,0x53,0x97,0xfd,0x55,0x97,0xfd,0x57,0x98,0xfd,0x59,0x99,0xfd,0x5b,0x99,0xfd,0x5e,0x9a,0xfd,0x60,0x9b,0xfd,0x61,0x9b,0xfd,0x63,0x9c,0xfd,0x65,0x9d,0xfd,0x67,0x9e,0xfd,0x69,0x9e,0xfd,0x6b,0x9f,0xfd,0x6d,0xa0,0xfc,0x6e,0xa0,0xfc,0x70,0xa1,0xfc,0x72,0xa2,0xfc,0x73,0xa3,0xfc,0x75,0xa3,0xfc,0x77,0xa4,0xfc,0x78,0xa5,0xfc,0x7a,0xa5,0xfc,0x7c,0xa6,0xfc,0x7d,0xa7,0xfc,0x7f,0xa8,0xfb,0x80,0xa8,0xfb,0x82,0xa9,0xfb,0x83,0xaa,0xfb,0x85,0xab,0xfb,0x86,0xab,0xfb,0x88,0xac,0xfb,0x89,0xad,0xfb,0x8b,0xad,0xfb,0x8c,0xae,0xfb,0x8d,0xaf,0xfb,0x8f,0xb0,0xfa,0x90,0xb0,0xfa,0x92,0xb1,0xfa,0x93,0xb2,0xfa,0x94,0xb3,0xfa,0x96,0xb3,0xfa,0x97,0xb4,0xfa,0x98,0xb5,0xfa,0x9a,0xb6,0xfa,0x9b,0xb6,0xfa,0x9c,0xb7,0xfa,0x9e,0xb8,0xf9,0x9f,0xb9,0xf9,0xa0,0xb9,0xf9,0xa1,0xba,0xf9,0xa3,0xbb,0xf9,0xa4,0xbb,0xf9,0xa5,0xbc,0xf9,0xa6,0xbd,0xf9,0xa8,0xbe,0xf9,0xa9,0xbe,0xf9,0xaa,0xbf,0xf8,0xab,0xc0,0xf8,0xad,0xc1,0xf8,0xae,0xc2,0xf8,0xaf,0xc2,0xf8,0xb0,0xc3,0xf8,0xb1,0xc4,0xf8,0xb3,0xc5,0xf8,0xb4,0xc5,0xf8,0xb5,0xc6,0xf7,0xb6,0xc7,0xf7,0xb7,0xc8,0xf7,0xb9,0xc8,0xf7,0xba,0xc9,0xf7,0xbb,0xca,0xf7,0xbc,0xcb,0xf7,0xbd,0xcb,0xf7,0xbe,0xcc,0xf7,0xc0,0xcd,0xf6,0xc1,0xce,0xf6,0xc2,0xce,0xf6,0xc3,0xcf,0xf6,0xc4,0xd0,0xf6,0xc5,0xd1,0xf6,0xc6,0xd2,0xf6,0xc7,0xd2,0xf6,0xc9,0xd3,0xf6,0xca,0xd4,0xf5,0xcb,0xd5,0xf5,0xcc,0xd5,0xf5,0xcd,0xd6,0xf5,0xce,0xd7,0xf5,0xcf,0xd8,0xf5,0xd0,0xd9,0xf5,0xd1,0xd9,0xf5,0xd3,0xda,0xf4,0xd4,0xdb,0xf4,0xd5,0xdc,0xf4,0xd6,0xdc,0xf4,0xd7,0xdd,0xf4,0xd8,0xde,0xf4,0xd9,0xdf,0xf4,0xda,0xe0,0xf4,0xdb,0xe0,0xf3,0xdc,0xe1,0xf3,0xdd,0xe2,0xf3,0xde,0xe3,0xf3,0xdf,0xe4,0xf3,0xe0,0xe4,0xf3,0xe2,0xe5,0xf3,0xe3,0xe6,0xf2,0xe4,0xe7,0xf2,0xe5,0xe7,0xf2,0xe6,0xe8,0xf2,0xe7,0xe9,0xf2,0xe8,0xea,0xf1,0xe9,0xea,0xf1,0xea,0xeb,0xf1,0xea,0xec,0xf0,0xeb,0xec,0xf0,0xec,0xec,0xef,0xec,0xed,0xee,0xed,0xed,0xed,0xed,0xed,0xec,0xee,0xed,0xeb,0xee,0xec,0xea,0xee,0xec,0xe8,0xee,0xec,0xe7,0xee,0xeb,0xe5,0xed,0xea,0xe4,0xed,0xea,0xe2,0xed,0xe9,0xe0,0xec,0xe8,0xdf,0xec,0xe7,0xdd,0xec,0xe7,0xdb,0xeb,0xe6,0xda,0xeb,0xe5,0xd8,0xea,0xe4,0xd6,0xea,0xe4,0xd5,0xe9,0xe3,0xd3,0xe9,0xe2,0xd1,0xe9,0xe1,0xd0,0xe8,0xe0,0xce,0xe8,0xe0,0xcc,0xe7,0xdf,0xca,0xe7,0xde,0xc9,0xe6,0xdd,0xc7,0xe6,0xdc,0xc5,0xe5,0xdc,0xc4,0xe5,0xdb,0xc2,0xe4,0xda,0xc0,0xe4,0xd9,0xbf,0xe3,0xd8,0xbd,0xe3,0xd8,0xbb,0xe2,0xd7,0xba,0xe2,0xd6,0xb8,0xe2,0xd5,0xb6,0xe1,0xd5,0xb5,0xe1,0xd4,0xb3,0xe0,0xd3,0xb1,0xe0,0xd2,0xb0,0xdf,0xd1,0xae,0xdf,0xd1,0xac,0xde,0xd0,0xab,0xde,0xcf,0xa9,0xdd,0xce,0xa7,0xdc,0xce,0xa6,0xdc,0xcd,0xa4,0xdb,0xcc,0xa2,0xdb,0xcb,0xa1,0xda,0xcb,0x9f,0xda,0xca,0x9d,0xd9,0xc9,0x9c,0xd9,0xc8,0x9a,0xd8,0xc7,0x98,0xd8,0xc7,0x97,0xd7,0xc6,0x95,0xd7,0xc5,0x94,0xd6,0xc4,0x92,0xd6,0xc4,0x90,0xd5,0xc3,0x8f,0xd4,0xc2,0x8d,0xd4,0xc1,0x8b,0xd3,0xc1,0x8a,0xd3,0xc0,0x88,0xd2,0xbf,0x86,0xd2,0xbe,0x85,0xd1,0xbe,0x83,0xd0,0xbd,0x81,0xd0,0xbc,0x80,0xcf,0xbb,0x7e,0xcf,0xbb,0x7d,0xce,0xba,0x7b,0xce,0xb9,0x79,0xcd,0xb8,0x78,0xcc,0xb8,0x76,0xcc,0xb7,0x74,0xcb,0xb6,0x73,0xcb,0xb5,0x71,0xca,0xb5,0x6f,0xc9,0xb4,0x6e,0xc9,0xb3,0x6c,0xc8,0xb2,0x6a,0xc7,0xb2,0x69,0xc7,0xb1,0x67,0xc6,0xb0,0x66,0xc6,0xaf,0x64,0xc5,0xaf,0x62,0xc4,0xae,0x61,0xc4,0xad,0x5f,0xc3,0xac,0x5d,0xc2,0xac,0x5c,0xc2,0xab,0x5a,0xc1,0xaa,0x58,0xc1,0xa9,0x57,0xc0,0xa9,0x55,0xbf,0xa8,0x53,0xbf,0xa7,0x51,0xbe,0xa6,0x50,0xbd,0xa6,0x4e,0xbd,0xa5,0x4c,0xbc,0xa4,0x4b,0xbb,0xa4,0x49,0xbb,0xa3,0x47,0xba,0xa2,0x45,0xb9,0xa1,0x44,0xb9,0xa1,0x42,0xb8,0xa0,0x40,0xb7,0x9f,0x3e,0xb7,0x9f,0x3c,0xb6,0x9e,0x3b,0xb5,0x9d,0x39,0xb4,0x9c,0x37,0xb4,0x9c,0x35,0xb3,0x9b,0x33,0xb2,0x9a,0x31,0xb2,0x99,0x2f,0xb1,0x99,0x2d,0xb0,0x98,0x2b,0xb0,0x97,0x29,0xaf,0x97,0x27,0xae,0x96,0x24,0xad,0x95,0x22,0xad,0x95,0x20,0xac,0x94,0x1d,0xab,0x93,0x1a,0xab,0x92,0x17,0xaa,0x92,0x14,0xa9,0x91,0x11,0xa8,0x90,0x0d,0xa8,0x90,0x08};
}

#endif//_CET_LUT_HPP_
